(* ::Package:: *)

BeginPackage["TwoMassTadpoles`"];

Quiet[Check[ Needs["HPL`"] , Global`HPL::usage="Harmonic Polylogarithm" ] ] ; 


(*
if you don't want to use the HPL.m package, replace the line above by the following lines: 

BeginPackage["TwoMassTadpoles`"];
HPL::usage="Harmonic Polylogarithm";
*)


TwoMassTadpoles::usage =
        "TwoMassTadpoles[id, ep, x [,options]]

- <id> identifier of the integral
- <ep> in d dimensions ep=(4-d)/2
- <x>  mass ration m2/m1
- the options modify the output in various ways, refer to manual

example: TwoMassTadpoles[\"m-3l-3\", ep, x]";


OneMassTadpoles::usage =
        "OneMassTadpoles[id, ep [, options]]

- <id> identifier of the integral
- <ep> in d dimensions ep=(4-d)/2
- the options modify the output in various ways, refer to manual

example: OneMassTadpoles[\"s-3l-1\", ep]";

(* "solutionType"::usage =
 "For the not exactly known integrals choose from:

- \"numeric\" (default) : Interpolation for 0 <= x <= 1, based on expansions around x=0, x=1 and discrete numeric evaluations. 

- \"expansion0\": expansion around x=0, numeric coefficients
    - \"expansion0-symbolic\": expansion around x=0, coefficients with symbols (e.g. D3, B4,...)
    - \"expansion0-exact\": expansion around x=0, exact coefficients (e.g. Im[PolyLog[2, Exp[I Pi/3]]],...)

- \"expansion1\": expansion around x=1, exact coefficients
- \"interpolation\" for 0.1 <= x <= 1; works only with the integrals with 4 lines";
*)

D3::usage =
    "MATAD symbol, refer to manual";
S2::usage =
    "MATAD symbol, refer to manual";
B4::usage =
    "MATAD symbol, refer to manual";
OepS2::usage =
    "MATAD symbol, refer to manual";
T1ep::usage =
    "MATAD symbol, refer to manual";


Options[TwoMassTadpoles]={
			      "solutionType" -> "numeric",
			      epOrder -> no,
			      switchPropagatorSign -> False,
			      loopConstant -> I*Pi^(2-Global`ep)*Gamma[1+Global`ep],
			      massM1 -> 1,
			      warn -> True
			      };


Options[OneMassTadpoles]={
		          warn -> True,
			  epOrder -> no,
			  switchPropagatorSign -> False,
			  loopConstant -> I*Pi^(2-Global`ep)*Gamma[1+Global`ep],
			  massM1 -> 1
			  };

Global`ep::usage=
"ep = 1/2(4-d) in d dimensions, refer to manual.";

Begin["`Private`"]

If[Length[$HPLFunctions] == 0 , HPL = Global`HPL ] ;

(* ep = Global`ep ; *)

Options[TwoMassTadpolesBare]=Options[TwoMassTadpoles];

	knownIntegrals={"m-2l-1","m-3l-1","m-3l-2","m-3l-3","m-3l-4","m-3l-4b","m-3l-7a","m-3l-7b","i-3l-2","i-3l-5b","i-3l-1","i-3l-5a","i-3l-0","i-3l-6a","i-3l-6b","m-3l-5a","m-3l-5b","m-3l-6a","m-3l-6b","m-2l-2","m-3l-8a","m-3l-9a","m-3l-10a","m-3l-8b","m-3l-9b","m-3l-10b"};
	knownEpOrders={"m-2l-1"->3,"m-3l-1"->1,"m-3l-2"->1,"m-3l-3"->2,"m-3l-4"->2,"m-3l-4b"->2,"m-3l-7a"->1,"m-3l-7b"->2,"i-3l-2"->0,"i-3l-5b"->1,"i-3l-1"->0,"i-3l-5a"->2,"i-3l-0"->0,"i-3l-6a"->1,"i-3l-6b"->1,"m-3l-5a"->3,"m-3l-5b"->3,"m-3l-6a"->2,"m-3l-6b"->2,"m-2l-2"->3,"m-3l-8a"->0,"m-3l-9a"->0,"m-3l-10a"->0,"m-3l-8b"->0,"m-3l-9b"->0,"m-3l-10b"->0};

	exactKnown={"m-2l-1","m-3l-1","m-3l-2","m-3l-3","m-3l-4","m-3l-4b","m-3l-7a","m-3l-7b","i-3l-2","i-3l-5b","i-3l-1","i-3l-5a","i-3l-0","i-3l-6a","i-3l-6b","m-3l-5a","m-3l-5b","m-3l-6a","m-3l-6b","m-2l-2"};

	interpolationKnown={"m-3l-8a","m-3l-9a","m-3l-8b","m-3l-9b"};

	expansionKnown={"m-3l-8a","m-3l-9a","m-3l-10a","m-3l-8b","m-3l-9b","m-3l-10b"};

	numberOfProps={"m-3l-10b"->6,"m-3l-10a"->6,"m-2l-1"->3,"m-3l-1"->4,"m-3l-2"->3,"m-3l-3"->4,"m-3l-4"->3,"m-3l-4b"->3,"m-3l-7a"->5,"m-3l-7b"->5,"i-3l-2"->6,"i-3l-5b"->6,"i-3l-1"->6,"i-3l-5a"->6,"i-3l-0"->6,"i-3l-6a"->6,"i-3l-6b"->6,"m-3l-5a"->3,"m-3l-5b"->3,"m-3l-6a"->4,"m-3l-6b"->4,"m-2l-2"->2,"m-3l-8a"->4,"m-3l-9a"->5,"m-3l-10a"->6,"m-3l-8b"->4,"m-3l-9b"->5,"m-3l-10b"->6};
	numberOfLoops={"m-3l-10b"->3,"m-3l-10a"->3,"m-2l-1"->2,"m-3l-1"->3,"m-3l-2"->3,"m-3l-3"->3,"m-3l-4"->3,"m-3l-4b"->3,"m-3l-7a"->3,"m-3l-7b"->3,"i-3l-2"->3,"i-3l-5b"->3,"i-3l-1"->3,"i-3l-5a"->3,"i-3l-0"->3,"i-3l-6a"->3,"i-3l-6b"->3,"m-3l-5a"->3,"m-3l-5b"->3,"m-3l-6a"->3,"m-3l-6b"->3,"m-2l-2"->2,"m-3l-8a"->3,"m-3l-9a"->3,"m-3l-10a"->3,"m-3l-8b"->3,"m-3l-9b"->3,"m-3l-10b"->3};



TwoMassTadpoles[id_String,epd_Symbol,xd_, opts:OptionsPattern[]]  := Module[
    {result,i,relLoopFactor, myLoopConstant,maxEpOrder,massFactor},
 
    If[FreeQ[knownIntegrals,id],
       If[OptionValue[warn],Print["I'm sorry, I'm afraid I can't do that. I don't know the integral ", id,"."]];
       Return[Indeterminate]
   ];

    If[OptionValue["solutionType"]=="interpolation" && FreeQ[interpolationKnown,id],
       If[OptionValue[warn],Print["I'm sorry, I'm afraid I can't do that. Interpolation is not available for the integral ", id,"."]];
       Return[Indeterminate]
   ];

    If[(OptionValue["solutionType"]=="expansion0" || OptionValue["solutionType"]=="expansion0-symbolic" || OptionValue["solutionType"]=="expansion0-exact" || OptionValue["solutionType"]=="expansion1" ) && FreeQ[expansionKnown,id],
       If[OptionValue[warn],Print["I'm sorry, I'm afraid I can't do that. Expansion is not available for the integral ", id,"."]];
       Return[Indeterminate]
   ];

    If[(OptionValue[epOrder]===no || OptionValue[epOrder]==0) && MemberQ[expansionKnown,id] && OptionValue["solutionType"] == "numeric",
       If[OptionValue[warn],Print["Please note that the finite part of the integral ", id," is not known exactly."]];
   ];


    massFactor = OptionValue[massM1]^((id/.numberOfLoops)*(4-2*ep)-2*(id/.numberOfProps));

    myloopConstant = I*Pi^(2-ep)*Gamma[1+ep];
    
    relLoopFactor = (myloopConstant/OptionValue[loopConstant]/.epd->ep)^(id/.numberOfLoops);
    
    maxEpOrder = id/.knownEpOrders;

    result = Series[massFactor*relLoopFactor*TwoMassTadpolesBare[id, opts],{ep,0,maxEpOrder}];

    (* epOrder *)

    If[!(OptionValue[epOrder] === no),
       If[IntegerQ[OptionValue[epOrder]],
	  If[OptionValue[epOrder] > id/.knownEpOrders,
	     If[OptionValue[warn],Print["I'm sorry, I'm afraid I can't do that. The integral ", id," is known up to order ep^",id/.knownEpOrders,"."]];
	     result= unknown["integral: "<>id,"epOrder: "<>ToString[OptionValue[epOrder]],x];
(* else *),
	     result = SeriesCoefficient[result,{ep,0,OptionValue[epOrder]}];
	 ];
(* else *),
	  If[OptionValue[warn],Print["I'm sorry, I'm afraid I can't do that. epOrder must be integer."]];
	  Return[Indeterminate];
      ];
   ];
    

    result=result/.x->xd/.ep->epd;

    (* check sign convention *)
    If[(OptionValue[switchPropagatorSign]) && OddQ[id/.numberOfProps],
       result=-result;
   ];


	Return[result];

];


(* for internal use only *)
TwoMassTadpolesBare[id_String, opts:OptionsPattern[]]  := Module[{result,i},

  maxEpOrder = id/.knownEpOrders;

 Which[
     OptionValue["solutionType"]=="numeric",
     result = Sum[(masterData[id,i])*ep^i,{i,-3,maxEpOrder}]+O[ep]^(maxEpOrder+1);
     ,
     OptionValue["solutionType"]=="interpolation",
     result = Sum[(If[i==0, masterData[id,i,"ipol"],masterData[id,i]])*ep^i,{i,-3,maxEpOrder}]+O[ep]^(maxEpOrder+1);
     ,
     OptionValue["solutionType"]=="expansion0",
     result = Sum[(If[i==0, masterData[id,i,"exp0"],masterData[id,i]])*ep^i,{i,-3,maxEpOrder}]+O[ep]^(maxEpOrder+1);
     ,
     OptionValue["solutionType"]=="expansion0-symbolic",
     result = Sum[(If[i==0, masterData[id,i,"exp0-sym"],masterData[id,i]])*ep^i,{i,-3,maxEpOrder}]+O[ep]^(maxEpOrder+1);
     ,
     OptionValue["solutionType"]=="expansion0-exact",
     result = Sum[(If[i==0, masterData[id,i,"exp0-ex"],masterData[id,i]])*ep^i,{i,-3,maxEpOrder}]+O[ep]^(maxEpOrder+1);
     ,
     OptionValue["solutionType"]=="expansion1",
     result = Sum[(If[i==0, masterData[id,i,"exp1"],masterData[id,i]])*ep^i,{i,-3,maxEpOrder}]+O[ep]^(maxEpOrder+1);
 ];

Return[result];

];



(***********************************************************)
(* single scale integrals *)
(***********************************************************)

	knownIntegralsS={"s-1l-0","s-2l-1","s-2l-2","s-3l-0","s-3l-1","s-3l-2","s-3l-3","s-3l-4","s-3l-5","s-2l-0","s-3l-6","s-3l-7"};
	numberOfPropsS={"s-1l-0"->1,"s-2l-1"->3,"s-2l-2"->3,"s-3l-0"->3,"s-3l-1"->4,"s-3l-2"->5,"s-3l-3"->4,"s-3l-4"->4,"s-3l-5"->4,"s-2l-0"->2,"s-3l-6"->6,"s-3l-7"->7};
	numberOfLoopsS={"s-1l-0"->1,"s-2l-1"->2,"s-2l-2"->2,"s-3l-0"->3,"s-3l-1"->3,"s-3l-2"->3,"s-3l-3"->3,"s-3l-4"->3,"s-3l-5"->3,"s-2l-0"->2,"s-3l-6"->3,"s-3l-7"->3};

knownEpOrdersS={"s-1l-0"->Infinity,"s-2l-1"->Infinity,"s-2l-2"->Infinity,"s-3l-0"->Infinity,"s-3l-1"->Infinity,"s-3l-2"->Infinity,"s-3l-3"->2,"s-3l-4"->0,"s-3l-5"->Infinity,"s-2l-0"->Infinity,"s-3l-6"->0,"s-3l-7"->Infinity};


OneMassTadpoles[id_String,epd_Symbol, opts:OptionsPattern[]]  := Module[
{result,i,relLoopFactor, myLoopConstant,maxEpOrder,massFactor},
									   
If[FreeQ[knownIntegralsS,id],
   If[OptionValue[warn],Print["I'm sorry, I'm afraid I can't do that. I don't know the integral ", id,"."]];
   Return[Indeterminate]
];

massFactor = OptionValue[massM1]^((id/.numberOfLoopsS)*(4-2*ep)-2*(id/.numberOfPropsS));

myloopConstant = I*Pi^(2-ep)*Gamma[1+ep];

relLoopFactor = (myloopConstant/OptionValue[loopConstant]/.epd->ep)^(id/.numberOfLoopsS);

maxEpOrder = id/.knownEpOrdersS;

If[maxEpOrder < Infinity,
   result = Series[massFactor*relLoopFactor*singScal[id],{ep,0,maxEpOrder}];
(* else *),
   result = massFactor*relLoopFactor*singScal[id];
];

(* epOrder *)

If[!(OptionValue[epOrder] === no),
   If[IntegerQ[OptionValue[epOrder]],
      If[OptionValue[epOrder] > id/.knownEpOrdersS,
	 If[OptionValue[warn],Print["Unknown epOrder, ",id," known up to order ep^", id/.knownEpOrdersS]];

	 result = unknown["integral: "<>id,"epOrder: "<>ToString[OptionValue[epOrder]]];
(* else *),
	 result = SeriesCoefficient[result,{ep,0,OptionValue[epOrder]}];
     ];
(* else *),
       If[OptionValue[warn],Print["I'm sorry, I'm afraid I can't do that. epOrder must be integer."]];
      Return[Indeterminate];
  ];
];

result=result/.ep->epd;

(* check sign convention *)
If[(OptionValue[switchPropagatorSign]) && OddQ[id/.numberOfPropsS],
   result=-result;
];

	Return[result];

];


(* data section *)


f8aAsy = 135/16 + (81*S2)/4 + (595*x^2)/48 + (2*OepS2*x^2)/3 - 
     (101*Pi^2*x^2)/48 - (19*Pi^4*x^2)/720 - (243*S2*x^2)/4 - T1ep*x^2 + 
     (247*x^4)/432 - (4*OepS2*x^4)/27 + (101*Pi^2*x^4)/216 + 
     (19*Pi^4*x^4)/3240 + (63*S2*x^4)/4 + (2*T1ep*x^4)/9 - (217*x^6)/1944 - 
     (4*OepS2*x^6)/243 + (101*Pi^2*x^6)/1944 + (19*Pi^4*x^6)/29160 + 
     (7*S2*x^6)/6 + (2*T1ep*x^6)/81 - (25*x^8)/2592 - (4*OepS2*x^8)/729 + 
     (101*Pi^2*x^8)/5832 + (19*Pi^4*x^8)/87480 + (29*S2*x^8)/81 + 
     (2*T1ep*x^8)/243 - (1901*x^10)/1749600 - (16*OepS2*x^10)/6561 + 
     (101*Pi^2*x^10)/13122 + (19*Pi^4*x^10)/196830 + (217*S2*x^10)/1458 + 
     (8*T1ep*x^10)/2187 + (29123*x^12)/78732000 - (76*OepS2*x^12)/59049 + 
     (1919*Pi^2*x^12)/472392 + (361*Pi^4*x^12)/7085880 + 
     (2461*S2*x^12)/32805 + (38*T1ep*x^12)/19683 + (380479*x^14)/642978000 - 
     (404*OepS2*x^14)/531441 + (10201*Pi^2*x^14)/4251528 + 
     (1919*Pi^4*x^14)/63772920 + (25321*S2*x^14)/590490 + 
     (202*T1ep*x^14)/177147 + (534952937*x^16)/972182736000 - 
     (2324*OepS2*x^16)/4782969 + (58681*Pi^2*x^16)/38263752 + 
     (11039*Pi^4*x^16)/573956280 + (995047*S2*x^16)/37200870 + 
     (1162*T1ep*x^16)/1594323 + (217774353269*x^18)/472480809696000 - 
     (4724*OepS2*x^18)/14348907 + (119281*Pi^2*x^18)/114791256 + 
     (22439*Pi^4*x^18)/1721868840 + (11909357*S2*x^18)/669615660 + 
     (2362*T1ep*x^18)/4782969 + (1197424873417*x^20)/3189245465448000 - 
     (90388*OepS2*x^20)/387420489 + (2282297*Pi^2*x^20)/3099363912 + 
     (429343*Pi^4*x^20)/46490458680 + (56120416*S2*x^20)/4519905705 + 
     (45194*T1ep*x^20)/129140163 + (2115235307847509*x^22)/
      6946176623745744000 - (597364*OepS2*x^22)/3486784401 + 
     (15083441*Pi^2*x^22)/27894275208 + (2837479*Pi^4*x^22)/418414128120 + 
     (366393082*S2*x^22)/40679151345 + (298682*T1ep*x^22)/1162261467 + 
     (170579674840445971*x^24)/687671485750828656000 - 
     (4063660*OepS2*x^24)/31381059609 + (102607415*Pi^2*x^24)/251048476872 + 
     (3860477*Pi^4*x^24)/753145430616 + (54280688479*S2*x^24)/8054471966310 + 
     (2031830*T1ep*x^24)/10460353203 + (35493990374882535469*x^26)/
      174324721637835064296000 - (9437840*OepS2*x^26)/94143178827 + 
     (59576365*Pi^2*x^26)/188286357654 + (2241487*Pi^4*x^26)/564859072962 + 
     (124992953543*S2*x^26)/24163415898930 + (4718920*T1ep*x^26)/
      31381059609 + (6877265226178709052407*x^28)/
      40791984863253405045264000 - (67097420*OepS2*x^28)/847288609443 + 
     (1694209855*Pi^2*x^28)/6778308875544 + (63742549*Pi^4*x^28)/
      20334926626632 + (11467932582527*S2*x^28)/2827119660174810 + 
     (33548710*T1ep*x^28)/282429536481 + (51708212856876061124843*x^30)/
      367127863769280645407376000 - (485305220*OepS2*x^30)/7625597484987 + 
     (12253956805*Pi^2*x^30)/61004779879896 + (461039959*Pi^4*x^30)/
      183014339639688 + (5887327524367*S2*x^30)/1817434067255235 + 
     (242652610*T1ep*x^30)/2541865828329 + (1568533716479116595772847*x^32)/
      13216603095694103234665536000 - (3562717636*OepS2*x^32)/
      68630377364883 + (89958620309*Pi^2*x^32)/549043018919064 + 
     (16922908771*Pi^4*x^32)/8235645283785960 + (120348884502533*S2*x^32)/
      45799338494831922 + (1781358818*T1ep*x^32)/22876792454961 + 
     (13862838238723282365133961653*x^34)/137505538607601450053460236544000 - 
     (26496080368*OepS2*x^34)/617673396283947 + (167256507323*Pi^2*x^34)/
      1235346792567894 + (31464095437*Pi^4*x^34)/18530201888518410 + 
     (17813820869738137*S2*x^34)/8243880929069745960 + 
     (13248040184*T1ep*x^34)/205891132094649 + 
     (907749013481585531490976166393*x^36)/
      10519173703481510929089708095616000 - (199315180028*OepS2*x^36)/
      5559060566555523 + (5032708295707*Pi^2*x^36)/44472484532444184 + 
     (946747105133*Pi^4*x^36)/667087267986662760 + 
     (1134114318332014697*S2*x^36)/630656891073835565940 + 
     (99657590014*T1ep*x^36)/1853020188851841 + 
     (7626914405076554176716336349188857*x^38)/
      102530386087834287025837384807969152000 - (4543790140052*OepS2*x^38)/
      150094635296999121 + (114730701036313*Pi^2*x^38)/1200757082375992968 + 
     (21583003165247*Pi^4*x^38)/18011356235639894520 + 
     (25754685448542423473*S2*x^38)/17027736058993560280380 + 
     (2271895070026*T1ep*x^38)/50031545098999707 + 
     (1131598016566750188912713924413081157*x^40)/
      17532696021019663081418192802162724992000 - (34841932134428*OepS2*x^40)/
      1350851717672992089 + (879758786394307*Pi^2*x^40)/
      10806813741383936712 + (165499177638533*Pi^4*x^40)/
      162102206120759050680 + (3739250747265481159763*S2*x^40)/
      2911742866087898807944980 + (17420966067214*T1ep*x^40)/
      450283905890997363 - 33*x^2*Log[x] + 27*S2*x^2*Log[x] + 
     (5*x^4*Log[x])/4 - 6*S2*x^4*Log[x] + (11*x^6*Log[x])/54 - 
     (2*S2*x^6*Log[x])/3 + (19*x^8*Log[x])/324 - (2*S2*x^8*Log[x])/9 + 
     (751*x^10*Log[x])/29160 - (8*S2*x^10*Log[x])/81 + 
     (2227*x^12*Log[x])/164025 - (38*S2*x^12*Log[x])/729 + 
     (331433*x^14*Log[x])/41334300 - (202*S2*x^14*Log[x])/6561 + 
     (26691517*x^16*Log[x])/5208121800 - (1162*S2*x^16*Log[x])/59049 + 
     (217023343*x^18*Log[x])/62497461600 - (2362*S2*x^18*Log[x])/177147 + 
     (2076238693*x^20*Log[x])/843715731600 - (45194*S2*x^20*Log[x])/4782969 + 
     (6037514957*x^22*Log[x])/3341114297136 - (298682*S2*x^22*Log[x])/
      43046721 + (11294557752133*x^24*Log[x])/8269257885411600 - 
     (2031830*S2*x^24*Log[x])/387420489 + (170505280450009*x^26*Log[x])/
      161250528765526200 - (4718920*S2*x^26*Log[x])/1162261467 + 
     (31516965192555377*x^28*Log[x])/37732623731133130800 - 
     (33548710*S2*x^28*Log[x])/10460353203 + (227957315295754703*x^30*Log[x])/
      339593613580198177200 - (242652610*S2*x^30*Log[x])/94143178827 + 
     (836738936641975937*x^32*Log[x])/1528171261110891797400 - 
     (1781358818*S2*x^32*Log[x])/847288609443 + 
     (338523722094130970549*x^34*Log[x])/748192649439892624007040 - 
     (13248040184*S2*x^34*Log[x])/7625597484987 + 
     (21645457865633815632907*x^36*Log[x])/57236737682151785736538560 - 
     (99657590014*S2*x^36*Log[x])/68630377364883 + 
     (9375582643761824549548327*x^38*Log[x])/29362446430943866082844281280 - 
     (2271895070026*S2*x^38*Log[x])/1853020188851841 + 
     (1365953241323709207209253751*x^40*Log[x])/
      5020978339691401100166372098880 - (17420966067214*S2*x^40*Log[x])/
      16677181699666569 + 12*x^2*Log[x]^2 - (x^4*Log[x]^2)/2 - 
     2*x^2*Log[x]^3 - PolyGamma[2, 1]/2 - (x^2*PolyGamma[2, 1])/2 - Zeta[3] + 
     (5*x^2*Zeta[3])/2 - (7*x^4*Zeta[3])/9 - (7*x^6*Zeta[3])/81 - 
     (7*x^8*Zeta[3])/243 - (28*x^10*Zeta[3])/2187 - 
     (133*x^12*Zeta[3])/19683 - (707*x^14*Zeta[3])/177147 - 
     (4067*x^16*Zeta[3])/1594323 - (8267*x^18*Zeta[3])/4782969 - 
     (158179*x^20*Zeta[3])/129140163 - (1045387*x^22*Zeta[3])/1162261467 - 
     (7111405*x^24*Zeta[3])/10460353203 - (16516220*x^26*Zeta[3])/
      31381059609 - (117420485*x^28*Zeta[3])/282429536481 - 
     (849284135*x^30*Zeta[3])/2541865828329 - (6234755863*x^32*Zeta[3])/
      22876792454961 - (46368140644*x^34*Zeta[3])/205891132094649 - 
     (348801565049*x^36*Zeta[3])/1853020188851841 - 
     (7951632745091*x^38*Zeta[3])/50031545098999707 - 
     (60973381235249*x^40*Zeta[3])/450283905890997363
  
f8aGl = (18238544178211009600760021415451130 + 
      34537886185779096687597545229941276*x + 
      339128653949585443267118414795680516*x^2 - 
      1725534162206891477439558032020387968*x^3 + 
      6997887507240111621208215493455373278*x^4 - 
      25248755142792780989794456973353758468*x^5 + 
      78851635280364913230554458142664606696*x^6 - 
      212333658263880602700060498275673549216*x^7 + 
      494494032492106018627084015303042350282*x^8 - 
      1000421352850895879312150730097280633748*x^9 + 
      1765891012701407985722512484670675455292*x^10 - 
      2729497633722533580318322875634111464672*x^11 + 
      3704625746337617246929701527506440839646*x^12 - 
      4423453572803114235715434611754464905524*x^13 + 
      4651054974260134402812153756541552590768*x^14 - 
      4306571782516076643843393984015465105984*x^15 + 
      3508370697908025791770339197274664650782*x^16 - 
      2509768095029555248912678232401918081260*x^17 + 
      1571758504176904675697332615958695651644*x^18 - 
      857956931624857056597231410103567094848*x^19 + 
      405784889375317407414826021744701949194*x^20 - 
      164987069751010911795436922003446943052*x^21 + 
      57067849859955688676100433500490490856*x^22 - 
      16560392488696364051664077488967229984*x^23 + 
      3956035135834042640064685553850104094*x^24 - 
      757527613190636660188740176379230364*x^25 + 
      111784275692468054009923828283062020*x^26 - 
      11933232844884328409955882895824992*x^27 + 
      820197759866046619979884718529850*x^28 - 
      27253868223217993348907295717244*x^29 + 
      16069011624387232777139448633683625*Zeta[3] - 
      1525936742560991307398328929702250*x*Zeta[3] - 
      74694339695700667222996300466631750*x^2*Zeta[3] + 
      193245308252673581870707433780088000*x^3*Zeta[3] - 
      610438990092187700078849967874246125*x^4*Zeta[3] + 
      2061920269200261069235333238454663750*x^5*Zeta[3] - 
      6208142304277175908205762394565873500*x^6*Zeta[3] + 
      16340287890051947055888212780267046000*x^7*Zeta[3] - 
      37471558308094757623420952878466271375*x^8*Zeta[3] + 
      74972911903899165143927567588841630750*x^9*Zeta[3] - 
      131237096974269780654289843290835508250*x^10*Zeta[3] + 
      201532987708619111644017912198743538000*x^11*Zeta[3] - 
      272107525067105224870524279492525286125*x^12*Zeta[3] + 
      323519519821264645649148806753740164750*x^13*Zeta[3] - 
      338954539429620971255125864918353573000*x^14*Zeta[3] + 
      312903237442184875590862872808449756000*x^15*Zeta[3] - 
      254248846998627062277664044584473090125*x^16*Zeta[3] + 
      181472915306477532035199375637818905250*x^17*Zeta[3] - 
      113425408121621875423443068333574260250*x^18*Zeta[3] + 
      61806839476233373432228935027254844000*x^19*Zeta[3] - 
      29187505935753285320324567049395163375*x^20*Zeta[3] + 
      11850903984668272929620131492753427250*x^21*Zeta[3] - 
      4094052307300387750893021478316785500*x^22*Zeta[3] + 
      1186708704767164006364795354477982000*x^23*Zeta[3] - 
      283197621120044517313215914418418125*x^24*Zeta[3] + 
      54177934917676971119415400484030250*x^25*Zeta[3] - 
      7987906291749125595603963511047750*x^26*Zeta[3] + 
      852056370211648360802383029690000*x^27*Zeta[3] - 
      58521175472619218891033799672375*x^28*Zeta[3] + 
      1943256938714006352382776080250*x^29*Zeta[3])/
     2771264166556576226766093287424000
 
f8bAsy = -145/48 - Pi^2/12 + 19*x^2 + (261*x^4)/16 - (3*Pi^2*x^4)/4 - 
     (19*x^6)/12 - (4157*x^8)/288 + (23*Pi^2*x^8)/6 - (510593*x^10)/7200 + 
     (107*Pi^2*x^10)/6 - (13208647*x^12)/36000 + (2773*Pi^2*x^12)/30 - 
     (1789925017*x^14)/882000 + (7792*Pi^2*x^14)/15 - 
     (587799137747*x^16)/49392000 + (326044*Pi^2*x^16)/105 - 
     (21704098476521*x^18)/296352000 + (8179453*Pi^2*x^18)/420 - 
     (78162342759941*x^20)/166698000 + (79946653*Pi^2*x^20)/630 - 
     (100094456416309127*x^22)/32272732800 + (537359041*Pi^2*x^22)/630 - 
     (37420548129693625913*x^24)/1775000304000 + (20381619673*Pi^2*x^24)/
      3465 - (7331169339282300095977*x^26)/49995841896000 + 
     (95746326757*Pi^2*x^26)/2310 - (1352086880965649104123781*x^28)/
      1299891889296000 + (4466644791899*Pi^2*x^28)/15015 - 
     (9754853542804710815193749*x^30)/1299891889296000 + 
     (9305183813491*Pi^2*x^30)/4290 - (285694888161351679870613497*x^32)/
      5199567557184000 + (48151323490427*Pi^2*x^32)/3003 - 
     (2449653103340937452697520326757*x^34)/6010700096104704000 + 
     (14411109515028983*Pi^2*x^34)/120120 - 
     (52073721202169041420039533916639*x^36)/17030316938963328000 + 
     (926371630928894473*Pi^2*x^36)/1021020 - 
     (1282363236609341154656639777433229033*x^38)/55331499734691852672000 + 
     (21218233215515993557*Pi^2*x^38)/3063060 - 
     (186368234537462060268202882880942336653*x^40)/
      1051298494959145200768000 + (3104357052010564868467*Pi^2*x^40)/
      58198140 - (179663345038004708836854206784056924507*x^42)/
      131412311869893150096000 + (12044586464641500788387*Pi^2*x^42)/
      29099070 - (3722521885977393120183891787614700478317*x^44)/
      350432831653048400256000 + (20914978486910711456441*Pi^2*x^44)/
      6466460 - (15404233377400087797419522694204309966227263*x^46)/
      185378967944462603735424000 + (164471932797348558108061*Pi^2*x^46)/
      6466460 - (2788673295798765120808531021498036460006311697*x^48)/
      4263716262722639885914752000 + (29920836527972761629963059*Pi^2*x^48)/
      148728580 - (5809013497697504332348038526751394569100121439*x^50)/
      1122030595453326285767040000 + (3130592358796135332789346*Pi^2*x^50)/
      1956955 - (21955620464854315877806714787116717963803394174529*x^52)/
      532964532840329985739344000000 + (9506177226227674417816913633*Pi^2*
       x^52)/743642900 - (526627379653280177060742060517077289185468559905251*
       x^54)/1598893598520989957218032000000 + 
     (228923472361283326010349127867*Pi^2*x^54)/2230928700 - 
     (114191847453717964963852917603024029636039503420943627*x^56)/
      43170127160066728844886864000000 + (1277543748181258459476798998531*
       Pi^2*x^56)/1544489100 - 
     (96805877209929529818422223209798133979638084200747419537*x^58)/
      4538259617702014869818731578000000 + 
     (5169234885009309537375551848609*Pi^2*x^58)/772244550 - 
     (181810368616779394103728585805514324447739553744363522000461*x^60)/
      1052876231306867449797945726096000000 + 
     (347868520903837563149900798537059*Pi^2*x^60)/6398597700 - 
     (473157876388711833758273975327562492196749030744927013386510337*x^62)/
      337271352761966539751941947592752000000 + 
     (944989371079271635533770146534213*Pi^2*x^62)/2132865900 - 
     (239132323905184784828101274346843746554789246631145046502576741531*
       x^64)/20910823871241925464620400750750624000000 + 
     (239497788761052237926306231017475107*Pi^2*x^64)/66118842900 - 
     33*x^2*Log[x] - Pi^2*x^2*Log[x] - (201*x^4*Log[x])/4 + 
     2*Pi^2*x^4*Log[x] - (29*x^6*Log[x])/2 - (307*x^8*Log[x])/12 + 
     6*Pi^2*x^8*Log[x] - (7927*x^10*Log[x])/120 + 24*Pi^2*x^10*Log[x] - 
     (14107*x^12*Log[x])/75 + 114*Pi^2*x^12*Log[x] - 
     (1041373*x^14*Log[x])/2100 + 606*Pi^2*x^14*Log[x] - 
     (17922707*x^16*Log[x])/29400 + 3486*Pi^2*x^16*Log[x] + 
     (838236341*x^18*Log[x])/117600 + 21258*Pi^2*x^18*Log[x] + 
     (53722822613*x^20*Log[x])/529200 + 135582*Pi^2*x^20*Log[x] + 
     (5686300973581*x^22*Log[x])/5821200 + 896046*Pi^2*x^22*Log[x] + 
     (537310322458421*x^24*Log[x])/64033200 + 6095490*Pi^2*x^24*Log[x] + 
     (9547166738499463*x^26*Log[x])/138738600 + 42470280*Pi^2*x^26*Log[x] + 
     (1993186460288040089*x^28*Log[x])/3607203600 + 
     301938390*Pi^2*x^28*Log[x] + (15853308727933948751*x^30*Log[x])/
      3607203600 + 2183873490*Pi^2*x^30*Log[x] + 
     (1570478295333325787*x^32*Log[x])/45090045 + 16032229362*Pi^2*x^32*
      Log[x] + (135355504319065467983671*x^34*Log[x])/490579689600 + 
     119232361656*Pi^2*x^34*Log[x] + (3042100540242652994567947*x^36*Log[x])/
      1389975787200 + 896918310126*Pi^2*x^36*Log[x] + 
     (4136071041215086644816368261*x^38*Log[x])/237685859611200 + 
     6815685210078*Pi^2*x^38*Log[x] + (626636998963581538908534100181*x^40*
       Log[x])/4516031332612800 + 52262898201642*Pi^2*x^40*Log[x] + 
     (1253163436331144354942886033113*x^42*Log[x])/1129007833153200 + 
     404022890110872*Pi^2*x^42*Log[x] + (1915699837958802188969219457827*x^44*
       Log[x])/215049111076800 + 3146342571901278*Pi^2*x^44*Log[x] + 
     (2483512541184420765934395516686797*x^46*Log[x])/34622906883364800 + 
     24666061437979938*Pi^2*x^46*Log[x] + 
     (461446194025591007129266018110316643*x^48*Log[x])/796326858317390400 + 
     194550540203413314*Pi^2*x^48*Log[x] + 
     (196821244477772375130010119601363201*x^50*Log[x])/41911939911441600 + 
     1543054453426870326*Pi^2*x^50*Log[x] + 
     (759979949370287614852080335784355478071*x^52*Log[x])/
      19908171457934760000 + 12301289652059571330*Pi^2*x^52*Log[x] + 
     (6196124423801129843894482456815378606983*x^54*Log[x])/
      19908171457934760000 + 98529858464586026706*Pi^2*x^54*Log[x] + 
     (1367824977286935020440234840113821949808691*x^56*Log[x])/
      537520629364238520000 + 792646507494208348206*Pi^2*x^56*Log[x] + 
     (81300013312219381689239346971751371267239123*x^58*Log[x])/
      3897024562890729270000 + 6402491110326322375368*Pi^2*x^58*Log[x] + 
     (77516419404917917570480407169656603545470954697*x^60*Log[x])/
      452054849295324595320000 + 51910321501343280217722*Pi^2*x^60*Log[x] + 
     (6600112286734100237498100822980652096442501740119*x^62*Log[x])/
      4671233442718354151640000 + 422360874221108942008782*Pi^2*x^62*Log[x] + 
     (1689869920381138064064130725999150857842767892860371*x^64*Log[x])/
      144808236724268978700840000 + 3447780035243225151693438*Pi^2*x^64*
      Log[x] + 12*x^2*Log[x]^2 + (117*x^4*Log[x]^2)/2 + 12*x^6*Log[x]^2 + 
     46*x^8*Log[x]^2 + 214*x^10*Log[x]^2 + (5546*x^12*Log[x]^2)/5 + 
     (31168*x^14*Log[x]^2)/5 + (1304176*x^16*Log[x]^2)/35 + 
     (8179453*x^18*Log[x]^2)/35 + (159893306*x^20*Log[x]^2)/105 + 
     (1074718082*x^22*Log[x]^2)/105 + (81526478692*x^24*Log[x]^2)/1155 + 
     (191492653514*x^26*Log[x]^2)/385 + (17866579167596*x^28*Log[x]^2)/5005 + 
     (18610367626982*x^30*Log[x]^2)/715 + (192605293961708*x^32*Log[x]^2)/
      1001 + (14411109515028983*x^34*Log[x]^2)/10010 + 
     (926371630928894473*x^36*Log[x]^2)/85085 + 
     (21218233215515993557*x^38*Log[x]^2)/255255 + 
     (3104357052010564868467*x^40*Log[x]^2)/4849845 + 
     (24089172929283001576774*x^42*Log[x]^2)/4849845 + 
     (62744935460732134369323*x^44*Log[x]^2)/1616615 + 
     (493415798392045674324183*x^46*Log[x]^2)/1616615 + 
     (89762509583918284889889177*x^48*Log[x]^2)/37182145 + 
     (37567108305553623993472152*x^50*Log[x]^2)/1956955 + 
     (28518531678683023253450740899*x^52*Log[x]^2)/185910725 + 
     (228923472361283326010349127867*x^54*Log[x]^2)/185910725 + 
     (1277543748181258459476798998531*x^56*Log[x]^2)/128707425 + 
     (10338469770018619074751103697218*x^58*Log[x]^2)/128707425 + 
     (347868520903837563149900798537059*x^60*Log[x]^2)/533216475 + 
     (944989371079271635533770146534213*x^62*Log[x]^2)/177738825 + 
     (239497788761052237926306231017475107*x^64*Log[x]^2)/5509903575 - 
     2*x^2*Log[x]^3 - 28*x^4*Log[x]^3 + 8*x^6*Log[x]^3 + 24*x^8*Log[x]^3 + 
     96*x^10*Log[x]^3 + 456*x^12*Log[x]^3 + 2424*x^14*Log[x]^3 + 
     13944*x^16*Log[x]^3 + 85032*x^18*Log[x]^3 + 542328*x^20*Log[x]^3 + 
     3584184*x^22*Log[x]^3 + 24381960*x^24*Log[x]^3 + 
     169881120*x^26*Log[x]^3 + 1207753560*x^28*Log[x]^3 + 
     8735493960*x^30*Log[x]^3 + 64128917448*x^32*Log[x]^3 + 
     476929446624*x^34*Log[x]^3 + 3587673240504*x^36*Log[x]^3 + 
     27262740840312*x^38*Log[x]^3 + 209051592806568*x^40*Log[x]^3 + 
     1616091560443488*x^42*Log[x]^3 + 12585370287605112*x^44*Log[x]^3 + 
     98664245751919752*x^46*Log[x]^3 + 778202160813653256*x^48*Log[x]^3 + 
     6172217813707481304*x^50*Log[x]^3 + 49205158608238285320*x^52*Log[x]^3 + 
     394119433858344106824*x^54*Log[x]^3 + 3170586029976833392824*x^56*
      Log[x]^3 + 25609964441305289501472*x^58*Log[x]^3 + 
     207641286005373120870888*x^60*Log[x]^3 + 1689443496884435768035128*x^62*
      Log[x]^3 + 13791120140972900606773752*x^64*Log[x]^3 + 
     Pi^2*x^6*(1 + 2*Log[x]) - (x^2*PolyGamma[2, 1])/2 - 
     (x^4*PolyGamma[2, 1])/2 + x^2*Zeta[3] - 5*x^4*Zeta[3] - 4*x^6*Zeta[3] - 
     12*x^8*Zeta[3] - 48*x^10*Zeta[3] - 228*x^12*Zeta[3] - 
     1212*x^14*Zeta[3] - 6972*x^16*Zeta[3] - 42516*x^18*Zeta[3] - 
     271164*x^20*Zeta[3] - 1792092*x^22*Zeta[3] - 12190980*x^24*Zeta[3] - 
     84940560*x^26*Zeta[3] - 603876780*x^28*Zeta[3] - 
     4367746980*x^30*Zeta[3] - 32064458724*x^32*Zeta[3] - 
     238464723312*x^34*Zeta[3] - 1793836620252*x^36*Zeta[3] - 
     13631370420156*x^38*Zeta[3] - 104525796403284*x^40*Zeta[3] - 
     808045780221744*x^42*Zeta[3] - 6292685143802556*x^44*Zeta[3] - 
     49332122875959876*x^46*Zeta[3] - 389101080406826628*x^48*Zeta[3] - 
     3086108906853740652*x^50*Zeta[3] - 24602579304119142660*x^52*Zeta[3] - 
     197059716929172053412*x^54*Zeta[3] - 1585293014988416696412*x^56*
      Zeta[3] - 12804982220652644750736*x^58*Zeta[3] - 
     103820643002686560435444*x^60*Zeta[3] - 844721748442217884017564*x^62*
      Zeta[3] - 6895560070486450303386876*x^64*Zeta[3]
 
f8bGl = (11802787975301377458630086187167110 - 
      299551167388391018264656652687098904*x + 
      3663771746623834554373104476684584908*x^2 - 
      28954859639711547187428980738570751384*x^3 + 
      166887642803837815081662571341642012594*x^4 - 
      744335921759302964548331814355283082384*x^5 + 
      2666990533441239674890290829193518948344*x^6 - 
      7873369649228084343176827159963996399056*x^7 + 
      19494723336117860114818931379900354293142*x^8 - 
      41010242486184624487661587317315638924616*x^9 + 
      73993846869745794353168931654027792659508*x^10 - 
      115299327698196726555084203675750112416904*x^11 + 
      155925050389326605284287818798601986041170*x^12 - 
      183600684975834257980282494307760364884832*x^13 + 
      188576195847957777916446997462843087915920*x^14 - 
      169029039562166191219979671015213517204448*x^15 + 
      132112022355735767627694966775960180561314*x^16 - 
      89844776591799075118679760632777105113896*x^17 + 
      52971176362794740706854965495362641533812*x^18 - 
      26932404649023485470178551841493467157288*x^19 + 
      11721914075062977038041640286165974057958*x^20 - 
      4323799715379282979049063284179882427152*x^21 + 
      1333491294465352003464092564326051153656*x^22 - 
      337509879915205740867464267442358932816*x^23 + 
      68283429659925949174004354664534561090*x^24 - 
      10618876691363090149742401665424871544*x^25 + 
      1191848693418434023213846275138762252*x^26 - 
      85943581471161516884411689513083832*x^27 + 
      2990162038797393061234104487296278*x^28 - 
      10139886476434976601677051429339625*Zeta[3] + 
      250270693930911841046722736355982500*x*Zeta[3] - 
      3037077257204371730275746932825963250*x^2*Zeta[3] + 
      24045912611355078165350486786042614500*x^3*Zeta[3] - 
      138655941992730498921488846768599648875*x^4*Zeta[3] + 
      618540447970503241732444154677272855000*x^5*Zeta[3] - 
      2216600884294337834259580450866594064500*x^6*Zeta[3] + 
      6544496203710980040698548831771038723000*x^7*Zeta[3] - 
      16205736612167128310613718405160626106625*x^8*Zeta[3] + 
      34093461193307680879133923655859499291500*x^9*Zeta[3] - 
      61517019909845057772041832082633938132750*x^10*Zeta[3] + 
      95861252405338761670869210231354965671500*x^11*Zeta[3] - 
      129642011363441117128613004317447585350875*x^12*Zeta[3] + 
      152656534820406490177898485073050790922000*x^13*Zeta[3] - 
      156796890139638298384477033812093583911000*x^14*Zeta[3] + 
      140546485883172206122578986144696262018000*x^15*Zeta[3] - 
      109852009171384558349822656972162559137875*x^16*Zeta[3] + 
      74707569178608554991752006297421847165500*x^17*Zeta[3] - 
      44047044281703586818998477701142202336750*x^18*Zeta[3] + 
      22395309065854415725803169868766788989500*x^19*Zeta[3] - 
      9747308939159919383468547166972593077625*x^20*Zeta[3] + 
      3595469457843286185934076550010933167000*x^21*Zeta[3] - 
      1108877801847443349983100788705184928500*x^22*Zeta[3] + 
      280661697300704589097670957106803211000*x^23*Zeta[3] - 
      56782545750308827927785217704230311875*x^24*Zeta[3] + 
      8830407520717944202113643892141320500*x^25*Zeta[3] - 
      991118807898603959263351237556231250*x^26*Zeta[3] + 
      71469423280916988903239668196692500*x^27*Zeta[3] - 
      2486586802406902569320919430082625*x^28*Zeta[3])/
     95560833329537111267796320256000
 
f10aAsy = D3 - (317*x^2)/48 + (2*OepS2*x^2)/3 - (77*Pi^2*x^2)/48 - 
     (19*Pi^4*x^2)/720 - (297*S2*x^2)/4 - T1ep*x^2 - (2191*x^4)/864 + 
     (11*OepS2*x^4)/27 - (1003*Pi^2*x^4)/864 - (209*Pi^4*x^4)/12960 - 
     (153*S2*x^4)/4 - (11*T1ep*x^4)/18 - (5849*x^6)/3888 + 
     (74*OepS2*x^6)/243 - (3521*Pi^2*x^6)/3888 - (703*Pi^4*x^6)/58320 - 
     (319*S2*x^6)/12 - (37*T1ep*x^6)/81 - (50357*x^8)/46656 + 
     (359*OepS2*x^8)/1458 - (34801*Pi^2*x^8)/46656 - (6821*Pi^4*x^8)/699840 - 
     (53333*S2*x^8)/2592 - (359*T1ep*x^8)/972 - (37277*x^10)/43740 + 
     (6826*OepS2*x^10)/32805 - (1671077*Pi^2*x^10)/2624400 - 
     (64847*Pi^4*x^10)/7873200 - (1230109*S2*x^10)/72900 - 
     (3413*T1ep*x^10)/10935 - (559651*x^12)/787320 + 
     (10685*OepS2*x^12)/59049 - (1052941*Pi^2*x^12)/1889568 - 
     (40603*Pi^4*x^12)/5668704 - (1883051*S2*x^12)/131220 - 
     (10685*T1ep*x^12)/39366 - (507371339*x^14)/826686000 + 
     (597334*OepS2*x^14)/3720087 - (206906041*Pi^2*x^14)/416649744 - 
     (5674673*Pi^4*x^14)/892820880 - (724134637*S2*x^14)/57868020 - 
     (298667*T1ep*x^14)/1240029 - (421946864693*x^16)/777746188800 + 
     (2767225*OepS2*x^16)/19131876 - (68676689*Pi^2*x^16)/153055008 - 
     (10515455*Pi^4*x^16)/1836660096 - (26459463383*S2*x^16)/2380855680 - 
     (2767225*T1ep*x^16)/12754584 - (28807664408921*x^18)/59060101212000 + 
     (1891358*OepS2*x^18)/14348907 - (94096403*Pi^2*x^18)/229582512 - 
     (17967901*Pi^4*x^18)/3443737680 - (1675511344*S2*x^18)/167403915 - 
     (945679*T1ep*x^18)/4782969 - (28331394459118921*x^20)/
      63784909308960000 + (234854023*OepS2*x^20)/1937102445 - 
     (117051599659*Pi^2*x^20)/309936391200 - (4462226437*Pi^4*x^20)/
      929809173600 - (1647737861381*S2*x^20)/180796228200 - 
     (234854023*T1ep*x^20)/1291401630 - (36852125243204069*x^22)/
      90210086022672000 + (4309604566*OepS2*x^22)/38354628411 - 
     (2366091061205*Pi^2*x^22)/6750414600336 - (40941243377*Pi^4*x^22)/
      9205110818640 - (41213708221094*S2*x^22)/4922177312745 - 
     (2154802283*T1ep*x^22)/12784876137 - (13529426639051037133*x^24)/
      35723194064978112000 + (6576939619*OepS2*x^24)/62762119218 - 
     (657297332717*Pi^2*x^24)/2008387814976 - (124961852761*Pi^4*x^24)/
      30125817224640 - (998667912724463*S2*x^24)/128871551460960 - 
     (6576939619*T1ep*x^24)/41841412812 - (3159479981804366757307*x^26)/
      8939729314760772528000 + (40082391494*OepS2*x^26)/407953774917 - 
     (26063041538939*Pi^2*x^26)/84854385182736 - (380782719193*Pi^4*x^26)/
      97908905980080 - (893010345958571*S2*x^26)/123745978391490 - 
     (20041195747*T1ep*x^26)/135984591639 - (94688861896831740158615317*x^28)/
      285543894042773835316848000 + (548867054899*OepS2*x^28)/5931020266101 - 
     (384659853375821*Pi^2*x^28)/1328548539606624 - 
     (10428474043081*Pi^4*x^28)/2846889727728480 - 
     (534777070845860131*S2*x^28)/79159350484894680 - 
     (548867054899*T1ep*x^28)/3954013510734 - 
     (57380060647717267294398437*x^30)/183563931884640322703688000 + 
     (3336499252634*OepS2*x^30)/38127987424935 - (835687752414541*Pi^2*x^30)/
      3050238993994800 - (31696742900023*Pi^4*x^30)/9150716981984400 - 
     (808240942074550451*S2*x^30)/127220384707866450 - 
     (1668249626317*T1ep*x^30)/12709329141645 - 
     (62559211265423809052020315097*x^32)/211465649531105651754648576000 + 
     (45589283181421*OepS2*x^32)/549043018919064 - 
     (9140404825282159*Pi^2*x^32)/35138753210820096 - 
     (866196380446999*Pi^4*x^32)/263540649081150720 - 
     (50232304995284938901*S2*x^32)/8374736181912122880 - 
     (45589283181421*T1ep*x^32)/366028679279376 - 
     (1136251334116920711792499625387*x^34)/4044280547282395589807654016000 + 
     (829844808634126*OepS2*x^34)/10500447736827099 - 
     (707480381042125595*Pi^2*x^34)/2856121784416970928 - 
     (7883525682024197*Pi^4*x^34)/2520107456838503760 - 
     (13538661586029680275283*S2*x^34)/2382481588501156582440 - 
     (414922404317063*T1ep*x^34)/3500149245609033 - 
     (165602738138274221071746625543037*x^36)/
      618774923734206525240571064448000 + (419275704620389*OepS2*x^36)/
      5559060566555523 - (42072324657199757*Pi^2*x^36)/177889938129776736 - 
     (7966238387787391*Pi^4*x^36)/2668349071946651040 - 
     (13622842409254839528499*S2*x^36)/2522627564295342263760 - 
     (419275704620389*T1ep*x^36)/3706040377703682 - 
     (6897216100530191586381571474389239*x^38)/
      26981680549430075533115101265255040 + (205768662994340470*OepS2*x^38)/
      2851798070642983299 - (196234275060693687997*Pi^2*x^38)/
      866946613475466922896 - (20576866299434047*Pi^4*x^38)/
      7204542494255957808 - (12653105152789837449698977*S2*x^38)/
      2458805086918670104486872 - (102884331497170235*T1ep*x^38)/
      950599356880994433 - (Pi^2*x^2*Log[x])/3 + 27*S2*x^2*Log[x] - 
     x^4*Log[x] - (Pi^2*x^4*Log[x])/6 + (33*S2*x^4*Log[x])/2 - 
     (32*x^6*Log[x])/27 - (Pi^2*x^6*Log[x])/9 + (37*S2*x^6*Log[x])/3 - 
     (761*x^8*Log[x])/648 - (Pi^2*x^8*Log[x])/12 + (359*S2*x^8*Log[x])/36 - 
     (3251*x^10*Log[x])/2916 - (Pi^2*x^10*Log[x])/15 + 
     (3413*S2*x^10*Log[x])/405 - (27455*x^12*Log[x])/26244 - 
     (Pi^2*x^12*Log[x])/18 + (10685*S2*x^12*Log[x])/1458 - 
     (2892731*x^14*Log[x])/2952450 - (Pi^2*x^14*Log[x])/21 + 
     (298667*S2*x^14*Log[x])/45927 - (7658236781*x^16*Log[x])/8332994880 - 
     (Pi^2*x^16*Log[x])/24 + (2767225*S2*x^16*Log[x])/472392 - 
     (13506139039*x^18*Log[x])/15624365400 - (Pi^2*x^18*Log[x])/27 + 
     (945679*S2*x^18*Log[x])/177147 - (6881417982053*x^20*Log[x])/
      8437157316000 - (Pi^2*x^20*Log[x])/30 + (234854023*S2*x^20*Log[x])/
      47829690 - (837383782559*x^22*Log[x])/1084777369200 - 
     (Pi^2*x^22*Log[x])/33 + (2154802283*S2*x^22*Log[x])/473513931 - 
     (899367186425*x^24*Log[x])/1227348109152 - (Pi^2*x^24*Log[x])/36 + 
     (6576939619*S2*x^24*Log[x])/1549681956 - (5767868712146759*x^26*Log[x])/
      8269257885411600 - (Pi^2*x^26*Log[x])/39 + (20041195747*S2*x^26*Log[x])/
      5036466357 - (87905011287933248603*x^28*Log[x])/132064183058965957800 - 
     (Pi^2*x^28*Log[x])/42 + (548867054899*S2*x^28*Log[x])/146444944842 - 
     (540526659628056258679*x^30*Log[x])/848984033950495443000 - 
     (Pi^2*x^30*Log[x])/45 + (1668249626317*S2*x^30*Log[x])/470715894135 - 
     (59687487156674286078571*x^32*Log[x])/97802960711097075033600 - 
     (Pi^2*x^32*Log[x])/48 + (45589283181421*S2*x^32*Log[x])/13556617751088 - 
     (64490702306443784507489*x^34*Log[x])/110028330799984209412800 - 
     (Pi^2*x^34*Log[x])/51 + (414922404317063*S2*x^34*Log[x])/
      129635157244779 - (4746766233904115585156299*x^36*Log[x])/
      8417167306198792020079200 - (Pi^2*x^36*Log[x])/54 + 
     (419275704620389*S2*x^36*Log[x])/137260754729766 - 
     (2099739202495452923356298747*x^38*Log[x])/
      3863479793545245537216352800 - (Pi^2*x^38*Log[x])/57 + 
     (102884331497170235*S2*x^38*Log[x])/35207383588184979 + 
     (65*x^2*Zeta[3])/6 + (209*x^4*Zeta[3])/36 + (655*x^6*Zeta[3])/162 + 
     (6077*x^8*Zeta[3])/1944 + (55967*x^10*Zeta[3])/21870 + 
     (171023*x^12*Zeta[3])/78732 + (4688825*x^14*Zeta[3])/2480058 + 
     (42753979*x^16*Zeta[3])/25509168 + (14414221*x^18*Zeta[3])/9565938 + 
     (707606777*x^20*Zeta[3])/516560652 + (32130117497*x^22*Zeta[3])/
      25569752274 + (97178081881*x^24*Zeta[3])/83682825624 + 
     (22592837221*x^26*Zeta[3])/20920706406 + (7984369252681*x^28*Zeta[3])/
      7908027021468 + (24104646989383*x^30*Zeta[3])/25418658283290 + 
     (654651271609375*x^32*Zeta[3])/732057358558752 + 
     (5924193434274293*x^34*Zeta[3])/7000298491218066 + 
     (5954666536397575*x^36*Zeta[3])/7412080755407364 + 
     (1453986315265520681*x^38*Zeta[3])/1901198713761988866
 
f10aGl = (62210166601933451476821765070138649762665904916600 - 
      1010454252436611569701097490729407458207334400000*Pi^4 - 
      574752448608865625746348012627214208572092240485074*x + 
      4096512210300855787335019195684611308442316856037368*x^2 - 
      24411927460613194833047883310381895787563426309825508*x^3 + 
      118716369034420706716151811989591238974233829024529264*x^4 - 
      474377571131852724617929753891275946701688406357544150*x^5 + 
      1580433893735158678300597543238560918915705006879147920*x^6 - 
      4449646731103075175164932737060765380829616663684113640*x^7 + 
      10704796250677074838130585212154084779878351372927651240*x^8 - 
      22199365725589890133580711335257642756064652167828480770*x^9 + 
      39954603828350605426178833066078020798691462816626057000*x^10 - 
      62733464240240442137548572687043333013063537936583974940*x^11 + 
      86252846825942083163000372634303628315245768716808098880*x^12 - 
      104110280796500484196631593004282673032064114719961288630*x^13 + 
      110479453371686936442626483063945391823605905170935865440*x^14 - 
      103110272112348888506218910618080789543280848997569767600*x^15 + 
      84579917332802113677786545485736845836728374425759476040*x^16 - 
      60872427638687944590745467727230900247766856985893112230*x^17 + 
      38326148455033526574196871201683628941125761724355502280*x^18 - 
      21020537549622787653684832419842612531100572250590117340*x^19 + 
      9984564415317626112690911418018986848171444009318042800*x^20 - 
      4075262727893868207207819900628731451056677596237731570*x^21 + 
      1414532245118078703281246073067750696672148100769889040*x^22 - 
      411786266855096763045442341595281959032445070241380840*x^23 + 
      98655879124169258157583395922060241262610127944308120*x^24 - 
      18941710204973804000414741118614913293564016600342150*x^25 + 
      2801998504882644333412026334861042963402626526137624*x^26 - 
      299799393088653788962049861666239825300971536725668*x^27 + 
      20649262636471528618594617017665742682599626690208*x^28 - 
      687484600879472639820833887773860044208627459714*x^29 - 
      5511568649654244925642349949433131590221824000000*Pi^2*Log[2]^2 + 
      5511568649654244925642349949433131590221824000000*Log[2]^4 + 
      132277647591701878215416398786395158165323776000000*PolyLog[4, 1/2] - 
      16525228503778060740993983110280354983530921352500*Zeta[3] + 
      477219329806296338495622759332068051459663320046875*x*Zeta[3] - 
      3445102336555344307036888818649101677809503607312500*x^2*Zeta[3] + 
      20423388299479158539249694970627160365561210345593750*x^3*Zeta[3] - 
      99149066679071276124081649704800496012654956363625000*x^4*Zeta[3] + 
      395920379529077840147841581777445299453775208472390625*x^5*Zeta[3] - 
      1318599978788258349684812058767167507953997258230375000*x^6*Zeta[3] + 
      3711721452645179909237257474959972991855025340147937500*x^7*Zeta[3] - 
      8928344483772065232110356983344824933698112846772437500*x^8*Zeta[3] + 
      18513666221905108919899449147779414407388885619580171875*x^9*Zeta[3] - 
      33318720484195410577610670293362644207001446069557437500*x^10*Zeta[3] + 
      52311502425551162690413775689846208840649030462190406250*x^11*Zeta[3] - 
      71920474635750300110375129883496646362405422333181500000*x^12*Zeta[3] + 
      86807520175495623517680446245367451539554372848055640625*x^13*Zeta[3] - 
      92115443941826329410277296401443859838180076752680250000*x^14*Zeta[3] + 
      85969033402693055548452696693378981722179661469909525000*x^15*Zeta[3] - 
      70517693166773056409004593002145273794633496292660187500*x^16*Zeta[3] + 
      50750863085868397263938101152994815672222985397602265625*x^17*Zeta[3] - 
      31952950327631815827665576599851336191207398123257187500*x^18*Zeta[3] + 
      17524813689719944605716497064085187198085978691644906250*x^19*Zeta[3] - 
      8324021816523394657315627472812222293746474917715925000*x^20*Zeta[3] + 
      3397463305090723482727639175394069572545181989026796875*x^21*Zeta[3] - 
      1179254611553409924700816225673282014058923697379375000*x^22*Zeta[3] + 
      343291129777066795936537365533185899264245608257937500*x^23*Zeta[3] - 
      82245103413850679072189107092148070925868485779062500*x^24*Zeta[3] + 
      15790756703382806288647407787965201683649678922955625*x^25*Zeta[3] - 
      2335869657126737927320960817694279954906293336062500*x^26*Zeta[3] + 
      249924396065337555634194183549876157778134470093750*x^27*Zeta[3] - 
      17213923239429411161432684124836529707163105750000*x^28*Zeta[3] + 
      573107237014877306833754349207975842900809171875*x^29*Zeta[3])/
     4133676487240683694231762462074848692666368000000
 
f10bAsy = Pi^4/30 - 4*x^2 - Pi^2*x^2 + (7*x^4)/4 - (Pi^2*x^4)/12 - 
     (553*x^6)/81 + (23*Pi^2*x^6)/9 - (87587*x^8)/1728 + 
     (1957*Pi^2*x^8)/144 - (9136091*x^10)/33750 + (30907*Pi^2*x^10)/450 - 
     (236649223*x^12)/162000 + (40103*Pi^2*x^12)/108 - 
     (359545151369*x^14)/43218000 + (1053147*Pi^2*x^14)/490 - 
     (6576066436297*x^16)/131712000 + (88336613*Pi^2*x^16)/6720 - 
     (2818882925839573*x^18)/9001692000 + (952305721*Pi^2*x^18)/11340 - 
     (40744218655998847*x^20)/20003760000 + (20999245199*Pi^2*x^20)/37800 - 
     (159948192070044678287*x^22)/11715002006400 + (1729495441447*Pi^2*x^22)/
      457380 - (2998818306853930156289*x^24)/31950005472000 + 
     (13150233596989*Pi^2*x^24)/498960 - (100254911749785349660885417*x^26)/
      152087351047632000 + (1316908706850133*Pi^2*x^26)/7027020 - 
     (110328955682053944076902163*x^28)/23398054007328000 + 
     (10258656104310127*Pi^2*x^28)/7567560 - 
     (3006855805997548009296525509*x^30)/87742702527480000 + 
     (80692470966975403*Pi^2*x^30)/8108100 - 
     (54022868480220272403532913363*x^32)/213925065209856000 + 
     (512089792136508455*Pi^2*x^32)/6918912 - 
     (525909217140627256889835310067203*x^34)/279175552678005984000 + 
     (15812907343596446183*Pi^2*x^34)/28402920 - 
     (11757446369884800146361209480240033*x^36)/827673403233617740800 + 
     (1399452086090693481241*Pi^2*x^36)/330810480 - 
     (720163659906547401509848983962932688629*x^38)/
      6658223801407919604864000 + (1406543867655045097969*Pi^2*x^38)/
      43363320 + 12*x^2*Log[x] + (4*Pi^2*x^2*Log[x])/3 - (15*x^4*Log[x])/2 + 
     (8*Pi^2*x^4*Log[x])/3 - (257*x^6*Log[x])/9 + (58*Pi^2*x^6*Log[x])/9 - 
     (3613*x^8*Log[x])/48 + (64*Pi^2*x^8*Log[x])/3 - 
     (103577*x^10*Log[x])/500 + (1354*Pi^2*x^10*Log[x])/15 - 
     (1039019*x^12*Log[x])/1800 + (4031*Pi^2*x^12*Log[x])/9 - 
     (33242317*x^14*Log[x])/25725 + (51748*Pi^2*x^14*Log[x])/21 + 
     (29959957*x^16*Log[x])/31360 + (43688*Pi^2*x^16*Log[x])/3 + 
     (230666906737*x^18*Log[x])/4762800 + (2449498*Pi^2*x^18*Log[x])/27 + 
     (569825044351*x^20*Log[x])/1058400 + (8829983*Pi^2*x^20*Log[x])/15 + 
     (142476784662493*x^22*Log[x])/29348550 + (130209556*Pi^2*x^22*Log[x])/
      33 + (31230631191229469*x^24*Log[x])/768398400 + 
     (488868743*Pi^2*x^24*Log[x])/18 + (827694412775645029*x^26*Log[x])/
      2512159650 + (7453922116*Pi^2*x^26*Log[x])/39 + 
     (199355260107058221223*x^28*Log[x])/75751275600 + 
     (28778995568*Pi^2*x^28*Log[x])/21 + (23065809428014262911*x^30*Log[x])/
      1104246000 + (449348796058*Pi^2*x^30*Log[x])/45 + 
     (38202272940965957811857*x^32*Log[x])/230861030400 + 
     (221340211396*Pi^2*x^32*Log[x])/3 + (18595478943160954697318839*x^34*
       Log[x])/14177753029440 + (28143523825402*Pi^2*x^34*Log[x])/51 + 
     (335044734790464074041631593*x^36*Log[x])/32168011075200 + 
     (112647851072999*Pi^2*x^36*Log[x])/27 + 
     (177891285346459108377111791159*x^38*Log[x])/2145114882991080 + 
     (1815305790213412*Pi^2*x^38*Log[x])/57 - 12*x^2*Log[x]^2 - 
     x^4*Log[x]^2 + (92*x^6*Log[x]^2)/3 + (1957*x^8*Log[x]^2)/12 + 
     (61814*x^10*Log[x]^2)/75 + (40103*x^12*Log[x]^2)/9 + 
     (6318882*x^14*Log[x]^2)/245 + (88336613*x^16*Log[x]^2)/560 + 
     (952305721*x^18*Log[x]^2)/945 + (20999245199*x^20*Log[x]^2)/3150 + 
     (1729495441447*x^22*Log[x]^2)/38115 + (13150233596989*x^24*Log[x]^2)/
      41580 + (1316908706850133*x^26*Log[x]^2)/585585 + 
     (10258656104310127*x^28*Log[x]^2)/630630 + 
     (80692470966975403*x^30*Log[x]^2)/675675 + 
     (512089792136508455*x^32*Log[x]^2)/576576 + 
     (15812907343596446183*x^34*Log[x]^2)/2366910 + 
     (1399452086090693481241*x^36*Log[x]^2)/27567540 + 
     (1406543867655045097969*x^38*Log[x]^2)/3613610 + (16*x^2*Log[x]^3)/3 + 
     (32*x^4*Log[x]^3)/3 + (232*x^6*Log[x]^3)/9 + (256*x^8*Log[x]^3)/3 + 
     (5416*x^10*Log[x]^3)/15 + (16124*x^12*Log[x]^3)/9 + 
     (206992*x^14*Log[x]^3)/21 + (174752*x^16*Log[x]^3)/3 + 
     (9797992*x^18*Log[x]^3)/27 + (35319932*x^20*Log[x]^3)/15 + 
     (520838224*x^22*Log[x]^3)/33 + (977737486*x^24*Log[x]^3)/9 + 
     (29815688464*x^26*Log[x]^3)/39 + (115115982272*x^28*Log[x]^3)/21 + 
     (1797395184232*x^30*Log[x]^3)/45 + (885360845584*x^32*Log[x]^3)/3 + 
     (112574095301608*x^34*Log[x]^3)/51 + (450591404291996*x^36*Log[x]^3)/
      27 + (7261223160853648*x^38*Log[x]^3)/57 + 6*Zeta[3] + 4*x^2*Zeta[3] - 
     2*x^4*Zeta[3] - (32*x^6*Zeta[3])/3 - 41*x^8*Zeta[3] - 
     (896*x^10*Zeta[3])/5 - (2684*x^12*Zeta[3])/3 - (34492*x^14*Zeta[3])/7 - 
     (58249*x^16*Zeta[3])/2 - (1632992*x^18*Zeta[3])/9 - 
     (5886652*x^20*Zeta[3])/5 - (86806364*x^22*Zeta[3])/11 - 
     (162956246*x^24*Zeta[3])/3 - (4969281404*x^26*Zeta[3])/13 - 
     (19185997042*x^28*Zeta[3])/7 - (299565864032*x^30*Zeta[3])/15 - 
     (590240563721*x^32*Zeta[3])/4 - (18762349216928*x^34*Zeta[3])/17 - 
     (75098567381996*x^36*Zeta[3])/9 - (1210203860142268*x^38*Zeta[3])/19
 

f10bGl = (140814056907084834536120892845777101549085797474334 - 
      34843250084021088610382672094117498558873600000*Pi^4 - 
      3349626965663653380889010074331389462752656207538392*x + 
      40011684115249422545882349544496908800802994959081596*x^2 - 
      313258769273834164846860559275631623944266693936956888*x^3 + 
      1791895124531520809310985514704379486317117463324883450*x^4 - 
      7945735692977304387967451961746766405001616849761320720*x^5 + 
      28340419170035042060941393897252655265557793984085907160*x^6 - 
      83355118178889944026469129600286360491250588207727225680*x^7 + 
      205750455899648216757803503908106424123365842215609658990*x^8 - 
      431687047692873056063197882353450822982167444608300689800*x^9 + 
      777109103474944583792965923765836960345877921267732311940*x^10 - 
      1208503816256517743328200026908384909899850003594180027720*x^11 + 
      1631450057429523765779811185032518191218868027959254698010*x^12 - 
      1918018915784539045951119675060715248152087699303607274080*x^13 + 
      1967236186590478587283875809000204565782949589048254901200*x^14 - 
      1761089995506368954161471379716465600574473087715086191840*x^15 + 
      1374877702463064908301632243149400424440442237501828563370*x^16 - 
      934028164859220583036787721821894474986871058990956717160*x^17 + 
      550161678345597417588452611012500985886326424882369802180*x^18 - 
      279474919130229208551002194278297957693196121778610669800*x^19 + 
      121538161133709553917923852118694945052868075391236419070*x^20 - 
      44797335888357210698892124773338453675647400778241679760*x^21 + 
      13806147547194666786137865079492757444039597914432760280*x^22 - 
      3492088928786709854837810770321355038418264468974802640*x^23 + 
      706072463961464960667206466313926961429439626101717450*x^24 - 
      109739887472267188096586236073379583702584495780617784*x^25 + 
      12310460277416167378108427345006915536709966556124092*x^26 - 
      887253465316266137048218551148749817834425878658296*x^27 + 
      30854797540618125675426067875636409595265706067438*x^28 - 
      190054091367387756056632756877004537593856000000*Pi^2*Log[2]^2 + 
      190054091367387756056632756877004537593856000000*Log[2]^4 + 
      4561298192817306145359186165048108902252544000000*PolyLog[4, 1/2] - 
      114302175593654608687393143461218348585423485058125*Zeta[3] + 
      2784327930244976691400084340840283362823396474562500*x*Zeta[3] - 
      33293432414599268661294705135281034545503599318656250*x^2*Zeta[3] + 
      260657594277102999910679083957413551278127279736562500*x^3*Zeta[3] - 
      1490948266222106243479989995039418124415978126861484375*x^4*Zeta[3] + 
      6611073798215540233678258451604504829783077782024175000*x^5*Zeta[3] - 
      23579573760662954335129493864432126614301854152942562500*x^6*Zeta[3] + 
      69351548079878734336851896581639511377996083585736875000*x^7*Zeta[3] - 
      171182919163525940965709279511018956632139808888499453125*x^8*Zeta[3] + 
      359157863604973672407225439744750046135907267547897687500*x^9*Zeta[3] - 
      646540581150176648354244260310647025479173870783855743750*x^10*
       Zeta[3] + 1005448301597967200350410889005459549111340820339676187500*
       x^11*Zeta[3] - 
      1357324827170375770009798865284567747373038990575204234375*x^12*
       Zeta[3] + 1595737542100959345147840209757352506877725948788420250000*
       x^13*Zeta[3] - 
      1636680329249665095637784890783340780653861426103635875000*x^14*
       Zeta[3] + 1465169466069951201187125081335079714746562754705403250000*
       x^15*Zeta[3] - 
      1143851025450503352452851209521858856474494398011558609375*x^16*
       Zeta[3] + 777077918760948876274023308210918501994215020800744937500*
       x^17*Zeta[3] - 
      457714028512760870139010001611093312405424201025486843750*x^18*
       Zeta[3] + 232512386801493494569254386943815999773377092381451937500*
       x^19*Zeta[3] - 
      101114944882146980549249832462736541965290592757113828125*x^20*
       Zeta[3] + 37269568442187367227921372384848694487819118969394375000*
       x^21*Zeta[3] - 
      11486143120596978170600837544110248279671606220176562500*x^22*Zeta[3] + 
      2905270573530559246733142917669558427935775158149875000*x^23*Zeta[3] - 
      587421960997732209426348469161345075836929795993359375*x^24*Zeta[3] + 
      91298797921333388825319855861866025612190239006892500*x^25*Zeta[3] - 
      10241758073143278841345630205803850169318649598156250*x^26*Zeta[3] + 
      738155097918670429664965535956147821936520789312500*x^27*Zeta[3] - 
      25669791414594279809981496352643504554208824453125*x^28*Zeta[3])/
     142540568525540817042474567657753403195392000000
 
f9aAsy = 5/2 - (27*S2)/2 + (53*x^2)/144 - (2*OepS2*x^2)/9 + 
     (101*Pi^2*x^2)/144 + (19*Pi^4*x^2)/2160 + (99*S2*x^2)/4 + (T1ep*x^2)/3 - 
     (5*x^4)/12 - S2*x^4 - (19*x^6)/5832 - (4*OepS2*x^6)/729 + 
     (101*Pi^2*x^6)/5832 + (19*Pi^4*x^6)/87480 + (5*S2*x^6)/18 + 
     (2*T1ep*x^6)/243 + (13*x^8)/3888 - (8*OepS2*x^8)/2187 + 
     (101*Pi^2*x^8)/8748 + (19*Pi^4*x^8)/131220 + (49*S2*x^8)/243 + 
     (4*T1ep*x^8)/729 + (5609*x^10)/1749600 - (16*OepS2*x^10)/6561 + 
     (101*Pi^2*x^10)/13122 + (19*Pi^4*x^10)/196830 + (193*S2*x^10)/1458 + 
     (8*T1ep*x^10)/2187 + (162743*x^12)/59049000 - (304*OepS2*x^12)/177147 + 
     (1919*Pi^2*x^12)/354294 + (361*Pi^4*x^12)/5314410 + 
     (8989*S2*x^12)/98415 + (152*T1ep*x^12)/59049 + 
     (8064373*x^14)/3472081200 - (2020*OepS2*x^14)/1594323 + 
     (51005*Pi^2*x^14)/12754584 + (1919*Pi^4*x^14)/38263752 + 
     (23503*S2*x^14)/354294 + (1010*T1ep*x^14)/531441 + 
     (8551388813*x^16)/4374822312000 - (4648*OepS2*x^16)/4782969 + 
     (58681*Pi^2*x^16)/19131876 + (11039*Pi^4*x^16)/286978140 + 
     (934042*S2*x^16)/18600435 + (2324*T1ep*x^16)/1594323 + 
     (334966958489*x^18)/202491775584000 - (33068*OepS2*x^18)/43046721 + 
     (834967*Pi^2*x^18)/344373768 + (157073*Pi^4*x^18)/5165606520 + 
     (11271617*S2*x^18)/286978140 + (16534*T1ep*x^18)/14348907 + 
     (6751745058553*x^20)/4783868198172000 - (723104*OepS2*x^20)/1162261467 + 
     (2282297*Pi^2*x^20)/1162261467 + (429343*Pi^4*x^20)/17433922005 + 
     (427609163*S2*x^20)/13559717115 + (361552*T1ep*x^20)/387420489 + 
     (2812568285381009*x^22)/2315392207915248000 - 
     (597364*OepS2*x^22)/1162261467 + (15083441*Pi^2*x^22)/9298091736 + 
     (2837479*Pi^4*x^22)/139471376040 + (350712277*S2*x^22)/13559717115 + 
     (298682*T1ep*x^22)/387420489 + (43508489194762997*x^24)/
      41260289145049719360 - (40636600*OepS2*x^24)/94143178827 + 
     (513037075*Pi^2*x^24)/376572715308 + (19302385*Pi^4*x^24)/
      1129718145924 + (52168601194*S2*x^24)/2416341589893 + 
     (20318300*T1ep*x^24)/31381059609 + (43872619856195977729*x^26)/
      47543105901227744808000 - (103816240*OepS2*x^26)/282429536481 + 
     (655340015*Pi^2*x^26)/564859072962 + (24656357*Pi^4*x^26)/
      1694577218886 + (120533574143*S2*x^26)/6590022517890 + 
     (51908120*T1ep*x^26)/94143178827 + (2074236730819341502343*x^28)/
      2549499053953337815329000 - (268389680*OepS2*x^28)/847288609443 + 
     (1694209855*Pi^2*x^28)/1694577218886 + (63742549*Pi^4*x^28)/
      5083731656658 + (22180264344079*S2*x^28)/1413559830087405 + 
     (134194840*T1ep*x^28)/282429536481 + (61186678026873541675583*x^30)/
      84721814715987841247856000 - (6308967860*OepS2*x^30)/22876792454961 + 
     (159301438465*Pi^2*x^30)/183014339639688 + (5993519467*Pi^4*x^30)/
      549043018919064 + (5707157961442*S2*x^30)/419407861674285 + 
     (3154483930*T1ep*x^30)/7625597484987 + (1826985639229090123193407*x^32)/
      2832129234791593550285472000 - (49878046904*OepS2*x^32)/
      205891132094649 + (629710342163*Pi^2*x^32)/823564528378596 + 
     (118460361397*Pi^4*x^32)/12353467925678940 + (116909971304384*S2*x^32)/
      9814143963178269 + (24939023452*T1ep*x^32)/68630377364883 + 
     (15936675183118579986433601533*x^34)/27501107721520290010692047308800 - 
     (132480401840*OepS2*x^34)/617673396283947 + (836282536615*Pi^2*x^34)/
      1235346792567894 + (31464095437*Pi^4*x^34)/3706040377703682 + 
     (17336414493667513*S2*x^34)/1648776185813949192 + 
     (66240200920*T1ep*x^34)/205891132094649 + 
     (2064128037600327245403947765611*x^36)/
      3944690138805566598408640535856000 - (3189042880448*OepS2*x^36)/
      16677181699666569 + (10065416591414*Pi^2*x^36)/16677181699666569 + 
     (1893494210266*Pi^4*x^36)/250157725494998535 + 
     (4421985831702452723*S2*x^36)/472992668305376674455 + 
     (1594521440224*T1ep*x^36)/5559060566555523 + 
     (8589811119105767338698778357739057*x^38)/
      18093597544911933004559538495523968000 - (77244432380884*OepS2*x^38)/
      450283905890997363 + (1950421917617321*Pi^2*x^38)/3602271247127978904 + 
     (366911053809199*Pi^4*x^38)/54034068706919683560 + 
     (25140660367966496453*S2*x^38)/3004894598645922402420 + 
     (38622216190442*T1ep*x^38)/150094635296999121 + 3*x^2*Log[x] - 
     9*S2*x^2*Log[x] + (x^4*Log[x])/3 + (11*x^6*Log[x])/162 - 
     (2*S2*x^6*Log[x])/9 + (19*x^8*Log[x])/486 - (4*S2*x^8*Log[x])/27 + 
     (751*x^10*Log[x])/29160 - (8*S2*x^10*Log[x])/81 + 
     (8908*x^12*Log[x])/492075 - (152*S2*x^12*Log[x])/2187 + 
     (331433*x^14*Log[x])/24800580 - (1010*S2*x^14*Log[x])/19683 + 
     (26691517*x^16*Log[x])/2604060900 - (2324*S2*x^16*Log[x])/59049 + 
     (217023343*x^18*Log[x])/26784626400 - (16534*S2*x^18*Log[x])/531441 + 
     (2076238693*x^20*Log[x])/316393399350 - (361552*S2*x^20*Log[x])/
      14348907 + (6037514957*x^22*Log[x])/1113704765712 - 
     (298682*S2*x^22*Log[x])/14348907 + (11294557752133*x^24*Log[x])/
      2480777365623480 - (20318300*S2*x^24*Log[x])/1162261467 + 
     (170505280450009*x^26*Log[x])/43977416936052600 - 
     (51908120*S2*x^26*Log[x])/3486784401 + (31516965192555377*x^28*Log[x])/
      9433155932783282700 - (134194840*S2*x^28*Log[x])/10460353203 + 
     (227957315295754703*x^30*Log[x])/78367756980045733200 - 
     (3154483930*S2*x^30*Log[x])/282429536481 + 
     (836738936641975937*x^32*Log[x])/327465270238048242300 - 
     (24939023452*S2*x^32*Log[x])/2541865828329 + 
     (338523722094130970549*x^34*Log[x])/149638529887978524801408 - 
     (66240200920*S2*x^34*Log[x])/7625597484987 + 
     (21645457865633815632907*x^36*Log[x])/10731888315403459825600980 - 
     (1594521440224*S2*x^36*Log[x])/205891132094649 + 
     (9375582643761824549548327*x^38*Log[x])/5181608193695976367560755520 - 
     (38622216190442*S2*x^38*Log[x])/5559060566555523 - 2*x^2*Log[x]^2 + 
     (2*x^2*Log[x]^3)/3 + PolyGamma[2, 1]/3 + (x^2*PolyGamma[2, 1])/6 + 
     (2*Zeta[3])/3 - (5*x^2*Zeta[3])/6 - (7*x^6*Zeta[3])/243 - 
     (14*x^8*Zeta[3])/729 - (28*x^10*Zeta[3])/2187 - 
     (532*x^12*Zeta[3])/59049 - (3535*x^14*Zeta[3])/531441 - 
     (8134*x^16*Zeta[3])/1594323 - (57869*x^18*Zeta[3])/14348907 - 
     (1265432*x^20*Zeta[3])/387420489 - (1045387*x^22*Zeta[3])/387420489 - 
     (71114050*x^24*Zeta[3])/31381059609 - (181678420*x^26*Zeta[3])/
      94143178827 - (469681940*x^28*Zeta[3])/282429536481 - 
     (11040693755*x^30*Zeta[3])/7625597484987 - (87286582082*x^32*Zeta[3])/
      68630377364883 - (231840703220*x^34*Zeta[3])/205891132094649 - 
     (5580825040784*x^36*Zeta[3])/5559060566555523 - 
     (135177756666547*x^38*Zeta[3])/150094635296999121
 
f9aGl = (121589926472801018815151119309736990 - 
      86946538832905412814471574543779486*x - 
      392365623848232117549817470554595484*x^2 + 
      2832567780489019633428303896490953196*x^3 - 
      12921325868361312455951767962493747710*x^4 + 
      48554642508270056535679943905425042414*x^5 - 
      154720072351598316343582258249041909816*x^6 + 
      421683226386369802484771951036248056984*x^7 - 
      989927868311438388607933153663952149794*x^8 + 
      2014179874247825773081319087333786440770*x^9 - 
      3570487038580654185557926174414996304196*x^10 + 
      5537064438840112191160238292890343674292*x^11 - 
      7535029033904883069606752660993846567694*x^12 + 
      9016455001064450554419304613729198589918*x^13 - 
      9497351240485031947720778803681489898640*x^14 + 
      8807220054494616069900758384521657017552*x^15 - 
      7184130890464639455109788137197235776182*x^16 + 
      5145036677691327385545195355602402392310*x^17 - 
      3225266363869173132254328122192442676068*x^18 + 
      1762056337099950258548335877365509927060*x^19 - 
      834032165340390392428209214815100413642*x^20 + 
      339339344727786194800239457915326005082*x^21 - 
      117447361989840655906456371406993445304*x^22 + 
      34100771301033483069780898733603952408*x^23 - 
      8150296767940849135692730356714609990*x^24 + 
      1561393051336320465585496647023278182*x^25 - 
      230503849770338774094947269489812540*x^26 + 
      24616397680212124245194174844064588*x^27 - 
      1692547328063549848688675624295210*x^28 + 
      56259342253718544632919099330010*x^29 - 
      128447124682632996903283196573122125*Zeta[3] + 
      6111539393884853743250591184154125*x*Zeta[3] + 
      341394493643537986307936555383358250*x^2*Zeta[3] - 
      770044830251965020484977049211657250*x^3*Zeta[3] + 
      2493102389353016068833154180734628125*x^4*Zeta[3] - 
      8341671408364558205695104426763813125*x^5*Zeta[3] + 
      25029478569951617743840034036429068500*x^6*Zeta[3] - 
      65790715388600802187992283766673286500*x^7*Zeta[3] + 
      150766751039751271451766668205027625875*x^8*Zeta[3] - 
      301529055138196790918704336988018551875*x^9*Zeta[3] + 
      527671184663139516864481906262843619750*x^10*Zeta[3] - 
      810157319236892510584043819154365436750*x^11*Zeta[3] + 
      1093708319662656512472053413024757875125*x^12*Zeta[3] - 
      1300209278026296522685130097154812550125*x^13*Zeta[3] + 
      1362121365475077882748692551601083415000*x^14*Zeta[3] - 
      1257340930339430044852226648182260243000*x^15*Zeta[3] + 
      1021588306842010649705871548694781352625*x^16*Zeta[3] - 
      729132922767924277485258118321870916625*x^17*Zeta[3] + 
      455707719752147561743888676596695681750*x^18*Zeta[3] - 
      248311164067375681749091974935224398750*x^19*Zeta[3] + 
      117257984233083312107593867295789631375*x^20*Zeta[3] - 
      47608482025788052832049820479141270375*x^21*Zeta[3] + 
      16446559666098525491172787228871284500*x^22*Zeta[3] - 
      4767117005908089134800860144529246500*x^23*Zeta[3] + 
      1137607101963299651637134326936415625*x^24*Zeta[3] - 
      217629122810583281817707360405357625*x^25*Zeta[3] + 
      32086336909656330536987787165380250*x^26*Zeta[3] - 
      3422541830999492819041734151091250*x^27*Zeta[3] + 
      235064638795371594369760009785375*x^28*Zeta[3] - 
      7805465529164996213253692334375*x^29*Zeta[3])/
     33255169998678914721193119449088000
 
f9bAsy = 25/6 + Pi^2/6 - (11*x^2)/2 - (Pi^2*x^2)/2 - (3*x^4)/4 + Pi^2*x^4 - 
     (53*x^6)/6 - (5999*x^8)/144 + (32*Pi^2*x^8)/3 - (196621*x^10)/800 + 
     (131*Pi^2*x^10)/2 - (14055067*x^12)/9000 + (6401*Pi^2*x^12)/15 - 
     (1833662683*x^14)/176400 + (8701*Pi^2*x^14)/3 - 
     (196769438909*x^16)/2744000 + (713093*Pi^2*x^16)/35 - 
     (21553215935141*x^18)/42336000 + (8817193*Pi^2*x^18)/60 - 
     (1233674795035961*x^20)/333396000 + (341140777*Pi^2*x^20)/315 - 
     (32781025238815393*x^22)/1195286400 + (568720651*Pi^2*x^22)/70 - 
     (36675836022766254407*x^24)/177500030400 + (42875326631*Pi^2*x^24)/693 - 
     (7174786748105678892037*x^26)/4545076536000 + (100205706157*Pi^2*x^26)/
      210 - (661079593132212091093723*x^28)/54162162054000 + 
     (18622179988571*Pi^2*x^28)/5005 - (9535126683835546285504889*x^30)/
      99991683792000 + (9665522939341*Pi^2*x^30)/330 - 
     (279227030349850910949432697*x^32)/371397682656000 + 
     (99741560179003*Pi^2*x^32)/429 - (2394372832532996563049245220989*x^34)/
      400713339740313600 + (14888515891099607*Pi^2*x^34)/8008 - 
     (101817908284139167669693743898823*x^36)/2128789617370416000 + 
     (3819957965341183957*Pi^2*x^36)/255255 - 
     (1254044219961508050813445274569083793*x^38)/3254794102040697216000 + 
     (21832258296091920577*Pi^2*x^38)/180180 - 
     (60772037149714672930037467821161969131*x^40)/19468490647391577792000 + 
     (3188846037186812350297*Pi^2*x^40)/3233230 - 
     (175824830242716233809002850291469818727*x^42)/6916437466836481584000 + 
     (12353973053087252685467*Pi^2*x^42)/1531530 - 
     (3644478768820140541365735824826562589071*x^44)/
      17521641582652420012800 + (21423620946598129909838*Pi^2*x^44)/323323 - 
     (307910839299782250933227547374049586088167*x^46)/
      180154487798311568256000 + (504808805509634227887003*Pi^2*x^46)/
      923780 - (2732521283557449147412171884966925996463237837*x^48)/
      193805284669210903905216000 + (30578455291215638296879289*Pi^2*x^48)/
      6760390 - (5694467194286588096588550055331625771473660039*x^50)/
      48783938932753316772480000 + (3196237752881047963633201*Pi^2*x^50)/
      85085 - (2691469399341954435749962714770622381505711317513*x^52)/
      2775856941876718675725750000 + (58180534196190742831476238923*Pi^2*
       x^52)/185910725 - (516674739153083366424699141624197013295775795424539*
       x^54)/63955743940839598288721280000 + 
     (233319734142394984022296765111*Pi^2*x^54)/89237148 - 
     (112079256685590546252374697691027988875219233086175527*x^56)/
      1660389506156412647880264000000 + (16914127199100828249931679869553*
       Pi^2*x^56)/772244550 - 
     (31684196685837648150596676884429643717733946428177765079*x^58)/
      56027896514839689750848538000000 + (5260795789942141966559273927209*
       Pi^2*x^58)/28601650 - 
     (178586392127821863589369359917643940801706448819446837420611*x^60)/
      37602722546673837492783775932000000 + 
     (2476598804297457399513252025814338*Pi^2*x^60)/1599649425 - 
     (464941672391288498471684653566176006977627871017165081854972937*x^62)/
      11630046646964363439722136123888000000 + 
     (960521079805485296268177191850313*Pi^2*x^62)/73547100 + 9*x^2*Log[x] + 
     Pi^2*x^2*Log[x] - 9*x^4*Log[x] - (5*x^6*Log[x])/2 - (31*x^8*Log[x])/6 + 
     12*Pi^2*x^8*Log[x] + (633*x^10*Log[x])/40 + 72*Pi^2*x^10*Log[x] + 
     (26762*x^12*Log[x])/75 + 456*Pi^2*x^12*Log[x] + 
     (1576739*x^14*Log[x])/420 + 3030*Pi^2*x^14*Log[x] + 
     (164661933*x^16*Log[x])/4900 + 20916*Pi^2*x^16*Log[x] + 
     (4764373781*x^18*Log[x])/16800 + 148806*Pi^2*x^18*Log[x] + 
     (154455605393*x^20*Log[x])/66150 + 1084656*Pi^2*x^20*Log[x] + 
     (4102188119567*x^22*Log[x])/215600 + 8064414*Pi^2*x^22*Log[x] + 
     (989293120326869*x^24*Log[x])/6403320 + 60954900*Pi^2*x^24*Log[x] + 
     (15820466067618103*x^26*Log[x])/12612600 + 467173080*Pi^2*x^26*Log[x] + 
     (3066253205093855849*x^28*Log[x])/300600300 + 3623260680*Pi^2*x^28*
      Log[x] + (23075620196613123311*x^30*Log[x])/277477200 + 
     28390355370*Pi^2*x^30*Log[x] + (4380371657310242554*x^32*Log[x])/
      6441435 + 224451211068*Pi^2*x^32*Log[x] + 
     (182440403637577123096183*x^34*Log[x])/32705312640 + 
     1788485424840*Pi^2*x^34*Log[x] + (3987944502853672829390407*x^36*Log[x])/
      86873486700 + 14350692962016*Pi^2*x^36*Log[x] + 
     (5298293824489674847422847301*x^38*Log[x])/13981521153600 + 
     115866648571326*Pi^2*x^38*Log[x] + (262410201527978479101103678247*x^40*
       Log[x])/83630209863200 + 940732167629556*Pi^2*x^40*Log[x] + 
     (1548309764462222718181899506873*x^42*Log[x])/59421464902800 + 
     7676434912106568*Pi^2*x^42*Log[x] + (466605991322838226560122100919*x^44*
       Log[x])/2150491110768 + 62926851438025560*Pi^2*x^44*Log[x] + 
     (2986724182631839530076417440687757*x^46*Log[x])/1648709851588800 + 
     517987290197578698*Pi^2*x^46*Log[x] + 
     (548829652417498655223359154745376963*x^48*Log[x])/36196675378063200 + 
     4280111884475092908*Pi^2*x^48*Log[x] + 
     (231802617734760736516881341812519681*x^50*Log[x])/1822258257019200 + 
     35490252428818017498*Pi^2*x^50*Log[x] + 
     (887225570977953884409861599600041280671*x^52*Log[x])/
      829507144080615000 + 295230951649429711920*Pi^2*x^52*Log[x] + 
     (7176691357422461826284135640262021966151*x^54*Log[x])/
      796326858317390400 + 2463246461614650667650*Pi^2*x^54*Log[x] + 
     (1573032826246201265994484446750514683067091*x^56*Log[x])/
      20673870360163020000 + 20608809194849417053356*Pi^2*x^56*Log[x] + 
     (30964570937119520644965378029801347923052241*x^58*Log[x])/
      48111414356675670000 + 172867259978810704134936*Pi^2*x^58*Log[x] + 
     (88049239641347339550867665112121248682272422297*x^60*Log[x])/
      16144816046261592690000 + 1453489002037611846096216*Pi^2*x^60*Log[x] + 
     (7456515311518839642765206287449002739183669674519*x^62*Log[x])/
      161077015266150143160000 + 12248465352412159318254678*Pi^2*x^62*
      Log[x] - 6*x^2*Log[x]^2 + 12*x^4*Log[x]^2 + 24*x^6*Log[x]^2 + 
     128*x^8*Log[x]^2 + 786*x^10*Log[x]^2 + (25604*x^12*Log[x]^2)/5 + 
     34804*x^14*Log[x]^2 + (8557116*x^16*Log[x]^2)/35 + 
     (8817193*x^18*Log[x]^2)/5 + (1364563108*x^20*Log[x]^2)/105 + 
     (3412323906*x^22*Log[x]^2)/35 + (171501306524*x^24*Log[x]^2)/231 + 
     (200411412314*x^26*Log[x]^2)/35 + (223466159862852*x^28*Log[x]^2)/5005 + 
     (19331045878682*x^30*Log[x]^2)/55 + (398966240716012*x^32*Log[x]^2)/
      143 + (44665547673298821*x^34*Log[x]^2)/2002 + 
     (15279831861364735828*x^36*Log[x]^2)/85085 + 
     (21832258296091920577*x^38*Log[x]^2)/15015 + 
     (19133076223120874101782*x^40*Log[x]^2)/1616615 + 
     (24707946106174505370934*x^42*Log[x]^2)/255255 + 
     (257083451359177558918056*x^44*Log[x]^2)/323323 + 
     (1514426416528902683661009*x^46*Log[x]^2)/230945 + 
     (183470731747293829781275734*x^48*Log[x]^2)/3380195 + 
     (38354853034572575563598412*x^50*Log[x]^2)/85085 + 
     (698166410354288913977714867076*x^52*Log[x]^2)/185910725 + 
     (233319734142394984022296765111*x^54*Log[x]^2)/7436429 + 
     (33828254398201656499863359739106*x^56*Log[x]^2)/128707425 + 
     (31564774739652851799355643563254*x^58*Log[x]^2)/14300825 + 
     (9906395217189829598053008103257352*x^60*Log[x]^2)/533216475 + 
     (960521079805485296268177191850313*x^62*Log[x]^2)/6128925 + 
     2*x^2*Log[x]^3 + 8*x^6*Log[x]^3 + 48*x^8*Log[x]^3 + 288*x^10*Log[x]^3 + 
     1824*x^12*Log[x]^3 + 12120*x^14*Log[x]^3 + 83664*x^16*Log[x]^3 + 
     595224*x^18*Log[x]^3 + 4338624*x^20*Log[x]^3 + 32257656*x^22*Log[x]^3 + 
     243819600*x^24*Log[x]^3 + 1868692320*x^26*Log[x]^3 + 
     14493042720*x^28*Log[x]^3 + 113561421480*x^30*Log[x]^3 + 
     897804844272*x^32*Log[x]^3 + 7153941699360*x^34*Log[x]^3 + 
     57402771848064*x^36*Log[x]^3 + 463466594285304*x^38*Log[x]^3 + 
     3762928670518224*x^40*Log[x]^3 + 30705739648426272*x^42*Log[x]^3 + 
     251707405752102240*x^44*Log[x]^3 + 2071949160790314792*x^46*Log[x]^3 + 
     17120447537900371632*x^48*Log[x]^3 + 141961009715272069992*x^50*
      Log[x]^3 + 1180923806597718847680*x^52*Log[x]^3 + 
     9852985846458602670600*x^54*Log[x]^3 + 82435236779397668213424*x^56*
      Log[x]^3 + 691469039915242816539744*x^58*Log[x]^3 + 
     5813956008150447384384864*x^60*Log[x]^3 + 48993861409648637273018712*
      x^62*Log[x]^3 + 2*Pi^2*x^6*(1 + Log[x]) + (x^2*PolyGamma[2, 1])/2 - 
     x^2*Zeta[3] - 4*x^6*Zeta[3] - 24*x^8*Zeta[3] - 144*x^10*Zeta[3] - 
     912*x^12*Zeta[3] - 6060*x^14*Zeta[3] - 41832*x^16*Zeta[3] - 
     297612*x^18*Zeta[3] - 2169312*x^20*Zeta[3] - 16128828*x^22*Zeta[3] - 
     121909800*x^24*Zeta[3] - 934346160*x^26*Zeta[3] - 
     7246521360*x^28*Zeta[3] - 56780710740*x^30*Zeta[3] - 
     448902422136*x^32*Zeta[3] - 3576970849680*x^34*Zeta[3] - 
     28701385924032*x^36*Zeta[3] - 231733297142652*x^38*Zeta[3] - 
     1881464335259112*x^40*Zeta[3] - 15352869824213136*x^42*Zeta[3] - 
     125853702876051120*x^44*Zeta[3] - 1035974580395157396*x^46*Zeta[3] - 
     8560223768950185816*x^48*Zeta[3] - 70980504857636034996*x^50*Zeta[3] - 
     590461903298859423840*x^52*Zeta[3] - 4926492923229301335300*x^54*
      Zeta[3] - 41217618389698834106712*x^56*Zeta[3] - 
     345734519957621408269872*x^58*Zeta[3] - 2906978004075223692192432*x^60*
      Zeta[3] - 24496930704824318636509356*x^62*Zeta[3]
 
f9bGl = (-82433349679279512246187214669590038 + 
      2091863852467174615149475584368884540*x - 
      25815635924573981755638525005400450192*x^2 + 
      206528462941847348678241939092391586500*x^3 - 
      1200405285499287721602551900034266988750*x^4 + 
      5390034144670278471620470697766623131848*x^5 - 
      19422067254422847617594019957123342731376*x^6 + 
      57613898066420883093138311370701026061016*x^7 - 
      143250535190415804469828685597144182837806*x^8 + 
      302455483287703484091534519185847439208340*x^9 - 
      547487317422226681543100298382241671455456*x^10 + 
      855589318559503354066323640776304054572876*x^11 - 
      1160084100604698231222428244816556834867590*x^12 + 
      1369230745598086542177203155670009480671536*x^13 - 
      1409375805070972678999603156219095348346080*x^14 + 
      1265784893460859934766616110251975847622416*x^15 - 
      991130060602467618646400697647115182005506*x^16 + 
      675165554215100748624783038212498975632036*x^17 - 
      398687485781215757112325066808745880911696*x^18 + 
      202999974784717920891720592408964700108060*x^19 - 
      88471752005715159126685796627765066141226*x^20 + 
      32675227318431185119535501920481322920328*x^21 - 
      10089175003231359148820058629929479727536*x^22 + 
      2556425337942670067440074839312563342488*x^23 - 
      517743539017037311257249274377828979770*x^24 + 
      80594382834969444337872207025105868556*x^25 - 
      9054207988866833502641909067949787712*x^26 + 
      653467828260588650928956719729285716*x^27 - 
      22754480907362552736651205990315522*x^28 + 
      69047944662377321753737956172466625*Zeta[3] - 
      1740914848762574080980831997320020250*x*Zeta[3] + 
      21471446163398157042320843485437591000*x^2*Zeta[3] - 
      171787486826023678453732746848988747750*x^3*Zeta[3] + 
      998528315752163371069109396599796503125*x^4*Zeta[3] - 
      4483665691625132560265503026340386787500*x^5*Zeta[3] + 
      16156320125545468193412032446569661593000*x^6*Zeta[3] - 
      47926721725358634597348674430000245410500*x^7*Zeta[3] + 
      119165125106844143107063369593527856961125*x^8*Zeta[3] - 
      251603232197127241642811427313349272158750*x^9*Zeta[3] + 
      455439022113218069981102353012794424338000*x^10*Zeta[3] - 
      711742114142183277729239699344124192627250*x^11*Zeta[3] + 
      965045326090799868220030724198187302939625*x^12*Zeta[3] - 
      1139031281363019208641897114362628541581000*x^13*Zeta[3] + 
      1172428786503431809265943720787414688370000*x^14*Zeta[3] - 
      1052980015697401280768255873395527659631000*x^15*Zeta[3] + 
      824501316516256986635546799635002289515875*x^16*Zeta[3] - 
      561657297899913336130893894220624565901750*x^17*Zeta[3] + 
      331660771870828135564238505352700822379000*x^18*Zeta[3] - 
      168872067186488325897122462437247102966250*x^19*Zeta[3] + 
      73598126817899044660542429068068364553375*x^20*Zeta[3] - 
      27181975639257172077956847002563871575500*x^21*Zeta[3] + 
      8393020793212815877823705799089591301000*x^22*Zeta[3] - 
      2126649791253690584703851011164392710500*x^23*Zeta[3] + 
      430702858249075091791257219557493384375*x^24*Zeta[3] - 
      67045251552807725248864242588483575250*x^25*Zeta[3] + 
      7532062019309141760148232939493084000*x^26*Zeta[3] - 
      543610440135660947023491708524082750*x^27*Zeta[3] + 
      18929130080624537718532820152795875*x^28*Zeta[3])/
     95560833329537111267796320256000
 
f8aAsyN = 13.7112912870512825038535151499626234054646567716806765864991754250\
26487146398422972126869603117416561892035864231435991439844626226746715`100. \
+ 6.8872716047025339845955231377989352479789632675365167116682303083707811578\
32899865325601295202568779364577774413823581914173112466473747`100.*x^2 + 
     2.3818608975162460594069409860405281010563033596230714625736349786983249\
81192513693497296334745808778129208923933754314179055377921533247`100.*x^4 - 
     0.0624230237712770943332806560767247123857300686911185457448810022647351\
25648523008561568255899938596394056008656002820811705420492616582`100.*x^6 - 
     0.0012823221853826901913458232494167322118942581838565806140903073012102\
71491739681366471341515674420962158337078645409088492333619817091`100.*x^8 - 
     0.0000491244905878473216698883953423668873798474983073786047377819702917\
4040917151665473555817763013769221569330926710352184775597055466`100.*x^10 - 
     2.4926793794276720639275925648368224653604137442775696953936143952028743\
01542452515313445247306884637622948086601893246883986747935`100.*^-6*x^12 - 
     1.4882631761907561915018699258745803229339708755385370488759619710457624\
8933263010085974561029156594803717281972883148122249515579`100.*^-7*x^14 - 
     9.8844264506675003269901753052254288602790255170006423640978569413309735\
64615629621709297089472583795025619979695461454811403082`100.*^-9*x^16 - 
     7.0780049135156487307062151548868591507507772390921951550601170626013409\
6967524519224323110538956353716004651274952465793476732`100.*^-10*x^18 - 
     5.3605433819615464191734127450555905106775733753164957328288925130674842\
096329116523939312910727042644143448326505384331740905`100.*^-11*x^20 - 
     4.2397210398630074833972414984145914910691714217024807917161085442053137\
13986552192724392325383798742449080127598148387144936`100.*^-12*x^22 - 
     3.4711187364241144704768128669600617307858602771952402617234516083513471\
0265604734011852005760525055506386190369485916338824`100.*^-13*x^24 - 
     2.9230621094534240397446820018194212495259446403505315963698715196066284\
93286393590550927528937319771348919779112716988073`100.*^-14*x^26 - 
     2.5198622225315832767930817290170038602285774573059593733131003463227816\
88889326530853377989113925431531894813690711055692`100.*^-15*x^28 - 
     2.2156549594582222323833490592248574248114079053893977964499940231220612\
71208309616929078524441345812040779728303724119836787783625398684539`100.*^-16\
*x^30 - 1.9814064379169630793384711039826299576757087508595452569801162790120\
4653134775459415540928286917018377536321899434733301313549066653734497`100.*^\
-17*x^32 - 1.7980480749828972300108493881476341681677096450550944540009579113\
844075830418279907868294799960155410255338751498660659903570356690154681`100.\
*^-18*x^34 - 1.65265759142431937169131870872880582537838280477928311938242003\
6365286400890702502570028375720382645880634742597824160811201766602554513`100.\
*^-19*x^36 - 1.53623896753504676165143501864087541129507723539157260725461160\
196896073751703575204166974080797774502632835786731502734438776711629576`100.\
*^-20*x^38 - 1.44238204350279763233298791045230791328039341778661204294168996\
65130338647774689556615297169119456860731407120145960505473846635221106`100.*^\
-21*x^40 - 25.968278283931623328195313133383168792713790971092431218001099433\
298017138135436037164173862510111250810618847691418678080207165031004377`100.*
      x^2*Log[x] - 0.31260482579297259373437485924818471273026867309057084044\
42001259337739693032364361857391416644197220420847005130180715377317411042212\
49`100.*x^4*Log[x] + 0.030080945282262304399884274898349846733673851138084721\
43212591193328437378112187746084379907432373458791651475781280686617795469212\
3565`100.*x^6*Log[x] + 0.0007677225014948422073688323735240229852986911201023\
14551449378051835532001114699894355340432181985603379578993345009696133392304\
781929`100.*x^8*Log[x] + 0.00003256802535573233907750574625759046260188741140\
34978253355260477293722474090024221826204389944627373045042439558067785284212\
71261104`100.*x^10*Log[x] + 1.75658128342663574769593398162953427445292391974\
73090505399819806254762559858462753953551483121237008340299890214787912346832\
8904`100.*^-6*x^12*Log[x] + 1.09266379508371230167012710025872699187223141311\
80984763630421820476240757801353850743941415669201786010701013122338704411860\
8388`100.*^-7*x^14*Log[x] + 7.47461396120524401892429590599205440792253950805\
18348169140120404481983691585202395661279236902467093601107664403769107392039\
79`100.*^-9*x^16*Log[x] + 5.4733178996082050646115202088882325097787031104767\
9462856610039374926203812707841367215657735647168126240013199570319900763706`\
100.*^-10*x^18*Log[x] + 4.218423709192789298082994720200654628293686233104577\
2921500591782257696444721403762681216697384243376745674326457892846715001`100.\
*^-11*x^20*Log[x] + 3.3837523821090236168933578535789638881680541617705485401\
60924011620036283771527592077761439288342168270275523180933050514669`100.*^-12\
*x^22*Log[x] + 2.802628804392081042138284710607547981851244589967766798419509\
32029462958431397652185524235117443835413725479447172586994217`100.*^-13*x^24*
      Log[x] + 2.383142408822852433153484991250964150721881979399095959751400\
4972741497385205188923606622518295206812413198808408949692811`100.*^-14*x^26*
      Log[x] + 2.071433542358528373970032147546286571430118885546754089997258\
008312493783700188982839709446491511042195085927769393888591`100.*^-15*x^28*
      Log[x] + 1.834333189260918660057534456676013124223789567328152004568933\
04557135907127742691614643362100381120583265942597469172864426334963246643704\
9`100.*^-16*x^30*Log[x] + 1.6505527412733918318485520698429380534756802418561\
52502505141408194852040955334420150358454429155059186795323547419236230903192\
45033457703`100.*^-17*x^32*Log[x] + 1.505943841687769987855944598516727867725\
00331156732790976752230337321966609789264816664991185026906992688783257175105\
57273254653282783683`100.*^-18*x^34*Log[x] + 1.390819544952132324175145414446\
57413800355830235355803233474963766434342970229239796007414810480072055502948\
6578850044858922241225043201`100.*^-19*x^36*Log[x] + 
     1.2983755252800712044028675427312088360567294114060477513841258161259517\
2022700943766346394733531225372736939601805944027702557305915073`100.*^-20*
      x^38*Log[x] + 1.2237252559547090517289001198348249652336192775096277062\
23719668235572040539085432244349855941556997520722695964819376374813620723082\
6`100.*^-21*x^40*Log[x] + 12.`100.*x^2*Log[x]^2 - 0.5`100.*x^4*Log[x]^2 - 
     2.`100.*x^2*Log[x]^3
 
 
f8bAsyN = -3.8433003667574465515695409166563459279428082839367325522011124480\
18337068534933770250147783643212685985335492814501928673147695676836024`100. \
+ 21.404113806319188570799476323022899981529972584680997763584543110683676411\
572626180372911747218670516292398315590756454988270774997107269`100.*x^2 + 
     4.1020690865446038942751791040470866854547802752074115030209017464676135\
60040343707002846452773744793547183933487969731965129188914261209`100.*x^4 - 
     6.3915609459717104749322859793791332963932785026953288605024195547006861\
56478585694079156827770674365918129964514846243309874883327547872`100.*x^6 + 
     8.9747729218162988362909131169434016850782344418925997086328028336303355\
72060085238158216453164649346459931664811438877924058240040702555`100.*x^8 + 
     47.393519356655258558916546634130651245263852952339042067231251441738121\
010955020726803965988621644632066458110347480038557330497134557736`100.*
      x^10 + 271.304598442527773485350039486163860935301629444545557408391568\
279555921055224708954507537989678627993156276208054858971148111250631849064`1\
00.*x^12 + 1640.6440896124662869208588534826534674357204367397214153443583923\
4404521053923150351944101369383894222195540000764634373385998022718644868`100.\
*x^14 + 10365.471656291683744449786094071235364875424672591753609085790351464\
924257951350310123995993437743193700417491901742369`100.*x^16 + 
     67865.226264467876661910289799387177065748976635286360964409289408494504\
5576482795503903558899210001391628826374655857025`100.*x^18 + 
     457606.89828511517028751304972859108591706187923303528627527427537384541\
50047333650199858978009238262877066460100053862878`100.*x^20 + 
     3.1625731528992755620288899291194939181725019318545878729268082268696215\
995180238589290649890400340776592422404096993912329`100.*^6*x^22 + 
     2.2318160856498917058547074141559261837365999079461258838810859012737596\
867068648457516302960271729774606077249607735247825`100.*^7*x^24 + 
     1.6034257675484727054692503499055009187801291899991274540703997133967882\
87666684234954850765592847927726845765550235355842774`100.*^8*x^26 + 
     1.1699508897238393115128059331292740937782134061205867507686331110110532\
17248431064989328071641324623516116397032154253303542`100.*^9*x^28 + 
     8.6529338414985216725946144953666915148324540854486918390969778153165552\
703209738961171966367120771866025937505875441232022206`100.*^9*x^30 + 
     6.4764053478458821117348140569616568990444507663756249919269134554270526\
1075402838585506856937027135510806330571857826697188656`100.*^10*x^32 + 
     4.8988528464709278622584996450897257538342016809867139764285378043388077\
72709151798107584761908830435807083499867807167206029144`100.*^11*x^34 + 
     3.7406930574686413253277954918041514259215310110491059874541950933288281\
38817468052054409969707385350371513764579354974715388267`100.*^12*x^36 + 
     2.8806401895127304244856022832675514900659075425037336832243087388376106\
067093467347829443179633952622261823727216630385613495313`100.*^13*x^38 + 
     2.2353599203403567091634943353196381201023601811286770290817602430592110\
65297707799759519552797214540615974865523533271354539607116`100.*^14*x^40 + 
     1.7467026775207988488952264835111497791625122302439872302499072532650353\
909003655936952878339756286395009306282579938260881593708348`100.*^15*x^42 + 
     1.3735229377938834882433300490615895530032451073915805740353475956946500\
9288769726416055534687935583026072363623675347609168631411398`100.*^16*x^44 + 
     1.0863368159674357093832363747861936552263542581779018771551046522339070\
29336932766894508895449973985476363420235578754134810295763853`100.*^17*
      x^46 + 8.63772632060225426260599989722941886278587752159765455062489525\
3968111511420679819170338927416973074813446686711209085270323440839309`100.*^\
17*x^48 + 6.90175439396030915559975792409842540968774365835756249814676950488\
70441056891105863090650649935167265911113736934347403171796519653279`100.*^18*
      x^50 + 5.53966999741202165710564496189343505774730556403949067106257313\
027159692776041130884146474583368603390460355830262848174310198545490045`100.\
*^19*x^52 + 4.465080968686435828393724952316330105498909266802582906247467176\
000649747110583270620405276499125972996647021648057879073509419670972394`100.\
*^20*x^54 + 3.612997114647032493215912465722551385970347336113356768954303763\
1070522353875936249833861229019553575605191564792506662850605038292238153`100.\
*^21*x^56 + 2.934158264346389037096888101336395387248877762185749857404812766\
29868614185379915912248168121821875005652582720303206039922159929319401237`10\
0.*^22*x^58 + 2.3909651390923219367004547660748538539699888796474715335639324\
8813878480462847115824440720760189515754150872595791297084`100.*^23*x^60 + 
     1.9545319809373926185681373738661868198266010728404751571449566621441682\
38035292133371850139904975638856915244403501272976`100.*^24*x^62 + 
     1.6025325828108300797038268199779039310287780017468292321211738330765567\
513170952212292898464788394538583533200728774060092`100.*^25*x^64 - 
     42.869604401089358618834490999876151135313699407240790626413349376220044\
822419205243001773403718552231824025913774023144077772348122032336`100.*x^2*
      Log[x] - 30.51079119782128276233101800024769772937260118551841874717330\
1247559910355161589513996453192562895536351948172451953711844455303755935329`\
100.*x^4*Log[x] - 14.5`100.*x^6*Log[x] + 33.634293073202818379673612665923573\
47854886311011141042514676292398693560118189812467730708897798005761082214931\
0805531133300755398860681`100.*x^8*Log[x] + 170.81217229281127351869445066369\
42939141954524404456417005870516959477424047275924987092283559119202304432885\
97243222124533203021595442722`100.*x^10*Log[x] + 937.041568390853549213798640\
65254789609242839909211679807778849555575177642245606436886883469058162109460\
5620836905305091532714352578352929`100.*x^12*Log[x] + 
     5485.0883622982465611089396411630428260953399360260143577017278172274424\
004812764724971699207486807477234549418422961205`100.*x^14*Log[x] + 
     33795.825057843762648658396169785949932533488106430511769935439326863620\
4686404243070361548744785193386419556959604623673`100.*x^16*Log[x] + 
     216935.91040087459232190469811074137049436256757735601965330178376077414\
82091371249196772772475415003509178639634435581465`100.*x^18*Log[x] + 
     1.4396577534417551678022797879213232136287066793514929079681222785884952\
932281310858613527605950020064427085432704857208107`100.*^6*x^20*Log[x] + 
     9.8204457963949312922451724526200130080377298006340401940510353281665964\
279367270256014686248671102689762641260637033294461`100.*^6*x^22*Log[x] + 
     6.8551195825245007360508088689316380809249471211855934713320009068801756\
4049992759137435826874911649581722021724767198166383`100.*^7*x^24*Log[x] + 
     4.8797892524180958004335975629903881202662985803167560681918300660972234\
02212200934050915454594996303310359732987518019998145`100.*^8*x^26*Log[x] + 
     3.5325697014029610260893884348906012316592889700046247424124564913216508\
176353289224296605467699577404058795857096853184634872`100.*^9*x^28*Log[x] + 
     2.5948870076956988874954058837605432013024189415433389760244605131765706\
1580738568447904956223496096887899400003465102443262138`100.*^10*x^30*
      Log[x] + 1.930615846683242385603538892836063549330415353624871730349818\
934508909491372364911900611263556462982834957166585236314794793436`100.*^11*
      x^32*Log[x] + 1.4526855527007716416723330604760576104697506310888668849\
808204962476997778705981146897645311428949660624961485293051397691535373`100.\
*^12*x^34*Log[x] + 1.10408285646117230054818399068836788911279249145256142833\
693059363443750553187824552188579205937412564368280959576101822950985541`100.\
*^13*x^36*Log[x] + 8.46695349369654901699587022581323729335168462987285679204\
621765780267614475472441424965345118680711674276228767241350927716211392`100.\
*^13*x^38*Log[x] + 6.54572467416906350249661702024818607285546089994362120495\
8122195176968997568887399584292026815225868352127918935224350461270719295`100.\
*^14*x^40*Log[x] + 5.09751486477389524045023819344777636719947062532681331256\
59871237894583845143686591990418296909137014381684250421999051032541230966`10\
0.*^15*x^42*Log[x] + 3.996135345689564471168035770901128160033189464274089757\
95014659796553856579305931065795089218596314485344070357247282565166200511403`\
100.*^16*x^44*Log[x] + 3.1517459866681466734835375827992043388380796030512021\
16178407390841193747854086974184785353541425385174465611935984442638306156920\
604`100.*^17*x^46*Log[x] + 2.499605196949730010649366271921664725869946636053\
43368087997258939670968519574388129220431248893177944080954485890791575904847\
25494725`100.*^18*x^48*Log[x] + 1.9925403226647977365750412342240535455943961\
23404310262543531484882104836030192190755199384708263547986525522340441448408\
32250213949447`100.*^19*x^50*Log[x] + 1.5958313434399865001789736749522453500\
99933412005055297584975321393935938936898343105697761422977208615040914807712\
910042653791671277274`100.*^20*x^52*Log[x] + 1.283685959824700724610300115998\
71928062841188871848081816070739644509496241584682947864878009523201786486146\
20737838883639261089818982676`100.*^21*x^54*Log[x] + 
     1.0367800448432721357256902603720289007716392394272599953017309643762527\
9574312877724905291461039440480714678680696053252992415598411933437`100.*^22*
      x^56*Log[x] + 8.4052128055856040285975878451818942835964623946286303362\
161613963662875919078520450762952108250616050913317337670274917`100.*^22*x^58*
      Log[x] + 6.838100324274811149360943629576866634549516031915053175684138\
37433012069439133796971258386542126491840305285718927056105`100.*^23*x^60*
      Log[x] + 5.581461835587427628497582508645459647749047866766820359177281\
610086685373131203889797163839514691809364419851899204452052`100.*^24*x^62*
      Log[x] + 4.569793357480652693894399657776065270667446987163681723369108\
184326086174392429300824628065563921039162882969480060671016`100.*^25*x^64*
      Log[x] + 12.`100.*x^2*Log[x]^2 + 58.5`100.*x^4*Log[x]^2 + 
     12.`100.*x^6*Log[x]^2 + 46.`100.*x^8*Log[x]^2 + 
     214.`100.*x^10*Log[x]^2 + 1109.2`100.*x^12*Log[x]^2 + 
     6233.6`100.*x^14*Log[x]^2 + 37262.17142857142857142857142857142857142857\
14285714285714285714285714285714285714285714285714285714285714285714285714286`\
100.*x^16*Log[x]^2 + 233698.6571428571428571428571428571428571428571428571428\
571428571428571428571428571428571428571428571428571428571428571429`100.*x^18*
      Log[x]^2 + 1.5227933904761904761904761904761904761904761904761904761904\
761904761904761904761904761904761904761904761904761904761904762`100.*^6*x^20*
      Log[x]^2 + 1.0235410304761904761904761904761904761904761904761904761904\
7619047619047619047619047619047619047619047619047619047619047619`100.*^7*x^22*
      Log[x]^2 + 7.0585695837229437229437229437229437229437229437229437229437\
2294372294372294372294372294372294372294372294372294372294372294`100.*^7*x^24*
      Log[x]^2 + 4.9738351562077922077922077922077922077922077922077922077922\
07792207792207792207792207792207792207792207792207792207792207792`100.*^8*
      x^26*Log[x]^2 + 3.56974608743176823176823176823176823176823176823176823\
17682317682317682317682317682317682317682317682317682317682317682317682`100.*^\
9*x^28*Log[x]^2 + 2.602848619158321678321678321678321678321678321678321678321\
67832167832167832167832167832167832167832167832167832167832167832168`100.*^10*
      x^30*Log[x]^2 + 1.92412881080627372627372627372627372627372627372627372\
6273726273726273726273726273726273726273726273726273726273726273726273726`100.\
*^11*x^32*Log[x]^2 + 1.439671280222675624375624375624375624375624375624375624\
3756243756243756243756243756243756243756243756243756243756243756243756244`100.\
*^12*x^34*Log[x]^2 + 1.088760217346059203149791385085502732561556090967855673\
7380266792031497913850855027325615560909678556737380266792031497913850855`100.\
*^13*x^36*Log[x]^2 + 8.312563207583002705921529450941215647098000039176509764\
74505886270592152945094121564709800003917650976474505886270592152945094121`10\
0.*^13*x^38*Log[x]^2 + 6.4009407558603725860661526296201218801837996884436512\
91948505570796592468419093806090710115477917335502474821360270276678945409596`\
100.*^14*x^40*Log[x]^2 + 4.96699851836151497146279932657641635969809344422347\
51832275052089293575361686816795175928302863287383411222420510346206940634185\
216`100.*^15*x^42*Log[x]^2 + 3.8812540685773752173104295085719234326045471556\
30746962016311861513099903192782449748394020839841273277805785545723626218982\
25613396`100.*^16*x^44*Log[x]^2 + 3.05215402796612473795048913934362850771519\
50216965696841857832569906873312446067864024520371269597275789226253622538452\
25981448891666`100.*^17*x^46*Log[x]^2 + 2.41412940495816701510601868181623195\
75699573007420631596159931063686616250891388864198125202298038480566411647310\
826204351577887720033`100.*^18*x^48*Log[x]^2 + 1.9196715461292479384284335613\
23586899034469366950185364507615147001336259648280108638164904149558881016681\
52819047959712921349749994251`100.*^19*x^50*Log[x]^2 + 
     1.5339906656102289555081204109660698703638534032934355992641091577691389\
24072293300991645317934185884111849921514748543958397236092753659`100.*^20*
      x^52*Log[x]^2 + 1.23136237762121214905890517003255191436642506773076163\
30365017940734726304789570370402245486375248119762859297116936099302501240850\
951445`100.*^21*x^54*Log[x]^2 + 9.9259521988048355366972728926167235495543477\
77527209483058184094662759355180946243000355263109334989803424316817774887501\
6340354878516139`100.*^21*x^56*Log[x]^2 + 8.032535628786465951557265400358992\
49790756050010323802220423569191909479969784183002651167949323824946385183294\
59236715`100.*^22*x^58*Log[x]^2 + 6.52396422867162090499737088088020911206841\
46152835956540915207092954132746929846831908185132501766754299930436320445650\
2`100.*^23*x^60*Log[x]^2 + 5.316730157742809628305859153362879494674278396968\
135690105974313715644288747829856532471169425138261153689971788662381446`100.\
*^24*x^62*Log[x]^2 + 4.346678403733267472404110647571089426914335792164929129\
4539578217573435484304278410171633538977131736828987973714222394536`100.*^25*
      x^64*Log[x]^2 - 2.`100.*x^2*Log[x]^3 - 28.`100.*x^4*Log[x]^3 + 
     8.`100.*x^6*Log[x]^3 + 24.`100.*x^8*Log[x]^3 + 96.`100.*x^10*Log[x]^3 + 
     456.`100.*x^12*Log[x]^3 + 2424.`100.*x^14*Log[x]^3 + 
     13944.`100.*x^16*Log[x]^3 + 85032.`100.*x^18*Log[x]^3 + 
     542328.`100.*x^20*Log[x]^3 + 3.584184`100.*^6*x^22*Log[x]^3 + 
     2.438196`100.*^7*x^24*Log[x]^3 + 1.6988112`100.*^8*x^26*Log[x]^3 + 
     1.20775356`100.*^9*x^28*Log[x]^3 + 8.73549396`100.*^9*x^30*Log[x]^3 + 
     6.4128917448`100.*^10*x^32*Log[x]^3 + 4.76929446624`100.*^11*x^34*
      Log[x]^3 + 3.587673240504`100.*^12*x^36*Log[x]^3 + 
     2.7262740840312`100.*^13*x^38*Log[x]^3 + 2.09051592806568`100.*^14*x^40*
      Log[x]^3 + 1.616091560443488`100.*^15*x^42*Log[x]^3 + 
     1.2585370287605112`100.*^16*x^44*Log[x]^3 + 9.8664245751919752`100.*^16*
      x^46*Log[x]^3 + 7.78202160813653256`100.*^17*x^48*Log[x]^3 + 
     6.172217813707481304`100.*^18*x^50*Log[x]^3 + 
     4.920515860823828532`100.*^19*x^52*Log[x]^3 + 
     3.94119433858344106824`100.*^20*x^54*Log[x]^3 + 
     3.170586029976833392824`100.*^21*x^56*Log[x]^3 + 
     2.5609964441305289501472`100.*^22*x^58*Log[x]^3 + 
     2.07641286005373120870888`100.*^23*x^60*Log[x]^3 + 
     1.689443496884435768035128`100.*^24*x^62*Log[x]^3 + 
     1.3791120140972900606773752`100.*^25*x^64*Log[x]^3 + 
     9.8696044010893586188344909998761511353136994072407906264133493762200448\
22419205243001773403718552231824025913774023144077772348122032336`100.*x^6*
      (1.`100. + 2.`100.*Log[x])
 
 
f10aAsyN = -3.027009493987652019786374701758957286150741786417375620053670876\
027739313134860024807700482154237821720880113425939011667601520489556284`100. \
- 1.8787030962832836156248282778207715223973920661332138996478872143633743527\
90150166557415331881307586245972687688210231271229160300072313`100.*x^2 - 
     0.5539687846855071635856909569276275684861745482230159805793712935495262\
20994258261360287641072571690534915423622256501921582270550474298`100.*x^4 - 
     0.2301165183859894064783441282663050409740456084440747471302405735327159\
34531855748921001448208746646730768376026713163570925051136574755`100.*x^6 - 
     0.1168726073595103399548220580625955788043258036143421215451143551743617\
70433252837372157689853547443472172899689581378830177866087742053`100.*x^8 - 
     0.0675727103421320392094973803631624720052894204000759701505489759493354\
20766934505683455800715431824304601753109103526257671021442271183`100.*x^10 - 
     0.0427122214547844812242475639942242891204291386686190553315114503460158\
99788694519791014276550630427908967457752530590142344311851607861`100.*x^12 - 
     0.0287993540925285154165543234840255152458927061750223667536304514818773\
61642663982333750766142521240184517284709257649427710512480860249`100.*x^14 - 
     0.0203888770509498070591076274033401232745075574264230972713653172867882\
13538276474693256005065010999803180565993468622861318057705527117`100.*x^16 - 
     0.0149946218278940527249314186290544281401703370488137199878144070242197\
46300484842676823316501884089420854878968759692119094326627268391`100.*x^18 - 
     0.0113691931581792189206849419498646713329570392607380798271441911920182\
55139179503183237322676599024910027561483261977359386434574845265`100.*x^20 - 
     0.0088385224305540136237235926614546006839632152658477824695602697920267\
45035797977162674698443648558237396667589936791637101926661188756`100.*x^22 - 
     0.0070159053693339091203723634325502762450426637031199397974208604288191\
71807880970639826390186249241094400186582128604899526710337821915`100.*x^24 - 
     0.0056683076917611438250982605284796877230957516055806670881368966635030\
22229935542788642919169475181701324962516441790677104661229067455`100.*x^26 - 
     0.0046493974251240633868045370793578006817318844055267984244372959856575\
97538712888340283987634158800220772345175112161861156902676327842`100.*x^28 - 
     0.0038640182221505727235085812392339536762075707409222775510591947844241\
71453553841817301932996659942183551949428295298324466473459547921`100.*x^30 - 
     0.0032484047925287209971462728725923831342837488975556600607972495492692\
99366000287857668398735146117420445878538823580623341667181361817`100.*x^32 - 
     0.0027586972419367075607062300344464866127007856592724110077272384505640\
55360263552868949081850929929958453597036194613161308627579158872`100.*x^34 - 
     0.0023640287052417297222857508755513615276016517628311267948146864815450\
03249813095144617657567451956427359004719972394352805710487722059`100.*x^36 - 
     0.0020422321684209583640969696873600219001649897210791671042596912174597\
93287795876599030144390295889828363712696380314914949654337588081`100.*x^38 + 
     3.7418535823719237988598565333247808288483092264939719065277841079619679\
21058162215168568336250371338581372514383906940560535385594985612`100.*x^2*
      Log[x] + 1.652229204082448196297115696286482770789288949792271373485992\
116947870945180699325677153738957395530311728607448462506049133563349603424`1\
00.*x^4*Log[x] + 0.9302131343793297442871974699498443759477338198075670283486\
31809654234104780444684418637116711838439920874931005571612522622021737710708`\
100.*x^6*Log[x] + 0.600257345247231663634041989841022799851172211307935341561\
85597116480269217430333124991557372187996932226515911840002047212558390533436\
3`100.*x^8*Log[x] + 0.4218632472379723043199864962829017588316547368800179136\
99763688970229065569287259534557091535634725558632188540276651090951705895585\
018`100.*x^10*Log[x] + 0.3141447368543458171732471511728826631337215584575969\
95775345665534152539053804401677994305876822322666498829929213097815752129154\
621716`100.*x^12*Log[x] + 0.2438700542431413445607582994753850738953778949835\
65222840904340332979058300630126145659470294255870078173973700699552219480663\
159835183`100.*x^14*Log[x] + 0.1953378253576481357320478601124823540064165911\
87488175619413268982052139119426691670787654309504704091528834307410546778183\
871632874759`100.*x^16*Log[x] + 0.1603289486117302351231520900248685126598577\
41628495297281598998217560445101290652947311458224565657693647167046534041006\
509353999814106`100.*x^18*Log[x] + 0.1341919972967074812020666350216927701419\
21116737557508003430379105826602673100782548033646588224440656193660993946330\
374010619200170585`100.*x^20*Log[x] + 0.1141283669494773893038639538615794045\
86874667953181870832516423129414029308373332600749232174357800797473302600934\
638961800064404228986`100.*x^22*Log[x] + 0.0983691272807883756654325752500713\
57132289787477184627702419810765313777224987806202687270771354048099386031648\
646945795046566861035241`100.*x^24*Log[x] + 0.0857499162837474027272356870784\
78840393121490351735777516960975684297550108133641697493090680398885300971276\
572701875695883300609963466`100.*x^26*Log[x] + 0.0754778701179965721944672360\
52560178903036659754202831289910210561339596622799266096206470929801450725307\
578823671844394559143759716043`100.*x^28*Log[x] + 0.0669973161852436547897203\
85907459770314670771859035415611115411049729794104572932321703116312294430238\
342107298135069768696412569569212`100.*x^30*Log[x] + 
     0.0599090509446079401975448940791043440809038525679276932329617801027598\
63836545193749507150100082824137027359571559283876449852732829845`100.*x^32*
      Log[x] + 0.053920041898360246495723179305478974059441556660762510949196\
27680180694926353845567175508529938265898918696637006890077334208871555916`10\
0.*x^34*Log[x] + 0.0488110920340469316643452338124714049578097403041187780765\
99484216492629785227362083031477269577233482019950862353977194718564146824208`\
100.*x^36*Log[x] + 0.04441547574021526137855385665504036003798712715019786361\
00243669868490049003314654390715435502106899122227616669941403075485227704126\
67`100.*x^38*Log[x]
 
 
f10bAsyN = 10.459311120090980286946440058692203652914170609799174013802557978\
383391083278785080789464149481111300576167388495691864040679749426051061`100. \
- 9.0613767884509814772355383538303511722537542378787950992442631548526919992\
73952882255949909281211199239229282592980719546487324987139431`100.*x^2 - 
     1.4765808397433017890356839063459125761394475352843969824523222253686801\
46774226617289726197528549868944400475071689807605456873910949143`100.*x^4 + 
     5.5732215641433058211526650052897591727035508730450941456671690995333465\
23967913276299619997176230233941448047112563297843719889680541062`100.*x^6 + 
     34.159411041742802009669292461995558053234472245314272160574213887901029\
748925871593242836157090449214706890409485263942259424475423949206`100.*x^8 + 
     191.75877308224990442448013627160490937152299177463693199147098729200094\
6100523160413674093942679626545353338146082780819542971622981212813`100.*
      x^10 + 1128.58380017895596103693172021744702226983875139631848027862441\
300496311158253708488201240565768540280605460306114558030839367399282151`100.*
      x^12 + 6970.15175066346029568666969266410689149810246151067081912738265\
05361770317680934715284128912950089759596849974065728224`100.*x^14 + 
     44802.275681295211971572514274189050520556896307969291099540785046134842\
6438535342706696927264268776214343662910378488537`100.*x^16 + 
     297569.64144738042302217552162568188031623622250602936608881591929387266\
56459399353026300049403674508371070766811868392969`100.*x^18 + 
     2.0308703333785354737493187780908324972612058555712418644392473673422094\
378975403495251805054645024453637636542320847226389`100.*^6*x^20 + 
     1.4180734800203648411298277490699828412262136122291675330430243952105418\
4842352647597436049182922165824587184613307079219789`100.*^7*x^22 + 
     1.0096230992072702623171418834987209427691816424052310796770334988967019\
50114805457295912683214293244613454354500210423426349`100.*^8*x^24 + 
     7.3094517216211284126042021533313547299765089234113176351212680955274604\
3729484386400252790282530926820446961653532498000355`100.*^8*x^26 + 
     5.3693588145485173124219227929286232775875555419468528771241102495207320\
63719506284872879830241129570897582832177285723181234`100.*^9*x^28 + 
     3.9947745534846369584921661107106535534220288349068237968317200889904730\
3636511944161983685082566386708657425419573236852074448`100.*^10*x^30 + 
     3.0057211775923620871639027044218429894053237085712851946848181624605958\
44576707412908299785715010196303898054152822386294596107`100.*^11*x^32 + 
     2.2842916653902030705907780715303881764261694758962257692735878412183953\
831330702131454547970650684817679179290529635219563682577`100.*^12*x^34 + 
     1.7516395467099267664618427422028680874093609862663314930545214880631942\
2332211323324961549503392864432327365042027060391905537514`100.*^13*x^36 + 
     1.3540657178630951097126856932587661880867635372617708364104333133637751\
41403307885139158625114279797901712515509131955922016779914`100.*^14*x^38 + 
     25.159472534785811491779321333168201513751599209654387501884465834960059\
76322560699066903120495806964243203455169869752543702979749604311`100.*x^2*
      Log[x] + 18.81894506957162298355864266633640302750319841930877500376893\
1669920119526451213981338062409916139284864069103397395050874059594992086233`\
100.*x^4*Log[x] + 35.04856169590919998804449755475741842757717395777398403688\
60293134180666333682115660114286017417810495326114443214824840567551323419861\
62`100.*x^6*Log[x] + 135.2807272232396505351358079973578908866922540211368666\
96818120026027622878276378517371165945995780945579219493845827073659143426603\
356489`100.*x^8*Log[x] + 683.742290604999437993460054255487242480983266493602\
03387757833702679604597037359326829341257566131479264873915000182247208691729\
0482118827`100.*x^10*Log[x] + 3843.253371199022732502425913388973914049946923\
39862522389691237061588896435242403717112762115438711627584982871367636597527\
7815031101371658`100.*x^12*Log[x] + 23028.36682102141337275501921556653292377\
10908934586251053899535204189592750795943759260765157295961163547667213925455\
134`100.*x^14*Log[x] + 144683.11479661430658260150270290391325972557881274317\
94792556052371888747747664060826994037185112203081120691287552151891`100.*
      x^16*Log[x] + 943822.65803627912617199722713778894029218514379366242139\
89961109788646243738938016550062866757409707184079224013017708262`100.*x^18*
      Log[x] + 6.348279389379221492906803867886425205433188731061738448792902\
2903404183852107368277588040669670364730617731888573218110178`100.*^6*x^20*
      Log[x] + 4.379757831080906175970209323507318462553672195073241191565228\
89773548399280984042342027699226790167241064100618266149216159`100.*^7*x^22*
      Log[x] + 3.086960835847834320010948010390150213625960995817570922868222\
963651377043897603159350673228831498183335308596050075349542267`100.*^8*x^24*
      Log[x] + 2.215815308304257698048297355333271771123810397876119999886169\
5958498593367951744822153807152442475384636589234569739404376475`100.*^9*x^26*
      Log[x] + 1.615729406874218482695892470712718964141586759402196123994823\
41087219707202198066895435454992435176218151957669372494181484524`100.*^10*
      x^28*Log[x] + 1.1944150787121064503337829901223411072129233606986560252\
51053308436720397561882493061496070522714756946854182522236898718566332`100.*^\
11*x^30*Log[x] + 8.9365746429402323892673071841453109355738060230642407324553\
96802351981122227086820879393686307898434257802254620299756109210099`100.*^11*
      x^32*Log[x] + 6.7579769379368157848203065750581696525694943111552667285\
594410601147870168357880451084802549500968596150549237623404408173234995`100.\
*^12*x^34*Log[x] + 5.15928604617868178506509517356440092330570417682112604586\
296903415226160702422824404764295245240063318219740718363599090729046349`100.\
*^13*x^36*Log[x] + 3.97250488744494000113197830845552338866141493614666686614\
2338410335878700709398660820936050150741936612286189262563873009847915682`100.\
*^14*x^38*Log[x] - 12.`100.*x^2*Log[x]^2 - 1.`100.*x^4*Log[x]^2 + 
     30.666666666666666666666666666666666666666666666666666666666666666666666\
666666666666666666666666666666666666666666666666666666666666666667`100.*x^6*
      Log[x]^2 + 163.08333333333333333333333333333333333333333333333333333333\
33333333333333333333333333333333333333333333333333333333333333333333333333333\
33`100.*x^8*Log[x]^2 + 824.18666666666666666666666666666666666666666666666666\
66666666666666666666666666666666666666666666666666666666666666666666666666666\
66666667`100.*x^10*Log[x]^2 + 4455.888888888888888888888888888888888888888888\
8888888888888888888888888888888888888888888888888888888888888888888888889`100.\
*x^12*Log[x]^2 + 25791.355102040816326530612244897959183673469387755102040816\
3265306122448979591836734693877551020408163265306122448979592`100.*x^14*
      Log[x]^2 + 157743.95178571428571428571428571428571428571428571428571428\
57142857142857142857142857142857142857142857142857142857142857`100.*x^16*
      Log[x]^2 + 1.0077309216931216931216931216931216931216931216931216931216\
931216931216931216931216931216931216931216931216931216931216931`100.*^6*x^18*
      Log[x]^2 + 6.6664270473015873015873015873015873015873015873015873015873\
015873015873015873015873015873015873015873015873015873015873016`100.*^6*x^20*
      Log[x]^2 + 4.5375716684953430407975862521317066771612226157680703135248\
5897940443394988849534304079758625213170667716122261576807031353`100.*^7*x^22*
      Log[x]^2 + 3.1626343427101972101972101972101972101972101972101972101972\
10197210197210197210197210197210197210197210197210197210197210197`100.*^8*
      x^24*Log[x]^2 + 2.24887711749811385196000580615965231349846734462119077\
50369288830827292365753904215442676981138519600058061596523134984673446`100.*^\
9*x^26*Log[x]^2 + 1.626731380414843410557696271981986267700553414839129124843\
41055769627198198626770055341483912912484341055769627198198626770055`100.*^10*
      x^28*Log[x]^2 + 1.19424976456100052540052540052540052540052540052540052\
5400525400525400525400525400525400525400525400525400525400525400525400525`100.\
*^11*x^30*Log[x]^2 + 8.881566213933782450188700188700188700188700188700188700\
1887001887001887001887001887001887001887001887001887001887001887001887`100.*^\
11*x^32*Log[x]^2 + 6.68082324363682868507885808923871207608231829685116882348\
71625875086082698539445944290234947674394041176048096463321376816186505`100.*^\
12*x^34*Log[x]^2 + 5.07644891815045332750401377852358244515107260205299420985\
695495499417068044519024911181773926871966087652362162166083734711185692`100.\
*^13*x^36*Log[x]^2 + 3.892351049656839276980637091440415540138531828282520803\
296426565124626066454321301966731329612216038808836592770110775650941855928`1\
00.*^14*x^38*Log[x]^2 + 5.333333333333333333333333333333333333333333333333333\
33333333333333333333333333333333333333333333333333333333333333333333333333333\
3333333`100.*x^2*Log[x]^3 + 10.6666666666666666666666666666666666666666666666\
66666666666666666666666666666666666666666666666666666666666666666666666666666\
666666666667`100.*x^4*Log[x]^3 + 25.77777777777777777777777777777777777777777\
77777777777777777777777777777777777777777777777777777777777777777777777777777\
77777777777777777`100.*x^6*Log[x]^3 + 85.333333333333333333333333333333333333\
33333333333333333333333333333333333333333333333333333333333333333333333333333\
3333333333333333333333`100.*x^8*Log[x]^3 + 361.066666666666666666666666666666\
66666666666666666666666666666666666666666666666666666666666666666666666666666\
6666666666666666666666666667`100.*x^10*Log[x]^3 + 1791.5555555555555555555555\
55555555555555555555555555555555555555555555555555555555555555555555555555555\
555555555555555555555555555555555556`100.*x^12*Log[x]^3 + 
     9856.7619047619047619047619047619047619047619047619047619047619047619047\
619047619047619047619047619047619047619047619048`100.*x^14*Log[x]^3 + 
     58250.666666666666666666666666666666666666666666666666666666666666666666\
6666666666666666666666666666666666666666666666667`100.*x^16*Log[x]^3 + 
     362888.59259259259259259259259259259259259259259259259259259259259259259\
25925925925925925925925925925925925925925925925926`100.*x^18*Log[x]^3 + 
     2.3546621333333333333333333333333333333333333333333333333333333333333333\
333333333333333333333333333333333333333333333333333`100.*^6*x^20*Log[x]^3 + 
     1.5782976484848484848484848484848484848484848484848484848484848484848484\
8484848484848484848484848484848484848484848484848485`100.*^7*x^22*Log[x]^3 + 
     1.0863749844444444444444444444444444444444444444444444444444444444444444\
44444444444444444444444444444444444444444444444444444`100.*^8*x^24*Log[x]^3 + 
     7.6450483241025641025641025641025641025641025641025641025641025641025641\
02564102564102564102564102564102564102564102564102564`100.*^8*x^26*Log[x]^3 + 
     5.4817134415238095238095238095238095238095238095238095238095238095238095\
238095238095238095238095238095238095238095238095238095`100.*^9*x^28*
      Log[x]^3 + 3.9942115205155555555555555555555555555555555555555555555555\
5555555555555555555555555555555555555555555555555555555555555555556`100.*^10*
      x^30*Log[x]^3 + 2.95120281861333333333333333333333333333333333333333333\
3333333333333333333333333333333333333333333333333333333333333333333333333`100.\
*^11*x^32*Log[x]^3 + 2.207335201992313725490196078431372549019607843137254901\
9607843137254901960784313725490196078431372549019607843137254901960784314`100.\
*^12*x^34*Log[x]^3 + 1.668857052933318518518518518518518518518518518518518518\
51851851851851851851851851851851851851851851851851851851851851851851851852`10\
0.*^13*x^36*Log[x]^3 + 1.2738988001497628070175438596491228070175438596491228\
07017543859649122807017543859649122807017543859649122807017543859649122807018`\
100.*^14*x^38*Log[x]^3
 
 
f9aAsyN = -1.0158608580341883359023434333084156036431045144537843909994502833\
50991430932281981417913068744944374594690576154290660959896417484497811`100. \
+ 3.3761964177772181171022734318364934518880470823057558931104066583267367576\
99794038697437257847458531743370933913489026348574435006008022`100.*x^2 - 
     0.6771008042988287656223958098746974521217114455150951400740333543222956\
61550539406030956523610736620340347450085503011922955290184036874`100.*x^4 - 
     0.0157941837100486473777795062091832630062977143740253950096060154326976\
462526540232770487854542589097000325837590321391262054810488516`100.*x^6 - 
     0.0007269277066726530930024101040238176437130569358873346508186418588342\
58994307337595255004271752616374208961553539437776305990362414406`100.*x^8 - 
     0.0000436964863618919318236374376327684769461995964067956338485276290035\
11701270016251038454771131060569331609268607802392093019092011143`100.*x^10 - 
     3.0308089586657901272874677561775075747383976724122080854348221968329196\
92725628974518701138357158900024925783965611197306201782408`100.*^-6*x^12 - 
     2.2983279944706416022247620264145127062445795570445453353994295880683334\
6959102760392051032689145655029510968266268015696396091233`100.*^-7*x^14 - 
     1.8523083907800793317492967959452181985904294449325978925376711875920580\
734371505870157572858330126471824554831650860091166272167`100.*^-8*x^16 - 
     1.5603125148268479527545915326587965933455363039468989590379256413778251\
92288772571295551314968290297316304184108294033534651755`100.*^-9*x^18 - 
     1.3591711733698658901448601533448132257091247961993225738852036838475662\
9516090743436724631645708073154924916482938042743523247`100.*^-10*x^20 - 
     1.2155204389237518514042831519647280491846171904812350951788171630679268\
42799773531282688340293667253263552779559762298634903`100.*^-11*x^22 - 
     1.1103290987348368061232995438098947772310993492322839739341587141122052\
07813449504675252646682176212452333054657090956630378`100.*^-12*x^24 - 
     1.0320703999858746073538253174796050556474816684718766526730962155678612\
852296690016626623897465252381405819209939813128054`100.*^-13*x^26 - 
     9.7342099663999117115106548914769676790092900149660451449195250505723777\
91607274626273560382040449885761731600134611908001`100.*^-15*x^28 - 
     9.2954492927754765636515901805283799868121359954660317838551519259337056\
6335643718733493466907852998453793558498702256451`100.*^-16*x^30 - 
     8.9714712534002623982714398069451167935740274637018524488230190673570751\
3946363236936685024431793501442056246804905101468947972109839714143`100.*^-17*
      x^32 - 8.73924973463319115207825617431871619621771434001425095171020250\
63598346375261578459063724146716995268065214036540384873305462909636461056`10\
0.*^-18*x^34 - 8.582370563437681261657842210812535379017448575097250297983781\
921004136899800031280713472312491240657937547046091920516849762547244422138`1\
00.*^-19*x^36 - 8.48895822848525311529098718184309252466264943198457014921211\
144180311889255870102195888454002265517952796579524510858157059602691016773`1\
00.*^-20*x^38 + 0.65609276131054110939843771112772293090459699036414373933369\
9811099339046045145345721391287503370416936872949230472892693402388343668126`\
100.*x^2*Log[x] + 0.333333333333333333333333333333333333333333333333333333333\
33333333333333333333333333333333333333333333333333333333333333333333333333333\
3`100.*x^4*Log[x] + 0.0100269817607541014666280916327832822445579503793615738\
10708637311094791260373959153614599691441244862638838252604268955392651564041\
189`100.*x^6*Log[x] + 0.00051181500099656147157922158234934865686579408006820\
97009662520345570213340764665962368936214546570689197193288966731307555948698\
54619`100.*x^8*Log[x] + 0.000032568025355732339077505746257590462601887411403\
49782533552604772937224740900242218262043899446273730450424395580677852842127\
1261104`100.*x^10*Log[x] + 2.342108377902180996927911975506045699270565226329\
74540071997597416730167464779503386047353108283160111203998536197172164624438\
5386`100.*^-6*x^12*Log[x] + 1.82110632513952050278354516709787831978705235519\
68307939384036367460401263002256417906569026115336310017835021870564507353101\
3979`100.*^-7*x^14*Log[x] + 1.49492279224104880378485918119841088158450790161\
03669633828024080896396738317040479132255847380493418720221532880753821478407\
957`100.*^-8*x^16*Log[x] + 1.277107509908581181742688048740587585615030725777\
91874666542342520816114222965162985683653471651005896122669746566407976844864\
9`100.*^-9*x^18*Log[x] + 1.12491298911807714615546525872017456754498299549455\
394457334911419353857185923743367149911193024649004655131537221047591240001`1\
00.*^-10*x^20*Log[x] + 1.0151257146327070850680073560736891664504162485311645\
620482772034860108851314582776233284317865026504810826569542799151544008`100.\
*^-11*x^22*Log[x] + 9.3420960146402701404609490353584932728374819665592226613\
9836440098209861437992173951747450391479451379084931490575289980726`100.*^-13*
      x^24*Log[x] + 8.7381888323504589215627783012535352193135672577966851857\
55135156671882374575235938655761590041575831218172896416614887364`100.*^-14*
      x^26*Log[x] + 8.2857341694341134958801285901851462857204755421870163599\
89032033249975134800755931358837785966044168780343711077575554365`100.*^-15*
      x^28*Log[x] + 7.9487771534639808602493159789293902049697547917553253531\
3204319747588930886884996996787902434984855860819084589033082412`100.*^-16*
      x^30*Log[x] + 7.7025794592758285486265763259337109162198411286620450116\
90659904909309524458227294035006120669390276205044843221289769077546554044219\
77381`100.*^-17*x^32*Log[x] + 7.529719208438849939279722992583639338625016557\
83663954883761151686609833048946324083324955925134534963443916285875527863661\
24756595504955`100.*^-18*x^34*Log[x] + 7.417704239744705728934108877048395402\
68564427921897617245199806754316495841222612245372878989227050962682392842053\
35725807862161658352`100.*^-19*x^36*Log[x] + 7.357461309920403491616249408810\
18340432146666463427059117671295804705974795305348009296236823343610445509324\
410233682823529044769829617`100.*^-20*x^38*Log[x] - 2.`100.*x^2*Log[x]^2 + 
     0.6666666666666666666666666666666666666666666666666666666666666666666666\
66666666666666666666666666666666666666666666666666666666666666667`100.*x^2*
      Log[x]^3
 
 
f9bAsyN = 5.81160073351489310313908183331269185588561656787346510440222489603\
6674137069867540500295567286425371970670985629003857346295391353672061`100. - 
     12.838916006863867880216721822960975549186822288301393076791217798793698\
822782228801873798449077946632204411272477768027027156949058123437`100.*x^2 + 
     9.1196044010893586188344909998761511353136994072407906264133493762200448\
22419205243001773403718552231824025913774023144077772348122032336`100.*x^4 - 
     13.641560945971710474932285979379133296393278502695328860502419554700686\
156478585694079156827770674365918129964514846243309874883327547872`100.*x^6 + 
     34.766692380234006862418632566848590109430900438840904629838987129254138\
944711119538655086450818288721725274404278280521414766857780835462`100.*x^8 + 
     227.58664421637141243609686523423910069288928507723994705198728017318823\
4235228858429766512143820894011421018629664051177938593002201394583`100.*
      x^10 + 1553.73917796553786854829947827092939178742071732424062867246052\
0896099572432126868002464569304005322519927915250672088430358802178816572717`\
100.*x^12 + 10945.76462921145471515876408799478875022627215171161425557265587\
03339472529367957538457900288435350849715044709593797789`100.*x^14 + 
     79090.742466671983791027914649320387155519292088765777539482461772221355\
7820283140142620533978657188315234827993906853975`100.*x^16 + 
     583524.53905171243279432437765108092470742412023568253657751591773984860\
60081065193125711298532177511495991104439808789906`100.*x^18 + 
     4.3806840630017989462012442917893902941508483735400287441862553422850109\
666519324630905635627048916135230074397152859507076`100.*^6*x^20 + 
     3.3373381274290945704382595588385451767571382287008310953366791705909892\
6096305782431623192137938618334213122267191461858198`100.*^7*x^22 + 
     2.5745720647761167426572478576025080877828472640054055574476859466177684\
68731861225320348209464628802251468735823157123865678`100.*^8*x^24 + 
     2.0077578069242247660378552630455704166714570380148780028870311880413282\
865439627051528816148818825356650483287546347924269593`100.*^9*x^26 + 
     1.5805695527387552251198365414996589741168205358449353380429825577793464\
0157988372410867671330808743523963365572406936988742474`100.*^10*x^28 + 
     1.2546257497795927618120701785856970569933399781854968878838301416499807\
15932095890719188040884318082702286887578113287237919746`100.*^11*x^30 + 
     1.0032275410325856149230509126164351433327438749738310853872588304852328\
400741822196147401628896611388568767211298627731158037909`100.*^12*x^32 + 
     8.0746220460567776142239159978726174359861778370245044071332169546320615\
479990267545062594084346931367418733240663633206936204853`100.*^12*x^34 + 
     6.5371503201804122707985647822308262260308458634048502940951774461433437\
7487388800604799884756150362341626342812484846865937615478`100.*^13*x^36 + 
     5.3204359968564691724753173928454993977796270537499901010836357389140718\
38643625669843488013097112301621648148010447841018152308908`100.*^14*x^38 + 
     4.3509340903210952516191206545877579198270213710287997125950745472654283\
674143184095463497963757474665263611538891211059612348287722`100.*^15*x^40 + 
     3.5736108305282125749234422283435733987687467687299164031031231373930401\
6193641306098099897603824010012367661494229826482266551074079`100.*^16*x^42 + 
     2.9468526428722452000450618866682355140081496879968656359682025212875771\
14065047493854008238368009817764119307652130593465955728483677`100.*^17*
      x^44 + 2.43889461286502232337897326619096689291724792232615404783464013\
92332644490002631591877079481220166387590864630915146058150169289501224`100.*^\
18*x^46 + 2.02528005037998243830578829098655538610639038655415568518147558534\
282001677233675428208477965618066543099874831941139454742358061212177`100.*^19\
*x^48 + 1.6870305267441109926166963842538405215079008475924548877009335603681\
25386110005044388844934183922024515281892066512062693367445059000152`100.*^20*
      x^50 + 1.40931236655088452271430347460203668136435000596973052593426631\
73348800596093436312772364270712335085678568997330164811204771660927399734`10\
0.*^21*x^52 + 1.1804545401628439933289462438790184904061479111365697674699021\
6382241718489843815912903375812954309414240482851570366418657366036683801195`\
100.*^22*x^54 + 9.91218252050392055022421754106464805390872269360835759693205\
52662664622098793078135813303768502811320609232002495319986`100.*^22*x^56 + 
     8.3424879540145306015914772658673622597517930776329561318038025388247669\
6260065033188451529983044370540718632013653793767`100.*^23*x^58 + 
     7.0366074056722419802293205264884341228434446646086729527632178855051034\
8767928614156996937455636968703637707554161984641`100.*^24*x^60 + 
     5.9472158364978099752724775096442147598845955045757189736792384007224221\
589589073812682235977001639431532752013651139142331`100.*^25*x^62 + 
     18.869604401089358618834490999876151135313699407240790626413349376220044\
822419205243001773403718552231824025913774023144077772348122032336`100.*x^2*
      Log[x] - 9.`100.*x^4*Log[x] - 2.5`100.*x^6*Log[x] + 
     113.26858614640563675934722533184714695709772622022282085029352584797387\
1202363796249354614177955960115221644298621611062266601510797721361`100.*x^8*
      Log[x] + 726.4365168784338205560833519910828817425863573213369251017611\
55087843227214182777496127685067735760691329865791729666373599609064786328166`\
100.*x^10*Log[x] + 4857.36627356341419685519456261019158436971359636846719231\
11539822230071056898242574754753387623264843784224833476212204`100.*x^12*
      Log[x] + 33659.04181149123280554469820581521413047669968013007178850863\
90861372120024063823624858496037434037386172747092114806028`100.*x^14*
      Log[x] + 240037.1217756340044633789484472871281666295000671544991910412\
073897531513832711172707883578182996874604231627471913456326`100.*x^16*
      Log[x] + 1.752250029948979289110475743918046736317680830184349280430255\
3434682761803211027315805980835899333595992821906012477641681`100.*^6*x^18*
      Log[x] + 1.304005541801023181860871449384677618522012962528813373993545\
44191841528220155248773670125609504922420178588223543619569622`100.*^7*x^20*
      Log[x] + 9.861942247231628639211131397834202183424433011046826650836407\
98582612726133353051351751223857087543255482818964780918697773`100.*^7*x^22*
      Log[x] + 7.560976540896795108345181163303932453219319415557887843626373\
20125247001279429988574665264104348879018951458954204427603612`100.*^8*x^24*
      Log[x] + 5.865151693280684601256178098510206153072149217569210895790233\
8519277249632126418066767862208337167128621749270654906012187388`100.*^9*x^26*
      Log[x] + 4.596058250426730054484089298691898301167969940828726514071770\
96640915780433921788373876947930077246531023232602844555897936143`100.*^10*
      x^28*Log[x] + 3.6336379719202407215761954810565383295253124561741728366\
63966499297373968381769221990596598737617091710524367877214163930239961`100.*^\
11*x^30*Log[x] + 2.8952750664371667124723270773431163416899541224474477951171\
191356851006605486835040334831416064208033415674058467034680853381837`100.*^12\
*x^32*Log[x] + 2.322995457073425024946062028276523978142188384195737889908793\
18193398722924345960959708435915190488665618178523152014721616786843`100.*^13*
      x^34*Log[x] + 1.8754085920724816011920735236099388958366235954208838527\
12891617735414987989513743108273422904095386597266298021137944146354277198`10\
0.*^14*x^36*Log[x] + 1.522507726004243359948513232897662496340766387470150752\
2953075904535141599028125625789120667021489749439170394929373557924120687788`\
100.*^15*x^38*Log[x] + 1.2422398489090351563100525899408747119158209588742883\
29811947050839820344246590669986079665981519829658407773621943085849818183568\
94`100.*^16*x^40*Log[x] + 1.0181978094906552454001732500208416733648803532543\
29281219812605609290668419416862042993875944136890656663223178528328176558917\
573574`100.*^17*x^42*Log[x] + 8.380396098236866464067114492659448663326833644\
11125421210192438208238712190539686629074118645591041703466198569951801392522\
2235841447`100.*^17*x^44*Log[x] + 6.92388197479972048811047783781269196233148\
66685771814123932338464655756036180433244282944461496892816242700476017927140\
630410744224354`100.*^18*x^46*Log[x] + 5.740544373785222724939207666409285592\
67087832939176041389753900730962746993955042748483073949863029957544511516270\
56767134224184860399`100.*^19*x^48*Log[x] + 4.7748098967419595879654381948476\
81844770558020524932140300883929928974748834270049600775075243962048470676854\
202063291052063104670831533`100.*^20*x^50*Log[x] + 3.983394290816990495980348\
86098199582727622552914147627413035168712236014585578535355283915920856388908\
72831876899858384982088236203408248`100.*^21*x^52*Log[x] + 
     3.3323511373238730264316408070000533930076722285692782087054186705200846\
6908751277740064440510183252585978224815562908190284028486325518352`100.*^22*
      x^54*Log[x] + 2.7948876385805559082537674058934423775018055002861480826\
1508234832488486248394428327754113061811880239661588886627513346`100.*^23*
      x^56*Log[x] + 2.3497328137959777472369213722027013815501204515507625710\
00405933938088597812098470470864823717699015869298086446556659478`100.*^24*
      x^58*Log[x] + 1.9799077330836633308710379250903247487945486350890508457\
324739519053879271765044783514316674504559439071547304493162027435`100.*^25*
      x^60*Log[x] + 1.6717912338977821085473575190408120927939666653320592610\
6247141006229520109552742660650222515351200732721865676865591490974`100.*^26*
      x^62*Log[x] - 6.`100.*x^2*Log[x]^2 + 12.`100.*x^4*Log[x]^2 + 
     24.`100.*x^6*Log[x]^2 + 128.`100.*x^8*Log[x]^2 + 
     786.`100.*x^10*Log[x]^2 + 5120.8`100.*x^12*Log[x]^2 + 
     34804.`100.*x^14*Log[x]^2 + 244489.0285714285714285714285714285714285714\
28571428571428571428571428571428571428571428571428571428571428571428571428571\
4`100.*x^16*Log[x]^2 + 1.7634386`100.*^6*x^18*Log[x]^2 + 
     1.2995839123809523809523809523809523809523809523809523809523809523809523\
8095238095238095238095238095238095238095238095238095`100.*^7*x^20*Log[x]^2 + 
     9.7494968742857142857142857142857142857142857142857142857142857142857142\
8571428571428571428571428571428571428571428571428571`100.*^7*x^22*Log[x]^2 + 
     7.4242989837229437229437229437229437229437229437229437229437229437229437\
22943722943722943722943722943722943722943722943722944`100.*^8*x^24*Log[x]^2 + 
     5.7260403518285714285714285714285714285714285714285714285714285714285714\
285714285714285714285714285714285714285714285714285714`100.*^9*x^26*
      Log[x]^2 + 4.4648583389181218781218781218781218781218781218781218781218\
7812187812187812187812187812187812187812187812187812187812187812188`100.*^10*
      x^28*Log[x]^2 + 3.51473561430581818181818181818181818181818181818181818\
1818181818181818181818181818181818181818181818181818181818181818181818182`100.\
*^11*x^30*Log[x]^2 + 2.789973711300783216783216783216783216783216783216783216\
7832167832167832167832167832167832167832167832167832167832167832167832168`100.\
*^12*x^32*Log[x]^2 + 2.231046337327613436563436563436563436563436563436563436\
56343656343656343656343656343656343656343656343656343656343656343656343656`10\
0.*^13*x^34*Log[x]^2 + 1.7958314463612547250396662161368043720984897455485690\
77980842686725039666216136804372098489745548569077980842686725039666216136804`\
100.*^14*x^36*Log[x]^2 + 1.45402985654957846000666000666000666000666000666000\
66600066600066600066600066600066600066600066600066600066600066600066600066600\
067`100.*^15*x^38*Log[x]^2 + 1.1835270749758522654919074733316219384330839439\
19857232550731002743386644315436885096327820786025120390445467844848649802210\
1737272`100.*^16*x^40*Log[x]^2 + 9.679710918953401645779318720495191083426377\
54402460284813225989696577931872049519108342637754402460284813225989696577931\
872049519108`100.*^16*x^42*Log[x]^2 + 7.9512886914688271146208590171438468652\
09094311261493924032623723026199806385564899496788041679682546555611571091447\
252437964512267918`100.*^17*x^44*Log[x]^2 + 6.5575198273567415776960271926216\
19866201909545562796336790144839680443395613674251445149277966615427915737513\
2607330749745610426724978`100.*^18*x^46*Log[x]^2 + 5.427815015030015421633241\
09999571030665390606163253895115518483401105557519610555012358754450556846572\
461056240838176495734713529840734`100.*^19*x^48*Log[x]^2 + 
     4.5078278233028824779453971910442498677792795439854263383675148381030733\
97191044249867779279543985426338367514838103073397191044249867779`100.*^20*
      x^50*Log[x]^2 + 3.75538533537690692119948898631856768887324816790424543\
82338619786459334177735039223799487630420461218684398116353965055001533666226\
087817`100.*^21*x^52*Log[x]^2 + 3.1375238591317819886708629250813797859160626\
69326904082591254485183681576197392592600561371593812029940714824279234024825\
62531021273786114`100.*^22*x^54*Log[x]^2 + 2.62830636213890974043365095208034\
81228841304221570744655951278646123174323470460231800923684084270973488903223\
7262147075`100.*^23*x^56*Log[x]^2 + 2.207199566434303741172669658096927974435\
04133502787426599514363681815559591841729410715815346317432735523999489539939\
1294`100.*^24*x^58*Log[x]^2 + 1.857856176928859821529897046646458551379156092\
2794067831456257986027157169140357112934291837100494691203980522169724782041`\
100.*^25*x^60*Log[x]^2 + 1.56719339819868132872922607447523505345554073512075\
935013073255097753684373687065839441663913329009573457009181871209061948`100.\
*^26*x^62*Log[x]^2 + 2.`100.*x^2*Log[x]^3 + 8.`100.*x^6*Log[x]^3 + 
     48.`100.*x^8*Log[x]^3 + 288.`100.*x^10*Log[x]^3 + 
     1824.`100.*x^12*Log[x]^3 + 12120.`100.*x^14*Log[x]^3 + 
     83664.`100.*x^16*Log[x]^3 + 595224.`100.*x^18*Log[x]^3 + 
     4.338624`100.*^6*x^20*Log[x]^3 + 3.2257656`100.*^7*x^22*Log[x]^3 + 
     2.438196`100.*^8*x^24*Log[x]^3 + 1.86869232`100.*^9*x^26*Log[x]^3 + 
     1.449304272`100.*^10*x^28*Log[x]^3 + 1.1356142148`100.*^11*x^30*
      Log[x]^3 + 8.97804844272`100.*^11*x^32*Log[x]^3 + 
     7.15394169936`100.*^12*x^34*Log[x]^3 + 5.7402771848064`100.*^13*x^36*
      Log[x]^3 + 4.63466594285304`100.*^14*x^38*Log[x]^3 + 
     3.762928670518224`100.*^15*x^40*Log[x]^3 + 3.0705739648426272`100.*^16*
      x^42*Log[x]^3 + 2.5170740575210224`100.*^17*x^44*Log[x]^3 + 
     2.071949160790314792`100.*^18*x^46*Log[x]^3 + 
     1.7120447537900371632`100.*^19*x^48*Log[x]^3 + 
     1.41961009715272069992`100.*^20*x^50*Log[x]^3 + 
     1.18092380659771884768`100.*^21*x^52*Log[x]^3 + 
     9.8529858464586026706`100.*^21*x^54*Log[x]^3 + 
     8.2435236779397668213424`100.*^22*x^56*Log[x]^3 + 
     6.91469039915242816539744`100.*^23*x^58*Log[x]^3 + 
     5.813956008150447384384864`100.*^24*x^60*Log[x]^3 + 
     4.8993861409648637273018712`100.*^25*x^62*Log[x]^3 + 
     19.739208802178717237668981999752302270627398814481581252826698752440089\
644838410486003546807437104463648051827548046288155544696244064671`100.*x^6*
      (1.`100. + Log[x])
 
 
matadSymbols = {D3 -> -Pi^4/24 - 6*Im[PolyLog[2, E^((I/3)*Pi)]]^2 + 
       6*Zeta[3], SeriesData[ep, 0, {(-13*Pi^4)/180 + 
         (2*Log[2]^2*(-Pi^2 + Log[2]^2))/3 + 16*PolyLog[4, 1/2]}, 0, 1, 1] -> 
      (-13*Pi^4)/180 - (2*Pi^2*Log[2]^2)/3 + (2*Log[2]^4)/3 + 
       16*PolyLog[4, 1/2], S2 -> (4*Im[PolyLog[2, E^((I/3)*Pi)]])/
       (9*Sqrt[3]), OepS2 -> -763/32 + (65*Pi^2)/32 - 
       (35*Pi^3)/(16*Sqrt[3]) + (19*Pi^4)/480 + 
       (45*Sqrt[3]*Im[PolyLog[2, E^((I/3)*Pi)]])/2 - 
       27*Sqrt[3]*Im[PolyLog[3, 1/(Sqrt[3]*E^((I/6)*Pi))]] - 
       (9*Sqrt[3]*Pi*Log[3]^2)/16 - (15*Zeta[3])/4, 
     T1ep -> -45/2 - (3*Pi^2)/4 - (35*Pi^3)/(72*Sqrt[3]) + 
       6*Sqrt[3]*Im[PolyLog[2, E^((I/3)*Pi)]] - 
       6*Sqrt[3]*Im[PolyLog[3, 1/(Sqrt[3]*E^((I/6)*Pi))]] - 
       (Sqrt[3]*Pi*Log[3]^2)/8 + Zeta[3]}
 
Clausen[n_, x_] := Im[PolyLog[n, Exp[I*x]]]

points8a = 
    {{1/10, 15.25853985149189381796291585808645999392`15.995827280017563 + 
       1.00999999999999999999999999999999915401`16./eps^3 + 
       3.85906921945648803718720641030719436167`16./eps^2 + 
       8.66018952521898772011480806664720277488`16./eps}, 
     {21/200, 15.35701806982276372450801964912424262205`15.996014752996498 + 
       1.01102500000000000000000000000000000005`16./eps^3 + 
       3.86863413805212409749750780894400417485`16./eps^2 + 
       8.70122161639980382453049134398594185848`16./eps}, 
     {11/100, 15.4559514326153440583286876999014950043`15.99620516294997 + 
       1.01209999999999999999999999999999999998`16./eps^3 + 
       3.87851187851545353257692429439661731487`16./eps^2 + 
       8.7430990978741272425899312153560664`16./eps}, 
     {23/200, 15.55524940924423862316401737078611522624`15.996398321346415 + 
       1.01322500000000000000000000000000000003`16./eps^3 + 
       3.88869543344872100786186505441265459103`16./eps^2 + 
       8.78578345449253162888805298048841167507`16./eps}, 
     {3/25, 15.65482886689154047376823226139753228577`15.996594056675129 + 
       1.01439999999999999999999999999999999997`16./eps^3 + 
       3.89917810476384393369723101215568950154`16./eps^2 + 
       8.82923846453093819058866142651483300672`16./eps}, 
     {1/8, 15.75461325698059219489768939787056148432`15.9967922129658 + 
       1.01562500000000000000000000000000000003`16./eps^3 + 
       3.90995347721415897580253516575716591736`16./eps^2 + 
       8.87342997834226712322433308740979338355`16./eps}, 
     {13/100, 15.85453191828885479745908937847645692001`15.99699264846921 + 
       1.01689999999999999999999999999999999997`16./eps^3 + 
       3.92101539517296298650817918688429954369`16./eps^2 + 
       8.91832572621785410339789389701625783543`16./eps}, 
     {27/200, 15.95451947629405150609405168304772008788`15.997195234476175 + 
       1.01822500000000000000000000000000000003`16./eps^3 + 
       3.93235794214847721320864943182424375124`16./eps^2 + 
       8.96389515063116489847996520362156007934`16./eps}, 
     {7/50, 16.05451532250338899052972520175198170653`15.997399854256404 + 
       1.01959999999999999999999999999999999997`16./eps^3 + 
       3.94397542262138923257325447168134814769`16./eps^2 + 
       9.01010925898431707932692897423774976253`16./eps}, 
     {29/200, 16.15446316073233883546271787611381159697`15.99760640210173 + 
       1.02102500000000000000000000000000000004`16./eps^3 + 
       3.955862345866537230832443321294846125`16./eps^2 + 
       9.05694049371226279216070243054521224462`16./eps}, 
     {3/20, 16.2543106097913908006293520517368295518`15.99781478246096 + 
       1.02249999999999999999999999999999999999`16./eps^3 + 
       3.96801341147979698788769853789735101905`16./eps^2 + 
       9.10436261717411865158870600358560412211`16./eps}, 
     {31/200, 16.3540088539882873885931536593586650201`15.998024909155541 + 
       1.02402500000000000000000000000000000006`16./eps^3 + 
       3.98042349637859949451876262132212545608`16./eps^2 + 
       9.15235060921499601148941011560109041933`16./eps}, 
     {4/25, 16.45351233439138119424107694350336189399`15.998236704666615 + 
       1.02560000000000000000000000000000000001`16./eps^3 + 
       3.9930876430825368846788564463942331736`16./eps^2 + 
       9.20088057564327526257486138558326965874`16./eps}, 
     {33/200, 16.55277847502364034490122500651735807798`15.998450099485872 + 
       1.02722499999999999999999999999999999997`16./eps^3 + 
       4.00600104911128612240002544118683824291`16./eps^2 + 
       9.24992966615866107519247185111040576454`16./eps}, 
     {17/100, 16.65176743913818403896210469861941968193`15.9986650315231 + 
       1.02890000000000000000000000000000000005`16./eps^3 + 
       4.01915905736216025411775173353933534805`16./eps^2 + 
       9.29947600050131771674853762954511966967`16./eps}, 
     {7/40, 16.75044191151878962075878769788140222687`15.998881445564768 + 
       1.03062500000000000000000000000000000001`16./eps^3 + 
       4.03255714735017765458468175057989055324`16./eps^2 + 
       9.34949860178382486653815517199516922342`16./eps}, 
     {9/50, 16.84876690339321144080436283034105040851`15.999099292778345 + 
       1.03239999999999999999999999999999999998`16./eps^3 + 
       4.04619092721053527289050690252716664341`16./eps^2 + 
       9.39997733612469614398682476792293171965`16./eps}, 
     {37/200, 16.94670957707439870600841437124009572948`15.999318530257858 + 
       1.03422500000000000000000000000000000006`16./eps^3 + 
       4.06005612637749058769868129693366529839`16./eps^2 + 
       9.45089285783174992809827623619474278386`16./eps}, 
     {19/100, 17.04423908787865474324752864264092142251`15.999539120606846 + 
       1.03610000000000000000000000000000000003`16./eps^3 + 
       4.07414858886545146000598594487784542484`16./eps^2 + 
       9.50222655949113162132540358901405461537`16./eps}, 
     {39/200, 17.14132644122894743384237877603353649581`15.999761031555 + 
       1.038025`16./eps^3 + 4.08846426708797786776926132434307834729`16./
        eps^2 + 9.55396052640749099439343365854669639262`16./eps}, 
     {1/5, 17.23794436315041615785744773929788104702`15.999984235605577 + 
       1.03999999999999999999999999999999999997`16./eps^3 + 
       4.10299921615875871161875778665380918888`16./eps^2 + 
       9.60607749491604909293030439308110774314`16./eps}, 
     {41/200, 17.33406718261499701224960584550623953874`15.999988646244798 + 
       1.04202500000000000000000000000000000006`16./eps^3 + 
       4.11774958862571478440407855942247755493`16./eps^2 + 
       9.65856081415068637608616087964245885122`16./eps}, 
     {21/100, 17.42967072440201100871897796102271590372`15.99997680068329 + 
       1.04410000000000000000000000000000000004`16./eps^3 + 
       4.13271162959541562555413142610709993973`16./eps^2 + 
       9.7113944109058527916889032915403652048`16./eps}, 
     {43/200, 17.52473221131870518117709571871862091288`15.99996488987729 + 
       1.04622500000000000000000000000000000002`16./eps^3 + 
       4.14788167221016088383739482552835237791`16./eps^2 + 
       9.76456275727573081912528830450153373999`16./eps}, 
     {11/50, 17.61923017477485543673388210071390276066`15.999952913919127 + 
       1.0484`16./eps^3 + 4.1632561334445100713803150735507420213`16./eps^2 + 
       9.81805084079303755266316149116539724676`16./eps}, 
     {9/40, 17.7131443728332681155055519810332221623`15.999940872689685 + 
       1.05062499999999999999999999999999999999`16./eps^3 + 
       4.17883151019186575723441096835789176577`16./eps^2 + 
       9.87184413682323798423012194569104216783`16./eps}, 
     {23/100, 17.80645571496711062082548193090753132509`15.99992876586909 + 
       1.05289999999999999999999999999999999998`16./eps^3 + 
       4.19460437561502071084294547997520574276`16./eps^2 + 
       9.92592858299866115394256990329546435488`16./eps}, 
     {47/200, 17.89914619284851892251246839887283640694`15.999916592946551 + 
       1.05522499999999999999999999999999999997`16./eps^3 + 
       4.21057137573744868683216706468440927188`16./eps^2 + 
       9.98029055550180342966829839467964224725`16./eps}, 
     {6/25, 17.99119881657337416398109040115134489976`15.999904353229395 + 
       1.05759999999999999999999999999999999996`16./eps^3 + 
       4.22672922625461718532162633803478509503`16./eps^2 + 
       10.03491684702857799013134662459280894681`16./eps}, 
     {49/200, 18.0825975557965695374072860417288338815`15.999892045851217 + 
       1.06002500000000000000000000000000000007`16./eps^3 + 
       4.24307470954678328452536157279176040202`16./eps^2 + 
       10.08979464628093051456226655670067776778`16./eps}, 
     {1/4, 18.17332728531220078125296753027834154768`15.99987966977954 + 
       1.06250000000000000000000000000000000006`16./eps^3 + 
       4.25960467187664615769226119911898080055`16./eps^2 + 
       10.1449115188545067462215868808744662872`16./eps}, 
     {51/200, 18.26337373466531756454698537153254909654`15.999867223822605 + 
       1.06502500000000000000000000000000000006`16./eps^3 + 
       4.276316020756910404950580491964296629`16./eps^2 + 
       10.20025538940127719735515440387812987125`16./eps}, 
     {13/50, 18.35272344142734096845144692968885384413`15.999854706635764 + 
       1.06760000000000000000000000000000000006`16./eps^3 + 
       4.2932057224742950372829020733054799665`16./eps^2 + 
       10.25581452495949022809364129142833607039`16./eps}, 
     {53/200, 18.44136370780696406379313823332925868419`15.999842116727205 + 
       1.07022500000000000000000000000000000007`16./eps^3 + 
       4.31027079975783102628073670742117812838`16./eps^2 + 
       10.31157751935428287395158620952702335509`16./eps}, 
     {27/100, 18.52928256030312964351775049942979997239`15.99982945246315 + 
       1.07290000000000000000000000000000000007`16./eps^3 + 
       4.32750832958044881366504906233407178968`16./eps^2 + 
       10.36753327858193646726646367984663246793`16./eps}, 
     {11/40, 18.61646871213721316248180141326808418758`15.999816712072695 + 
       1.07562499999999999999999999999999999996`16./eps^3 + 
       4.34491544108388564819226410380899070611`16./eps^2 + 
       10.42367100709929683494758354916003820485`16./eps}, 
     {7/25, 18.70291152822841371077335933800902334296`15.999803893652079 + 
       1.07839999999999999999999999999999999998`16./eps^3 + 
       4.36248931361785779351808489175842946167`16./eps^2 + 
       10.47998019494743572352975035322177620575`16./eps}, 
     {57/200, 18.78860099250006618590421309311402742312`15.999790995168647 + 
       1.08122499999999999999999999999999999999`16./eps^3 + 
       4.3802271748852588292349760300643769311`16./eps^2 + 
       10.53645060564533811594615493710919280711`16./eps}, 
     {29/100, 18.87352767732555418204761695833833595585`15.999778014464358 + 
       1.0841`16./eps^3 + 4.39812629918587472176380562093548655173`16./
        eps^2 + 10.59307226479536780059024504694651474021`16./eps}, 
     {59/200, 18.95768271494108390038513083089924260616`15.99976494925901 + 
       1.08702500000000000000000000000000000002`16./eps^3 + 
       4.4161840057517596366631794295209308293`16./eps^2 + 
       10.64983544934758396172798776281920539907`16./eps}, 
     {3/10, 19.04105777066908101097188974992324308884`15.99975179715308 + 
       1.09000000000000000000000000000000000004`16./eps^3 + 
       4.43439765716800271800814147879569640261`16./eps^2 + 
       10.70673067747473464193089382835705566301`16./eps}, 
     {61/200, 19.12364501781065754380303853919466054296`15.999738555630277 + 
       1.09302500000000000000000000000000000006`16./eps^3 + 
       4.45276465787314316568162873735618174813`16./eps^2 + 
       10.76374869901400759760464350497938805993`16./eps}, 
     {31/100, 19.20543711407869035326781861759975280827`15.999725222059825 + 
       1.09609999999999999999999999999999999996`16./eps^3 + 
       4.47128245273396574537006246467210951942`16./eps^2 + 
       10.82088048643543488032843712639601666135`16./eps}, 
     {63/200, 19.28642717945475108512645905258233478348`15.999711793698447 + 
       1.09922499999999999999999999999999999999`16./eps^3 + 
       4.48994852568983732509149065459512482246`16./eps^2 + 
       10.87811722630027602154400602574080579936`16./eps}, 
     {8/25, 19.36660877536359801149923146270806545948`15.99969826769213 + 
       1.10240000000000000000000000000000000002`16./eps^3 + 
       4.50876039846213233966245207786498085262`16./eps^2 + 
       10.93545031117579078122291052163635352524`16./eps}, 
     {13/40, 19.44597588506832820410436822797047247162`15.999684641077655 + 
       1.10562500000000000000000000000000000005`16./eps^3 + 
       4.52771562932464577939608973279788364789`16./eps^2 + 
       10.99287133197559504564917194037053974247`16./eps}, 
     {33/100, 19.52452289519772070193922735303329207119`15.999670910783895 + 
       1.10889999999999999999999999999999999997`16./eps^3 + 
       4.5468118119312103570134920306669666865`16./eps^2 + 
       11.05037207069730665562897093788088104021`16./eps}, 
     {67/200, 
      19.6022445783248875874043854546752287751070889806613804462115`31.999994\
01521981 + 1.1122250000000000000000000000000000000000000000000000000027`32./
        eps^3 + 
       4.5660465741970234169088063477945585450548317326387774332064`32./
        eps^2 + 
       11.1079444935314614714082402677634275163024931608909996249334`32./
        eps}, {17/50, 
      19.67913607652318612492506921939722779232`15.999643126340713 + 
       1.11560000000000000000000000000000000004`16./eps^3 + 
       4.58541757723045198316511083443564575791`16./eps^2 + 
       11.16558074431773991067800867206867246194`16./eps}, 
     {69/200, 19.75519288583151515052671567758919949873`15.99962906551836 + 
       1.11902499999999999999999999999999999996`16./eps^3 + 
       4.60492251431232380270182829673978045261`16./eps^2 + 
       11.22327313832641342952864205739162777`16./eps}, 
     {7/20, 19.8304108415666961191599205920426565233`15.999614887672088 + 
       1.1225`16./eps^3 + 4.62455910991993071712789419768368232392`16./
        eps^2 + 11.28101415634461910100214788753355748503`16./eps}, 
     {71/200, 19.90478610442568801056707346639389846404`15.999600589203977 + 
       1.12602500000000000000000000000000000005`16./eps^3 + 
       4.64432511879317030557565741706668343815`16./eps^2 + 
       11.33879643904861634447268713747164909328`16./eps}, 
     {9/25, 19.97831514732496227119007223646722890831`15.999586166412076 + 
       1.12959999999999999999999999999999999998`16./eps^3 + 
       4.66421832504043435526060776128572752425`16./eps^2 + 
       11.39661278164458866052691579902230423285`16./eps}, 
     {73/200, 20.05099474292851898457001581117626986758`15.999571615490522 + 
       1.13322500000000000000000000000000000003`16./eps^3 + 
       4.68423654128202000120789177651566041485`16./eps^2 + 
       11.45445612876183881340541763703984489033`16./eps}, 
     {37/100, 20.12282195181980250684922865585615477438`15.99955693252956 + 
       1.13689999999999999999999999999999999996`16./eps^3 + 
       4.70437760782899281221706795545178807661`16./eps^2 + 
       11.51231956958340058326385713415340096643`16./eps}, 
     {3/8, 20.19379411127621276335931101628255688172`15.999542113515309 + 
       1.14062500000000000000000000000000000001`16./eps^3 + 
       4.72463939189557200617381531939381431412`16./eps^2 + 
       11.57019633320016491196259482655507183089`16./eps}, 
     {19/50, 20.26390882460804169970733056346066636348`15.999527154329538 + 
       1.14440000000000000000000000000000000007`16./eps^3 + 
       4.74501978684323753198439882449569961011`16./eps^2 + 
       11.62807978417560270950895510181435869593`16./eps}, 
     {77/200, 20.33316395102652356463000384227292384875`15.999512050749228 + 
       1.14822500000000000000000000000000000001`16./eps^3 + 
       4.76551671145487801058470756877738082363`16./eps^2 + 
       11.68596341830906943421750124836223908518`16./eps}, 
     {39/100, 20.40155759600829988372937859827437368244`15.999496798446119 + 
       1.15210000000000000000000000000000000007`16./eps^3 + 
       4.78612810923740842638996228035094742138`16./eps^2 + 
       11.74384085858650553639350654854947763551`16./eps}, 
     {79/200, 20.46908810212598931367172307364896612926`15.999481392986063 + 
       1.15602500000000000000000000000000000002`16./eps^3 + 
       4.80685194775138784858057880789205880432`16./eps^2 + 
       11.8017058513081088698710967203495386676`16./eps}, 
     {2/5, 20.53575404031674054388045933666588910161`15.999465829828322 + 
       1.15999999999999999999999999999999999996`16./eps^3 + 
       4.82768621796626109795475972831531200245`16./eps^2 + 
       11.85955226238325641030180582182536942065`16./eps}, 
     {81/200, 20.60155420156265224383196408693143251721`15.999450104324813 + 
       1.16402500000000000000000000000000000003`16./eps^3 + 
       4.84862893363993484248452958645954193773`16./eps^2 + 
       11.91737407378359861534149960163689580848`16./eps}, 
     {41/100, 20.66648758895878488028155111008077259159`15.999434211719167 + 
       1.16809999999999999999999999999999999998`16./eps^3 + 
       4.86967813072147871807720407883855177605`16./eps^2 + 
       11.97516538014584549432244351382453661456`16./eps}, 
     {83/200, 20.73055341014618042755570278515310471124`15.999418147145821 + 
       1.17222500000000000000000000000000000006`16./eps^3 + 
       4.89083186677581628487811693175008900487`16./eps^2 + 
       12.0329203855163133952065237745851215884`16./eps}, 
     {21/50, 20.79375107008886130734419416831088337566`15.999401905628883 + 
       1.17640000000000000000000000000000000001`16./eps^3 + 
       4.91208822042933944447292646575273271903`16./eps^2 + 
       12.09063340022980968953967830259100752225`16./eps}, 
     {17/40, 20.85608016417521169009137995061400148346`15.999385482081097 + 
       1.18062499999999999999999999999999999997`16./eps^3 + 
       4.93344529083544381228962452674405493585`16./eps^2 + 
       12.14829883791590256945564539452390071249`16./eps}, 
     {43/100, 20.91754047162546366219900506143863362483`15.999368871302567 + 
       1.18490000000000000000000000000000000005`16./eps^3 + 
       4.95490119715904187221584064434055896892`16./eps^2 + 
       12.2059112126260583383510090935676630715`16./eps}, 
     {87/200, 20.97813194918822770205414569184712565108`15.999352067979512 + 
       1.18922500000000000000000000000000000002`16./eps^3 + 
       4.97645407807916590842919405178362035873`16./eps^2 + 
       12.26346513607553183688349946450092967854`16./eps}, 
     {11/25, 21.03785472511013041385796570922527992225`15.999335066682912 + 
       1.19359999999999999999999999999999999998`16./eps^3 + 
       4.99810209130882404981173187806005913459`16./eps^2 + 
       12.32095531499426967470770113845570873178`16./eps}, 
     {89/200, 21.09670909336366065893655611906064143493`15.99931786186711 + 
       1.19802500000000000000000000000000000007`16./eps^3 + 
       5.01984341313132058137602911878171958144`16./eps^2 + 
       12.37837654858143315995701589863182422627`16./eps}, 
     {9/20, 21.15469550811928543042751046658005129073`15.999300447868295 + 
       1.20250000000000000000000000000000000004`16./eps^3 + 
       5.04167623795229625346667535964572479769`16./eps^2 + 
       12.43572372605847043115122542181591589658`16./eps}, 
     {91/200, 21.21181457844878567175433871523937731813`15.99928281890301 + 
       1.20702500000000000000000000000000000001`16./eps^3 + 
       5.06359877786678590680319552403333358367`16./eps^2 + 
       12.49299182431596729565231625349844982908`16./eps}, 
     {23/50, 21.26806706324758573756352891435285694724`15.999264969066541 + 
       1.21159999999999999999999999999999999999`16./eps^3 + 
       5.08560926224062956095372296919917248544`16./eps^2 + 
       12.55017590564978547883362425619500262907`16./eps}, 
     {93/200, 21.32345386636461378241542206476351837965`15.999246892331232 + 
       1.21622500000000000000000000000000000008`16./eps^3 + 
       5.10770593730560939660305288783840966506`16./eps^2 + 
       12.60727111558225703908805738569882298094`16./eps}, 
     {47/100, 21.3779760319289389656434721183508939357`15.999228582544822 + 
       1.22090000000000000000000000000000000006`16./eps^3 + 
       5.12988706576771899077786853184730347609`16./eps^2 + 
       12.66427268076444610882476516935939251745`16./eps}, 
     {19/40, 21.43163473986308946438889239015024787306`15.999210033428595 + 
       1.22562500000000000000000000000000000004`16./eps^3 + 
       5.15215092642800291529131217402106135645`16./eps^2 + 
       12.72117590695571525120511541757517596997`16./eps}, 
     {12/25, 21.48443130157356696410682982722918384881`15.99919123857566 + 
       1.23040000000000000000000000000000000003`16./eps^3 + 
       5.17449581381543454341731450978724873663`16./eps^2 + 
       12.77797617707704482740349505961758779496`16./eps}, 
     {97/200, 21.5363671558096422508605682894592095347`15.99917219144898 + 
       1.23522500000000000000000000000000000001`16./eps^3 + 
       5.19692003783132777603124665314949965854`16./eps^2 + 
       12.83466894933475099242189988220884948978`16./eps}, 
     {49/100, 21.5874438646820461438943095770785100354`15.999152885379512 + 
       1.2401`16./eps^3 + 5.21942192340480453172821399408071702564`16./
        eps^2 + 12.89124975541143232398735274441874816818`16./eps}, 
     {99/200, 21.63766310983366335664109400030163831717`15.999133313564203 + 
       1.24502499999999999999999999999999999999`16./eps^3 + 
       5.24199981015886437019786907815071859625`16./eps^2 + 
       12.94771419872114759540306517144067659489`16./eps}, 
     {1/2, 21.68702668875479676785866732827174457206`15.999113469063962 + 
       1.24999999999999999999999999999999999999`16./eps^3 + 
       5.26465205208662564869752694083719172606`16./eps^2 + 
       13.00405795272598870566136559140684282509`16./eps}, 
     {101/200, 21.73553651123599860071692366093173534362`15.999093344801592 + 
       1.25502499999999999999999999999999999998`16./eps^3 + 
       5.28737701723732925328395716731810581776`16./eps^2 + 
       13.06027675931136408408500047398070113152`16./eps}, 
     {51/100, 21.78319459595186546332441767912981779745`15.999072933559678 + 
       1.26009999999999999999999999999999999998`16./eps^3 + 
       5.31017308741171629486405574348337133957`16./eps^2 + 
       13.11636642721744972222156103594111325164`16./eps}, 
     {103/200, 21.83000306716956831483995634562506970375`15.999052227978437 + 
       1.26522499999999999999999999999999999998`16./eps^3 + 
       5.33303865786641030809294588928971776367`16./eps^2 + 
       13.17232283052439805091929072298614274742`16./eps}, 
     {13/25, 21.87596415157623804622003187360547690555`15.999031220553443 + 
       1.27039999999999999999999999999999999999`16./eps^3 + 
       5.35597213702695251413234959629504703346`16./eps^2 + 
       13.22814190718901976256096752759092915675`16./eps}, 
     {21/40, 21.92108017521965443640717144681881862725`15.999009903633452 + 
       1.27562499999999999999999999999999999999`16./eps^3 + 
       5.37897194620915569018969234993870048124`16./eps^2 + 
       13.2838196576307709938818806492743559071`16./eps}, 
     {53/100, 21.96535356055699231213015567483220828633`15.998988269418058 + 
       1.2809`16./eps^3 + 5.40203651934845819287704532093190711919`16./
        eps^2 + 13.33935214336498852571551271913927735872`16./eps}, 
     {107/200, 22.00878682360666538603451944950630085502`15.998966309955335 + 
       1.28622500000000000000000000000000000001`16./eps^3 + 
       5.4251643027369747773166514290544970335`16./eps^2 + 
       13.39473548568141932967261552050175479187`16./eps}, 
     {27/50, 22.05138257119857684335119695179329821116`15.998944017139515 + 
       1.29160000000000000000000000000000000002`16./eps^3 + 
       5.44835375476795509798200158948467429675`16./eps^2 + 
       13.44996586436618833941420589011248987221`16./eps}, 
     {109/200, 22.09314349831833758919747887332258676976`15.998921382708492 + 
       1.29702500000000000000000000000000000003`16./eps^3 + 
       5.47160334568737422621457299260843664819`16./eps^2 + 
       13.5050395164654401619969722930205485442`16./eps}, 
     {11/20, 22.13407238554124933434783643278890420938`15.998898398241405 + 
       1.30250000000000000000000000000000000005`16./eps^3 + 
       5.49491155735239222447291826501266758903`16./eps^2 + 
       13.55995273508897695547485486970445203947`16./eps}, 
     {111/200, 22.17417209655207147604981077145567881286`15.9988750551561 + 
       1.30802500000000000000000000000000000007`16./eps^3 + 
       5.51827688299643182621207043009380474256`16./eps^2 + 
       13.61470186825229623653443745183639192419`16./eps}, 
     {14/25, 22.21344557574679903365260656581295308433`15.998851344706567 + 
       1.31359999999999999999999999999999999997`16./eps^3 + 
       5.54169782700063462697260758716586533125`16./eps^2 + 
       13.66928331775550927395091943524919972605`16./eps}, 
     {113/200, 22.25189584591287464786577756540787624958`15.998827257980418 + 
       1.319225`16./eps^3 + 5.56517290467146693772978159316509936156`16./
        eps^2 + 13.72369353809769327332510910390650436675`16./eps}, 
     {57/100, 22.28952600598444170158364093004406444913`15.998802785896158 + 
       1.32490000000000000000000000000000000002`16./eps^3 + 
       5.5887006420242566238509279714722230236`16./eps^2 + 
       13.77792903542529904686919584557653866857`16./eps}, 
     {23/40, 22.32633922886941877706403671046687029665`15.998777919200595 + 
       1.33062500000000000000000000000000000005`16./eps^3 + 
       5.61227957557245188748949819667264002726`16./eps^2 + 
       13.83198636651330054945578702671560825495`16./eps}, 
     {29/50, 22.36233875934533861168780533380592825311`15.998752648466091 + 
       1.33639999999999999999999999999999999997`16./eps^3 + 
       5.63590825212240208079135182676635441445`16./eps^2 + 
       13.8858621377778337904275418483127305004`16./eps}, 
     {117/200, 22.39752791202104823117770307879742948496`15.998726964087817 + 
       1.342225`16./eps^3 + 5.65958522857346929251013851547027121971`16./
        eps^2 + 13.939553004319130424178825400321918683`16./eps}, 
     {59/100, 22.43191006936151149454572458748312505498`15.998700856280987 + 
       1.34810000000000000000000000000000000003`16./eps^3 + 
       5.68330907172328766002830221364494952677`16./eps^2 + 
       13.99305566899360598973455746893781567112`16./eps}, 
     {119/200, 22.46548867977309163242596678931074633165`15.998674315078016 + 
       1.35402500000000000000000000000000000007`16./eps^3 + 
       5.70707835807799514892199802626213582773`16./eps^2 + 
       14.04636688151401450426149065190516347041`16./eps}, 
     {3/5, 22.49826725574681990072973530169475402917`15.998647330325635 + 
       1.35999999999999999999999999999999999999`16./eps^3 + 
       5.73089167366726993786195522400795491695`16./eps^2 + 
       14.09948343757663009792479377809354090258`16./eps}, 
     {121/200, 22.53024937205727778214580250903430312158`15.998619891682049 + 
       1.36602500000000000000000000000000000003`16./eps^3 + 
       5.75474761386401057091946837289380166392`16./eps^2 + 
       14.15240217801446277554199227628602733106`16./eps}, 
     {61/100, 22.56143866401483467837157894156131205767`15.998591988613931 + 
       1.37210000000000000000000000000000000008`16./eps^3 + 
       5.77864478320850571382405873224096448915`16./eps^2 + 
       14.20511998797555936036255380963665328268`16./eps}, 
     {123/200, 22.59183882576909118927574783266911479898`15.998563610393498 + 
       1.37822500000000000000000000000000000001`16./eps^3 + 
       5.80258179523694569555280714559723111028`16./eps^2 + 
       14.257633796125482362649790152918990556`16./eps}, 
     {31/50, 22.6214536086614802620444078884902370682`15.99853474609546 + 
       1.38440000000000000000000000000000000005`16./eps^3 + 
       5.82655727231413405066029777622286885934`16./eps^2 + 
       14.30994057387309905636141929594111033651`16./eps}, 
     {5/8, 22.65028681962507509839158059851537076308`15.998505384593994 + 
       1.39062499999999999999999999999999999999`16./eps^3 + 
       5.85056984547026301860135850004363002783`16./eps^2 + 
       14.36203733461885056781700829890999326978`16./eps}, 
     {63/100, 22.67834231962974406226772100083511169144`15.998475514559635 + 
       1.39690000000000000000000000000000000004`16./eps^3 + 
       5.87461815424162242044286433136024845016`16./eps^2 + 
       14.41392113302470639908423046476437886546`16./eps}, 
     {127/200, 22.70562402217087926797819876227233475888`15.998445124456174 + 
       1.40322499999999999999999999999999999998`16./eps^3 + 
       5.89870084651511653624122160000799704751`16./eps^2 + 
       14.46558906430504363639140995446400269454`16./eps}, 
     {16/25, 22.73213589180000733351164947552897360377`15.998414202537463 + 
       1.40960000000000000000000000000000000004`16./eps^3 + 
       5.92281657837646856243791348061211604352`16./eps^2 + 
       14.51703826353772223343278180247312411107`16./eps}, 
     {129/200, 22.75788194269566827328987009355590664166`15.998382736844274 + 
       1.41602499999999999999999999999999999998`16./eps^3 + 
       5.94696401396199695144843273068309014468`16./eps^2 + 
       14.56826590499465830752374472643943242468`16./eps}, 
     {13/20, 22.782866237273021871633800797321009713`15.998350715201003 + 
       1.42250000000000000000000000000000000004`16./eps^3 + 
       5.97114182531385243789801721724329579166`16./eps^2 + 
       14.61926920149122643351486245941619095054`16./eps}, 
     {131/200, 22.80709288483071044515944731348017422076`15.998318125212473 + 
       1.42902499999999999999999999999999999999`16./eps^3 + 
       5.99534869223860884961364349329218846827`16./eps^2 + 
       14.67004540375384955073954474913750355939`16./eps}, 
     {33/50, 22.83056604023357284050106578686958153625`15.998284954260521 + 
       1.43560000000000000000000000000000000006`16./eps^3 + 
       6.01958330216910489770752918634632160703`16./eps^2 + 
       14.7205917998051613912407076249818638182`16./eps}, 
     {133/200, 22.85328990262986704559526000632318072974`15.998251189500799 + 
       1.44222500000000000000000000000000000001`16./eps^3 + 
       6.04384435002943804939379039858165403244`16./eps^2 + 
       14.77090571436615136729929968846129311612`16./eps}, 
     {67/100, 22.87526871420171813994051384519070475576`15.998216817859259 + 
       1.44890000000000000000000000000000000008`16./eps^3 + 
       6.06813053810301531944303889321050818814`16./eps^2 + 
       14.82098450827472569243776888621312392078`16./eps}, 
     {27/40, 22.89650675894756463386066049460689401353`15.998181826028855 + 
       1.45562500000000000000000000000000000004`16./eps^3 + 
       6.09244057590356938068382288200254943077`16./eps^2 + 
       14.87082557792014121784408892557724857313`16./eps}, 
     {17/25, 22.91700836149542972969969895272934559042`15.998146200466032 + 
       1.4624`16./eps^3 + 6.11677318004905179943685893885580049665`16./
        eps^2 + 14.92042635469279010678845030699659334128`16./eps}, 
     {137/200, 22.93677788594589480879633945956467214738`15.998109927387263 + 
       1.46922500000000000000000000000000000008`16./eps^3 + 
       6.14112707413831845643431087178187312535`16./eps^2 + 
       14.96978430444883410057348741816191570627`16./eps}, 
     {69/100, 22.955819734743700795166012858402992143`15.998072992765577 + 
       1.47610000000000000000000000000000000004`16./eps^3 + 
       6.16550098863052532536668054788040821835`16./eps^2 + 
       15.01889692698920680486931472019840659394`16./eps}, 
     {139/200, 22.97413834757694883340231866441497089924`15.998035382326941 + 
       1.483025`16./eps^3 + 6.1898936607271557569988457311425870099`16./
        eps^2 + 15.06776175555252119568233396257170275707`16./eps}, 
     {7/10, 22.99173820030291544180999478404533450456`15.997997081546746 + 
       1.48999999999999999999999999999999999997`16./eps^3 + 
       6.2143038342566032636682455721912097408`16./eps^2 + 
       15.11637635632143745740154876334150891061`16./eps}, 
     {141/200, 23.00862380389953874674896833029064662913`15.99795807564614 + 
       1.49702500000000000000000000000000000006`16./eps^3 + 
       6.23873025956123652339233829051543292594`16./eps^2 + 
       15.16473832794206336623374717633958477803`16./eps}, 
     {71/100, 23.02479970344167193500619661920459422214`15.997918349588435 + 
       1.50410000000000000000000000000000000003`16./eps^3 + 
       6.26317169338687593087094953098553332843`16./eps^2 + 
       15.21284530105597576310819395648451262713`16./eps}, 
     {143/200, 23.04027047710123764504459464906458614875`15.997877888075365 + 
       1.51122500000000000000000000000000000001`16./eps^3 + 
       6.28762689877461352012869256019176134156`16./eps^2 + 
       15.26069493784446726055776681414504391055`16./eps}, 
     {18/25, 23.05504073517045280753005892462771447645`15.997836675543462 + 
       1.51839999999999999999999999999999999999`16./eps^3 + 
       6.31209464495491047583675164985115389791`16./eps^2 + 
       15.3082849315846372356096836855226719004`16./eps}, 
     {29/40, 23.06911511910732755776178835791940125375`15.99779469616024 + 
       1.52562500000000000000000000000000000008`16./eps^3 + 
       6.33657370724390874261251065879010846534`16./eps^2 + 
       15.35561300621696041062505131194335158278`16./eps}, 
     {73/100, 23.08249830060267433778364739711208717974`15.997751933820439 + 
       1.53290000000000000000000000000000000006`16./eps^3 + 
       6.3610628669418954386662381134874547798`16./eps^2 + 
       15.40267691592397994956827793931477767577`16./eps}, 
     {147/200, 23.09519498066789422956664495983925634014`15.99770837214225 + 
       1.54022500000000000000000000000000000005`16./eps^3 + 
       6.38556091123386088662626508077642988201`16./eps^2 + 
       15.4494744447197850297257691920584986395`16./eps}, 
     {37/50, 23.10720988874283717050865821132464768186`15.997663994463469 + 
       1.54760000000000000000000000000000000003`16./eps^3 + 
       6.41006663309209309455764289267565984023`16./eps^2 + 
       15.49600340604994531801409763770700226448`16./eps}, 
     {149/200, 23.1185477818230607611692327708166264771`15.99761878383762 + 
       1.55502500000000000000000000000000000002`16./eps^3 + 
       6.43457883118075345818911117395178290898`16./eps^2 + 
       15.54226164240158671464349745424193741442`16./eps}, 
     {3/4, 23.12921344360583930589865649167136181455`15.997572723030046 + 
       1.56250000000000000000000000000000000001`16./eps^3 + 
       6.45909630976238031505368207261458429771`16./eps^2 + 
       15.58824702492330415139618658170511251502`16./eps}, 
     {151/200, 23.13921168365430035937945011129431881764`15.997525794514047 + 
       1.57002500000000000000000000000000000001`16./eps^3 + 
       6.4836178786062687662962495706670705022`16./eps^2 + 
       15.63395745305461817204117020244155837027`16./eps}, 
     {19/25, 23.14854733657909047857749355145070356521`15.997477980466883 + 
       1.5776`16./eps^3 + 6.50814235289867689577941547792007008285`16./
        eps^2 + 15.67939085416469250196594884890257854995`16./eps}, 
     {153/200, 23.15722526123699530252016266476346424158`15.997429262765795 + 
       1.585225`16./eps^3 + 6.53266855315481016211487724634471604026`16./
        eps^2 + 15.72454518320003985520074877493615711047`16./eps}, 
     {77/100, 23.16525033994596136622539009748840190386`15.99737962298405 + 
       1.5929`16./eps^3 + 6.55719530513253732047839950067186463274`16./
        eps^2 + 15.76941842234095285067242666840196742074`16./eps}, 
     {31/40, 23.17262747771598839276797608491560404497`15.997329042386834 + 
       1.600625`16./eps^3 + 6.58172143974779275048532230949620086707`16./
        eps^2 + 15.81400858066640613564627000297559333215`16./eps}, 
     {39/50, 23.17936160149538118355871910448371843152`15.997277501927273 + 
       1.60840000000000000000000000000000000001`16./eps^3 + 
       6.60624579299162152681151705331832581311`16./eps^2 + 
       15.85831369382718466171929833671184237013`16./eps}, 
     {157/200, 23.18545765943186972088564360998649103562`15.99722498224232 + 
       1.61622500000000000000000000000000000002`16./eps^3 + 
       6.63076720584882497329835266637240064045`16./eps^2 + 
       15.90233182372700154523852810411825629529`16./eps}, 
     {79/100, 23.19092062014812465928346632415906721508`15.997171463648607 + 
       1.62410000000000000000000000000000000002`16./eps^3 + 
       6.65528452421816579150043153056209122897`16./eps^2 + 
       15.94606105821137708650713590835524256712`16./eps}, 
     {159/200, 23.19575547203121341281078207565086480994`15.997116926138418 + 
       1.63202500000000000000000000000000000004`16./eps^3 + 
       6.67979659883409315341439075419272522123`16./eps^2 + 
       15.98949951076405833659638525063032401359`16./eps}, 
     {4/5, 23.19996722253555868103261914723267695323`15.997061349375425 + 
       1.64000000000000000000000000000000000005`16./eps^3 + 
       6.7043022851899493977379532400615489991`16./eps^2 + 
       16.03264532021076610215021621892391998827`16./eps}, 
     {161/200, 23.20356089749897808066469026832484569824`15.997004712690627 + 
       1.64802500000000000000000000000000000007`16./eps^3 + 
       6.72880044346262117160869903151077532034`16./eps^2 + 
       16.0754966504300634816127368018052533966`16./eps}, 
     {81/100, 23.20654154047139875982593332800924864597`15.996946995078078 + 
       1.65609999999999999999999999999999999997`16./eps^3 + 
       6.75328993843859901741218036117203881159`16./eps^2 + 
       16.11805169007114694444387736927113188485`16./eps}, 
     {163/200, 23.20891421205585602247603114266613742497`15.996888175190694 + 
       1.66422499999999999999999999999999999999`16./eps^3 + 
       6.77776963944141051887791282556000429436`16./eps^2 + 
       16.16030865227836761103245799522144044892`16./eps}, 
     {41/50, 23.21068398926139927096412720607904371812`15.996828231336032 + 
       1.67240000000000000000000000000000000001`16./eps^3 + 
       6.80223842026039319415237567994877333059`16./eps^2 + 
       16.20226577442229677742607650430739101591`16./eps}, 
     {33/40, 23.21185596486754226896961005430963924412`15.996767141472084 + 
       1.68062500000000000000000000000000000004`16./eps^3 + 
       6.82669515908077435761271056613973430411`16./eps^2 + 
       16.2439213178371558673081865710065242939`16./eps}, 
     {83/100, 23.21243524679990790824285482349001747856`15.996704883202902 + 
       1.68890000000000000000000000000000000006`16./eps^3 + 
       6.85113873841502616853987410158274250618`16./eps^2 + 
       16.28527356756443689491172289128535804291`16./eps}, 
     {167/200, 23.21242695751673023902058122454989456704`15.996641433774448 + 
       1.69722499999999999999999999999999999998`16./eps^3 + 
       6.87556804503546504500108101032389678054`16./eps^2 + 
       16.32632083210254519725843479736353746508`16./eps}, 
     {21/25, 23.2118362334058886023182632963575700774`15.996576770070218 + 
       1.70560000000000000000000000000000000001`16./eps^3 + 
       6.89998196990806554691730890830826271654`16./eps^2 + 
       16.36706144316230165222300993295658181456`16./eps}, 
     {169/200, 23.2106682241921602984982020970368462745`15.99651086860694 + 
       1.71402500000000000000000000000000000004`16./eps^3 + 
       6.92437940812745972475871403104314955167`16./eps^2 + 
       16.40749375542814684991595613479399729218`16./eps}, 
     {17/20, 23.20892809235438933067032155716379091029`15.996443705530316 + 
       1.72249999999999999999999999999999999996`16./eps^3 + 
       6.9487592588530937909966474837156220321`16./eps^2 + 
       16.44761614632489473776673425041123332462`16./eps}, 
     {171/200, 23.20662101255227940047752511012420593743`15.996375256610621 + 
       1.731025`16./eps^3 + 6.97312042524651480165815682261552413421`16./
        eps^2 + 16.4874270157898881230349064429675473034`16./eps}, 
     {43/50, 23.20375217106252959812068538916961427726`15.996305497238401 + 
       1.73960000000000000000000000000000000004`16./eps^3 + 
       6.99746181440976083632840794627083370646`16./eps^2 + 
       16.52692478605041309843070133919161934323`16./eps}, 
     {173/200, 23.20032676522404096721382298553536180006`15.996234402420168 + 
       1.74822499999999999999999999999999999997`16./eps^3 + 
       7.02178233732482893792100713156426722489`16./eps^2 + 
       16.56610790140623396484115333447231214071`16./eps}, 
     {87/100, 23.19635000289193174308440735610192514291`15.996161946773936 + 
       1.75690000000000000000000000000000000002`16./eps^3 + 
       7.04608090879419581962306722893939990168`16./eps^2 + 
       16.60497482801711456721401793993747443935`16./eps}, 
     {7/8, 23.19182710190010774196103660775520153058`15.996088104525004 + 
       1.76562500000000000000000000000000000006`16./eps^3 + 
       7.07035644738236706670592467099336116081`16./eps^2 + 
       16.64352405369519614247560054424861751864`16./eps}, 
     {22/25, 23.18676328953214352998696605669949019948`15.9960128495015 + 
       1.7744`16./eps^3 + 7.09460787535843125640881384766860073534`16./
        eps^2 + 16.681754087702105808642335243348056789`16./eps}, 
     {177/200, 23.18116380200023793690982189547555228265`15.995936155130078 + 
       1.78322500000000000000000000000000000005`16./eps^3 + 
       7.11883411863959609083949201362244187668`16./eps^2 + 
       16.71966346055067370840429061607293052383`16./eps}, 
     {89/100, 23.17503388393201586430460567135957088943`15.995857994431512 + 
       1.79209999999999999999999999999999999999`16./eps^3 + 
       7.14303410673568428673594778490581334712`16./eps^2 + 
       16.75725072381114056448634213375896760308`16./eps}, 
     {179/200, 23.16837878786495562865657381139736724986`15.995778340016424 + 
       1.80102500000000000000000000000000000005`16./eps^3 + 
       7.16720677269456759289757399619735031147`16./eps^2 + 
       16.79451444992174101381955479942963255668`16./eps}, 
     {9/10, 23.161203773748228953771279210744558331`15.995697164080784 + 
       1.80999999999999999999999999999999999999`16./eps^3 + 
       7.19135105304851791198282738343953013067`16./eps^2 + 
       16.83145323200355156850164569102993799264`16./eps}, 
     {181/200, 23.15351410845174748405890402994083590473`15.995614438401766 + 
       1.81902500000000000000000000000000000005`16./eps^3 + 
       7.21546588776145508900537520308648381977`16./eps^2 + 
       16.86806568367949540895576393886983448986`16./eps}, 
     {91/100, 23.14531506528221674074711211698624176414`15.995530134333217 + 
       1.8281`16./eps^3 + 7.23955022017707149502755233679478628639`16./
        eps^2 + 16.90435043889739945363317277582086318454`16./eps}, 
     {183/200, 23.13661192350600495118987948056744347106`15.995444222801462 + 
       1.83722500000000000000000000000000000007`16./eps^3 + 
       7.26360299696781408199950605575825101189`16./eps^2 + 
       16.9403061517570022748395322191860897084`16./eps}, 
     {23/25, 23.12740996787864055509655326346449170403`15.99535667430096 + 
       1.84640000000000000000000000000000000002`16./eps^3 + 
       7.28762316808470511414265607399008799995`16./eps^2 + 
       16.97593149634081444636973058102728250705`16./eps}, 
     {37/40, 23.11771448818075829279186102497798232556`15.995267458889938 + 
       1.85562499999999999999999999999999999997`16./eps^3 + 
       7.3116096867079832934137083098666620837`16./eps^2 + 
       17.01122516654873581997862201062128753736`16./eps}, 
     {93/100, 23.10753077876031962246549325535385072518`15.99517654618619 + 
       1.86490000000000000000000000000000000005`16./eps^3 + 
       7.33556150919854749206731936580610791911`16./eps^2 + 
       17.0461858759363370384637298050913969731`16./eps}, 
     {187/200, 23.09686413808093890539241969747381546935`15.995083905362806 + 
       1.87422500000000000000000000000000000001`16./eps^3 + 
       7.35947759505018578479017132037052213337`16./eps^2 + 
       17.08081235755671530727309162223825022116`16./eps}, 
     {47/50, 23.08571986827615220786651994658698146327`15.994989505143856 + 
       1.88360000000000000000000000000000000008`16./eps^3 + 
       7.38335690684257293690827521982787945719`16./eps^2 + 
       17.11510336380583706788139020472189392778`16./eps}, 
     {189/200, 23.074103274709470841862806675968068935`15.994893313800246 + 
       1.89302500000000000000000000000000000005`16./eps^3 + 
       7.4071984101950199543486992582479070743`16./eps^2 + 
       17.14905766627128274833590434917011164697`16./eps}, 
     {19/20, 23.06201966554006677049035044343365389347`15.994795299145508 + 
       1.90250000000000000000000000000000000001`16./eps^3 + 
       7.43100107372095973591809272723623236776`16./eps^2 + 
       17.18267405558431121283567450806450445272`16./eps}, 
     {191/200, 23.04947435129394191247915643479049232361`15.994695428531625 + 
       1.91202499999999999999999999999999999998`16./eps^3 + 
       7.45476386898315328957154516666429902817`16./eps^2 + 
       17.21595134127516389629500686330202025567`16./eps}, 
     {24/25, 23.0364726444404380335599249380589032507`15.994593668844875 + 
       1.92160000000000000000000000000000000007`16./eps^3 + 
       7.47848577044960138219249466974142837059`16./eps^2 + 
       17.24888835163153089473325464364390225985`16./eps}, 
     {193/200, 23.02301985897394845139261619163797989878`15.994489986501781 + 
       1.93122500000000000000000000000000000004`16./eps^3 + 
       7.50216575545014688747245265735210375288`16./eps^2 + 
       17.28148393356010349106580306912678268278`16./eps}, 
     {97/100, 23.00912131000069710320588857835915974012`15.994384347445054 + 
       1.94090000000000000000000000000000000001`16./eps^3 + 
       7.52580280413375347923296550335800363502`16./eps^2 + 
       17.31373695245113973135398295297106889932`16./eps}, 
     {39/40, 22.99478231333045475505340847356087265364`15.994276717139488 + 
       1.95062499999999999999999999999999999999`16./eps^3 + 
       7.54939589942644668841699258513252479264`16./eps^2 + 
       17.34564629204597173158676142784607747477`16./eps}, 
     {49/50, 22.98000818507306615855576324548336901915`15.994167060568085 + 
       1.96040000000000000000000000000000000009`16./eps^3 + 
       7.5729440269899037014199267879775697746`16./eps^2 + 
       17.37721085430738539227788506220181139364`16./eps}, 
     {197/200, 22.9648042412396658515692173226099225905`15.994055342228078 + 
       1.97022500000000000000000000000000000007`16./eps^3 + 
       7.59644617518067862584151673545774528283`16./eps^2 + 
       17.40842955929280513011859814388767135497`16./eps}, 
     {99/100, 22.94917579734846407988144823505422452801`15.993941526127031 + 
       1.98010000000000000000000000000000000005`16./eps^3 + 
       7.61990133501005028751198870587939782137`16./eps^2 + 
       17.43930134503021810506995986154687224057`16./eps}, 
     {199/200, 22.93312816803498800580286440243330887253`15.993825575779024 + 
       1.99002500000000000000000000000000000004`16./eps^3 + 
       7.64330850010447995015580830340344085502`16./eps^2 + 
       17.4698251673967742299489828612918273673`16./eps}, 
     {1, 22.91666666666666666582198447245096153744`15.993707454200903 + 
       2.00000000000000000000000000000000000003`16./eps^3 + 
       7.66666666666666666666666666666666666677`16./eps^2 + 
       17.5000000000000000000000000000000000003`16./eps}}
 
points9a = 
    {{1/10, -1.18477559569396427605308316875628331133`15.85381641366593 - 
       0.67`16./eps^3 - 1.53135918426327379017351324788017697544`16./eps^2 - 
       1.77907068296466489378597649297962746088`16./eps}, 
     {21/200, -1.19126503794403313890396660682151106144`15.8570545109738 - 
       0.67034166666666666666666666666666666673`16./eps^3 - 
       1.53403558909029136583250260298133472494`16./eps^2 - 
       1.7870653420299302868965424655656227054`16./eps}, 
     {11/100, -1.19739144515618566599342006744816958028`15.86032372025819 - 
       0.67070000000000000000000000000000000004`16./eps^3 - 
       1.53679135978292895530341920924331688262`16./eps^2 - 
       1.79516800966219118809411165981514016747`16./eps}, 
     {23/200, -1.20315015584825854461338524530234036305`15.863624845829127 - 
       0.67107500000000000000000000000000000005`16./eps^3 - 
       1.53962416950026811373173279591532930808`16./eps^2 - 
       1.80337062998065060091101354048091975783`16./eps}, 
     {3/25, -1.20853743397666244555072980727343787094`15.866958956298907 - 
       0.67146666666666666666666666666666666666`16./eps^3 - 
       1.54253179492128131123241033738522983383`16./eps^2 - 
       1.81166570797556118287835758554420921966`16./eps}, 
     {1/8, -1.21355034537294120257467806376444382268`15.870327358489952 - 
       0.67187499999999999999999999999999999997`16./eps^3 - 
       1.54551210742208076971226608902668535986`16./eps^2 - 
       1.82004625325974194810167680415139131473`16./eps}, 
     {13/100, -1.21818665360783703415145989092317614468`15.87373157692786 - 
       0.67229999999999999999999999999999999999`16./eps^3 - 
       1.54856306533543210661383750673921095907`16./eps^2 - 
       1.82850573139689306611636303894875725006`16./eps}, 
     {27/200, -1.22244473168491751396746266280207270768`15.877173337989918 - 
       0.67274166666666666666666666666666666672`16./eps^3 - 
       1.55168270712240907106954981060808125034`16./eps^2 - 
       1.8370380215374128082409292042074129055`16./eps}, 
     {7/50, -1.22632348673252484340993051235907081359`15.880654557979915 - 
       0.67320000000000000000000000000000000003`16./eps^3 - 
       1.55486914531824085530219593500489382675`16./eps^2 - 
       1.84563737934410801374301607256825603011`16./eps}, 
     {29/200, -1.22982229544558992532414415147034891592`15.88417733455615 - 
       0.67367500000000000000000000000000000006`16./eps^3 - 
       1.55812056113954018805525888487605981898`16./eps^2 - 
       1.85429840438473647112980445454981541132`16./eps}, 
     {3/20, -1.23294094847650716321074603815977966166`15.887743941062997 - 
       0.67416666666666666666666666666666666667`16./eps^3 - 
       1.561435199659932329295899512632450339`16./eps^2 - 
       1.86301601132023297150596259910267238212`16./eps}, 
     {31/200, -1.23567960232146978077221966936810613095`15.891356823414558 - 
       0.67467499999999999999999999999999999999`16./eps^3 - 
       1.56481136547689427595069865155181959348`16./eps^2 - 
       1.87178540433720996053613643572509078589`16./eps}, 
     {4/25, -1.23803873752038527966121684899057835047`15.895018599259044 - 
       0.67520000000000000000000000000000000001`16./eps^3 - 
       1.56824741880529007267072992657585550025`16./eps^2 - 
       1.88060205436852529093800016750721363079`16./eps}, 
     {33/200, -1.24001912220291549738154387512979466307`15.898732059217307 - 
       0.67574166666666666666666666666666666662`16./eps^3 - 
       1.57174177194334537413334181372894608057`16./eps^2 - 
       1.88946167872201420643260369472537151751`16./eps}, 
     {17/100, -1.24162178018371327724128753340073165653`15.902500170044393 - 
       0.67630000000000000000000000000000000006`16./eps^3 - 
       1.57529288606516452915036168895755622762`16./eps^2 - 
       1.89836022279910183420864118517951744563`16./eps}, 
     {7/40, -1.24284796294652957761101852647053386109`15.906326079608897 - 
       0.67687499999999999999999999999999999997`16./eps^3 - 
       1.5788992683007536626393383613044079227`16./eps^2 - 
       1.90729384363512217149820773538650929391`16./eps}, 
     {9/50, -1.24369912496703362893049831192619789307`15.910213123625878 - 
       0.6774666666666666666666666666666666667`16./eps^3 - 
       1.58255946907017842429683563417572221411`16./eps^2 - 
       1.91625889503418749622647323338074837673`16./eps}, 
     {37/200, -1.24417690191360446698402603089891673052`15.914164834114747 - 
       0.67807500000000000000000000000000000002`16./eps^3 - 
       1.58627207964319130701067154342233287717`16./eps^2 - 
       1.92525191410523484353626680859363117495`16./eps}, 
     {19/100, -1.24428309133835859835770264251793578452`15.918184949586932 - 
       0.67870000000000000000000000000000000005`16./eps^3 - 
       1.59003572989959493111310642607039291635`16./eps^2 - 
       1.93426960903386101882889664563853365892`16./eps}, 
     {39/200, -1.24401963553062184406531120748261056537`15.92227742699916 - 
       0.67934166666666666666666666666666666667`16./eps^3 - 
       1.59384908626890928925642044144769278214`16./eps^2 - 
       1.94330884794786596557229956783452131716`16./eps}, 
     {1/5, -1.24338860625453237272887088791814502984`15.9264464555383 - 
       0.68`16./eps^3 - 1.59771084983069734831736370666238083887`16./eps^2 - 
       1.95236664875393742777526758685780120677`16./eps}, 
     {41/200, -1.24239219113350753730720345136167216352`15.930696472334278 - 
       0.68067500000000000000000000000000000003`16./eps^3 - 
       1.60161975455926603924580396425193696135`16./eps^2 - 
       1.96144016983932501719810762775433807071`16./eps}, 
     {21/100, -1.24103268147851817174403514046921271558`15.935032180228392 - 
       0.68136666666666666666666666666666666665`16./eps^3 - 
       1.60557456569847187518471047536903331338`16./eps^2 - 
       1.97052670154622428180948776843601750434`16./eps}, 
     {43/200, -1.23931246138575633143058812859077214472`15.939458567757631 - 
       0.68207499999999999999999999999999999997`16./eps^3 - 
       1.60957407825408140572357605295389523687`16./eps^2 - 
       1.97962365833836605820231715721179751771`16./eps}, 
     {11/50, -1.2372339979533645676191765466855073144`15.943980931550476 - 
       0.68280000000000000000000000000000000001`16./eps^3 - 
       1.61361711559261446823788280229469178487`16./eps^2 - 
       1.98872857158934178223351825818203713721`16./eps}, 
     {9/40, -1.23479983248722450120204910377123819479`15.948604901369341 - 
       0.68354166666666666666666666666666666663`16./eps^3 - 
       1.61770252813687191907813698945263058784`16./eps^2 - 
       1.99783908293078201340432178384025944603`16./eps}, 
     {23/100, -1.23201257258303049815422123834207692638`15.953336468077907 - 
       0.68429999999999999999999999999999999996`16./eps^3 - 
       1.62182919214945134805875960443617969189`16./eps^2 - 
       2.00695293810587979569316660051635216209`16./eps}, 
     {47/200, -1.22887488498652685464562499813633162673`15.958182014861231 - 
       0.68507499999999999999999999999999999999`16./eps^3 - 
       1.62599600859651067338850013267258086833`16./eps^2 - 
       2.01606798128010629121319029729697066982`16./eps}, 
     {6/25, -1.22538948914629320381398665434577759126`15.963148352082937 - 
       0.68586666666666666666666666666666666674`16./eps^3 - 
       1.63020190208487239510720877934492836512`16./eps^2 - 
       2.02518214976646264815572718712279089842`16./eps}, 
     {49/200, -1.22155915138417195451747153395904329728`15.96824275622929 - 
       0.68667499999999999999999999999999999995`16./eps^3 - 
       1.63444581986628887261956496870836457844`16./eps^2 - 
       2.03429346912738086898923492380239447401`16./eps}, 
     {1/4, -1.21738667961763151159289187808463708468`15.973473013465812 - 
       0.68749999999999999999999999999999999999`16./eps^3 - 
       1.63872673090332649701048734851560540421`16./eps^2 - 
       2.04340004861953668352108366194621038485`16./eps}, 
     {51/200, -1.21287491857628615210526592512822931675`15.978847468421751 - 
       0.68834166666666666666666666666666666661`16./eps^3 - 
       1.64304362499188680165019349732143220958`16./eps^2 - 
       2.05250007695146003569754844534373322581`16./eps}, 
     {13/50, -1.20802674546164377494730593570978182656`15.984375078922456 - 
       0.68920000000000000000000000000000000007`16./eps^3 - 
       1.64739551193587612353874513554627110055`16./eps^2 - 
       2.06159181832699981105670446568850225868`16./eps}, 
     {53/200, -1.20284506600508909533954911393912378153`15.990065477515298 - 
       0.69007499999999999999999999999999999999`16./eps^3 - 
       1.65178142076997145320469001358483715378`16./eps^2 - 
       2.07067360875048270356914304648444378647`16./eps}, 
     {27/100, -1.19733281088426781817361397504241619275`15.995929040783233 - 
       0.69096666666666666666666666666666666662`16./eps^3 - 
       1.65620039902681627122168302077802392984`16./eps^2 - 
       2.0797438525718554310074653004286159536`16./eps}, 
     {11/40, -1.19149293246253050900721487973885776441`15.999628856802227 - 
       0.69187499999999999999999999999999999996`16./eps^3 - 
       1.66065151204532299384186581238077467921`16./eps^2 - 
       2.08880101925226032697812251974645716413`16./eps}, 
     {7/25, -1.18532840182001854074659814764178628265`15.99928692788645 - 
       0.69279999999999999999999999999999999999`16./eps^3 - 
       1.66513384231706370895047274169725426429`16./eps^2 - 
       2.09784364033240523351703525594870543596`16./eps}, 
     {57/200, -1.17884220604840893538952954141840231208`15.998938091035777 - 
       0.69374166666666666666666666666666666663`16./eps^3 - 
       1.6696464888680029430783253433547923034`16./eps^2 - 
       2.1068703065877824090006571216624784508`16./eps}, 
     {29/100, -1.17203734578434798558959006013884328568`15.998581994722853 - 
       0.69469999999999999999999999999999999997`16./eps^3 - 
       1.674188566673069351699046318089606627`16./eps^2 - 
       2.11587966535629586332274845647262541466`16./eps}, 
     {59/200, -1.16491683295925262936702464199743592172`15.998218270530028 - 
       0.69567500000000000000000000000000000001`16./eps^3 - 
       1.67875920610128098999883758761808805413`16./eps^2 - 
       2.1248704180251961147152066636584141545`16./eps}, 
     {3/10, -1.15748368874549268002220459255025463527`15.997846531940167 - 
       0.69666666666666666666666666666666666665`16./eps^3 - 
       1.68335755238933423933604715959856546525`16./eps^2 - 
       2.13384131766541641556157766431586609128`16./eps}, 
     {61/200, -1.14974094168102761191694588269018745211`15.997466373028361 - 
       0.69767499999999999999999999999999999999`16./eps^3 - 
       1.68798276514174216633832069022983835759`16./eps^2 - 
       2.14279116680247273847328794601266884988`16./eps}, 
     {31/100, -1.14169162595639445048687123571996381223`15.99707736704515 - 
       0.69870000000000000000000000000000000003`16./eps^3 - 
       1.69263401785576635956779859933514760608`16./eps^2 - 
       2.15171881531404654327740386213883932744`16./eps}, 
     {63/200, -1.13333877984955877208366724460174287084`15.996679064880519 - 
       0.69974166666666666666666666666666666667`16./eps^3 - 
       1.69731049746952910836383021819837491222`16./eps^2 - 
       2.16062315844522779474990841441697422024`16./eps}, 
     {8/25, -1.12468544429557512275142154555328511529`15.996270993397195 - 
       0.70080000000000000000000000000000000001`16./eps^3 - 
       1.70201140393182189099859513706610472858`16./eps^2 - 
       2.16950313493316734979460036786361434945`16./eps}, 
     {13/40, -1.11573466157927889298043593297993836174`15.995852653619586 - 
       0.70187500000000000000000000000000000006`16./eps^3 - 
       1.70673594979224303757647435537707232508`16./eps^2 - 
       2.17835772523358266298188889777826357344`16./eps}, 
     {33/100, -1.10648947414036822706010952180264426793`15.995423518764044 - 
       0.7029666666666666666666666666666666667`16./eps^3 - 
       1.71148335981040345233783067688898889436`16./eps^2 - 
       2.18718594984218746986059391896785103274`16./eps}, 
     {67/200, 
      -1.0969529234812488198052112342185588871425578658711098572561`32. - 
       0.704075000000000000000000000000000000000000000000000000002`32./
        eps^3 - 
       1.7162528705830355834140465603759639593992995199705638694846`32./
        eps^2 - 
       2.1959868677046822961438716421533577899127183339161631684119`32./eps}, 
     {17/50, -1.08712804916892103831507696100983717715`15.994530604577207 - 
       0.70519999999999999999999999999999999998`16./eps^3 - 
       1.72104373018792843883281472258965969931`16./eps^2 - 
       2.20475957470945495825966345360990999025`16./eps}, 
     {69/200, -1.07701788792300021828078422978287122901`15.994065612337387 - 
       0.70634166666666666666666666666666666662`16./eps^3 - 
       1.72585519784369126756727609891326015058`16./eps^2 - 
       2.21350320225760450022869432758288075215`16./eps}, 
     {7/20, -1.06662547278268870026415990466725033438`15.993587393854261 - 
       0.70749999999999999999999999999999999997`16./eps^3 - 
       1.73068654358442135015374251033900506148`16./eps^2 - 
       2.22221691590532338036998096253037387811`16./eps}, 
     {71/200, -1.05595383234617115947568700318171878303`15.993095246907627 - 
       0.70867500000000000000000000000000000002`16./eps^3 - 
       1.73553704794841787963633025013333891179`16./eps^2 - 
       2.2308999140740556938762077432971585854`16./eps}, 
     {9/25, -1.04500599007649218513265447197756096084`15.992588425222033 - 
       0.70986666666666666666666666666666666667`16./eps^3 - 
       1.74040600168014478508686925376190917464`16./eps^2 - 
       2.23955142682419777735977646803154029952`16./eps}, 
     {73/200, -1.03378496366850357051751533712015477021`15.992066134782396 - 
       0.71107500000000000000000000000000000001`16./eps^3 - 
       1.74529270544470111151374170328299791566`16./eps^2 - 
       2.24817071468842521014900328996170980731`16./eps}, 
     {37/100, -1.02229376447194548864417028826091931182`15.991527529781003 - 
       0.71229999999999999999999999999999999995`16./eps^3 - 
       1.75019646955410871518346709626170713654`16./eps^2 - 
       2.25675706756102012235023207088520177776`16./eps}, 
     {3/8, -1.01053539696615571323193945526820740907`15.990971708152225 - 
       0.71354166666666666666666666666666666671`16./eps^3 - 
       1.75511661370477400205793843979793806235`16./eps^2 - 
       2.26530980363983760721155432810524507436`16./eps}, 
     {19/50, -0.99851285828228982240183851112259938647`15.990397706644533 - 
       0.71479999999999999999999999999999999995`16./eps^3 - 
       1.76005246672552362177257738594301098113`16./eps^2 - 
       2.27382826841779237256626806891823717836`16./eps}, 
     {77/200, -0.98622913776928699331094036641419676947`15.989804495372805 - 
       0.71607500000000000000000000000000000001`16./eps^3 - 
       1.7650033663356537813060136340369047186`16./eps^2 - 
       2.28231183372096874019393157097556806706`16./eps}, 
     {39/100, -0.973687216600134507507841906139566354`15.989190971785469 - 
       0.71736666666666666666666666666666666666`16./eps^3 - 
       1.76996865891246947546332076011698247242`16./eps^2 - 
       2.29075989679066066240752251055149309828`16./eps}, 
     {79/200, -0.96089006741527302089368136341952727398`15.98855595397136 - 
       0.71867500000000000000000000000000000001`16./eps^3 - 
       1.77494769926782372730463738040846404576`16./eps^2 - 
       2.2991718794068353126343195982904010088`16./eps}, 
     {2/5, -0.94784065400024684289273314231104843104`15.987898173220346 - 
       0.71999999999999999999999999999999999995`16./eps^3 - 
       1.77993985043319814376269768721621510473`16./eps^2 - 
       2.3075472270506855775199896156129030696`16./eps}, 
     {81/200, -0.93454193099494178251729483477110123885`15.987216265738105 - 
       0.72134166666666666666666666666666666672`16./eps^3 - 
       1.78494448345289494749484319548651397509`16./eps^2 - 
       2.31588540810409482575128708542921653759`16./eps}, 
     {41/100, -0.92099684363197003964143782902187372519`15.986508763400627 - 
       0.72269999999999999999999999999999999996`16./eps^3 - 
       1.78996097718493735047017913739062836967`16./eps^2 - 
       2.32418591308398290304724019310392734777`16./eps}, 
     {83/200, -0.90720832750195881392819074204143035439`15.985774083415455 - 
       0.72407500000000000000000000000000000002`16./eps^3 - 
       1.79498871810929987273715008836114076777`16./eps^2 - 
       2.33244825390963652580267813824520295001`16./eps}, 
     {21/50, -0.89317930834367952909273355555088130157`15.985010516735455 - 
       0.72546666666666666666666666666666666667`16./eps^3 - 
       1.80002710014311314815764215525091090719`16./eps^2 - 
       2.34067196320125112675377646972622414536`16./eps}, 
     {17/40, -0.8789127018571185379269552192416886414`15.984216215045512 - 
       0.72687500000000000000000000000000000004`16./eps^3 - 
       1.80507552446250904854098595335912942301`16./eps^2 - 
       2.34885659360802565332980693387173462762`16./eps}, 
     {43/100, -0.86441141353774021777821450964746148232`15.983389176112238 - 
       0.72829999999999999999999999999999999998`16./eps^3 - 
       1.81013339933079173518305799255796410073`16./eps^2 - 
       2.35700171716425765216788939432173186033`16./eps}, 
     {87/200, -0.84967833853033033761238304800718166654`15.98252722725088 - 
       0.72974166666666666666666666666666666664`16./eps^3 - 
       1.81520013993263863614306468392787344539`16./eps^2 - 
       2.36510692467198393099573235611393826862`16./eps}, 
     {11/25, -0.83471636150093312868608379000020837439`15.981628006620344 - 
       0.7312`16./eps^3 - 1.82027516821405246104835507046446415487`16./
        eps^2 - 2.37317182510880283999346160660773908246`16./eps}, 
     {89/200, -0.81952835652550986438001717795377936614`15.980688942005484 - 
       0.73267500000000000000000000000000000007`16./eps^3 - 
       1.82535791272780130490312081737168430095`16./eps^2 - 
       2.38119604505959836352444819255502185967`16./eps}, 
     {9/20, -0.80411718699405248697139675740316584276`15.979707226683125 - 
       0.73416666666666666666666666666666666672`16./eps^3 - 
       1.83044780848409875115555845321524159675`16./eps^2 - 
       2.38917922817096430759079166530416982833`16./eps}, 
     {91/200, -0.78848570552898180368847400419424234686`15.978679791892445 - 
       0.73567499999999999999999999999999999997`16./eps^3 - 
       1.8355442968062897467121762857888889698`16./eps^2 - 
       2.397121034627199405373045339960390557`16./eps}, 
     {23/50, -0.77263675391674855892274343836124532273`15.977603275338147 - 
       0.73720000000000000000000000000000000004`16./eps^3 - 
       1.84064682519132096476235210084416860555`16./eps^2 - 
       2.40502114064681159388823394557754578523`16./eps}, 
     {93/200, -0.7565731630516369077450554294758618537`15.976473985041936 - 
       0.7387416666666666666666666666666666667`16./eps^3 - 
       1.84575484717478646553435096261280322171`16./eps^2 - 
       2.41287923799853244921234470948916011291`16./eps}, 
     {47/100, -0.74029775289084461398951225618682516002`15.975287857719422 - 
       0.74029999999999999999999999999999999995`16./eps^3 - 
       1.85086782220035077470373395506021226799`16./eps^2 - 
       2.42069503353590117900057406255595088608`16./eps}, 
     {19/40, -0.72381333241998285448103657909816377469`15.974040410688799 - 
       0.74187500000000000000000000000000000002`16./eps^3 - 
       1.85598521549336208287488183578479822968`16./eps^2 - 
       2.42846824874953199908782678109973082384`16./eps}, 
     {12/25, -0.70712269962820216160492901462453324327`15.972726686105412 - 
       0.74346666666666666666666666666666666668`16./eps^3 - 
       1.86110649793847818113910483659574957933`16./eps^2 - 
       2.436198619336229475678696972406306893`16./eps}, 
     {97/200, -0.69022864149220882190116212024031642897`15.971341186052666 - 
       0.74507500000000000000000000000000000005`16./eps^3 - 
       1.8662311459611370364548599954942776639`16./eps^2 - 
       2.44388589478416377890870682126552919038`16./eps}, 
     {49/100, -0.67313393396849019989667597628527309912`15.969877796688191 - 
       0.74670000000000000000000000000000000001`16./eps^3 - 
       1.8713586414127126216871824424713501197`16./eps^2 - 
       2.45152983797336202581037922504755545506`16./eps}, 
     {99/200, -0.65584134199311670560518540319545307716`15.968329699226667 - 
       0.74834166666666666666666666666666666667`16./eps^3 - 
       1.87648847145920479006595635938357286525`16./eps^2 - 
       2.45913022479081322728342749787273979073`16./eps}, 
     {1/2, -0.63835361948853398677703127440931710608`15.96668926501044 - 
       0.75000000000000000000000000000000000004`16./eps^3 - 
       1.88162012847331966068764136369787747535`16./eps^2 - 
       2.46668684375952301087539169231075452699`16./eps}, 
     {101/200, -0.62067350937680110749322730358453401683`15.964947931242232 - 
       0.751675`16./eps^3 - 1.88675310992980419553909683355047971696`16./
        eps^2 - 2.4741994956808904672224772969997539025`16./eps}, 
     {51/100, -0.60280374359876944619428741999930929047`15.96309605308276 - 
       0.75336666666666666666666666666666666666`16./eps^3 - 
       1.89188691830390543162135191449445711316`16./eps^2 - 
       2.4816679932898133446252687884847915729`16./eps}, 
     {103/200, -0.58474704313873313060111913506246364548`15.961122726687409 - 
       0.75507500000000000000000000000000000004`16./eps^3 - 
       1.8970210609728312138087597408743503659`16./eps^2 - 
       2.48909216092195956024709325407002455895`16./eps}, 
     {13/25, -0.56650611805411517169746611593374467001`15.959015576281493 - 
       0.7568`16./eps^3 - 1.90215505012009528248856097654279345807`16./
        eps^2 - 2.49647183419267276105179614856536248547`16./eps}, 
     {21/40, -0.54808366750978439174401969378309483153`15.956760496431544 - 
       0.75854166666666666666666666666666666667`16./eps^3 - 
       1.90728840264263523006323078331290015752`16./eps^2 - 
       2.50380685968700759371519498057408799002`16./eps}, 
     {53/100, -0.52948237981662661808423381826339312733`15.949858040186388 - 
       0.76030000000000000000000000000000000004`16./eps^3 - 
       1.91242064006059717540345955142174681744`16./eps^2 - 
       2.51109709466041655997116821264643804243`16./eps}, 
     {107/200, -0.51070493247402051165111183591479656738`15.903027928571133 - 
       0.76207500000000000000000000000000000001`16./eps^3 - 
       1.91755128842968603688332825412927675243`16./eps^2 - 
       2.51834240674963496155314821460950105334`16./eps}, 
     {27/50, -0.49175399221589225010642840420489221384`15.85734170980173 - 
       0.76386666666666666666666666666666666668`16./eps^3 - 
       1.92267987825598503266066719649489143216`16./eps^2 - 
       2.52554267369333358707070932946403214985`16./eps}, 
     {109/200, -0.47263221506004693642436267221361579691`15.812514178389511 - 
       0.76567500000000000000000000000000000005`16./eps^3 - 
       1.92780594441315251984930210864725666041`16./eps^2 - 
       2.53269778306213056327953748462693920651`16./eps}, 
     {11/20, -0.45334224636049494410263820860300887047`15.768289467376487 - 
       0.76750000000000000000000000000000000002`16./eps^3 - 
       1.93292902606190851926875053278200030477`16./eps^2 - 
       2.53980763199757427891169450814302034954`16./eps}, 
     {111/200, -0.4338867208625113907160675541623004809`15.724431393546343 - 
       0.76934166666666666666666666666666666669`16./eps^3 - 
       1.93804866657172727540402347669793491466`16./eps^2 - 
       2.54687212695972857703781958578457438163`16./eps}, 
     {14/25, -0.41426826276018534841653179770970837548`15.680715448727728 - 
       0.77119999999999999999999999999999999996`16./eps^3 - 
       1.94316441344465598676864697349973288585`16./eps^2 - 
       2.55389118348300958179923159100963127508`16./eps}, 
     {113/200, -0.39448948575623128502716112202914086333`15.63692172132858 - 
       0.77307500000000000000000000000000000004`16./eps^3 - 
       1.94827581824118342368770497549947755839`16./eps^2 - 
       2.56086472593994065124852213154829420386`16./eps}, 
     {57/100, -0.37455299312385278130764548406971368099`15.592828174591146 - 
       0.77496666666666666666666666666666666672`16./eps^3 - 
       1.95338243650808554128364265715740764641`16./eps^2 - 
       2.567792687312508098449622550762437745`16./eps}, 
     {23/40, -0.35446137777046113803983451125444984067`15.54820376075871 - 
       0.77687499999999999999999999999999999998`16./eps^3 - 
       1.95848382770817840694094384333532441347`16./eps^2 - 
       2.57467500897081556134696069304612177242`16./eps}, 
     {29/50, -0.33421722230306653339357325530025211818`15.502800826236562 - 
       0.77879999999999999999999999999999999995`16./eps^3 - 
       1.9635795551519118047082283866998959106`16./eps^2 - 
       2.58151164045874928702114295869653692734`16./eps}, 
     {117/200, -0.31382309909517148908601638674489891503`15.456346156078732 - 
       0.78074166666666666666666666666666666663`16./eps^3 - 
       1.96866918593073976417004617182342367971`16./eps^2 - 
       2.588302539286380182351698464985837095`16./eps}, 
     {59/100, -0.29328157035500800683801035726027451299`15.40852979010039 - 
       0.78270000000000000000000000000000000002`16./eps^3 - 
       1.97375229085220699778721184899276095329`16./eps^2 - 
       2.59504767072884132143649464354392444254`16./eps}, 
     {119/200, -0.27259518819497150528773310255535470952`15.358990360035717 - 
       0.78467499999999999999999999999999999999`16./eps^3 - 
       1.97882844437669282741844378653182304444`16./eps^2 - 
       2.60174700763143173739918951560367424211`16./eps}, 
     {3/5, -0.2517664947021130972113191092948587467`15.307295035284676 - 
       0.78666666666666666666666666666666666667`16./eps^3 - 
       1.98389722455575664595398507466931829654`16./eps^2 - 
       2.60840053022070880615753354783936942712`16./eps}, 
     {121/200, -0.23079802200956466675250616558873275194`15.252911005796312 - 
       0.78867500000000000000000000000000000005`16./eps^3 - 
       1.98895821297203130141760056874237832583`16./eps^2 - 
       2.61500822592134239297347027375068504199`16./eps}, 
     {61/100, -0.20969229236877464765300671307025148996`15.195163336435225 - 
       0.79070000000000000000000000000000000003`16./eps^3 - 
       1.99401099468061301571913068852476592953`16./eps^2 - 
       2.62157008917851421698521575880714119095`16./eps}, 
     {123/200, -0.18845181822244774089006273556480062589`15.133170073758238 - 
       0.79274166666666666666666666666666666671`16./eps^3 - 
       1.99905515815189856518426904853241036754`16./eps^2 - 
       2.62808612128565562965086198072170458951`16./eps}, 
     {31/50, -0.16707910227808247104062220559930304051`15.065737600312092 - 
       0.79479999999999999999999999999999999998`16./eps^3 - 
       2.00409029521582246133121036985206735174`16./eps^2 - 
       2.63455633021732623292511634774920207713`16./eps}, 
     {5/8, -0.14557663758201238254140889815904765183`14.991182396396411 - 
       0.79687499999999999999999999999999999996`16./eps^3 - 
       2.00911600100744878397823061112565445368`16./eps^2 - 
       2.64098073046704451263390204390829308859`16./eps}, 
     {63/100, -0.12394690759386246505502847443745357462`14.907006256751965 - 
       0.79896666666666666666666666666666666665`16./eps^3 - 
       2.01413187391387414014762144378674936892`16./eps^2 - 
       2.64735934288988996043693242585445379885`16./eps}, 
     {127/200, -0.10219238626133620651773911446565387291`14.809250776572267 - 
       0.80107500000000000000000000000000000004`16./eps^3 - 
       2.01913751552239995652485164444711009433`16./eps^2 - 
       2.65369219454970403060350002442692265717`16./eps}, 
     {16/25, -0.08031553809525818836827319994025350051`14.691054434513719 - 
       0.80320000000000000000000000000000000002`16./eps^3 - 
       2.02413253056993396525708227131514979219`16./eps^2 - 
       2.65997931857072475043609065236030045591`16./eps}, 
     {129/200, -0.05831881824480047478774928574420428035`14.538827966987515 - 
       0.8053416666666666666666666666666666667`16./eps^3 - 
       2.02911652689358231714947757689436337638`16./eps^2 - 
       2.66622075399349689879097832317899695124`16./eps}, 
     {13/20, -0.03620467257282541703179824695807178273`14.318872363591305 - 
       0.80749999999999999999999999999999999998`16./eps^3 - 
       2.03408911538239525707711685019220970818`16./eps^2 - 
       2.67241654563490640748101187539979011156`16./eps}, 
     {131/200, -0.01397553773128475991998776833930692517`13.8928725391995 - 
       0.80967499999999999999999999999999999996`16./eps^3 - 
       2.03904990993023072764899227554184039754`16./eps^2 - 
       2.67856674395219404571457629490898687924`16./eps}, 
     {33/50, 0.00836615876338289011094818456447763381`13.65771908248127 - 
       0.81186666666666666666666666666666666665`16./eps^3 - 
       2.04399852738970163256917639544877386469`16./eps^2 - 
       2.68467140491080953713307195707265450522`16./eps}, 
     {133/200, 0.03081799845490897574192794947738272061`14.211965086349919 - 
       0.81407500000000000000000000000000000005`16./eps^3 - 
       2.04893458752717379424237457730499578856`16./eps^2 - 
       2.69073058985597305025260086889633419969`16./eps}, 
     {67/100, 0.05337757187195475985547296781069309575`14.438752865244988 - 
       0.81630000000000000000000000000000000003`16./eps^3 - 
       2.05385771297878288425879074218128037625`16./eps^2 - 
       2.69674436538781651286341444951378717347`16./eps}, 
     {27/40, 0.07604247845302106030332334456197544201`14.580937338518678 - 
       0.81854166666666666666666666666666666672`16./eps^3 - 
       2.05876752920743979356127429400084981026`16./eps^2 - 
       2.70271280323998244481570698722473943628`16./eps}, 
     {17/25, 0.09881032647154713096225397058055602658`14.683412796907913 - 
       0.8208`16./eps^3 - 2.06366366446079504425673075739637795225`16./
        eps^2 - 2.70863598016156299627118508235390055657`16./eps}, 
     {137/200, 0.12167873296124036930964722714367558388`14.762786374387131 - 
       0.82307499999999999999999999999999999999`16./eps^3 - 
       2.06854574973013392992254806837173548607`16./eps^2 - 
       2.7145139778022666336684953833185666379`16./eps}, 
     {69/100, 0.14464532364167090168983338411070161138`14.827059335831233 - 
       0.82536666666666666666666666666666666669`16./eps^3 - 
       2.07341341871017510845556018262680273846`16./eps^2 - 
       2.72034688260070444623459990863730018059`16./eps}, 
     {139/200, 0.1677077328441648083343811804419682034`14.88070406746623 - 
       0.82767499999999999999999999999999999997`16./eps^3 - 
       2.07826630775974636344405968815863957738`16./eps^2 - 
       2.72613478567569236398419754412986819337`16./eps}, 
     {7/10, 0.19086360343802630916868822075201047735`14.926474299217576 - 
       0.82999999999999999999999999999999999996`16./eps^3 - 
       2.08310405586331219900052630184151372751`16./eps^2 - 
       2.73187778272046969516228440985897399376`16./eps}, 
     {141/200, 0.21411058675711701684182247286817453701`14.96618556895281 - 
       0.83234166666666666666666666666666666665`16./eps^3 - 
       2.08792630459332884113077943017180947326`16./eps^2 - 
       2.73757597389973831769352780614975964632`16./eps}, 
     {71/100, 0.23744634252681792918893984816974683467`15.001097574749343 - 
       0.83470000000000000000000000000000000005`16./eps^3 - 
       2.09273269807340308806809428810628883924`16./eps^2 - 
       2.74322946374943060546017490883243412163`16./eps}, 
     {143/200, 0.26086853879139795188322346597293946755`15.03211969036076 - 
       0.83707500000000000000000000000000000005`16./eps^3 - 
       2.09752288294223228448734196450836460339`16./eps^2 - 
       2.74883836107911774559518968611036000179`16./eps}, 
     {18/25, 0.28437485184181042168665748390680598388`15.05992952465432 - 
       0.83946666666666666666666666666666666663`16./eps^3 - 
       2.10229650831830349194558388328371796121`16./eps^2 - 
       2.75440277887697351634949190945583458782`16./eps}, 
     {29/40, 0.30796296614393764076045995041809946772`15.085045247057085 - 
       0.84187500000000000000000000000000000003`16./eps^3 - 
       2.10705322576533069198194799737448059944`16./eps^2 - 
       2.75992283421721185485106745636326066703`16./eps}, 
     {73/100, 0.33163057426730133389254604964495825197`15.107871754785506 - 
       0.84430000000000000000000000000000000003`16./eps^3 - 
       2.11179268925840959066652381560692936966`16./eps^2 - 
       2.76539864816991965811185454989166703457`16./eps}, 
     {147/200, 0.35537537681425542016678525599571995676`15.128731270591963 - 
       0.84674166666666666666666666666666666673`16./eps^3 - 
       2.11651455515087029554208836025880975693`16./eps^2 - 
       2.77083034571320923639261712423868169394`16./eps}, 
     {37/50, 0.37919508234967621525386094219086405321`15.14788427388398 - 
       0.84920000000000000000000000000000000002`16./eps^3 - 
       2.12121848214180880929699207533633105776`16./eps^2 - 
       2.77621805564761768251699831641647889831`16./eps}, 
     {149/200, 0.40308740733116327107955504971853120372`15.165544211788585 - 
       0.85167500000000000000000000000000000001`16./eps^3 - 
       2.12590413124427893050748150242837179798`16./eps^2 - 
       2.7815619105126831405447997444825632245`16./eps}, 
     {3/4, 0.42705007603976330169202611754433930213`15.18188808328549 - 
       0.85416666666666666666666666666666666671`16./eps^3 - 
       2.13057116575412677168456069087152793019`16./eps^2 - 
       2.78686204650563055860836837692785329727`16./eps}, 
     {151/200, 0.45108082051122764037199457176458569863`15.197064211351872 - 
       0.85667500000000000000000000000000000001`16./eps^3 - 
       2.13521925121945069987652763466680124904`16./eps^2 - 
       2.79211860340210199957129885341651850208`16./eps}, 
     {19/25, 0.47517738046781375929770738383337916221`15.211198053899656 - 
       0.85920000000000000000000000000000000001`16./eps^3 - 
       2.13984805541067007637091627041780109144`16./eps^2 - 
       2.79733172447886896504323505954192188602`16./eps}, 
     {153/200, 0.49933750325063853450796084505159924086`15.22439661840876 - 
       0.86174166666666666666666666666666666671`16./eps^3 - 
       2.14445724829118672070495908211490478099`16./eps^2 - 
       2.80250155643846646842775804055402282251`16./eps}, 
     {77/100, 0.52355894375259162265995281019441061505`15.236751864046838 - 
       0.8643`16./eps^3 - 2.14904650198862355127057761133506598862`16./
        eps^2 - 2.80762824933569077605215235553506171144`16./eps}, 
     {31/40, 0.54783946435181533336962804322132421209`15.248343357411569 - 
       0.86687500000000000000000000000000000001`16./eps^3 - 
       2.1536154907666253612728852142765108884`16./eps^2 - 
       2.81271195650590482671651846385408974709`16./eps}, 
     {39/50, 0.57217683484575685616773409346997681287`15.259240369869019 - 
       0.86946666666666666666666666666666666671`16./eps^3 - 
       2.15816389099720717560383901777277526589`16./eps^2 - 
       2.8177528344950973436383173530938896476`16./eps}, 
     {157/200, 0.59656883238579781714004018623707643221`15.269503551477282 - 
       0.87207500000000000000000000000000000001`16./eps^3 - 
       2.16269138113363610221056199990191132149`16./eps^2 - 
       2.82275104299164357295028040741163310367`16./eps}, 
     {79/100, 0.62101324141246531084111114741495760664`15.279186279906622 - 
       0.87470000000000000000000000000000000001`16./eps^3 - 
       2.16719764168383304161125495463180818751`16./eps^2 - 
       2.82770674475971742360257720749686084023`16./eps}, 
     {159/200, 0.64550785359122798207890761117509531984`15.288335757093295 - 
       0.87734166666666666666666666666666666672`16./eps^3 - 
       2.17168235518428105113813025139757507619`16./eps^2 - 
       2.83262010557430654848013070943821659417`16./eps}, 
     {4/5, 0.67005046774887983842098985784790437904`15.296993908068858 - 
       0.88000000000000000000000000000000000002`16./eps^3 - 
       2.17614520617442757702376219113162741544`16./eps^2 - 
       2.83749129415778359932952676887653640961`16./eps}, 
     {161/200, 0.69463888981051408503393952969024978276`15.305198123186756 - 
       0.88267500000000000000000000000000000003`16./eps^3 - 
       2.18058588117156816831401078828136955117`16./eps^2 - 
       2.84232048211798851206594960866279555799`16./eps}, 
     {81/100, 0.71927093273708841362433938760998761446`15.312981875292891 - 
       0.88536666666666666666666666666666666662`16./eps^3 - 
       2.18500406864619967247072678705734625387`16./eps^2 - 
       2.84710784388777823739117952314040552845`16./eps}, 
     {163/200, 0.74394441646358305237394736804269501266`15.32037523622183 - 
       0.88807500000000000000000000000000000004`16./eps^3 - 
       2.18939945899783128407041538629777920904`16./eps^2 - 
       2.85185355666600182742471161358330657447`16./eps}, 
     {41/50, 0.76865716783775176990330686020170562983`15.327405311635838 - 
       0.89080000000000000000000000000000000005`16./eps^3 - 
       2.19377174453124217582856967109403553297`16./eps^2 - 
       2.85655780035986022510051897816610853957`16./eps}, 
     {33/40, 0.79340702055946608426455555664832998281`15.33409660916679 - 
       0.89354166666666666666666666666666666664`16./eps^3 - 
       2.19812061943317478587090352204657805461`16./eps^2 - 
       2.86122075752861148213315243119117715397`16./eps}, 
     {83/100, 0.81819181512065269321884511483770334348`15.340471351722975 - 
       0.89630000000000000000000000000000000006`16./eps^3 - 
       2.20244577974945316729106914497202523343`16./eps^2 - 
       2.8658426133285834559906833739240511584`16./eps}, 
     {167/200, 0.84300939874582117992286381703775328278`15.346549745436679 - 
       0.89907499999999999999999999999999999996`16./eps^3 - 
       2.20674692336251612611147144788574336696`16./eps^2 - 
       2.87042355545945730897899159450282641721`16./eps}, 
     {21/25, 0.86785762533318651710007120463568925579`15.352350209875178 - 
       0.90186666666666666666666666666666666668`16./eps^3 - 
       2.21102374996935518230576963610275424244`16./eps^2 - 
       2.87496377411178635556862254798570270104`16./eps}, 
     {169/200, 0.89273435539637572437882475737255894765`15.357889576686723 - 
       0.90467499999999999999999999999999999998`16./eps^3 - 
       2.21527596105984768603068245479216093045`16./eps^2 - 
       2.87946346191571597969140791975528366737`16./eps}, 
     {17/20, 0.91763745600672600380870731766592789328`15.363183261709729 - 
       0.90749999999999999999999999999999999999`16./eps^3 - 
       2.21950325989547570810999360568298512166`16./eps^2 - 
       2.88392281389087147399828037989987810068`16./eps}, 
     {171/200, 0.94256480073616636962415599338679740712`15.368245414665173 - 
       0.91034166666666666666666666666666666671`16./eps^3 - 
       2.22370535148842160055271894087184137686`16./eps^2 - 
       2.88834202739738173999687282653730598275`16./eps}, 
     {43/50, 0.96751426960068274603357426477318418082`15.373089049826499 - 
       0.91320000000000000000000000000000000002`16./eps^3 - 
       2.22788194258103138988724709320138901194`16./eps^2 - 
       2.89272130208800783347361869612749741502`16./eps}, 
     {173/200, 0.99248374900436309560211069778006807056`15.377726160478433 - 
       0.91607500000000000000000000000000000003`16./eps^3 - 
       2.23203274162563742375144682163253347241`16./eps^2 - 
       2.89706083986134634545300629568948174354`16./eps}, 
     {87/100, 1.01747113168401988206971822303960222886`15.382167819504106 - 
       0.91896666666666666666666666666666666664`16./eps^3 - 
       2.23615745876473193987435574297979996719`16./eps^2 - 
       2.90136084481607857687111113766312664457`16./eps}, 
     {7/8, 1.04247431665438671859741448442067056511`15.386424268056661 - 
       0.92187500000000000000000000000000000006`16./eps^3 - 
       2.24025580581148346667975266810889816464`16./eps^2 - 
       2.90562152320623739677292022906299981416`16./eps}, 
     {22/25, 1.06749120915388574892925424359329094056`15.390504993958086 - 
       0.92479999999999999999999999999999999997`16./eps^3 - 
       2.24432749623058819658071572700064468532`16./eps^2 - 
       2.90984308339746457073580911472405719366`16./eps}, 
     {177/200, 1.09251972059096233232913991318100252709`15.39441880121072 - 
       0.92774166666666666666666666666666666669`16./eps^3 - 
       2.24837224511944869694649733787414728887`16./eps^2 - 
       2.91402573582423220985275559251876208496`16./eps}, 
     {89/100, 1.11755776849098325900732203920817322743`15.398173871794265 - 
       0.9307`16./eps^3 - 2.25238976918967254002309370607971554429`16./
        eps^2 - 2.91816969294800282238575316430229293908`16./eps}, 
     {179/200, 1.14260327644369470758278576697675188818`15.401777820745368 - 
       0.93367500000000000000000000000000000002`16./eps^3 - 
       2.2563797867488836420769691098435612198`16./eps^2 - 
       2.92227516921630325146280852143593931487`16./eps}, 
     {9/10, 1.16765417405123580384516920910242153164`15.405237745370181 - 
       0.93666666666666666666666666666666666663`16./eps^3 - 
       2.26034201768283930399427579447984336666`16./eps^2 - 
       2.92634238102268855421789087363840474381`16./eps}, 
     {181/200, 1.19270839687670390787937217303103226397`15.408560269317755 - 
       0.93967500000000000000000000000000000006`16./eps^3 - 
       2.26427618343784614077956951213993905057`16./eps^2 - 
       2.93037154666757262177922455306791343501`16./eps}, 
     {91/100, 1.21776388639326704962600817949467408003`15.411751582139594 - 
       0.94269999999999999999999999999999999997`16./eps^3 - 
       2.26818200700346827612029522337603986321`16./eps^2 - 
       2.93436288631990305665744766871226884087`16./eps}, 
     {183/200, 1.24281858993381932941687752161539143823`15.414817474873663 - 
       0.94574166666666666666666666666666666669`16./eps^3 - 
       2.27205921289552136066650201858608363552`16./eps^2 - 
       2.93831662197965851547750872797498480206`16./eps}, 
     {23/25, 1.26787046064117518401328377934969360856`15.417763372118825 - 
       0.94880000000000000000000000000000000001`16./eps^3 - 
       2.27590752713934614915866313577447377482`16./eps^2 - 
       2.94223297744114739169167711292451015254`16./eps}, 
     {37/40, 1.29291745741879693023220913818618564123`15.420594361002424 - 
       0.95187500000000000000000000000000000003`16./eps^3 - 
       2.27972667725335554224901388106666513906`16./eps^2 - 
       2.94611217825708735591209276951615423866`16./eps}, 
     {93/100, 1.31795754488205243266703064108479256278`15.423315217392291 - 
       0.95496666666666666666666666666666666665`16./eps^3 - 
       2.28351639223284916402243978860203597306`16./eps^2 - 
       2.94995445170344589177019838668671053056`16./eps}, 
     {187/200, 1.34298869330999697176940235549043061565`15.425930429658214 - 
       0.95807499999999999999999999999999999997`16./eps^3 - 
       2.28727640253408970604116821790128513463`16./eps^2 - 
       2.95376002674502256366377859693708266488`16./eps}, 
     {47/50, 1.36800887859767530323333594021662656189`15.428444220250098 - 
       0.96119999999999999999999999999999999999`16./eps^3 - 
       2.29100644005863542341386951772040425625`16./eps^2 - 
       2.95752913400175433026525132822055874594`16./eps}, 
     {189/200, 1.3930160822089384149513123577378558154`15.430860565326455 - 
       0.96434166666666666666666666666666666673`16./eps^3 - 
       2.29470623813792331811623308608263569237`16./eps^2 - 
       2.96126200571572577507296011950792345788`16./eps}, 
     {19/20, 1.41800829112977174765683003938016026992`15.433183212638792 - 
       0.96750000000000000000000000000000000005`16./eps^3 - 
       2.29837553151809768975047535352318856607`16./eps^2 - 
       2.96495887571886666338868590784534840632`16./eps}, 
     {191/200, 1.44298349782212733631038616934288446907`15.435415697852108 - 
       0.97067499999999999999999999999999999996`16./eps^3 - 
       2.30201405634507887430162616666587745375`16./eps^2 - 
       2.96861997940131975466201783298893743604`16./eps}, 
     {24/25, 1.46793970017825760288558822567599206626`15.437561359461304 - 
       0.97386666666666666666666666666666666669`16./eps^3 - 
       2.30562155014986712739749822324714279231`16./eps^2 - 
       2.9722455536804623008843441618111096432`16./eps}, 
     {193/200, 1.49287490147554442622833365917947017851`15.439623352444082 - 
       0.97707500000000000000000000000000000002`16./eps^3 - 
       2.30919775183407674026859533022847902867`16./eps^2 - 
       2.97583583697056514633862525476174984513`16./eps}, 
     {97/100, 1.51778711033181884785129086578720572348`15.441604660774944 - 
       0.98030000000000000000000000000000000005`16./eps^3 - 
       2.31274240165569560418876627889711232266`16./eps^2 - 
       2.97939106915307381218177456960962492934`16./eps}, 
     {39/40, 1.54267434066116650417674756659602813893`15.44350810891138 - 
       0.98354166666666666666666666666666666667`16./eps^3 - 
       2.31625524121506556280566419504417492823`16./eps^2 - 
       2.98291149154749640169128117342932075646`16./eps}, 
     {49/50, 1.56753461163021385493336117514893642898`15.445336372350308 - 
       0.98679999999999999999999999999999999999`16./eps^3 - 
       2.31973601344107901158442004043696770263`16./eps^2 - 
       2.98639734688288359915584555211039013389`16./eps}, 
     {197/200, 1.59236594761489007723726855154091693775`15.447091987342535 - 
       0.99007500000000000000000000000000000003`16./eps^3 - 
       2.32318446257758731972495002293035953798`16./eps^2 - 
       2.98984887926988645791410038587921716433`16./eps}, 
     {99/100, 1.61716637815765976842683274714213893805`15.4487773598436 - 
       0.99336666666666666666666666666666666665`16./eps^3 - 
       2.32660033417001676250399623529313260669`16./eps^2 - 
       2.99326633417337808150368860163115874308`16./eps}, 
     {199/200, 1.64193393792522140145425207298103383279`15.450394773770919 - 
       0.99667499999999999999999999999999999998`16./eps^3 - 
       2.32998337505218776116304721224559139608`16./eps^2 - 
       2.99664995838562569680891860976777771156`16./eps}, 
     {1, 1.66666666666666665800675213332120896775`15.451946398629723 - 
       1.00000000000000000000000000000000000001`16./eps^3 - 
       2.33333333333333333333333333333333333336`16./eps^2 - 
       3.00000000000000000000000000000000000004`16./eps}}
 
points8b = 
    {{1/10, -1.6891704667230299869218429867769026761`15.955936246141942 + 
       0.01009999999999999999999999999999999999`16./eps^3 + 
       0.02750077051228446459761720518000821137`16./eps^2 - 
       0.07409611246826485839293955350754671306`16./eps}, 
     {21/200, -1.533739777391262984941724060269484653`15.950460347495705 + 
       0.01114655062500000000000000000000000001`16./eps^3 + 
       0.03741044987461353801399452279788613368`16./eps^2 - 
       0.03030026587447252004283323929486011523`16./eps}, 
     {11/100, -1.37546806381847650815563905907231358544`15.910170523724855 + 
       0.01224641000000000000000000000000000001`16./eps^3 + 
       0.04767878623569417473195252898768212027`16./eps^2 + 
       0.01465276531803109202093422658316351446`16./eps}, 
     {23/200, -1.21445931507340941390570047067703160324`15.85911210926987 + 
       0.01339990062500000000000000000000000001`16./eps^3 + 
       0.0583022272360672826864780517685359715`16./eps^2 + 
       0.06074096985767524231492492619548496432`16./eps}, 
     {3/25, -1.0508107355897858114538758186434655091`15.79556875666475 + 
       0.01460736000000000000000000000000000001`16./eps^3 + 
       0.06927759851170930565437793197244002592`16./eps^2 + 
       0.10794442402893978772802449752937701212`16./eps}, 
     {1/8, -0.88461365479095724396495637692883926418`15.71677185267614 + 
       0.015869140625`16./eps^3 + 
       0.08060207322247904796398987959297449904`16./eps^2 + 
       0.15624505249104272312104241962779846872`16./eps}, 
     {13/100, -0.71595430025155229521454073264992463286`15.617914973591136 + 
       0.01718561000000000000000000000000000001`16./eps^3 + 
       0.09227314499797580211882231006765553529`16./eps^2 + 
       0.20562642008792787362076476656719848008`16./eps}, 
     {27/200, -0.54491445817877423240594431984237215114`15.489793472155325 + 
       0.01855715062500000000000000000000000001`16./eps^3 + 
       0.10428860377647931179677137028090410268`16./eps^2 + 
       0.25607354961778640106024894018348223255`16./eps}, 
     {7/50, -0.37157204016968059884661447684001997479`15.31174662692548 + 
       0.01998416`16./eps^3 + 0.11664651411081435715679271363792366116`16./
        eps^2 + 0.30757276152316394997779885373391687277`16./eps}, 
     {29/200, -0.19600157148967504520505860792604691506`15.020364131159345 + 
       0.02146705062500000000000000000000000003`16./eps^3 + 
       0.12934519559179022555561422962196107017`16./eps^2 + 
       0.36011153221778482109290662499417416267`16./eps}, 
     {3/20, -0.01827461323416210571497644101582303728`13.974848125448531 + 
       0.02300624999999999999999999999999999997`16./eps^3 + 
       0.14238320510055451900931163876939848146`16./eps^2 + 
       0.41367836835828279872957024877719471303`16./eps}, 
     {31/200, 0.1615398715262061400862337726474473541`14.90496875649018 + 
       0.02460220062499999999999999999999999995`16./eps^3 + 
       0.15575932064959380439705583194332024176`16./eps^2 + 
       0.46826269483763478752029369421781714205`16./eps}, 
     {4/25, 0.34337519930581668913509217302025530885`15.21520565364934 + 
       0.02625535999999999999999999999999999996`16./eps^3 + 
       0.16947252661102943984108056311628457874`16./eps^2 + 
       0.5238547546512245137876062765394823273`16./eps}, 
     {33/200, 0.52716668858677486386999918748501352708`15.383421545389185 + 
       0.02796620062499999999999999999999999996`16./eps^3 + 
       0.18352200016239825593137349312612825097`16./eps^2 + 
       0.58044551908758562551462629028655682879`16./eps}, 
     {17/100, 0.7128514172885642476955120317028469414`15.493142554350404 + 
       0.02973521000000000000000000000000000001`16./eps^3 + 
       0.19790709880585978347242445040457559956`16./eps^2 + 
       0.63802660694006151063541522086748411634`16./eps}, 
     {7/40, 0.90036801051852992003302693975580852548`15.569564755009871 + 
       0.03156289062500000000000000000000000005`16./eps^3 + 
       0.21262734883794114009466017446957539079`16./eps^2 + 
       0.69659021163503174497158893436599751657`16./eps}, 
     {9/50, 1.08965645455436513612993167805429266548`15.628003185971966 + 
       0.03344975999999999999999999999999999997`16./eps^3 + 
       0.22768243466444462524047841647759370857`16./eps^2 + 
       0.75612903533627513947227678851576997634`16./eps}, 
     {37/200, 1.28065793363087795586435548737305320134`15.674311713773443 + 
       0.03539635062500000000000000000000000003`16./eps^3 + 
       0.24307218886971992259332269837544135461`16./eps^2 + 
       0.8166362292206162945204037005050011472`16./eps}, 
     {19/100, 1.47331468661564465859805285730871902466`15.71195034432499 + 
       0.03740320999999999999999999999999999997`16./eps^3 + 
       0.2587965829617037220850847967646925216`16./eps^2 + 
       0.87810533923278794352237311692847165953`16./eps}, 
     {39/200, 1.66756988108309637963742964025609780955`15.743131691343807 + 
       0.03947090062499999999999999999999999999`16./eps^3 + 
       0.27485571872439618877978031472603612129`16./eps^2 + 
       0.94053025672177927011771406303240376675`16./eps}, 
     {1/5, 1.86336750265086816014518703974035438645`15.769353479629059 + 
       0.04160000000000000000000000000000000003`16./eps^3 + 
       0.29124982011812607521492507625278059057`16./eps^2 + 
       1.00390517344025475313680126148761991488`16./eps}, 
     {41/200, 2.06065225773904114799484926379934965935`15.79167400130217 + 
       0.04379110062500000000000000000000000003`16./eps^3 + 
       0.30797922567533371619990802900860345559`16./eps^2 + 
       1.06822454045563609978803887722062172854`16./eps}, 
     {21/100, 2.25936948816273846613915671832139906097`15.8108665324717 + 
       0.04604481000000000000000000000000000001`16./eps^3 + 
       0.32504438134589795039467248455641282175`16./eps^2 + 
       1.13348303057831170054588016659580910617`16./eps}, 
     {43/200, 2.45946509617965600721730197155295474494`15.827511474628675 + 
       0.04836175062499999999999999999999999997`16./eps^3 + 
       0.34244583375143036171482864381511522152`16./eps^2 + 
       1.199675503960917762451419688871623701`16./eps}, 
     {11/50, 2.66088547879344020715795501334566709531`15.84205415072399 + 
       0.05074256000000000000000000000000000001`16./eps^3 + 
       0.36018422381260531295659623933712051472`16./eps^2 + 
       1.26679697656413242326306007182310125661`16./eps}, 
     {9/40, 2.86357747026645826938678906926009318003`15.854842567910312 + 
       0.05318789062499999999999999999999999998`16./eps^3 + 
       0.37826028071760726932106174557079497143`16./eps^2 + 
       1.33484259122008426220151126503196606881`16./eps}, 
     {23/100, 3.06748829192622812561043772347960439131`15.866152942616152 + 
       0.05569840999999999999999999999999999995`16./eps^3 + 
       0.39667481620325656871679577842324917627`16./eps^2 + 
       1.40380759105523553667492749366970743917`16./eps}, 
     {47/200, 3.27256550846186717890257007831663834254`15.876207454872809 + 
       0.05827480062499999999999999999999999995`16./eps^3 + 
       0.41542871912340249845944658364546894105`16./eps^2 + 
       1.4736872950612264965896645852920666438`16./eps}, 
     {6/25, 3.47875699000349742088796426283772725542`15.88518690320324 + 
       0.06091776000000000000000000000000000002`16./eps^3 + 
       0.43452295028181575173734435884305900521`16./eps^2 + 
       1.54447707562529401428292663822823619354`16./eps}, 
     {49/200, 3.68601087936097925912033919725317413463`15.893239917034427 + 
       0.06362800062500000000000000000000000003`16./eps^3 + 
       0.45395853750912722199929789627207790481`16./eps^2 + 
       1.6161723378520306432681567292489536205`16./eps}, 
     {1/4, 3.8942755638706492813726603369006582133`15.90048978741541 + 
       0.06640624999999999999999999999999999997`16./eps^3 + 
       0.47373657096539359407706146790683490639`16./eps^2 + 
       1.68876850052586606973479549631170820417`16./eps}, 
     {51/200, 4.10349965136157645529398701583721074198`15.907039614143638 + 
       0.06925325062500000000000000000000000004`16./eps^3 + 
       0.49385819865166170728107015161092007215`16./eps^2 + 
       1.76226097857909688553240016360746274216`16./eps}, 
     {13/50, 4.31363194980763159109368968676696828033`15.912976240007728 + 
       0.07216975999999999999999999999999999994`16./eps^3 + 
       0.5143246221154863929902171002830475265`16./eps^2 + 
       1.8366451669438689941549233934933759212`16./eps}, 
     {53/200, 4.52462145027951333769513834815893480198`15.918373296427752 + 
       0.07515655062499999999999999999999999997`16./eps^3 + 
       0.53513709233675849808853284464514926308`16./eps^2 + 
       1.91191642567848767981460318011708039771`16./eps}, 
     {27/100, 4.73641731285281750501713355254489323771`15.923293588218216 + 
       0.07821441000000000000000000000000000001`16./eps^3 + 
       0.55629690578144491736407988228904612313`16./eps^2 + 
       1.988070066269011383597670648277729044`16./eps}, 
     {11/40, 4.94896885516505399760334374970943073273`15.927790980163884 + 
       0.08134414062499999999999999999999999996`16./eps^3 + 
       0.57780540061195095664801071617676721485`16./eps^2 + 
       2.06510133901646137005910183570138723338`16./eps}, 
     {7/25, 5.1622255433469359892833563740675472624`15.931911903447574 + 
       0.08454656000000000000000000000000000003`16./eps^3 + 
       0.59966395304380456220838726945281786598`16./eps^2 + 
       2.14300542142830799024000202141208109289`16./eps}, 
     {57/200, 5.37613698508186082370491975327973222306`15.935696568780001 + 
       0.08782250062499999999999999999999999995`16./eps^3 + 
       0.62187397383924673021086455281500160574`16./eps^2 + 
       2.22177740754030937935558499365391022615`16./eps}, 
     {29/100, 5.59065292457278608574592838330754384228`15.939179950951825 + 
       0.09117281000000000000000000000000000002`16./eps^3 + 
       0.64443690492910551663114439304350205184`16./eps^2 + 
       2.30141229810139508960898765412074147528`16./eps}, 
     {59/200, 5.8057232392181092467884764730721448237`15.94239259359893 + 
       0.09459835062500000000000000000000000004`16./eps^3 + 
       0.66735421615504350559107247589571550525`16./eps^2 + 
       2.38190499156020403294652164062822810675`16./eps}, 
     {3/10, 6.02129793781802989877610196573991653661`15.945361271357564 + 
       0.09810000000000000000000000000000000004`16./eps^3 + 
       0.69062740212490987391627361164558841366`16./eps^2 + 
       2.46325027579718817511747446781843709314`16./eps}, 
     {61/200, 6.23732716015057174441032644732394716315`15.948109538013062 + 
       0.10167865062500000000000000000000000002`16./eps^3 + 
       0.71425797917450655582336243060796601891`16./eps^2 + 
       2.54544282055095406256748417080143542359`16./eps}, 
     {31/100, 6.45376117777218399352331463202594875205`15.950658182849729 + 
       0.10533520999999999999999999999999999996`16./eps^3 + 
       0.73824748242960062829685513704875559466`16./eps^2 + 
       2.62847717049179701121497287030771414164`16./eps}, 
     {63/200, 6.67055039591190846202069316935493712681`15.95302561258737 + 
       0.10907060062500000000000000000000000005`16./eps^3 + 
       0.76259746296248814642256364166619390737`16./eps^2 + 
       2.7123477388992427892508662551007033071`16./eps}, 
     {8/25, 6.88764535634066590455575030123476283341`15.955228172620773 + 
       0.11288576000000000000000000000000000001`16./eps^3 + 
       0.78730948503784370949198893007839556729`16./eps^2 + 
       2.79704880190389687240032140655350199903`16./eps}, 
     {13/40, 7.10499674110847384742007189520702735064`15.95728041846149 + 
       0.116781640625`16./eps^3 + 
       0.81238512344297980446018035551810322814`16./eps^2 + 
       2.88257449325705369600462519137765422222`16./eps}, 
     {33/100, 7.32255537705249845960729813518528312257`15.959195346101147 + 
       0.12075921000000000000000000000000000002`16./eps^3 + 
       0.83782596089799463943769726161289869363`16./eps^2 + 
       2.96891879959437436657504024856992103679`16./eps}, 
     {67/200, 
      7.5402722409879114493206102402980305336069157638645010825059`31.9651084\
2079286 + 0.1248194506249999999999999999999999999999999999999999999992`32./
        eps^3 + 
       0.8636335855416104270006545992237138769260835583505374566507`32./
        eps^2 + 
       3.0560755561625330885346636337321480325087225455118149720985`32./eps}, 
     {17/50, 7.75809846550167610659442586746805337801`15.962658582594688 + 
       0.12896335999999999999999999999999999996`16./eps^3 + 
       0.88980958848879914833955112602383373221`16./eps^2 + 
       3.14403844298008826328009575456576594833`16./eps}, 
     {69/200, 7.9759853452767291611751809435872637278`15.964226715322376 + 
       0.13319195062500000000000000000000000004`16./eps^3 + 
       0.91635556145656258810166518944535185519`16./eps^2 + 
       3.23280098140597860045507272977061037085`16./eps}, 
     {7/20, 8.19388434388065105357231925836467126282`15.965697446001444 + 
       0.13750625000000000000000000000000000006`16./eps^3 + 
       0.94327309445448040949089494278285057133`16./eps^2 + 
       3.3223565310909994879314542955314967846`16./eps}, 
     {71/200, 8.41174710095889253285479020491696464886`15.967078414632384 + 
       0.14190730062500000000000000000000000005`16./eps^3 + 
       0.97056377353686648526266853570500762019`16./eps^2 + 
       3.41269828728939959392431316903771912928`16./eps}, 
     {9/25, 8.62952543977803739550885419673055490677`15.968376534825104 + 
       0.14639616000000000000000000000000000003`16./eps^3 + 
       0.99822917861358160681082395967765476057`16./eps^2 + 
       3.50381927850936930163744502490821683561`16./eps}, 
     {73/200, 8.84717137506947074575658637823717087558`15.969598074779283 + 
       0.15097390062499999999999999999999999999`16./eps^3 + 
       1.02627088131674183469640120703492479781`16./eps^2 + 
       3.59571236448268624937813121040745025646`16./eps}, 
     {37/100, 9.06463712112825886903157684447808313567`15.970748727914666 + 
       0.15564161000000000000000000000000000005`16./eps^3 + 
       1.05469044292073771086876782832115431862`16./eps^2 + 
       3.68837023443515242168061594534508832974`16./eps}, 
     {3/8, 9.28187510012606790076395774794476206748`15.971833674641903 + 
       0.16040039062500000000000000000000000003`16./eps^3 + 
       1.08348941231314173707686754463999125659`16./eps^2 + 
       3.78178540564071388270467300931586825153`16./eps}, 
     {19/50, 9.49883795060060217067696399704214667621`15.972857636525681 + 
       0.16525136000000000000000000000000000001`16./eps^3 + 
       1.11266932401423119788815987167672427824`16./eps^2 + 
       3.87595022224330903482505013098775358148`16./eps}, 
     {77/200, 9.71547853608736269990697573558248099934`15.973824923895659 + 
       0.17019565062500000000000000000000000001`16./eps^3 + 
       1.14223169624299170098921079420810203384`16./eps^2 + 
       3.97085685433155375228216338787037416819`16./eps}, 
     {39/100, 9.93174995386254731376897352009038947083`15.974739477797668 + 
       0.17523440999999999999999999999999999996`16./eps^3 + 
       1.17217802902759473636445547270037229351`16./eps^2 + 
       4.06649729725235040409919753895804600849`16./eps}, 
     {79/200, 10.14760554376866510283254878466800968766`15.975604907042793 + 
       0.18036880062500000000000000000000000005`16./eps^3 + 
       1.20250980235846103089681509156144241429`16./eps^2 + 
       4.16286337115041027528710631488455083443`16./eps}, 
     {2/5, 10.3629988970969446695495499804769973191`15.976424520999348 + 
       0.18559999999999999999999999999999999995`16./eps^3 + 
       1.23322847438213131596694950804287848162`16./eps^2 + 
       4.25994672072151206786629805871413605204`16./eps}, 
     {81/200, 10.5778838655029039415902805182003488614`15.977201358678169 + 
       0.19092920062499999999999999999999999995`16./eps^3 + 
       1.26433547963426807172824618396426132045`16./eps^2 + 
       4.35773881516808916471394564019660519157`16./eps}, 
     {41/100, 10.79221456993353671200521713524852144333`15.977938214583183 + 
       0.19635761`16./eps^3 + 1.29583222731020652976142675681073952787`16./
        eps^2 + 4.45623094834645070371363375451199299646`16./eps}, 
     {83/200, 11.00594540954647958816682255367907866697`15.978637661731666 + 
       0.20188645062500000000000000000000000001`16./eps^3 + 
       1.3277200995715613083710509755580737824`16./eps^2 + 
       4.55541423909560122278642570880152903419`16./eps}, 
     {21/50, 11.21903107060326768720989164362125924202`15.979302072193352 + 
       0.20751696000000000000000000000000000001`16./eps^3 + 
       1.3600004498874770671496415895369634925`16./eps^2 + 
       4.65527963173823519585316435884432555212`16./eps}, 
     {17/40, 11.43142653532038148553803022035760062559`15.979933635449047 + 
       0.213250390625`16./eps^3 + 
       1.39267460140918799364591805369701144806`16./eps^2 + 
       4.75581789674505024857221087987630547769`16./eps}, 
     {43/100, 11.64308709066325568721159654700361336472`15.980534374829302 + 
       0.21908801000000000000000000000000000006`16./eps^3 + 
       1.42574384537662222322792518128436434099`16./eps^2 + 
       4.85701963155404989576999541237100606483`16./eps}, 
     {87/200, 11.85396833706974629188957191151047734002`15.981106162258945 + 
       0.22503110062500000000000000000000000004`16./eps^3 + 
       1.45920943955585385064088920734779811929`16./eps^2 + 
       4.95887526153699660803728526343153490782`16./eps}, 
     {11/25, 12.06402619709079612230014821008277277829`15.981650731504079 + 
       0.23108096`16./eps^3 + 1.49307260670626738856550112791158069813`16./
        eps^2 + 5.06137504110563191088374943715072784572`16./eps}, 
     {89/200, 12.27321692393715110522930188246733753344`15.982169690092384 + 
       0.23723890062499999999999999999999999999`16./eps^3 + 
       1.52733453307635770179667211794188627173`16./eps^2 + 
       5.16450905495070478591034209373754397309`16./eps}, 
     {9/20, 12.48149710992202233549015705404787459992`15.98266453005638 + 
       0.24350625`16./eps^3 + 1.56199636692714290278734554696891000753`16./
        eps^2 + 5.26826721940724536990265341376049144452`16./eps}, 
     {91/200, 12.68882369479052545911120280384967984071`15.98313663763029 + 
       0.24988435062500000000000000000000000004`16./eps^3 + 
       1.59705921708221871568172529742600200997`16./eps^2 + 
       5.37263928393989010056788655157639890571`16./eps}, 
     {23/50, 12.89515397392762033538293691906061687755`15.983587302015113 + 
       0.25637455999999999999999999999999999999`16./eps^3 + 
       1.63252415150353065781600519643092894777`16./eps^2 + 
       5.47761483274240910110018488244195335664`16./eps}, 
     {93/200, 13.10044560643705017775295588994023933163`15.98401772331264 + 
       0.26297825062500000000000000000000000001`16./eps^3 + 
       1.6683921958919852843307097758507965914`16./eps^2 + 
       5.58318328644590861241281813268371470338`16./eps}, 
     {47/100, 13.30465662308453428533347225599163789692`15.98442901971702 + 
       0.26969681000000000000000000000000000006`16./eps^3 + 
       1.70466433231206390757019751588410881041`16./eps^2 + 
       5.6893339039304823903834682914812861646`16./eps}, 
     {19/40, 13.50774543409913734863397717303226328526`15.98482223404193 + 
       0.27653164062500000000000000000000000005`16./eps^3 + 
       1.74134149783964183498318345921473196019`16./eps^2 + 
       5.79605578423536775650149748106350480687`16./eps}, 
     {12/25, 13.70967083682736177523004065814688547578`15.985198339652557 + 
       0.28348416000000000000000000000000000001`16./eps^3 + 
       1.77842458323225344769067970256387962342`16./eps^2 + 
       5.90333786856292586079034033700943461028`16./eps}, 
     {97/200, 13.91039202323508396814151919770766925351`15.985558245863118 + 
       0.29055580062500000000000000000000000004`16./eps^3 + 
       1.8159144316210785324318133077903484393`16./eps^2 + 
       6.01116894237201300164241558039965766568`16./eps}, 
     {49/100, 14.10986858725298214236068490840129519728`15.985902802854326 + 
       0.29774801000000000000000000000000000001`16./eps^3 + 
       1.85381183722395833453076902070494400798`16./eps^2 + 
       6.11953763755654175439578045487678153889`16./eps}, 
     {99/200, 14.30806053196158927715379836040478324672`15.986232806158707 + 
       0.30506225062499999999999999999999999998`16./eps^3 + 
       1.89211754407878095898000148656514491084`16./eps^2 + 
       6.22843243470524829575841553898002256907`16./eps}, 
     {1/2, 14.50492827661255175001613053819997041255`15.986549000756412 + 
       0.31250000000000000000000000000000000003`16./eps^3 + 
       1.93083224479660513976105280330711530581`16./eps^2 + 
       6.33784166543888669087049627203758732513`16./eps}, 
     {101/200, 14.70043266348308689508280390331637966526`15.986852084819619 + 
       0.32006275062500000000000000000000000005`16./eps^3 + 
       1.96995657933391914308810618717537235654`16./eps^2 + 
       6.44775351482126296810409850563581059838`16./eps}, 
     {51/100, 14.89453496456101092467927557305741936532`15.98714271313935 + 
       0.32775200999999999999999999999999999997`16./eps^3 + 
       2.00949113378345777811900420791008777667`16./eps^2 + 
       6.55815602384070240314686722138910259973`16./eps}, 
     {103/200, 15.08719688805805941288969111988921103695`15.987421500265073 + 
       0.33556930062499999999999999999999999999`16./eps^3 + 
       2.0494364391830252601875157029301152191`16./eps^2 + 
       6.66903709195871335997869167635828234473`16./eps}, 
     {13/25, 15.27838058474954364645799508187403301587`15.987689023384075 + 
       0.34351615999999999999999999999999999999`16./eps^3 + 
       2.08979297034179510044179092463807514713`16./eps^2 + 
       6.78038447972277102148181353047836725459`16./eps}, 
     {21/40, 15.46804865413868318154009684319404304292`15.9879458249648 + 
       0.35159414062500000000000000000000000004`16./eps^3 + 
       2.13056114468358036857342692450907577482`16./eps^2 + 
       6.89218581144029505948107794618951452565`16./eps}, 
     {53/100, 15.65616415044422797009031590881517044349`15.988192415186068 + 
       0.35980480999999999999999999999999999995`16./eps^3 + 
       2.17174132110658867230203604889811920521`16./eps^2 + 
       7.00442857791103736415425352532873786868`16./eps}, 
     {107/200, 15.84269058841023508353640615475972773418`15.988429274171436 + 
       0.368149750625`16./eps^3 + 
       2.21333379885919609275823520628341035463`16./eps^2 + 
       7.11710013921522994988574792891798835732`16./eps}, 
     {27/50, 16.02759194893709676922236680849815411362`15.98865685404648 + 
       0.37663055999999999999999999999999999997`16./eps^3 + 
       2.25533881643129317779177158313880301309`16./eps^2 + 
       7.23018772755496960942088781013046737874`16./eps}, 
     {109/200, 16.21083268453313001668824557622012199325`15.988875580834632 + 
       0.38524885062499999999999999999999999997`16./eps^3 + 
       2.29775655046077398946400674553414510554`16./eps^2 + 
       7.34367845014643529166908234636521267336`16./eps}, 
     {11/20, 16.39237772458623405318408636825852874816`15.989085856205762 + 
       0.39400624999999999999999999999999999998`16./eps^3 + 
       2.34058711465475618694570048201199814709`16./eps^2 + 
       7.45755929216064698545800332971131501342`16./eps}, 
     {111/200, 16.57219248045530283727044734740840026741`15.989288059090605 + 
       0.40290440062499999999999999999999999995`16./eps^3 + 
       2.3838305587251362569166830852197598207`16./eps^2 + 
       7.57181711971058152340955994591121712045`16./eps}, 
     {14/25, 16.75024285038124618589363144439286781855`15.989482547172265 + 
       0.41194496000000000000000000000000000006`16./eps^3 + 
       2.4274868673380993316764937325029627224`16./eps^2 + 
       7.68643868288256156776613527194998861662`16./eps}, 
     {113/200, 16.92649522421762552589047270765902408239`15.98966965826552 + 
       0.42112960062499999999999999999999999998`16./eps^3 + 
       2.47155595907721760829002731798802368331`16./eps^2 + 
       7.80141061880992946621781396077324410339`16./eps}, 
     {57/100, 17.10091648798105088034399399108264433969`15.989849711593356 + 
       0.43046000999999999999999999999999999997`16./eps^3 + 
       2.51603768541978524469592763400154007184`16./eps^2 + 
       7.91671945478710800750255695590968398586`16./eps}, 
     {23/40, 17.27347402822161477739969492209922024119`15.990023008969297 + 
       0.43993789062500000000000000000000000001`16./eps^3 + 
       2.5609318297260508022585955458890897123`16./eps^2 + 
       8.03235161142223567692217592790403193463`16./eps}, 
     {29/50, 17.44413573621375695842525243486042479269`15.990189835893359 + 
       0.44956495999999999999999999999999999998`16./eps^3 + 
       2.60623810624102086741444000248142430456`16./eps^2 + 
       8.14829340582664510218127564442934936027`16./eps}, 
     {117/200, 17.6128700119680620766463075482994737505`15.990350462568742 + 
       0.45934295062500000000000000000000000005`16./eps^3 + 
       2.65195615910852045393536948905056471915`16./eps^2 + 
       8.26453105483953026116418286457839838194`16./eps}, 
     {59/100, 17.77964576806459269359365325405049465366`15.990505144845592 + 
       0.46927361000000000000000000000000000005`16./eps^3 + 
       2.69808556139720719560667288145123005391`16./eps^2 + 
       8.38105067828622094783820915954172963524`16./eps}, 
     {119/200, 17.94443243330844995655207372727645054197`15.990654125097816 + 
       0.47935870062500000000000000000000000001`16./eps^3 + 
       2.74462581413824721828288539542370776706`16./eps^2 + 
       8.49783830226855219563569991409705837008`16./eps}, 
     {3/5, 18.10719995620833821663715563300917802245`15.990797633038223 + 
       0.48960000000000000000000000000000000006`16./eps^3 + 
       2.79157634537437095978922965196034907697`16./eps^2 + 
       8.61487986248588205876096101864024502842`16./eps}, 
     {121/200, 18.26791880827898557306022255055345315702`15.990935886476894 + 
       0.49999930062499999999999999999999999996`16./eps^3 + 
       2.83893650922003711352773186193737580482`16./eps^2 + 
       8.73216120758537355554348160845098408619`16./eps}, 
     {61/100, 18.42655998716834142180407665820981768531`15.991069092027034 + 
       0.51055841000000000000000000000000000003`16./eps^3 + 
       2.88670558493244233271858990744135686954`16./eps^2 + 
       8.84966810254021587528131437270760648803`16./eps}, 
     {123/200, 18.58309501961053543075049906139498812039`15.991197445762747 + 
       0.521279150625`16./eps^3 + 
       2.93488277599312337112039477755092323698`16./eps^2 + 
       8.96738623205451631947567896931616960344`16./eps}, 
     {31/50, 18.73749596420563939322162097709826457932`15.991321133831946 + 
       0.53216336000000000000000000000000000004`16./eps^3 + 
       2.98346720919990697547460137324967686157`16./eps^2 + 
       9.08530120399364805678589320239597103929`16./eps}, 
     {5/8, 18.88973541402732533181950987710109266649`15.991440333028294 + 
       0.54321289062500000000000000000000000006`16./eps^3 + 
       3.0324579337689711060503364948693826466`16./eps^2 + 
       9.20339855283888977446801305635104831949`16./eps}, 
     {63/100, 19.03978649905956041535443559539655604793`15.991555211324812 + 
       0.55442960999999999999999999999999999996`16./eps^3 + 
       3.08185392044678896445707670426067972077`16./eps^2 + 
       9.32166374316524185351808073804727530948`16./eps}, 
     {127/200, 19.18762288846352135171012822048623769566`15.99166592837234 + 
       0.56581540062499999999999999999999999995`16./eps^3 + 
       3.13165406063173487105962142600111275627`16./eps^2 + 
       9.44008217314134991693994368377074396537`16./eps}, 
     {16/25, 19.33321879267594920981991299785569342488`15.991772635965267 + 
       0.57737216000000000000000000000000000003`16./eps^3 + 
       3.18185716550513827545371887059622817286`16./eps^2 + 
       9.55863917805051062858041261922957103289`16./eps}, 
     {129/200, 19.4765489653401996753646944583864055554`15.991875478476963 + 
       0.58910180062500000000000000000000000002`16./eps^3 + 
       3.23246196517157911906776785091462196613`16./eps^2 + 
       9.67732003383177657387759803459198441949`16./eps}, 
     {13/20, 19.61758870507127436567975983750571881295`15.991974593267228 + 
       0.60100624999999999999999999999999999998`16./eps^3 + 
       3.28346710780822441458850843248054735908`16./eps^2 + 
       9.79610996064021704624522680548421602275`16./eps}, 
     {131/200, 19.75631385705614549394338081391672099731`15.992070111063619 + 
       0.61308745062500000000000000000000000005`16./eps^3 + 
       3.33487115882301227719129695937821744999`16./eps^2 + 
       9.91499412642542969931649194790435095352`16./eps}, 
     {33/50, 19.89270081449071196135100907522658719743`15.992162156318486 + 
       0.62534736000000000000000000000000000001`16./eps^3 + 
       3.3866726000214957512569952801579036334`16./eps^2 + 
       10.03395765052743440508096613384981656136`16./eps}, 
     {133/200, 20.02672651985474024738785556014587368169`15.992250847543735 + 
       0.63778795062499999999999999999999999998`16./eps^3 + 
       3.43886982878216463634679498327386129825`16./eps^2 + 
       10.15298560728911537423100530141975049617`16./eps}, 
     {67/100, 20.15836846602617280185489207599805795712`15.992336297624421 + 
       0.65041121000000000000000000000000000004`16./eps^3 + 
       3.49146115724006913990566587820156836046`16./eps^2 + 
       10.27206302968441073534103852036046062598`16./eps}, 
     {27/40, 20.28760469723618887118736842025348700469`15.992418614113099 + 
       0.66321914062500000000000000000000000002`16./eps^3 + 
       3.54444481147857458299862314989403758591`16./eps^2 + 
       10.39117491296148041615128305190035024319`16./eps}, 
     {17/25, 20.41441380986642680659680456619731927831`15.992497899505919 + 
       0.67621375999999999999999999999999999999`16./eps^3 + 
       3.59781893072908157022273275217631151458`16./eps^2 + 
       10.51030621830011340065005138891680476722`16./eps}, 
     {137/200, 20.53877495308978304322265901774725517112`15.99257425150185 + 
       0.68939710062499999999999999999999999996`16./eps^3 + 
       3.65158156657855101604175657607223862648`16./eps^2 + 
       10.62944187648266432271981715781057020718`16./eps}, 
     {69/100, 20.66066782935621354876696164011879983241`15.992647763246211 + 
       0.70277120999999999999999999999999999995`16./eps^3 + 
       3.70573068218467820684750043223879959037`16./eps^2 + 
       10.74856679157783696944659037890627150806`16./eps}, 
     {139/200, 20.78007269472497099619326640651240974646`15.992718523559507 + 
       0.71633815062499999999999999999999999996`16./eps^3 + 
       3.76026415149856468021424731637954668985`16./eps^2 + 
       10.86766584463665866942470353211821165294`16./eps}, 
     {7/10, 20.89697035904471642832059261540880210854`15.992786617152479 + 
       0.73010000000000000000000000000000000006`16./eps^3 + 
       3.81517975849474112872979289960525820825`16./eps^2 + 
       10.9867238974000147944328780489005416639`16./eps}, 
     {141/200, 21.01134218598294856973607213353185901312`15.992852124828445 + 
       0.74405885062499999999999999999999999999`16./eps^3 + 
       3.8704751964083987936371588348689567074`16./eps^2 + 
       11.10572579601713676414367561601321432019`16./eps}, 
     {71/100, 21.12317009290619641093396389677663932234`15.992915123673619 + 
       0.75821681000000000000000000000000000002`16./eps^3 + 
       3.9261480669796909110417075147918144077`16./eps^2 + 
       11.22465637477446006722942007933464338095`16./eps}, 
     {143/200, 21.23243655061242215399976638158303903725`15.99297568723624 + 
       0.77257600062500000000000000000000000007`16./eps^3 + 
       3.98219587970496971795094093502649264292`16./eps^2 + 
       11.34350045983429094946377725307495850603`16./eps}, 
     {18/25, 21.3391245829170815855900910828142771124`15.993033885695258 + 
       0.78713856000000000000000000000000000002`16./eps^3 + 
       4.03861605109482832385096242708349689678`16./eps^2 + 
       11.46224287298274161845038368481132345681`16./eps}, 
     {29/40, 21.44321776609428794879193779191246850075`15.99308978601914 + 
       0.80190664062499999999999999999999999999`16./eps^3 + 
       4.09540590393882041245057915550987665597`16./eps^2 + 
       11.58086843538641412101889820723408715456`16./eps}, 
     {73/100, 21.54470022817452310491366810628044902885`15.993143452115564 + 
       0.81688241000000000000000000000000000007`16./eps^3 + 
       4.15256266657673426386338136150905074276`16./eps^2 + 
       11.69936197135733250618166544873883492671`16./eps}, 
     {147/200, 21.64355664810033685142149711994294710499`15.993194944972446 + 
       0.83206805062499999999999999999999999997`16./eps^3 + 
       4.21008347217630098574827985396798894296`16./eps^2 + 
       11.81770831212564153454947684154104708792`16./eps}, 
     {37/50, 21.73977225474147085031829408183752468655`15.993244322790954 + 
       0.84746575999999999999999999999999999998`16./eps^3 + 
       4.26796535801722011838384005540070916408`16./eps^2 + 
       11.93589229961960807275755279039001126863`16./eps}, 
     {149/200, 21.83333282577083927282677335776162264576`15.993291641110794 + 
       0.86307775062500000000000000000000000001`16./eps^3 + 
       4.32620526478138893861860069926362440319`16./eps^2 + 
       12.05389879025247845516873142333209895706`16./eps}, 
     {3/4, 21.92422468640279208958236362061169025538`15.99333695292858 + 
       0.87890625000000000000000000000000000006`16./eps^3 + 
       4.38480003584922483615574107097265722193`16./eps^2 + 
       12.17171265871576153936256634610157688735`16./eps}, 
     {151/200, 22.01243470799508091931526467657756888254`15.993380308809272 + 
       0.89495350062500000000000000000000000001`16./eps^3 + 
       4.44374641660197307747895556037273070599`16./eps^2 + 
       12.28931880177852295931330721195014460796`16./eps}, 
     {19/25, 22.09795030651594027343380214162531755816`15.993421756991523 + 
       0.91122175999999999999999999999999999996`16./eps^3 + 
       4.50304105372989511245046290468000170912`16./eps^2 + 
       12.40670214209229122160685235796818141128`16./eps}, 
     {153/200, 22.18075944087768942284093910560357980722`15.993461343487027 + 
       0.92771330062499999999999999999999999996`16./eps^3 + 
       4.56268049454623532052890198599555191279`16./eps^2 + 
       12.5238476320011908248228975372352167362`16./eps}, 
     {77/100, 22.26085061113825202532266020855127136055`15.993499112174158 + 
       0.94443041000000000000000000000000000006`16./eps^3 + 
       4.62266118630686674176835229523522837079`16./eps^2 + 
       12.64074025735693153806130931558929818071`16./eps}, 
     {31/40, 22.33821285657198201230396519181876323219`15.993535104886671 + 
       0.96137539062500000000000000000000000006`16./eps^3 + 
       4.68297947553551889617248240044517544596`16./eps^2 + 
       12.75736504133829637782971671492866609465`16./eps}, 
     {39/50, 22.41283575361117521183296555555445938866`15.993569361497032 + 
       0.97855055999999999999999999999999999998`16./eps^3 + 
       4.74363160735449326730243767046273129527`16./eps^2 + 
       12.8737070482747836980853557745452124796`16./eps}, 
     {157/200, 22.48470941365963667834316257290360296252`15.993601919995466 + 
       0.99595825062500000000000000000000000002`16./eps^3 + 
       4.80461372482077441580657407670973245586`16./eps^2 + 
       12.9897513874740711798138728414175756033`16./eps}, 
     {79/100, 22.55382448077966388717315791087374084711`15.99363281656433 + 
       1.01360081000000000000000000000000000004`16./eps^3 + 
       4.86592186826744699911793683367636012251`16./eps^2 + 
       13.10548321705298139660250625185256162166`16./eps}, 
     {159/200, 22.62017212925379580647468425379328151252`15.993662085648385 + 
       1.031480600625`16./eps^3 + 
       4.92755197465033120815451805369670622103`16./eps^2 + 
       13.22088774777164006256067022220454218339`16./eps}, 
     {4/5, 22.68374406102266728171679540010672888498`15.993689760021228 + 
       1.04960000000000000000000000000000000006`16./eps^3 + 
       4.98949987689975129350920005400699818879`16./eps^2 + 
       13.33595024687052905892199649949981229174`16./eps}, 
     {161/200, 22.74453250300029766341555719742107739944`15.993715870847815 + 
       1.06796140062500000000000000000000000001`16./eps^3 + 
       5.05176130327735394523882007796698234063`16./eps^2 + 
       13.45065604191014690498180711391688383103`16./eps}, 
     {81/100, 22.8025302042681313460235463003075814664`15.993740447743598 + 
       1.08656720999999999999999999999999999998`16./eps^3 + 
       5.11433187673789531472711009776865480663`16./eps^2 + 
       13.56499052461299950598165931680647002347`16./eps}, 
     {163/200, 22.85773043314913694008458058097759109404`15.993763518830232 + 
       1.10541985062500000000000000000000000006`16./eps^3 + 
       5.17720711429591742684794278534185866469`16./eps^2 + 
       13.67893915470765379254528303661011521369`16./eps}, 
     {41/50, 22.91012697416326028243464019740854701403`15.993785110788131 + 
       1.12452176000000000000000000000000000001`16./eps^3 + 
       5.24038242639723662831515716101055021943`16./eps^2 + 
       13.79248746377459627984331792521358554591`16./eps}, 
     {33/40, 22.95971412486551505970228965074442807285`15.993805248906034 + 
       1.14387539062499999999999999999999999999`16./eps^3 + 
       5.30385311629516855607967949096411396148`16./eps^2 + 
       13.90562105909364763555798206762905435454`16./eps}, 
     {83/100, 23.00648669256798302008985837949860445162`15.993823957127619 + 
       1.16348321000000000000000000000000000007`16./eps^3 + 
       5.36761437943141589022077930541011146721`16./eps^2 + 
       14.01832562749269306891210025632574357526`16./eps}, 
     {167/200, 23.05043999094698406048378849166664645983`15.993841258095529 + 
       1.18334770062500000000000000000000000002`16./eps^3 + 
       5.43166130282154688116950509183672128192`16./eps^2 + 
       14.13058693919749675277864274800928097366`16./eps}, 
     {21/25, 23.09156983653666455199942271199244417519`15.99385717319267 + 
       1.20347135999999999999999999999999999997`16./eps^3 + 
       5.49598886444499431339368190637954972846`16./eps^2 + 
       14.2423908516823765807746074723700504886`16./eps}, 
     {169/200, 23.1298725451102401767563701761413470502`15.993871722581087 + 
       1.22385670062500000000000000000000000003`16./eps^3 + 
       5.56059193263950618886706226974098593529`16./eps^2 + 
       14.35372331352152335419937066920748163547`16./eps}, 
     {17/20, 23.16534492795011765621992988155039936856`15.993884925238518 + 
       1.24450625000000000000000000000000000006`16./eps^3 + 
       5.62546526549998098565346976435136253513`16./eps^2 + 
       14.46457036824075600202458898296504360144`16./eps}, 
     {171/200, 23.19798428800810750651424172078894213604`15.993896798992594 + 
       1.26542255062499999999999999999999999999`16./eps^3 + 
       5.69060351028162187158913167178721785244`16./eps^2 + 
       14.57491815816951167262408995855646924406`16./eps}, 
     {43/50, 23.22778841595692787266885748408470993973`15.99390736055301 + 
       1.28660815999999999999999999999999999999`16./eps^3 + 
       5.75600120280734573209205564706131758222`16./eps^2 + 
       14.68475292829287650974372229861838517452`16./eps}, 
     {173/200, 23.25475558613418728421896419637991541969`15.993916625541466 + 
       1.30806565062499999999999999999999999998`16./eps^3 + 
       5.82165276687938430623956492026028122847`16./eps^2 + 
       14.79406103010346964802930623295833883862`16./eps}, 
     {87/100, 23.27888455238002200250189333557263241404`15.993924608519803 + 
       1.32979761000000000000000000000000000006`16./eps^3 + 
       5.88755251369501611803513306677452991479`16./eps^2 + 
       14.90282892545299944543971209748910573133`16./eps}, 
     {7/8, 23.30017454376955142140647094932348726495`15.993931323016081 + 
       1.351806640625`16./eps^3 + 
       5.95369464126636924176603849011861210473`16./eps^2 + 
       15.01104319040331722078882750958503999595`16./eps}, 
     {22/25, 23.31862526024130278431158208123455717662`15.993936781548912 + 
       1.37409536`16./eps^3 + 6.02007323384423625300145140160439618862`16./
        eps^2 + 15.11869051907679979375887762178207792677`16./eps}, 
     {177/200, 23.33423686812274432400031910716350342776`15.993940995649993 + 
       1.396666400625`16./eps^3 + 
       6.08668226134584399150168094502798259555`16./eps^2 + 
       15.22575772750589794086196669024783716089`16./eps}, 
     {89/100, 23.34700999555405376920068266897793217204`15.99394397588494 + 
       1.41952241000000000000000000000000000006`16./eps^3 + 
       6.15351557878652200044970293242026939573`16./eps^2 + 
       15.33223175748169349245146411346687813479`16./eps}, 
     {179/200, 23.35694572781123704060961619271634513212`15.993945731872488 + 
       1.44266605062500000000000000000000000007`16./eps^3 + 
       6.22056692571521470926579908347198208316`16./eps^2 + 
       15.43809968040131321107566530289928302498`16./eps}, 
     {9/10, 23.36404560252969989841119174384305215986`15.993946272301995 + 
       1.46610000000000000000000000000000000005`16./eps^3 + 
       6.28782992565378359606167441127823552835`16./eps^2 + 
       15.54334870111405281793877051280512838044`16./eps}, 
     {181/200, 23.36831160482936325825091705169178385502`15.99394560494961 + 
       1.48982695062499999999999999999999999998`16./eps^3 + 
       6.35529808554004670171729672116896530734`16./eps^2 + 
       15.64796616176606957936239632873385169985`16./eps}, 
     {91/100, 23.36974616234240092580057398033532377978`15.99394373669265 + 
       1.51384961000000000000000000000000000005`16./eps^3 + 
       6.42296479517450397175885118366097792078`16./eps^2 + 
       15.75193954564350673597327540123545134523`16./eps}, 
     {183/200, 23.36835214014466658337712408791968689677`15.99394067352271 + 
       1.53817070062499999999999999999999999999`16./eps^3 + 
       6.4908233266706979757702456374893208042`16./eps^2 + 
       15.85525648101391776061920464256596866851`16./eps}, 
     {23/25, 23.36413283559186502011173969427332968904`15.9939364205573 + 
       1.56279296000000000000000000000000000008`16./eps^3 + 
       6.55886683390916059803001094270717560978`16./eps^2 + 
       15.95790474496586297318150084963442304347`16./eps}, 
     {37/40, 23.35709197306151078831637137138841729883`15.993930982049948 + 
       1.58771914062499999999999999999999999998`16./eps^3 + 
       6.62708835199489730843458332179265424102`16./eps^2 + 
       16.05987226724655542767451158462564166639`16./eps}, 
     {93/100, 23.34723369860170581398308823724173224997`15.993924361399095 + 
       1.61295201000000000000000000000000000004`16./eps^3 + 
       6.69548079671836161051203507144418006444`16./eps^2 + 
       16.16114713409743722520142607760273198726`16./eps}, 
     {187/200, 23.33456257448775581619633015502153465972`15.993916561155498 + 
       1.63849435062500000000000000000000000003`16./eps^3 + 
       6.76403696401987322437321303213902805163`16./eps^2 + 
       16.2617175920875715011179044370716000158`16./eps}, 
     {47/50, 23.31908357368763386952912866283822809903`15.993907583028285 + 
       1.66434896000000000000000000000000000003`16./eps^3 + 
       6.83274952945743449767924585497437464055`16./eps^2 + 
       16.36157205194473929154705648698683030724`16./eps}, 
     {189/200, 23.30080207423728798598756330950027758845`15.993897427889813 + 
       1.69051865062499999999999999999999999998`16./eps^3 + 
       6.90161104767790044797986023510824817969`16./eps^2 + 
       16.4606990923841343083677104701079572788`16./eps}, 
     {19/20, 23.27972385352677822471806367505989706225`15.993886095779052 + 
       1.71700625000000000000000000000000000003`16./eps^3 + 
       6.97061395189145872591691676656429845788`16./eps^2 + 
       16.55908746393455234792075832913471281652`16./eps}, 
     {191/200, 23.25585508249821754879283394348021217732`15.993873585903696 + 
       1.74381460062499999999999999999999999999`16./eps^3 + 
       7.03975055334937665158118879458498033715`16./eps^2 + 
       16.6567260927619756316953949905117860589`16./eps}, 
     {24/25, 23.22920231975647949920343862580734168524`15.993859896641027 + 
       1.77094655999999999999999999999999999998`16./eps^3 + 
       7.10901304082497331651636751167549582842`16./eps^2 + 
       16.75360408449045583171951636201666956983`16./eps}, 
     {193/200, 23.19977250559362462039331242786868717261`15.993845025537365 + 
       1.79840500062500000000000000000000000008`16./eps^3 + 
       7.17839348009777556221218877570419605387`16./eps^2 + 
       16.84971072802020287364839493094310502224`16./eps}, 
     {97/100, 23.16757295592798664934352371864304934173`15.993828969306287 + 
       1.82619281000000000000000000000000000004`16./eps^3 + 
       7.24788381344081744312022665424376154121`16./eps^2 + 
       16.94503549934278984080455425854112316247`16./eps}, 
     {39/40, 23.13261135615884853698188244642252074411`15.993811723825472 + 
       1.85431289062500000000000000000000000004`16./eps^3 + 
       7.31747585911104355893646640428240419844`16./eps^2 + 
       17.03956806535338742667894757630824795413`16./eps}, 
     {49/50, 23.09489575493762761606783928041524301008`15.993793284132183 + 
       1.88276815999999999999999999999999999999`16./eps^3 + 
       7.3871613108427773977739888289915524644`16./eps^2 + 
       17.13329828765994440550435053511425188928`16./eps}, 
     {197/200, 23.05443455785647862539384012516333333443`15.993773644417487 + 
       1.91156155062500000000000000000000000004`16./eps^3 + 
       7.45693173734421656952235455144339377733`16./eps^2 + 
       17.22621622638923351414486105326604212525`16./eps}, 
     {99/100, 23.01123652105521239834247064876217186387`15.99375279801901 + 
       1.94069601000000000000000000000000000008`16./eps^3 + 
       7.52677858179691752775965563381086009419`16./eps^2 + 
       17.31831214398968496724956620106305806768`16./eps}, 
     {199/200, 22.96531074474741821971511337247869021623`15.993730737412314 + 
       1.97017450062500000000000000000000000009`16./eps^3 + 
       7.59669316135823307962848320122409058656`16./eps^2 + 
       17.40957650903093256479001422211661393674`16./eps}, 
     {1, 22.91666666666666666582198447245096153744`15.993707454200903 + 
       2.00000000000000000000000000000000000003`16./eps^3 + 
       7.66666666666666666666666666666666666677`16./eps^2 + 
       17.5000000000000000000000000000000000003`16./eps}}
 
points9b = {{1/10, 4.6957886880113522219198489544766509451`15.95859555037193 - 
       0.00999999999999999999999999999999999999`16./eps^3 + 
       0.07258911387684529614612692302613574041`16./eps^2 + 
       0.66278795110600531864207052106111761674`16./eps}, 
     {21/200, 4.62370482220619051818976491749082158574`15.960041982993031 - 
       0.01102500000000000000000000000000000001`16./eps^3 + 
       0.06455989939579256916915885772266249156`16./eps^2 + 
       0.63880397391020913931037260330313188355`16./eps}, 
     {11/100, 4.55112103230191268542059849173095981409`15.961381363370617 - 
       0.0121`16./eps^3 + 0.05629258731787980075640903893671601876`16./
        eps^2 + 0.61449597101342643571766502055457949708`16./eps}, 
     {23/200, 4.47810153496254054089153473133612178102`15.96262559227076 - 
       0.01322499999999999999999999999999999999`16./eps^3 + 
       0.04779415816586232547146827892067874249`16./eps^2 + 
       0.58988811005804819726695937855724072613`16./eps}, 
     {3/25, 4.40470597703767066004716921960802843664`15.963784880454808 - 
       0.01439999999999999999999999999999999999`16./eps^3 + 
       0.03907128190282273296943565451097716501`16./eps^2 + 
       0.5650028760733164513649272433673723411`16./eps}, 
     {1/8, 4.33098994810839116372157149270614323749`15.96486804554745 - 
       0.01562500000000000000000000000000000001`16./eps^3 + 
       0.03013034440042435752986839958661058681`16./eps^2 + 
       0.53986124022077415569496958754582605531`16./eps}, 
     {13/100, 4.25700541737672703510093491351916187678`15.965882748071493 - 
       0.01690000000000000000000000000000000001`16./eps^3 + 
       0.02097747066037034682515414644903378928`16./eps^2 + 
       0.51448280580932080165091088315372824977`16./eps}, 
     {27/200, 4.18280110845629375328337286413180007173`15.966835680876198 - 
       0.01822499999999999999999999999999999999`16./eps^3 + 
       0.01161854529943945345801723484242291541`16./eps^2 + 
       0.48888593538776157527721238737776128301`16./eps}, 
     {7/50, 4.10842282279334495769404721785695591006`15.967732722481886 - 
       0.01959999999999999999999999999999999996`16./eps^3 + 
       0.00205923071194410076007886165198518616`16./eps^2 + 
       0.46308786196767595877095178229523190919`16./eps}, 
     {29/200, 4.03391372028740694306721592419051029342`15.968579062217048 - 
       0.02102500000000000000000000000000000003`16./eps^3 - 
       0.00769501675195389749910998796151279064`16./eps^2 + 
       0.43710478684579058661058663635055376555`16./eps}, 
     {3/20, 3.95931456401351630269002815672869079499`15.969379303108472 - 
       0.02249999999999999999999999999999999998`16./eps^3 - 
       0.01763893231313032122103187123068435064`16./eps^2 + 
       0.41095196603930108548211220269198285941`16./eps}, 
     {31/200, 3.88466393464886479623077954104651050806`15.970137547082333 - 
       0.02402500000000000000000000000000000005`16./eps^3 - 
       0.02776742976401616118542928798879211405`16./eps^2 + 
       0.3846437869883701183915906928247276423`16./eps}, 
     {4/25, 3.80999841918531569558090766588687753194`15.970857465994674 - 
       0.0256`16./eps^3 - 0.0380755897492035513455231130608998339`16./eps^2 + 
       0.35819383689442412718599949747835910735`16./eps}, 
     {33/200, 3.73535277769896757459053713034077893474`15.971542361231723 - 
       0.02722499999999999999999999999999999996`16./eps^3 - 
       0.04855864916336945573335877452017157533`16./eps^2 + 
       0.33161496383395738070218891582388544733`16./eps}, 
     {17/100, 3.66076009130129428212658758500349352423`15.972195214033153 - 
       0.02890000000000000000000000000000000004`16./eps^3 - 
       0.05921199152882692078441840020600201624`16./eps^2 + 
       0.30491933160269449737407644446144766274`16./eps}, 
     {7/40, 3.58625189387529595034556871199279300494`15.972818728243006 - 
       0.030625`16./eps^3 - 0.0700311382355943212513484172465571016`16./
        eps^2 + 0.2781184690946334855053767938404721179`16./eps}, 
     {9/50, 3.5118582897781885730636290761190098389`15.973415366848918 - 
       0.03239999999999999999999999999999999996`16./eps^3 - 
       0.08101174054386860622384023586049997584`16./eps^2 + 
       0.25122331489743751132058029985775487243`16./eps}, 
     {37/200, 3.43760805934820125813286477197969374172`15.973987383403701 - 
       0.03422500000000000000000000000000000004`16./eps^3 - 
       0.09214957226290725436534796360033196488`16./eps^2 + 
       0.22424425768429546939119957421910647477`16./eps}, 
     {19/100, 3.36352875377071077542699652283554718599`15.974536849215662 - 
       0.03610000000000000000000000000000000001`16./eps^3 - 
       0.10344052303211812667265261154451208265`16./eps^2 + 
       0.19719117289841694351331006308439902285`16./eps}, 
     {39/200, 3.2896467806262409001833048060322458183`15.975065677030964 - 
       0.03802499999999999999999999999999999999`16./eps^3 - 
       0.11488059214006120110259465767641167968`16./eps^2 + 
       0.17007345615640210328310129649643604804`16./eps}, 
     {1/5, 3.21598748124972267122786397619777417711`15.975575641803033 - 
       0.03999999999999999999999999999999999996`16./eps^3 - 
       0.1264658828254253782854244533204758501`16./eps^2 + 
       0.14290005373818771667419723942659637909`16./eps}, 
     {41/200, 3.14257520086961065040636292067605536315`15.976068399042976 - 
       0.04202500000000000000000000000000000005`16./eps^3 - 
       0.13819259701113145107074522608914421744`16./eps^2 + 
       0.11567949048202494840567711673698578751`16./eps}, 
     {21/100, 3.06943335236068372529705800388859481695`15.976545501163411 - 
       0.04410000000000000000000000000000000003`16./eps^3 - 
       0.15005703042874895888746475944043327376`16./eps^2 + 
       0.08841989536132715457153669469194748672`16./eps}, 
     {43/200, 2.99658447433104318325430153378677707151`15.977008412165368 - 
       0.04622500000000000000000000000000000001`16./eps^3 - 
       0.16205556809557755050406149219501904421`16./eps^2 + 
       0.06112902498490182539304852836460744661`16./eps}, 
     {11/50, 2.92405028416814039130541681986598817631`15.971572208520033 - 
       0.04839999999999999999999999999999999999`16./eps^3 - 
       0.17418468011117673804698174021740868718`16./eps^2 + 
       0.03381428523197465329944522545388859206`16./eps}, 
     {9/40, 2.85185172658747186000124678957552225584`15.964309253158918 - 
       0.05062499999999999999999999999999999998`16./eps^3 - 
       0.18644091774394909056774430169122509715`16./eps^2 + 
       0.00648275120765395978703464847922166168`16./eps}, 
     {23/100, 2.78000901815833721082867402029936883989`15.956936818002392 - 
       0.05289999999999999999999999999999999996`16./eps^3 - 
       0.19882090978168737750961214664187240881`16./eps^2 - 
       0.0208588143176393870794998015490564863`16./eps}, 
     {47/200, 2.70854168822247985144483330241698205471`15.949441761599758 - 
       0.05522499999999999999999999999999999995`16./eps^3 - 
       0.21132135912286535349883373135107593721`16./eps^2 - 
       0.04820394384031887363957089189091200265`16./eps}, 
     {6/25, 2.63746861656980090743322534131822190986`15.941810697890613 - 
       0.05759999999999999999999999999999999994`16./eps^3 - 
       0.22393903958795051865495967136811842885`16./eps^2 - 
       0.07554644929938794446718156136837269552`16./eps}, 
     {49/200, 2.56680806819298663202141764748972056282`15.934029925581065 - 
       0.06002500000000000000000000000000000005`16./eps^3 - 
       0.2366707929321999511920282394584270686`16./eps^2 - 
       0.10288040738214260696770477140718342218`16./eps}, 
     {1/4, 2.49657772540428340937461181068815397391`15.92608535604328 - 
       0.06250000000000000000000000000000000005`16./eps^3 - 
       0.24951352604331282436479537888014954635`16./eps^2 - 
       0.13020014585861005056325098583863115482`16./eps}, 
     {51/200, 2.42679471756559148303822250279157658326`15.917962438767752 - 
       0.06502500000000000000000000000000000005`16./eps^3 - 
       0.26246420830899373828391382529762996225`16./eps^2 - 
       0.15750023085438010709264533603119967792`16./eps}, 
     {13/50, 2.35747564865460933158908571823332694702`15.909646083357543 - 
       0.06760000000000000000000000000000000005`16./eps^3 - 
       0.27551986914096170394956873997214663306`16./eps^2 - 
       0.18477545498099943317011339706550676736`16./eps}, 
     {53/200, 2.28863662286518074734332013581801356229`15.901120576985852 - 
       0.07022500000000000000000000000000000005`16./eps^3 - 
       0.28867759564324769294740337408784479495`16./eps^2 - 
       0.21202082625144811070742913945333135956`16./eps}, 
     {27/100, 2.22029326841842985925459931969970875249`15.892369496141477 - 
       0.07289999999999999999999999999999999994`16./eps^3 - 
       0.30193453041378214699838239566740512289`16./eps^2 - 
       0.23923155771556629302239590128584786083`16./eps}, 
     {11/40, 2.15246075974253719971546022475739807079`15.883375611356803 - 
       0.07562499999999999999999999999999999995`16./eps^3 - 
       0.31528786946930231485893077047565737078`16./eps^2 - 
       0.26640305775678098093436755923937149254`16./eps}, 
     {7/25, 2.0851538381623877837340134834560324688`15.874120783445074 - 
       0.07839999999999999999999999999999999996`16./eps^3 - 
       0.32873486028452446018475155842509612833`16./eps^2 - 
       0.29353092099721570055110576784611631627`16./eps}, 
     {57/200, 2.01838683122586499326552495191280871982`15.864585849559901 - 
       0.08122499999999999999999999999999999997`16./eps^3 - 
       0.34227279993734216256830936339771024334`16./eps^2 - 
       0.32061091976334722700197136498743535255`16./eps}, 
     {29/100, 1.9521736707806965851984055823888467228`15.854750497122426 - 
       0.08409999999999999999999999999999999999`16./eps^3 - 
       0.35589903335254138843047228760215321439`16./eps^2 - 
       0.34763899606888758996824536941787624426`16./eps}, 
     {59/200, 1.8865279099044604563934401182980092425`15.844593123326925 - 
       0.087025`16./eps^3 - 0.36961095163717630332984609618759749462`16./
        eps^2 - 0.3746112540755883441456199909752424583`16./eps}, 
     {3/10, 1.82146273878030448667058601232155726455`15.834090677518267 - 
       0.09000000000000000000000000000000000002`16./eps^3 - 
       0.38340599050133605134147481212902973598`16./eps^2 - 
       0.40152395299624924668473299294759830382`16./eps}, 
     {61/200, 1.75699099960205406782410899914887386934`15.823218483214761 - 
       0.09302500000000000000000000000000000004`16./eps^3 - 
       0.39728162875855983234829540402284840627`16./eps^2 - 
       0.42837350040741821541986383803800655013`16./eps}, 
     {31/100, 1.69312520058442982796026466330096515672`15.811950035899201 - 
       0.09609999999999999999999999999999999995`16./eps^3 - 
       0.41123538690063241203672913133877615163`16./eps^2 - 
       0.45515644594213962983221158641651798293`16./eps}, 
     {63/200, 1.6298775291470821000690459307929000522`15.800256771884248 - 
       0.09922499999999999999999999999999999998`16./eps^3 - 
       0.42526482574192065842482398792845806992`16./eps^2 - 
       0.48186947533568338424972524325092266122`16./eps}, 
     {8/25, 1.5672598643348125824750691540303344464`15.788107802529124 - 
       0.10240000000000000000000000000000000001`16./eps^3 - 
       0.43936754512879900632911874453164749394`16./eps^2 - 
       0.50850940479950204938380110359084294038`16./eps}, 
     {13/40, 1.5052837885307431591618906095869625163`15.775469606779385 - 
       0.10562500000000000000000000000000000004`16./eps^3 - 
       0.45354118271006244606275639946455030874`16./eps^2 - 
       0.53507317570074798894566669333479072082`16./eps}, 
     {33/100, 1.44396059851413896863421836437476545717`15.762305673335225 - 
       0.10889999999999999999999999999999999995`16./eps^3 - 
       0.46778341276454369034682536400030001668`16./eps^2 - 
       0.56155784952656240958178175690355309872`16./eps}, 
     {67/200, 
      1.3833013159100619139180075630177832892110449146485455979256`31.7748367\
86182366 - 0.1122249999999999999999999999999999999999999999999999999996`32./
        eps^3 - 
       0.482091945082440083575473014461225211531231893245024941791`32./
        eps^2 - 
       0.5879606031140468884316149264600733697381550017484895052417`32./eps}, 
     {17/50, 1.32331669707395810339813027094220980609`15.734237007908089 - 
       0.11560000000000000000000000000000000003`16./eps^3 - 
       0.49646452389711864983177750110231243143`16./eps^2 - 
       0.61427872412836487477899036082972997114`16./eps}, 
     {69/200, 1.26401724245062051651966385570490207528`15.719240139496245 - 
       0.11902499999999999999999999999999999995`16./eps^3 - 
       0.51089892686440713603516163007311378523`16./eps^2 - 
       0.64050960677281350068608298274864225659`16./eps}, 
     {7/20, 1.2054132054436600530106980511457916687`15.703531974753204 - 
       0.12249999999999999999999999999999999999`16./eps^3 - 
       0.52539296408659738379456086435034851772`16./eps^2 - 
       0.6666507477159701411099428875911216347`16./eps}, 
     {71/200, 1.14751460082863226866226138529841330727`15.68705298089768 - 
       0.12602500000000000000000000000000000003`16./eps^3 - 
       0.53994447717858697224232408373335006876`16./eps^2 - 
       0.69269974222216708162862322989147575622`16./eps}, 
     {9/25, 1.09033121274026181621208302970075541837`15.669736572549933 - 
       0.12959999999999999999999999999999999996`16./eps^3 - 
       0.55455133837376768859394109461906085742`16./eps^2 - 
       0.71865428047259333207932940409462089895`16./eps}, 
     {73/200, 1.03387260226177942392035318490287803327`15.65150786265869 - 
       0.13322500000000000000000000000000000001`16./eps^3 - 
       0.56921144966743666787455844318232708047`16./eps^2 - 
       0.7445121440652756304470098698851294223`16./eps}, 
     {37/100, 0.97814811464212184599716369918813410136`15.632282121417399 - 
       0.13689999999999999999999999999999999995`16./eps^3 - 
       0.58392274199565947888373462211845474323`16./eps^2 - 
       0.77027120268306036705069621265560533332`16./eps}, 
     {3/8, 0.92316688616480556291592336942835208804`15.611962856544622 - 
       0.140625`16./eps^3 - 0.59868317444765533950714865272714752065`16./
        eps^2 - 0.79592941091951282163466298431573522346`16./eps}, 
     {19/50, 0.86893785069036507047562545230590252963`15.590439396815333 - 
       0.14440000000000000000000000000000000006`16./eps^3 - 
       0.61349073350990419865106549116236624115`16./eps^2 - 
       0.8214848052533771176988042067547113959`16./eps}, 
     {77/200, 0.81546974589264410717457407328939548807`15.567583815445978 - 
       0.148225`16./eps^3 - 0.62834343234029467725137423544404748907`16./
        eps^2 - 0.84693550116290622058179471292670420121`16./eps}, 
     {39/100, 0.76277111920767287716470327608241663408`15.54324696365573 - 
       0.15210000000000000000000000000000000006`16./eps^3 - 
       0.64323931007074175972329561368428075458`16./eps^2 - 
       0.87227969037198198722256753165447930996`16./eps}, 
     {79/200, 0.71085033351248762410658091369412130269`15.517253285825054 - 
       0.156025`16./eps^3 - 0.65817643113680451524724547455872547102`16./
        eps^2 - 0.89751563822050593790295879487120302678`16./eps}, 
     {2/5, 0.65971557254997164907060207608517274783`15.489393936898212 - 
       0.15999999999999999999999999999999999995`16./eps^3 - 
       0.67315288463292776462142639498197864758`16./eps^2 - 
       0.92264168115205673255996884683870920907`16./eps}, 
     {81/200, 0.60937484611464170694974758903350622797`15.459417487259135 - 
       0.16402500000000000000000000000000000002`16./eps^3 - 
       0.68816678369201817581786291979287525853`16./eps^2 - 
       0.9476562243122844772538612562876496134`16./eps}, 
     {41/100, 0.55983599501323431882940218003934474573`15.427017122736085 - 
       0.16809999999999999999999999999999999997`16./eps^3 - 
       0.70321626488814538474387074550521842628`16./eps^2 - 
       0.97255773925194870914172057931178198208`16./eps}, 
     {83/200, 0.51110669581297202462256532501035143633`15.391812623143897 - 
       0.17222500000000000000000000000000000004`16./eps^3 - 
       0.71829948766123295154478359841675567151`16./eps^2 - 
       0.99734476172890957740803441473560898057`16./eps}, 
     {21/50, 0.46319446538949764763960707466312180046`15.353324334310326 - 
       0.1764`16./eps^3 - 0.73341463376267277780625979908606605496`16./
        eps^2 - 1.02201588960375338026132940917867243647`16./eps}, 
     {17/40, 0.41610666528562631108179536393298455036`15.310934445206188 - 
       0.18062499999999999999999999999999999996`16./eps^3 - 
       0.74855990672086047895629119341072160254`16./eps^2 - 
       1.04656978082407695998942080161520388325`16./eps}, 
     {43/100, 0.36985050589133260574409654952705038603`15.263827329520593 - 
       0.18490000000000000000000000000000000004`16./eps^3 - 
       0.76373353132570853888250731100722563464`16./eps^2 - 
       1.07100515149277295650366818296519557766`16./eps}, 
     {87/200, 0.32443305045466530761426713642252767272`15.210893705303869 - 
       0.189225`16./eps^3 - 0.77893375313124924176252738511695366966`16./
        eps^2 - 1.09532077401595179298719706834181480637`16./eps}, 
     {11/25, 0.279861218932656575116128925258450218`15.150568601014738 - 
       0.19359999999999999999999999999999999997`16./eps^3 - 
       0.79415883797549071647839854472672580123`16./eps^2 - 
       1.11951547532640851998038481982321725938`16./eps}, 
     {89/200, 0.23614179169069209695387164619926692182`15.080539345648699 - 
       0.19802500000000000000000000000000000005`16./eps^3 - 
       0.80940707151673724804269578544838623622`16./eps^2 - 
       1.14358813517879509057334457766506557917`16./eps}, 
     {9/20, 0.19328141305826259161107897216659204223`14.99717413119765 - 
       0.20250000000000000000000000000000000002`16./eps^3 - 
       0.82467675878562958680000869297905812341`16./eps^2 - 
       1.16753768451289292277237499591250948526`16./eps}, 
     {91/200, 0.15128659474850854346598561445502777148`14.894272575056322 - 
       0.207025`16./eps^3 - 0.83996622375220257346986219070000025022`16./
        eps^2 - 1.19136310388159821611913601988117169807`16./eps}, 
     {23/50, 0.11016371914850302026279258112683787091`14.759862983971498 - 
       0.21159999999999999999999999999999999997`16./eps^3 - 
       0.85527380890729622762038963586583914992`16./eps^2 - 
       1.21506342194043478166470183673263735571`16./eps}, 
     {93/200, 0.0699190424867811661788604067005334228`14.5656300014274 - 
       0.21622499999999999999999999999999999995`16./eps^3 - 
       0.87059787485769272993638622117174299841`16./eps^2 - 
       1.23863771399559734763703412846748033911`16./eps}, 
     {47/100, 0.03055869788422503675629103176343050555`14.209231133186039 - 
       0.22090000000000000000000000000000000005`16./eps^3 - 
       0.88593679993438565744453519851397013725`16./eps^2 - 
       1.26208510060770353700172218766785265828`16./eps}, 
     {19/40, -0.00791130170596366370871884243379426604`13.625251463180653 - 
       0.22562500000000000000000000000000000003`16./eps^3 - 
       0.90128897981341958195797884068772802232`16./eps^2 - 
       1.28540474624859599726348034329919247155`16./eps}, 
     {12/25, -0.04548506066381478772902068978807126809`14.38761894197346 - 
       0.23040000000000000000000000000000000001`16./eps^3 - 
       0.91665282714876787675064784312058207149`16./eps^2 - 
       1.30859585800868842703609091721892067892`16./eps}, 
     {97/200, -0.08215679796860058675552659654187314046`14.646973814039548 - 
       0.235225`16./eps^3 - 0.93202677121674444269791331981616632498`16./
        eps^2 - 1.33165768435249133672612046379658757106`16./eps}, 
     {49/100, -0.11792084456053978037830605958730546845`14.806328760964362 - 
       0.24009999999999999999999999999999999999`16./eps^3 - 
       0.94740925757147119839488066074738369226`16./eps^2 - 
       1.35458951392008607743113767514266636533`16./eps}, 
     {99/200, -0.15277164079370857775781740936265830437`14.92101091311819 - 
       0.24502499999999999999999999999999999998`16./eps^3 - 
       0.96279874771094770353120241148405192913`16./eps^2 - 
       1.37739067437243968185028249361821937221`16./eps}, 
     {1/2, -0.18670373397593135318563945004943368547`15.010167868938161 - 
       0.24999999999999999999999999999999999997`16./eps^3 - 
       0.97819371875329231539625742442696575934`16./eps^2 - 
       1.40006053127856903262617507693226358088`16./eps}, 
     {101/200, -0.21971177599166543891901744937476897638`15.082726396939997 - 
       0.25502499999999999999999999999999999997`16./eps^3 - 
       0.99359266312274591995062383398477248416`16./eps^2 - 
       1.42259848704267140166743189099926170753`16./eps}, 
     {51/100, -0.25179052100412090865416104701668597369`15.143577167110587 - 
       0.26009999999999999999999999999999999997`16./eps^3 - 
       1.00899408824504962819738907681670467264`16./eps^2 - 
       1.44500397986944003387580636545437471886`16./eps}, 
     {103/200, -0.28293482323306629628658192725670181606`15.19569073592608 - 
       0.26522499999999999999999999999999999997`16./eps^3 - 
       1.02439651625182697475961255595638443096`16./eps^2 - 
       1.46727648276587868074127976221007367689`16./eps}, 
     {13/25, -0.31313963480496817542666971539908160232`15.241006285649808 - 
       0.27039999999999999999999999999999999997`16./eps^3 - 
       1.03979848369361918079901626296171370746`16./eps^2 - 
       1.48941550257801828315538844569608745633`16./eps}, 
     {21/40, -0.3424000036722967998397404289115780755`15.280859136601851 - 
       0.27562499999999999999999999999999999998`16./eps^3 - 
       1.05519854126123902352302568327203380594`16./eps^2 - 
       1.51142057906102278114558494172226396998`16./eps}, 
     {53/100, -0.37071107159900149906064882423489079202`15.316207443223776 - 
       0.28089999999999999999999999999999999999`16./eps^3 - 
       1.0705952535151248595437119875985737857`16./eps^2 - 
       1.53329128398124967991350463793931412743`16./eps}, 
     {107/200, -0.39806807220932111457530976393786106064`15.347761611395635 - 
       0.28622499999999999999999999999999999999`16./eps^3 - 
       1.08598719862239144398331809572116359056`16./eps^2 - 
       1.55502722024890488465944464382850316006`16./eps}, 
     {27/50, -0.42446632909724365056749833432268808152`15.376062594022141 - 
       0.29160000000000000000000000000000000001`16./eps^3 - 
       1.10137296810128843131533492281800762998`16./eps^2 - 
       1.5766280210800007612121279883920964496`16./eps}, 
     {109/200, -0.44990125399407869305867335243403802314`15.40153153270921 - 
       0.29702500000000000000000000000000000002`16./eps^3 - 
       1.11675116657279089288123965927510333004`16./eps^2 - 
       1.59809334918639168983861245388081765006`16./eps}, 
     {11/20, -0.47436834499172260486465301466601976903`15.424502474674313 - 
       0.30250000000000000000000000000000000004`16./eps^3 - 
       1.13212041151905889113958493167933424769`16./eps^2 - 
       1.61942289599272283673508352442906104864`16./eps}, 
     {111/200, -0.49786318481933322851255940864586976733`15.445244648076685 - 
       0.30802500000000000000000000000000000005`16./eps^3 - 
       1.14747933304851515954540376342713807574`16./eps^2 - 
       1.6406163808791857311134587573537231418`16./eps}, 
     {14/25, -0.52038143917126496045278797331280139153`15.463978054138982 - 
       0.31359999999999999999999999999999999996`16./eps^3 - 
       1.16282657366730129363927425383253199094`16./eps^2 - 
       1.66167355044902874539769477302889382526`16./eps}, 
     {113/200, -0.54191885508416365119267119177633195723`15.480884644590654 - 
       0.31922499999999999999999999999999999998`16./eps^3 - 
       1.17816078805688360439644825983176600845`16./eps^2 - 
       1.68259417781982195374556639464488261149`16./eps}, 
     {57/100, -0.56247125936130808701565575111168197402`15.496116502023481 - 
       0.32490000000000000000000000000000000001`16./eps^3 - 
       1.19348064285758995718426130480555627262`16./eps^2 - 
       1.70337806193752429534886765228731323515`16./eps}, 
     {23/40, -0.58203455704231436463686710073829363835`15.509801936101193 - 
       0.33062500000000000000000000000000000004`16./eps^3 - 
       1.20878481645786855415616486333930657368`16./eps^2 - 
       1.7240250269124466840408820791383653173`16./eps}, 
     {29/50, -0.60060472991644349245920571885074439001`15.522050099314027 - 
       0.33639999999999999999999999999999999995`16./eps^3 - 
       1.22407199878906874745801849343302106519`16./eps^2 - 
       1.74453492137624786106342887608961078218`16./eps}, 
     {117/200, -0.61817783507782965261292151541701461713`15.532954530917317 - 
       0.34222499999999999999999999999999999998`16./eps^3 - 
       1.23934089112555262584347184880360437276`16./eps^2 - 
       1.76490761785914054705509539495751128503`16./eps}, 
     {59/100, -0.63475000352102934153025898705709609242`15.54259591148422 - 
       0.34810000000000000000000000000000000002`16./eps^3 - 
       1.25459020588995432669496888031161618849`16./eps^2 - 
       1.78514301218652396430948393063177331314`16./eps}, 
     {119/200, -0.65031743877536727570268178970240562662`15.551044226949681 - 
       0.35402500000000000000000000000000000005`16./eps^3 - 
       1.26981866646341181558866469292880246683`16./eps^2 - 
       1.80524102289429521219756854681102272659`16./eps}, 
     {3/5, -0.66487641557662719809737007527591769493`15.558360484561199 - 
       0.35999999999999999999999999999999999998`16./eps^3 - 
       1.285025007000603271195288557341288223`16./eps^2 - 
       1.82520159066212641847260064351810828174`16./eps}, 
     {121/200, -0.67842327857470409823173432143566382383`15.56459808427808 - 
       0.36602500000000000000000000000000000002`16./eps^3 - 
       1.30020797224942723758613503956046833047`16./eps^2 - 
       1.84502467776402717892041082125205518459`16./eps}, 
     {61/100, -0.69095444107589876154703400289358054981`15.569803921938062 - 
       0.37209999999999999999999999999999999994`16./eps^3 - 
       1.31536631737517238049072539890763112196`16./eps^2 - 
       1.86471026753554265095564727642142357325`16./eps}, 
     {123/200, -0.70246638381859510898206282128993593678`15.574019281144105 - 
       0.37822499999999999999999999999999999999`16./eps^3 - 
       1.33049880778902902888614047893056443601`16./eps^2 - 
       1.88425836385696688895258594216511376879`16./eps}, 
     {31/50, -0.71295565378111999368481906872247877893`15.577280556845887 - 
       0.38440000000000000000000000000000000004`16./eps^3 - 
       1.34560421898080071732696444288953538837`16./eps^2 - 
       1.90366899065197869877534904324760623154`16./eps}, 
     {5/8, -0.72241886302063766331394353741821506453`15.579619843360813 - 
       0.39062499999999999999999999999999999997`16./eps^3 - 
       1.36068133635567968526802516671029669037`16./eps^2 - 
       1.92294219140113353790170613172487925421`16./eps}, 
     {63/100, -0.73085268754198543186073688848401846797`15.58106541199334 - 
       0.39690000000000000000000000000000000003`16./eps^3 - 
       1.37572895507495575377619766469358144013`16./eps^2 - 
       1.9420780286696698813107972775633613967`16./eps}, 
     {127/200, -0.73825386619539733360052539257811263096`15.581642097713313 - 
       0.40322499999999999999999999999999999997`16./eps^3 - 
       1.39074587990053320290788826667466361625`16./eps^2 - 
       1.96107658364911209181050007328076797178`16./eps}, 
     {16/25, -0.74461919960212500056836673691736456196`15.581371610015117 - 
       0.40960000000000000000000000000000000002`16./eps^3 - 
       1.40573092504313522910458014727878260878`16./eps^2 - 
       1.97993795571217425130827195708090107529`16./eps}, 
     {129/200, -0.74994554910698858766560753058060142313`15.580272779731434 - 
       0.41602499999999999999999999999999999997`16./eps^3 - 
       1.42068291401408028478176606401642346264`16./eps^2 - 
       1.99866226198049069637293496953699085398`16./eps}, 
     {13/20, -0.75422983575694736569198521768415897607`15.578361750950199 - 
       0.42250000000000000000000000000000000003`16./eps^3 - 
       1.43560067948051910456468388390996243494`16./eps^2 - 
       2.01724963690471922244303562619937026836`16./eps}, 
     {131/200, -0.75746903930481156683112591983044289705`15.575652125088865 - 
       0.42902499999999999999999999999999999998`16./eps^3 - 
       1.45048306312402551628031015995885452578`16./eps^2 - 
       2.03570023185658213714372888472696063786`16./eps}, 
     {33/50, -0.75966019723725605030462480705401438746`15.572155062473804 - 
       0.43560000000000000000000000000000000004`16./eps^3 - 
       1.46532891550243823104086251967965492734`16./eps^2 - 
       2.05401421473242861139921587121796351617`16./eps}, 
     {133/200, -0.76080040382633221535868712952314593831`15.567879345345304 - 
       0.442225`16./eps^3 - 1.48013709591485471606045706524831894269`16./
        eps^2 - 2.07219176956791915075780260668899765342`16./eps}, 
     {67/100, -0.76088680920370608155072845183108957344`15.562831404978354 - 
       0.44889999999999999999999999999999999995`16./eps^3 - 
       1.49490647226968198610970555987717446189`16./eps^2 - 
       2.09023309616344953859024334854136152068`16./eps}, 
     {27/40, -0.75991661845688589982877490444985380419`15.557015314506556 - 
       0.45562500000000000000000000000000000002`16./eps^3 - 
       1.509635920955652714017156215335881885`16./eps^2 - 
       2.10813840971994733444712096167421586001`16./eps}, 
     {17/25, -0.75788709074672914786288627760227016395`15.550432748005884 - 
       0.46239999999999999999999999999999999998`16./eps^3 - 
       1.52432432671571846610352560552246719024`16./eps^2 - 
       2.12590794048468898881355524706170166985`16./eps}, 
     {137/200, -0.75479553844555003256196623249349600649`15.543082905383667 - 
       0.46922500000000000000000000000000000006`16./eps^3 - 
       1.53897058252373512310097753844853979206`16./eps^2 - 
       2.14354193340679990100548614995569991407`16./eps}, 
     {69/100, -0.75063932629517541089603738580615280594`15.534962401577266 - 
       0.47610000000000000000000000000000000003`16./eps^3 - 
       1.55357358946385865870001388121374154889`16./eps^2 - 
       2.16104064780211333870379972591190054193`16./eps}, 
     {139/200, -0.74541587058432241193845734352082187714`15.52606511744369 - 
       0.48302499999999999999999999999999999999`16./eps^3 - 
       1.56813225661257242366551239780925206541`16./eps^2 - 
       2.1784043570270770919525926323896045799`16./eps}, 
     {7/10, -0.73912263834469729113305653905451396106`15.516382008457873 - 
       0.48999999999999999999999999999999999996`16./eps^3 - 
       1.58264550092326993033491223885787451591`16./eps^2 - 
       2.1956333481614090854868532295769219812`16./eps}, 
     {141/200, -0.73175714656523735036387125851386665498`15.505900865862905 - 
       0.49702500000000000000000000000000000005`16./eps^3 - 
       1.5971122471133198567256716238487617533`16./eps^2 - 
       2.21272792169921495308058341844927893889`16./eps}, 
     {71/100, -0.72331696142394101409826850854668551019`15.494606023144048 - 
       0.50410000000000000000000000000000000002`16./eps^3 - 
       1.6115314275535425975376161976521998511`16./eps^2 - 
       2.22968839124829181638052472649730236492`16./eps}, 
     {143/200, -0.71379969753675248638822314091294777933`15.482477998515549 - 
       0.511225`16./eps^3 - 1.62590198216003018679535922685842714343`16./
        eps^2 - 2.24651508323735323678556905833108000527`16./eps}, 
     {18/25, -0.70320301722298786129310791288577419358`15.469493061366558 - 
       0.51839999999999999999999999999999999997`16./eps^3 - 
       1.6402228582882438091700849831844872169`16./eps^2 - 
       2.26320833663092054904847572836750376336`16./eps}, 
     {29/40, -0.6915246297868091762781996520550737273`15.45562270710531 - 
       0.52562500000000000000000000000000000007`16./eps^3 - 
       1.65449301062932540927917732545677513181`16./eps^2 - 
       2.279768502651635564553202369089782001`16./eps}, 
     {73/100, -0.6787622908142713909868730047063978915`15.440833020289068 - 
       0.53290000000000000000000000000000000005`16./eps^3 - 
       1.66871140110856210533290478015412144259`16./eps^2 - 
       2.29619594450975897433556364967500110397`16./eps}, 
     {147/200, -0.66491380148548530727322163899830807651`15.425083899938489 - 
       0.54022500000000000000000000000000000003`16./eps^3 - 
       1.68287699878594421995959841410976260405`16./eps^2 - 
       2.31249103713962770917785137271604508199`16./eps}, 
     {37/50, -0.64997700790145610237439460628351227221`15.408328112949947 - 
       0.54760000000000000000000000000000000002`16./eps^3 - 
       1.6969887797587597612243095593423265069`16./eps^2 - 
       2.32865416694285304755099494924943669498`16./eps}, 
     {149/200, -0.63394980042517397299867081618366228103`15.390510130734702 - 
       0.55502500000000000000000000000000000001`16./eps^3 - 
       1.71104572706617012485577784061844872698`16./eps^2 - 
       2.34468573153804942163439923344768967376`16./eps}, 
     {3/4, -0.61683011303654789568421000263090846411`15.37156468944893 - 
       0.5625`16./eps^3 - 1.72504683059571364838701540594791712395`16./
        eps^2 - 2.3605861395168916758251051307835598916`16./eps}, 
     {151/200, -0.59861592270078992324701697725986124074`15.351414993686198 - 
       0.57002499999999999999999999999999999999`16./eps^3 - 
       1.73899108699168543296291623733373708052`16./eps^2 - 
       2.37635581020630599871389656024955550604`16./eps}, 
     {19/25, -0.57930524874986933804109959306252001209`15.32997045463194 - 
       0.57759999999999999999999999999999999999`16./eps^3 - 
       1.7528774995653435624460821445867366076`16./eps^2 - 
       2.39199517343660689512970517862576565821`16./eps}, 
     {153/200, -0.5588961522766723864082838582651067663`15.30712381235169 - 
       0.58522499999999999999999999999999999999`16./eps^3 - 
       1.76670507820689349544821057967804767646`16./eps^2 - 
       2.40750466931539940528327412166206846767`16./eps}, 
     {77/100, -0.53738673554151355707815510992451514274`15.282747431691568 - 
       0.59289999999999999999999999999999999999`16./eps^3 - 
       1.78047283929920398714506616733853129471`16./eps^2 - 
       2.42288474800707232815645706660518512275`16./eps}, 
     {31/40, -0.51477514139065865694887976173536836615`15.256688471918606 - 
       0.60062499999999999999999999999999999999`16./eps^3 - 
       1.79417980563320941715198897616286599846`16./eps^2 - 
       2.43813586951771448014955539156226924153`16./eps}, 
     {39/50, -0.4910595526865311276097487134839204734`15.228762494786494 - 
       0.60839999999999999999999999999999999999`16./eps^3 - 
       1.80782500632495486014485038665165913105`16./eps^2 - 
       2.45325850348529203091495205928166894307`16./eps}, 
     {157/200, -0.46623819174928437571217484800645564345`15.198744865562494 - 
       0.616225`16./eps^3 - 1.82140747673424163996501933303906729787`16./
        eps^2 - 2.46825312897493071885084122223489931103`16./eps}, 
     {79/100, -0.4403093198094340913454340600355302898`15.166358966868243 - 
       0.62410000000000000000000000000000000001`16./eps^3 - 
       1.83492625838483245816709819722875789555`16./eps^2 - 
       2.48312023427915227080773162249058252072`16./eps}, 
     {159/200, -0.41327123647125483579000131945773890421`15.131259696244838 - 
       0.63202500000000000000000000000000000002`16./eps^3 - 
       1.84838039888617648674772408752605856219`16./eps^2 - 
       2.49786031672291964544039212831464978299`16./eps}, 
     {4/5, -0.3851222791866551899631785565037808362`15.093009787303078 - 
       0.64000000000000000000000000000000000004`16./eps^3 - 
       1.86176895185661606440461990672821557983`16./eps^2 - 
       2.51247388247335079798858030662960922899`16./eps}, 
     {161/200, -0.35586082273925553686099001522463541935`15.051044853167427 - 
       0.64802500000000000000000000000000000005`16./eps^3 - 
       1.87509097684803783827536569817744198689`16./eps^2 - 
       2.5269614463539655361978488259883866739`16./eps}, 
     {81/100, -0.325485278738401545627702887928504887`15.00462002554784 - 
       0.65609999999999999999999999999999999996`16./eps^3 - 
       1.88834553927193235074551369450537209512`16./eps^2 - 
       2.5413235316633347121735385694212165854`16./eps}, 
     {163/200, -0.29399409512285550300164027895905680436`14.95272518326313 - 
       0.66422499999999999999999999999999999998`16./eps^3 - 
       1.90153171032682718554457949222667096051`16./eps^2 - 
       2.55556066999800548227413484074991972344`16./eps}, 
     {41/50, -0.26138575567391606237416035925944848002`14.893943591292905 - 
       0.6724`16./eps^3 - 1.91464856692705986081904234661543993206`16./
        eps^2 - 2.56967340107958067530155693449832561874`16./eps}, 
     {33/40, -0.22765877953772507081600999096593255787`14.826201540120282 - 
       0.68062500000000000000000000000000000002`16./eps^3 - 
       1.92769519163285769094604389947306749746`16./eps^2 - 
       2.58366227258583444639945729357353146207`16./eps}, 
     {83/100, -0.1928117207565279689847334376066714617`14.746289428860676 - 
       0.68890000000000000000000000000000000005`16./eps^3 - 
       1.94067067258169283520654076824940903378`16./eps^2 - 
       2.59752783998575036797205012177215347523`16./eps}, 
     {167/200, -0.156843167808662271900702285126955365`14.648846772681134 - 
       0.69722499999999999999999999999999999996`16./eps^3 - 
       1.9535741034208817116677476769905634344`16./eps^2 - 
       2.61127066637837192693697478350847925143`16./eps}, 
     {21/25, -0.11975174315705471389493601909390735067`14.523877271623103 - 
       0.7056`16./eps^3 - 1.96640458324139888025064224164159606081`16./
        eps^2 - 2.62489132233535906670586764395710810303`16./eps}, 
     {169/200, -0.08153610280601614587190616982204111696`14.349151390771794 - 
       0.71402500000000000000000000000000000003`16./eps^3 - 
       1.97916121651287639142538069770981612461`16./eps^2 - 
       2.63839038574714793907422375926585100214`16./eps}, 
     {17/20, -0.04219493586612863011919017509880742885`14.055262081952574 - 
       0.72249999999999999999999999999999999995`16./eps^3 - 
       1.99184311301976045766331415038228869872`16./eps^2 - 
       2.65176844167261442199484113969963430208`16./eps}, 
     {171/200, -0.00172696412702639409632131821755510037`12.659482100157206 - 
       0.73102499999999999999999999999999999999`16./eps^3 - 
       2.00444938779859813499149015594885746386`16./eps^2 - 
       2.66502608219214521999061847961191794828`16./eps}, 
     {43/50, 0.03986905836212184603674183384382277388`14.015030833053498 - 
       0.73960000000000000000000000000000000003`16./eps^3 - 
       2.01697916107642750299507461293750036931`16./eps^2 - 
       2.67816390626402350042085608838249224497`16./eps}, 
     {173/200, 0.08259434570461559351479576137726728138`14.323542485366612 - 
       0.74822499999999999999999999999999999996`16./eps^3 - 
       2.02943155821024560458767379823093375062`16./eps^2 - 
       2.69118251958403903635901888706844523102`16./eps}, 
     {87/100, 0.1264500805608910130407868673352889949`14.50071193413976 - 
       0.75690000000000000000000000000000000001`16./eps^3 - 
       2.04180570962752915295640056227273314562`16./eps^2 - 
       2.70408253444823573061333341298937973025`16./eps}, 
     {7/8, 0.17143741454603034460489445101376982363`14.625104425770088 - 
       0.76562500000000000000000000000000000005`16./eps^3 - 
       2.0541007507677837333725913376600278062`16./eps^2 - 
       2.71686456961871219031876068718899939472`16./eps}, 
     {22/25, 0.21755746862028209924909707691548069835`14.720786042408227 - 
       0.77439999999999999999999999999999999999`16./eps^3 - 
       2.06631582202509792307548051433526738946`16./eps^2 - 
       2.72952925019239371220742734417217158067`16./eps}, 
     {177/200, 0.26481133347275682276918628136846972386`14.798370876932808 - 
       0.78322500000000000000000000000000000004`16./eps^3 - 
       2.07845006869167942417282534695577520001`16./eps^2 - 
       2.74207720747269662955826677755628625492`16./eps}, 
     {89/100, 0.31320006989845827379117915406931912297`14.86348916502131 - 
       0.79209999999999999999999999999999999998`16./eps^3 - 
       2.09050264090235095340261445157247996637`16./eps^2 - 
       2.75450907884400846715725949290687881726`16./eps}, 
     {179/200, 0.36272470916880504252409710713574830663`14.919489822730302 - 
       0.80102500000000000000000000000000000003`16./eps^3 - 
       2.10247269357998425956424066286401699292`16./eps^2 - 
       2.76682550764890975438842556430781794441`16./eps}, 
     {9/10, 0.41338625339579312342060548927680256541`14.96852797174872 - 
       0.80999999999999999999999999999999999998`16./eps^3 - 
       2.11435938638185124531616071677286343326`16./eps^2 - 
       2.77902714306806566265367262091521423113`16./eps}, 
     {181/200, 0.4651856758899455180586201937930206501`15.012072875408611 - 
       0.81902500000000000000000000000000000004`16./eps^3 - 
       2.12616188364687175567204186975315048521`16./eps^2 - 
       2.79111464000271786533767365920374030507`16./eps}, 
     {91/100, 0.51812392151219067292999200424964272093`15.051171497173728 - 
       0.82809999999999999999999999999999999999`16./eps^3 - 
       2.13787935434373816169421900346145292303`16./eps^2 - 
       2.80308865895970916997234300613680652252`16./eps}, 
     {183/200, 0.57220190701980744441351896556351223118`15.08659646770964 - 
       0.83722500000000000000000000000000000005`16./eps^3 - 
       2.14951097201989741533283938909158424005`16./eps^2 - 
       2.81494986593897554643252618392495440643`16./eps}, 
     {23/25, 0.62742052140657035674376109305700860455`15.118934420347802 - 
       0.8464`16./eps^3 - 2.16105591475137178080932274065675465795`16./
        eps^2 - 2.82669893232344217507503133877353045777`16./eps}, 
     {37/40, 0.6837806262372250230969065457697377885`15.148641395042912 - 
       0.85562499999999999999999999999999999996`16./eps^3 - 
       2.17251336509339996008037497653332872631`16./eps^2 - 
       2.83833653477126206773627830854846266449`16./eps}, 
     {93/100, 0.7412830559764200697567162984018950264`15.176079026870626 - 
       0.86490000000000000000000000000000000003`16./eps^3 - 
       2.18388251003188082540065269913944125245`16./eps^2 - 
       2.84986335511033767531059516006013159195`16./eps}, 
     {187/200, 0.79992861831221789765492004181152034333`15.201539000674481 - 
       0.87422499999999999999999999999999999999`16./eps^3 - 
       2.19516254093560245145683798703718873716`16./eps^2 - 
       2.86128008023506769099133579081124799491`16./eps}, 
     {47/50, 0.8597180944743040083851437896561080223`15.225260061082707 - 
       0.88360000000000000000000000000000000007`16./eps^3 - 
       2.20635265350923960357494188649454610226`16./eps^2 - 
       2.87258740200526299079575398466167623786`16./eps}, 
     {189/200, 0.92065223954701027564891094137015878144`15.247440142462324 - 
       0.89302500000000000000000000000000000003`16./eps^3 - 
       2.21745204774710328768203259158124041062`16./eps^2 - 
       2.88378601714717732521888035852377037403`16./eps}, 
     {19/20, 0.9827317827772651092368661192226957888`15.268245208388198 - 
       0.9025`16./eps^3 - 2.22845992788762640258475939390289903136`16./
        eps^2 - 2.89487662715659999016605772353604521887`16./eps}, 
     {191/200, 1.04595742787758002611467740917262891324`15.28781581710215 - 
       0.91202499999999999999999999999999999997`16./eps^3 - 
       2.23937550236856995623821183333096569485`16./eps^2 - 
       2.90585993820395926398605349896681230838`16./eps}, 
     {24/25, 1.11032985332417914522425823934350118998`15.306272080955516 - 
       0.92160000000000000000000000000000000005`16./eps^3 - 
       2.25019798378293471552582800307476171043`16./eps^2 - 
       2.91673666104138690265303248543332892997`16./eps}, 
     {193/200, 1.17584971265037531764130224572328206729`15.323717469534577 - 
       0.93122500000000000000000000000000000003`16./eps^3 - 
       2.2609265888355635541391193240187704194`16./eps^2 - 
       2.92750751091169543901587576428524953543`16./eps}, 
     {97/100, 1.24251763473529373613509091682865441411`15.340241765778723 - 
       0.9409`16./eps^3 - 2.27156053830042014589963217002467030137`16./
        eps^2 - 2.93817320745922143654532370882887478794`16./eps}, 
     {39/40, 1.31033422408804113706747041714448199746`15.355923391968922 - 
       0.95062499999999999999999999999999999998`16./eps^3 - 
       2.28209905697853002175032591846585811806`16./eps^2 - 
       2.94873447464248920507384352028796226954`16./eps}, 
     {49/50, 1.37930006112741618276391742528277367988`15.370831260312713 - 
       0.96040000000000000000000000000000000007`16./eps^3 - 
       2.29254137365657036808659345464423644117`16./eps^2 - 
       2.95919204064865079746753665633117040158`16./eps}, 
     {197/200, 1.44941570245725392154599464776791683452`15.385026260257357 - 
       0.97022500000000000000000000000000000006`16./eps^3 - 
       2.30288672106609529250818340212441194731`16./eps^2 - 
       2.96954663780965937374230115763765149326`16./eps}, 
     {99/100, 1.5206816811374949252468138867907053186`15.398562464964678 - 
       0.98010000000000000000000000000000000004`16./eps^3 - 
       2.31313433584338362084532203921273115344`16./eps^2 - 
       2.97979900252013424451106580489347622927`16./eps}, 
     {199/200, 1.59309850695106718769888048202227663224`15.411488118345243 - 
       0.99002500000000000000000000000000000002`16./eps^3 - 
       2.32328345848989661682247497007010752163`16./eps^2 - 
       2.98994987515687709042675582930333313483`16./eps}, 
     {1, 1.66666666666666667136493680743520010952`15.423846448934023 - 
       1.00000000000000000000000000000000000001`16./eps^3 - 
       2.33333333333333333333333333333333333336`16./eps^2 - 
       3.00000000000000000000000000000000000004`16./eps}}

(* best guess data *)
numeric8a = InterpolatingFunction[{{0., 1.}}, {4, 7, 0, {201}, {4}, 0, 0, 
      0, 0, Automatic}, {{0., 0.005, 0.01, 0.015, 0.02, 0.025, 0.03, 0.035, 
      0.04, 0.045, 0.05, 0.055, 0.06, 0.065, 0.07, 0.075, 0.08, 0.085, 0.09, 
      0.095, 0.1, 0.105, 0.11, 0.115, 0.12, 0.125, 0.13, 0.135, 0.14, 0.145, 
      0.15, 0.155, 0.16, 0.165, 0.17, 0.175, 0.18, 0.185, 0.19, 0.195, 0.2, 
      0.205, 0.21, 0.215, 0.22, 0.225, 0.23, 0.235, 0.24, 0.245, 0.25, 0.255, 
      0.26, 0.265, 0.27, 0.275, 0.28, 0.285, 0.29, 0.295, 0.3, 0.305, 0.31, 
      0.315, 0.32, 0.325, 0.33, 0.335, 0.34, 0.345, 0.35, 0.355, 0.36, 0.365, 
      0.37, 0.375, 0.38, 0.385, 0.39, 0.395, 0.4, 0.405, 0.41, 0.415, 0.42, 
      0.425, 0.43, 0.435, 0.44, 0.445, 0.45, 0.455, 0.46, 0.465, 0.47, 0.475, 
      0.48, 0.485, 0.49, 0.495, 0.5, 0.505, 0.51, 0.515, 0.52, 0.525, 0.53, 
      0.535, 0.54, 0.545, 0.55, 0.555, 0.56, 0.565, 0.57, 0.575, 0.58, 0.585, 
      0.59, 0.595, 0.6, 0.605, 0.61, 0.615, 0.62, 0.625, 0.63, 0.635, 0.64, 
      0.645, 0.65, 0.655, 0.66, 0.665, 0.67, 0.675, 0.68, 0.685, 0.69, 0.695, 
      0.7, 0.705, 0.71, 0.715, 0.72, 0.725, 0.73, 0.735, 0.74, 0.745, 0.75, 
      0.755, 0.76, 0.765, 0.77, 0.775, 0.78, 0.785, 0.79, 0.795, 0.8, 0.805, 
      0.81, 0.815, 0.82, 0.825, 0.83, 0.835, 0.84, 0.845, 0.85, 0.855, 0.86, 
      0.865, 0.87, 0.875, 0.88, 0.885, 0.89, 0.895, 0.9, 0.905, 0.91, 0.915, 
      0.92, 0.925, 0.93, 0.935, 0.94, 0.945, 0.95, 0.955, 0.96, 0.965, 0.97, 
      0.975, 0.98, 0.985, 0.99, 0.995, 1.}}, {Developer`PackedArrayForm, {0, 
      1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
      39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
      57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
      75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
      93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 
      108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
      122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
      136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 
      150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 
      164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
      178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 
      192, 193, 194, 195, 196, 197, 198, 199, 200, 201}, {13.711291287051283, 
      13.73076157963752, 13.768920805897958, 13.818332852162877, 
      13.876035226324868, 13.940271510320258, 14.00984687261475, 
      14.083884100959308, 14.161706631601984, 14.242774227108743, 
      14.326644213427393, 14.412946523093598, 14.50136679967105, 
      14.591634498105838, 14.68351423109482, 14.77679930719696, 
      14.871306796892169, 14.966873692985159, 15.06335387314216, 
      15.16061566228156, 15.258539851491895, 15.357018069822765, 
      15.455951432615343, 15.555249409244238, 15.65482886689154, 
      15.754613256980592, 15.854531918288854, 15.95451947629405, 
      16.054515322503388, 16.154463160732337, 16.25431060979139, 
      16.354008853988287, 16.45351233439138, 16.55277847502364, 
      16.651767439138183, 16.750441911518788, 16.848766903393212, 
      16.946709577074397, 17.044239087878655, 17.141326441228948, 
      17.237944363150415, 17.334067182614998, 17.429670724402012, 
      17.524732211318707, 17.619230174774856, 17.71314437283327, 
      17.80645571496711, 17.89914619284852, 17.991198816573373, 
      18.08259755579657, 18.1733272853122, 18.26337373466532, 
      18.35272344142734, 18.441363707806964, 18.52928256030313, 
      18.616468712137213, 18.702911528228412, 18.788600992500065, 
      18.873527677325555, 18.957682714941082, 19.04105777066908, 
      19.123645017810656, 19.20543711407869, 19.28642717945475, 
      19.3666087753636, 19.44597588506833, 19.52452289519772, 
      19.60224457832489, 19.679136076523186, 19.755192885831516, 
      19.830410841566696, 19.90478610442569, 19.978315147324963, 
      20.05099474292852, 20.1228219518198, 20.193794111276212, 
      20.26390882460804, 20.333163951026524, 20.4015575960083, 
      20.46908810212599, 20.53575404031674, 20.601554201562653, 
      20.666487588958784, 20.73055341014618, 20.793751070088863, 
      20.85608016417521, 20.917540471625465, 20.978131949188228, 
      21.03785472511013, 21.09670909336366, 21.154695508119286, 
      21.211814578448784, 21.268067063247585, 21.323453866364613, 
      21.377976031928938, 21.43163473986309, 21.48443130157357, 
      21.536367155809643, 21.587443864682047, 21.637663109833664, 
      21.68702668872379, 21.735536511213027, 21.783194595934898, 
      21.83000306715707, 21.87596415156706, 21.921080175212936, 
      21.96535356055209, 22.0087868236031, 22.05138257119599, 
      22.09314349831647, 22.134072385539906, 22.174172096551107, 
      22.21344557574611, 22.251895845912383, 22.289526005984094, 
      22.326339228869173, 22.362338759345164, 22.397527912020927, 
      22.431910069361425, 22.46548867977303, 22.49826725574678, 
      22.53024937205725, 22.561438664014815, 22.591838825769077, 
      22.621453608661472, 22.65028681962507, 22.67834231962974, 
      22.705624022170877, 22.732135891800006, 22.75788194269567, 
      22.782866237273023, 22.80709288483071, 22.830566040233574, 
      22.853289902629868, 22.875268714201717, 22.896506758947563, 
      22.91700836149543, 22.936777885945894, 22.955819734743702, 
      22.97413834757695, 22.991738200302915, 23.00862380389954, 
      23.024799703441673, 23.040270477101238, 23.055040735170454, 
      23.069115119107327, 23.082498300602673, 23.095194980667895, 
      23.107209888742837, 23.11854778182306, 23.12921344360584, 
      23.1392116836543, 23.14854733657909, 23.157225261236995, 
      23.16525033994596, 23.172627477715988, 23.17936160149538, 
      23.18545765943187, 23.190920620148123, 23.195755472031212, 
      23.19996722253556, 23.203560897498978, 23.2065415404714, 
      23.208914212055856, 23.210683989261398, 23.211855964867542, 
      23.21243524679991, 23.21242695751673, 23.21183623340589, 
      23.210668224192162, 23.20892809235439, 23.20662101255228, 
      23.20375217106253, 23.20032676522404, 23.196350002891933, 
      23.191827101900106, 23.186763289532145, 23.18116380200024, 
      23.175033883932016, 23.168378787864956, 23.16120377374823, 
      23.15351410845175, 23.145315065282215, 23.136611923506006, 
      23.12740996787864, 23.11771448818076, 23.10753077876032, 
      23.09686413808094, 23.08571986827615, 23.074103274709472, 
      23.062019665540067, 23.04947435129394, 23.036472644440437, 
      23.02301985897395, 23.009121310000697, 22.994782313330454, 
      22.980008185073068, 22.964804241239666, 22.949175797348463, 
      22.933128168034987, 22.916666666666668}}, {Automatic}]
 
numeric9a = InterpolatingFunction[{{0., 1.}}, {4, 7, 0, {201}, {4}, 0, 0, 
      0, 0, Automatic}, {{0., 0.005, 0.01, 0.015, 0.02, 0.025, 0.03, 0.035, 
      0.04, 0.045, 0.05, 0.055, 0.06, 0.065, 0.07, 0.075, 0.08, 0.085, 0.09, 
      0.095, 0.1, 0.105, 0.11, 0.115, 0.12, 0.125, 0.13, 0.135, 0.14, 0.145, 
      0.15, 0.155, 0.16, 0.165, 0.17, 0.175, 0.18, 0.185, 0.19, 0.195, 0.2, 
      0.205, 0.21, 0.215, 0.22, 0.225, 0.23, 0.235, 0.24, 0.245, 0.25, 0.255, 
      0.26, 0.265, 0.27, 0.275, 0.28, 0.285, 0.29, 0.295, 0.3, 0.305, 0.31, 
      0.315, 0.32, 0.325, 0.33, 0.335, 0.34, 0.345, 0.35, 0.355, 0.36, 0.365, 
      0.37, 0.375, 0.38, 0.385, 0.39, 0.395, 0.4, 0.405, 0.41, 0.415, 0.42, 
      0.425, 0.43, 0.435, 0.44, 0.445, 0.45, 0.455, 0.46, 0.465, 0.47, 0.475, 
      0.48, 0.485, 0.49, 0.495, 0.5, 0.505, 0.51, 0.515, 0.52, 0.525, 0.53, 
      0.535, 0.54, 0.545, 0.55, 0.555, 0.56, 0.565, 0.57, 0.575, 0.58, 0.585, 
      0.59, 0.595, 0.6, 0.605, 0.61, 0.615, 0.62, 0.625, 0.63, 0.635, 0.64, 
      0.645, 0.65, 0.655, 0.66, 0.665, 0.67, 0.675, 0.68, 0.685, 0.69, 0.695, 
      0.7, 0.705, 0.71, 0.715, 0.72, 0.725, 0.73, 0.735, 0.74, 0.745, 0.75, 
      0.755, 0.76, 0.765, 0.77, 0.775, 0.78, 0.785, 0.79, 0.795, 0.8, 0.805, 
      0.81, 0.815, 0.82, 0.825, 0.83, 0.835, 0.84, 0.845, 0.85, 0.855, 0.86, 
      0.865, 0.87, 0.875, 0.88, 0.885, 0.89, 0.895, 0.9, 0.905, 0.91, 0.915, 
      0.92, 0.925, 0.93, 0.935, 0.94, 0.945, 0.95, 0.955, 0.96, 0.965, 0.97, 
      0.975, 0.98, 0.985, 0.99, 0.995, 1.}}, {Developer`PackedArrayForm, {0, 
      1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
      39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
      57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
      75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
      93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 
      108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
      122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
      136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 
      150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 
      164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
      178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 
      192, 193, 194, 195, 196, 197, 198, 199, 200, 201}, 
      {-1.0158608580341884, -1.0197458885132187, -1.0265778923801328, 
      -1.0347690274180017, -1.043745643032133, -1.0531896117869624, 
      -1.0628969207059078, -1.0727258634451142, -1.0825728629781406, 
      -1.092359491866746, -1.102024821000431, -1.1115205945178241, 
      -1.1208080270561656, -1.1298555903832876, -1.1386374330622424, 
      -1.1471322212728285, -1.1553222690657199, -1.1631928730486516, 
      -1.1707317948949774, -1.1779288529358558, -1.1847755956939643, 
      -1.191265037944033, -1.1973914451561856, -1.2031501558482585, 
      -1.2085374339766624, -1.2135503453729413, -1.218186653607837, 
      -1.2224447316849174, -1.2263234867325248, -1.22982229544559, 
      -1.2329409484765073, -1.2356796023214698, -1.2380387375203852, 
      -1.2400191222029155, -1.2416217801837133, -1.2428479629465297, 
      -1.2436991249670337, -1.2441769019136044, -1.2442830913383587, 
      -1.244019635530622, -1.2433886062545323, -1.2423921911335076, 
      -1.2410326814785182, -1.2393124613857562, -1.2372339979533646, 
      -1.2347998324872245, -1.2320125725830304, -1.2288748849865267, 
      -1.2253894891462933, -1.221559151384172, -1.2173866796176316, 
      -1.2128749185762862, -1.2080267454616438, -1.2028450660050891, 
      -1.1973328108842678, -1.1914929324625305, -1.1853284018200185, 
      -1.178842206048409, -1.172037345784348, -1.1649168329592525, 
      -1.1574836887454927, -1.1497409416810276, -1.1416916259563945, 
      -1.1333387798495587, -1.1246854442955752, -1.115734661579279, 
      -1.1064894741403681, -1.0969529234812487, -1.087128049168921, 
      -1.0770178879230001, -1.0666254727826887, -1.0559538323461712, 
      -1.045005990076492, -1.0337849636685035, -1.0222937644719454, 
      -1.0105353969661557, -0.9985128582822899, -0.986229137769287, 
      -0.9736872166001345, -0.960890067415273, -0.9478406540002469, 
      -0.9345419309949418, -0.92099684363197, -0.9072083275019588, 
      -0.8931793083436795, -0.8789127018571186, -0.8644114135377402, 
      -0.8496783385303304, -0.8347163615009331, -0.8195283565255098, 
      -0.8041171869940524, -0.7884857055289818, -0.7726367539167486, 
      -0.7565731630516369, -0.7402977528908447, -0.7238133324199828, 
      -0.7071226996282022, -0.6902286414922089, -0.6731339339684902, 
      -0.6558413419931167, -0.6383536194836246, -0.6206735093731647, 
      -0.6028037435960837, -0.5847470431367553, -0.566506118052663, 
      -0.5480836675087215, -0.5294823798158511, -0.5107049324734565, 
      -0.4917539922154834, -0.4726322150597515, -0.45334224636028225, 
      -0.4338867208623588, -0.4142682627600762, -0.39448948575615356, 
      -0.37455299312379764, -0.35446137777042214, -0.3342172223030391, 
      -0.3138230990951522, -0.2932815703549946, -0.27259518819496215, 
      -0.2517664947021067, -0.2307980220095602, -0.2096922923687716, 
      -0.18845181822244564, -0.16707910227808098, -0.14557663758201142, 
      -0.12394690759386182, -0.10219238626133573, -0.0803155380952579, 
      -0.058318818244800286, -0.036204672572825294, -0.013975537731284677, 
      0.008366158763382947, 0.030817998454908933, 0.053377571871954785, 
      0.07604247845302108, 0.09881032647154714, 0.12167873296124038, 
      0.1446453236416709, 0.16770773284416482, 0.1908636034380263, 
      0.21411058675711703, 0.23744634252681793, 0.26086853879139793, 
      0.28437485184181044, 0.30796296614393764, 0.3316305742673013, 
      0.3553753768142554, 0.3791950823496762, 0.40308740733116327, 
      0.42705007603976325, 0.4510808205112276, 0.47517738046781377, 
      0.4993375032506385, 0.5235589437525916, 0.5478394643518153, 
      0.5721768348457569, 0.5965688323857978, 0.6210132414124653, 
      0.645507853591228, 0.6700504677488799, 0.694638889810514, 
      0.7192709327370884, 0.743944416463583, 0.7686571678377517, 
      0.7934070205594661, 0.8181918151206524, 0.8430093987458211, 
      0.8678576253331866, 0.8927343553963757, 0.917637456006726, 
      0.9425648007361663, 0.9675142696006828, 0.9924837490043631, 
      1.01747113168402, 1.0424743166543866, 1.0674912091538857, 
      1.0925197205909623, 1.1175577684909832, 1.1426032764436946, 
      1.1676541740512358, 1.1927083968767038, 1.217763886393267, 
      1.2428185899338193, 1.2678704606411753, 1.292917457418797, 
      1.3179575448820524, 1.342988693309997, 1.3680088785976752, 
      1.3930160822089384, 1.4180082911297718, 1.4429834978221274, 
      1.4679397001782577, 1.4928749014755445, 1.5177871103318188, 
      1.5426743406611665, 1.5675346116302138, 1.5923659476148901, 
      1.6171663781576597, 1.6419339379252214, 1.6666666666666667}}, 
     {Automatic}]
 
numeric10a = InterpolatingFunction[{{0., 1.}}, {4, 7, 0, {201}, {4}, 0, 0, 
      0, 0, Automatic}, {{0., 0.005, 0.01, 0.015, 0.02, 0.025, 0.03, 0.035, 
      0.04, 0.045, 0.05, 0.055, 0.06, 0.065, 0.07, 0.075, 0.08, 0.085, 0.09, 
      0.095, 0.1, 0.105, 0.11, 0.115, 0.12, 0.125, 0.13, 0.135, 0.14, 0.145, 
      0.15, 0.155, 0.16, 0.165, 0.17, 0.175, 0.18, 0.185, 0.19, 0.195, 0.2, 
      0.205, 0.21, 0.215, 0.22, 0.225, 0.23, 0.235, 0.24, 0.245, 0.25, 0.255, 
      0.26, 0.265, 0.27, 0.275, 0.28, 0.285, 0.29, 0.295, 0.3, 0.305, 0.31, 
      0.315, 0.32, 0.325, 0.33, 0.335, 0.34, 0.345, 0.35, 0.355, 0.36, 0.365, 
      0.37, 0.375, 0.38, 0.385, 0.39, 0.395, 0.4, 0.405, 0.41, 0.415, 0.42, 
      0.425, 0.43, 0.435, 0.44, 0.445, 0.45, 0.455, 0.46, 0.465, 0.47, 0.475, 
      0.48, 0.485, 0.49, 0.495, 0.5, 0.505, 0.51, 0.515, 0.52, 0.525, 0.53, 
      0.535, 0.54, 0.545, 0.55, 0.555, 0.56, 0.565, 0.57, 0.575, 0.58, 0.585, 
      0.59, 0.595, 0.6, 0.605, 0.61, 0.615, 0.62, 0.625, 0.63, 0.635, 0.64, 
      0.645, 0.65, 0.655, 0.66, 0.665, 0.67, 0.675, 0.68, 0.685, 0.69, 0.695, 
      0.7, 0.705, 0.71, 0.715, 0.72, 0.725, 0.73, 0.735, 0.74, 0.745, 0.75, 
      0.755, 0.76, 0.765, 0.77, 0.775, 0.78, 0.785, 0.79, 0.795, 0.8, 0.805, 
      0.81, 0.815, 0.82, 0.825, 0.83, 0.835, 0.84, 0.845, 0.85, 0.855, 0.86, 
      0.865, 0.87, 0.875, 0.88, 0.885, 0.89, 0.895, 0.9, 0.905, 0.91, 0.915, 
      0.92, 0.925, 0.93, 0.935, 0.94, 0.945, 0.95, 0.955, 0.96, 0.965, 0.97, 
      0.975, 0.98, 0.985, 0.99, 0.995, 1.}}, {Developer`PackedArrayForm, {0, 
      1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
      39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
      57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
      75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
      93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 
      108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
      122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
      136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 
      150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 
      164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
      178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 
      192, 193, 194, 195, 196, 197, 198, 199, 200, 201}, {-3.027009493987652, 
      -3.027552105578106, -3.028920633185236, -3.0309683848920566, 
      -3.0336173851971164, -3.0368133107716724, -3.04051439448928, 
      -3.044686720391392, -3.0493017644814375, -3.054334941916141, 
      -3.059764675321735, -3.0655717607767645, -3.071738916456828, 
      -3.0782504496988654, -3.0850920042557464, -3.0922503638141485, 
      -3.099713296168809, -3.1074694275161994, -3.1155081395425746, 
      -3.1238194840846263, -3.13239411155811, -3.1412232103287354, 
      -3.150298454890717, -3.159611961215922, -3.1691562480009554, 
      -3.1789242028106157, -3.188909052320726, -3.1991043360196416, 
      -3.2095038828486167, -3.2201017903556743, -3.230892406012162, 
      -3.241870310400568, -3.253030302029861, -3.2643673835732128, 
      -3.2758767493544516, -3.2875537739354375, -3.2993940016778884, 
      -3.311393137170952, -3.3235470364306257, -3.3358516987896127, 
      -3.348303259406707, -3.360897982333732, -3.3736322540856767, 
      -3.386502577666155, -3.399505567005951, -3.4126379417771857, 
      -3.4258965225498637, -3.43927822626115, -3.452780061970913, 
      -3.466399126879812, -3.480132602588647, -3.4939777515798123, 
      -3.5079319139035636, -3.5219925040534954, -3.5361570080170632, 
      -3.550422980488325, -3.5647880422312115, -3.579249877582707, 
      -3.5938062320862145, -3.608454910246249, -3.623193754260135, 
      -3.6380207224315533, -3.6529337599644864, -3.6679308870618126, 
      -3.683010173189819, -3.6981697354169683, -3.713407736828235, 
      -3.7287223850105864, -3.744111930605483, -3.7595746659246574, 
      -3.775108923625597, -3.7907130754434206, -3.8063855309760837, 
      -3.8221247365200406, -3.8379291739536248, -3.85379735966573, 
      -3.869727843527328, -3.8857192079037204, -3.901770066705359, 
      -3.917879064475405, -3.934044875512109, -3.9502662030243965, 
      -3.9665417783189625, -3.9828703600174378, -3.999250733302183, 
      -4.015681709189344, -4.032162123827949, -4.048690837823846, 
      -4.065266735587333, -4.081888724703456, -4.098555735323936, 
      -4.11526671957983, -4.132020651013945, -4.148816524032276, 
      -4.165653353373535, -4.182530173596095, -4.19944603858161, 
      -4.216400021054592, -4.2333912121173585, -4.250418720799621, 
      -4.267481673622283, -4.284579214174737, -4.301710502705226, 
      -4.318874715723721, -4.336071045616833, -4.353298700274354, 
      -4.370556902726866, -4.3878448907941605, -4.40516191674395, 
      -4.422507246960517, -4.439880161622984, -4.4572799543927895, 
      -4.474705932110115, -4.492157414498858, -4.509633733879912, 
      -4.527134234892464, -4.544658274222987, -4.562205220341682, 
      -4.579774453246147, -4.597365364211975, -4.614977355550089, 
      -4.632609840370572, -4.65026224235276, -4.667933995521419, 
      -4.6856245440288244, -4.7033333419424785, -4.721059853038363, 
      -4.738803550599496, -4.756563917219684, -4.774340444612205, 
      -4.792132633423379, -4.809939993050835, -4.827762041466254, 
      -4.845598305042598, -4.863448318385545, -4.881311624169094, 
      -4.899187772975185, -4.9170763231371835, -4.934976840587201, 
      -4.952888898707031, -4.970812078182656, -4.988745966862249, 
      -5.006690159617463, -5.0246442582080535, -5.04260787114962, 
      -5.060580613584427, -5.078562107155232, -5.096551979882015, 
      -5.1145498660415285, -5.13255540604958, -5.150568246346004, 
      -5.1685880392822305, -5.186614443011352, -5.204647121380691, 
      -5.222685743826712, -5.240729985272285, -5.258779526026227, 
      -5.276834051685003, -5.294893253036623, -5.312956825966576, 
      -5.3310244713658514, -5.349095895040911, -5.367170807625587, 
      -5.3852489244948725, -5.403329965680554, -5.421413655788597, 
      -5.439499723918309, -5.457587903583175, -5.475677932633347, 
      -5.4937695531797655, -5.511862511519817, -5.529956558064578, 
      -5.548051447267496, -5.566146937554561, -5.584242791255902, 
      -5.602338774538774, -5.620434657341864, -5.638530213310967, 
      -5.656625219735932, -5.674719457488857, -5.692812710963525, 
      -5.710904768016042, -5.728995419906658, -5.7470844612426975, 
      -5.765171689922642, -5.78325690708129, -5.801339917035992, 
      -5.819420527233923, -5.837498548200366, -5.855573793488004, 
      -5.873646079627171, -5.891715226077066, -5.909781055177899, 
      -5.927843392103918, -5.945902064817359, -5.963956904023232, 
      -5.982007743124979, -6.000054418180965, -6.018096767861743, 
      -6.036134633408163, -6.054167858590219}}, {Automatic}]
 

numeric8b = InterpolatingFunction[{{0., 1.}}, {4, 7, 0, {201}, {4}, 0, 0, 
      0, 0, Automatic}, {{0., 0.005, 0.01, 0.015, 0.02, 0.025, 0.03, 0.035, 
      0.04, 0.045, 0.05, 0.055, 0.06, 0.065, 0.07, 0.075, 0.08, 0.085, 0.09, 
      0.095, 0.1, 0.105, 0.11, 0.115, 0.12, 0.125, 0.13, 0.135, 0.14, 0.145, 
      0.15, 0.155, 0.16, 0.165, 0.17, 0.175, 0.18, 0.185, 0.19, 0.195, 0.2, 
      0.205, 0.21, 0.215, 0.22, 0.225, 0.23, 0.235, 0.24, 0.245, 0.25, 0.255, 
      0.26, 0.265, 0.27, 0.275, 0.28, 0.285, 0.29, 0.295, 0.3, 0.305, 0.31, 
      0.315, 0.32, 0.325, 0.33, 0.335, 0.34, 0.345, 0.35, 0.355, 0.36, 0.365, 
      0.37, 0.375, 0.38, 0.385, 0.39, 0.395, 0.4, 0.405, 0.41, 0.415, 0.42, 
      0.425, 0.43, 0.435, 0.44, 0.445, 0.45, 0.455, 0.46, 0.465, 0.47, 0.475, 
      0.48, 0.485, 0.49, 0.495, 0.5, 0.505, 0.51, 0.515, 0.52, 0.525, 0.53, 
      0.535, 0.54, 0.545, 0.55, 0.555, 0.56, 0.565, 0.57, 0.575, 0.58, 0.585, 
      0.59, 0.595, 0.6, 0.605, 0.61, 0.615, 0.62, 0.625, 0.63, 0.635, 0.64, 
      0.645, 0.65, 0.655, 0.66, 0.665, 0.67, 0.675, 0.68, 0.685, 0.69, 0.695, 
      0.7, 0.705, 0.71, 0.715, 0.72, 0.725, 0.73, 0.735, 0.74, 0.745, 0.75, 
      0.755, 0.76, 0.765, 0.77, 0.775, 0.78, 0.785, 0.79, 0.795, 0.8, 0.805, 
      0.81, 0.815, 0.82, 0.825, 0.83, 0.835, 0.84, 0.845, 0.85, 0.855, 0.86, 
      0.865, 0.87, 0.875, 0.88, 0.885, 0.89, 0.895, 0.9, 0.905, 0.91, 0.915, 
      0.92, 0.925, 0.93, 0.935, 0.94, 0.945, 0.95, 0.955, 0.96, 0.965, 0.97, 
      0.975, 0.98, 0.985, 0.99, 0.995, 1.}}, {Developer`PackedArrayForm, {0, 
      1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
      39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
      57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
      75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
      93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 
      108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
      122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
      136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 
      150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 
      164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
      178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 
      192, 193, 194, 195, 196, 197, 198, 199, 200, 201}, 
      {-3.8433003667574464, -3.8212246992848833, -3.7763945494844178, 
      -3.7168576988318143, -3.645870499453331, -3.565373491168459, 
      -3.476688177309112, -3.3807834930734795, -3.2784046661516455, 
      -3.170144613144285, -3.0564872539427634, -2.937835563631876, 
      -2.8145306610419505, -2.6868653117571144, -2.5550937830891063, 
      -2.4194392236949214, -2.2800993094741253, -2.1372506422844517, 
      -1.9910522307333385, -1.8416482818923559, -1.68917046672303, 
      -1.5337397773912629, -1.3754680638184766, -1.2144593150734093, 
      -1.050810735589786, -0.8846136547909571, -0.7159543002515523, 
      -0.544914458178774, -0.3715720401696806, -0.1960015714896752, 
      -0.018274613234162105, 0.16153987152620614, 0.34337519930581667, 
      0.5271666885867748, 0.7128514172885643, 0.9003680105185299, 
      1.0896564545543652, 1.2806579336308779, 1.4733146866156446, 
      1.6675698810830963, 1.8633675026508683, 2.060652257739041, 
      2.2593694881627386, 2.459465096179656, 2.6608854787934404, 
      2.8635774702664585, 3.067488291926228, 3.272565508461867, 
      3.4787569900034976, 3.686010879360979, 3.894275563870649, 
      4.1034996513615765, 4.313631949807632, 4.524621450279513, 
      4.736417312852818, 4.948968855165054, 5.162225543346936, 
      5.376136985081861, 5.590652924572786, 5.805723239218109, 
      6.02129793781803, 6.2373271601505715, 6.453761177772184, 
      6.670550395911908, 6.887645356340666, 7.104996741108474, 
      7.322555377052498, 7.540272240987911, 7.758098465501676, 
      7.9759853452767295, 8.19388434388065, 8.411747100958893, 
      8.629525439778037, 8.84717137506947, 9.064637121128259, 
      9.281875100126069, 9.498837950600603, 9.715478536087362, 
      9.931749953862548, 10.147605543768664, 10.362998897096945, 
      10.577883865502905, 10.792214569933536, 11.005945409546479, 
      11.219031070603268, 11.431426535320382, 11.643087090663256, 
      11.853968337069746, 12.064026197090795, 12.27321692393715, 
      12.481497109922023, 12.688823694790525, 12.89515397392762, 
      13.10044560643705, 13.304656623084535, 13.507745434099137, 
      13.709670836827362, 13.910392023235085, 14.109868587252983, 
      14.308060531961589, 14.504928276530494, 14.700432663421674, 
      14.894534964515177, 15.08719688802395, 15.278380584724234, 
      15.468048654119958, 15.656164150430417, 15.84269058840008, 
      16.027591948929654, 16.21083268452769, 16.392377724582275, 
      16.57219248045243, 16.750242850379166, 16.92649522421613, 
      17.100916487979976, 17.273474028220846, 17.44413573621321, 
      17.612870011967672, 17.779645768064317, 17.944432433308258, 
      18.107199956208202, 18.26791880827889, 18.426559987168275, 
      18.58309501961049, 18.737495964205607, 18.889735414027303, 
      19.039786499059545, 19.187622888463512, 19.333218792675943, 
      19.476548965340196, 19.61758870507127, 19.756313857056142, 
      19.89270081449071, 20.02672651985474, 20.15836846602617, 
      20.287604697236187, 20.414413809866428, 20.53877495308978, 
      20.660667829356214, 20.78007269472497, 20.896970359044715, 
      21.011342185982947, 21.123170092906197, 21.232436550612423, 
      21.33912458291708, 21.44321776609429, 21.544700228174523, 
      21.643556648100336, 21.73977225474147, 21.83333282577084, 
      21.92422468640279, 22.01243470799508, 22.09795030651594, 
      22.18075944087769, 22.260850611138252, 22.33821285657198, 
      22.412835753611176, 22.484709413659637, 22.553824480779664, 
      22.620172129253795, 22.68374406102267, 22.744532503000297, 
      22.80253020426813, 22.857730433149136, 22.910126974163262, 
      22.959714124865513, 23.006486692567982, 23.050439990946984, 
      23.091569836536664, 23.12987254511024, 23.165344927950116, 
      23.197984288008108, 23.227788415956926, 23.254755586134188, 
      23.27888455238002, 23.30017454376955, 23.3186252602413, 
      23.334236868122744, 23.347009995554053, 23.356945727811237, 
      23.3640456025297, 23.368311604829362, 23.369746162342402, 
      23.368352140144665, 23.364132835591864, 23.35709197306151, 
      23.347233698601705, 23.334562574487755, 23.319083573687635, 
      23.30080207423729, 23.27972385352678, 23.25585508249822, 
      23.229202319756478, 23.199772505593625, 23.167572955927987, 
      23.132611356158847, 23.094895754937628, 23.054434557856478, 
      23.011236521055213, 22.96531074474742, 22.916666666666668}}, 
     {Automatic}]
 
numeric9b = InterpolatingFunction[{{0., 1.}}, {4, 7, 0, {201}, {4}, 0, 0, 
      0, 0, Automatic}, {{0., 0.005, 0.01, 0.015, 0.02, 0.025, 0.03, 0.035, 
      0.04, 0.045, 0.05, 0.055, 0.06, 0.065, 0.07, 0.075, 0.08, 0.085, 0.09, 
      0.095, 0.1, 0.105, 0.11, 0.115, 0.12, 0.125, 0.13, 0.135, 0.14, 0.145, 
      0.15, 0.155, 0.16, 0.165, 0.17, 0.175, 0.18, 0.185, 0.19, 0.195, 0.2, 
      0.205, 0.21, 0.215, 0.22, 0.225, 0.23, 0.235, 0.24, 0.245, 0.25, 0.255, 
      0.26, 0.265, 0.27, 0.275, 0.28, 0.285, 0.29, 0.295, 0.3, 0.305, 0.31, 
      0.315, 0.32, 0.325, 0.33, 0.335, 0.34, 0.345, 0.35, 0.355, 0.36, 0.365, 
      0.37, 0.375, 0.38, 0.385, 0.39, 0.395, 0.4, 0.405, 0.41, 0.415, 0.42, 
      0.425, 0.43, 0.435, 0.44, 0.445, 0.45, 0.455, 0.46, 0.465, 0.47, 0.475, 
      0.48, 0.485, 0.49, 0.495, 0.5, 0.505, 0.51, 0.515, 0.52, 0.525, 0.53, 
      0.535, 0.54, 0.545, 0.55, 0.555, 0.56, 0.565, 0.57, 0.575, 0.58, 0.585, 
      0.59, 0.595, 0.6, 0.605, 0.61, 0.615, 0.62, 0.625, 0.63, 0.635, 0.64, 
      0.645, 0.65, 0.655, 0.66, 0.665, 0.67, 0.675, 0.68, 0.685, 0.69, 0.695, 
      0.7, 0.705, 0.71, 0.715, 0.72, 0.725, 0.73, 0.735, 0.74, 0.745, 0.75, 
      0.755, 0.76, 0.765, 0.77, 0.775, 0.78, 0.785, 0.79, 0.795, 0.8, 0.805, 
      0.81, 0.815, 0.82, 0.825, 0.83, 0.835, 0.84, 0.845, 0.85, 0.855, 0.86, 
      0.865, 0.87, 0.875, 0.88, 0.885, 0.89, 0.895, 0.9, 0.905, 0.91, 0.915, 
      0.92, 0.925, 0.93, 0.935, 0.94, 0.945, 0.95, 0.955, 0.96, 0.965, 0.97, 
      0.975, 0.98, 0.985, 0.99, 0.995, 1.}}, {Developer`PackedArrayForm, {0, 
      1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
      39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
      57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
      75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
      93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 
      108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
      122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
      136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 
      150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 
      164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
      178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 
      192, 193, 194, 195, 196, 197, 198, 199, 200, 201}, {5.811600733514893, 
      5.797132990319849, 5.769372648228694, 5.73375130775308, 
      5.692349441600357, 5.646375454556799, 5.59663973561932, 
      5.54373113242597, 5.488100442583437, 5.430105800151409, 
      5.370039746080026, 5.30814649240784, 5.244633507077931, 
      5.179679605527471, 5.113440788740225, 5.0460545699659445, 
      4.977643254642564, 4.90831647524425, 4.838173183285181, 
      4.767303237734478, 4.695788688011354, 4.623704822206162, 
      4.551121032301913, 4.478101534962541, 4.404705977037671, 
      4.330989948108391, 4.257005417376726, 4.182801108456293, 
      4.108422822793344, 4.033913720287405, 3.9593145640135163, 
      3.8846639346488647, 3.8099984191853156, 3.7353527776989677, 
      3.6607600913012943, 3.586251893875296, 3.5118582897781887, 
      3.4376080593482015, 3.363528753770711, 3.289646780626241, 
      3.215987481249723, 3.1425752008696106, 3.069433352360684, 
      2.9965844743310432, 2.9240502841681404, 2.851851726587472, 
      2.7800090181583372, 2.7085416882224798, 2.6374686165698007, 
      2.566808068192987, 2.4965777254042836, 2.4267947175655915, 
      2.357475648654609, 2.2886366228651807, 2.22029326841843, 
      2.1524607597425374, 2.085153838162388, 2.018386831225865, 
      1.9521736707806965, 1.8865279099044605, 1.8214627387803044, 
      1.756990999602054, 1.6931252005844297, 1.6298775291470822, 
      1.5672598643348126, 1.505283788530743, 1.443960598514139, 
      1.383301315910062, 1.323316697073958, 1.2640172424506204, 
      1.2054132054436602, 1.1475146008286323, 1.0903312127402618, 
      1.0338726022617795, 0.9781481146421218, 0.9231668861648056, 
      0.8689378506903651, 0.8154697458926441, 0.7627711192076729, 
      0.7108503335124876, 0.6597155725499716, 0.6093748461146417, 
      0.5598359950132343, 0.5111066958129721, 0.46319446538949766, 
      0.4161066652856263, 0.3698505058913326, 0.3244330504546653, 
      0.2798612189326566, 0.2361417916906921, 0.1932814130582626, 
      0.15128659474850856, 0.11016371914850302, 0.06991904248678117, 
      0.030558697884225036, -0.007911301705963663, -0.04548506066381479, 
      -0.08215679796860059, -0.11792084456053978, -0.15277164079370859, 
      -0.18670373393329814, -0.2197117759597632, -0.25179052098031496, 
      -0.28293482321535235, -0.31313963479182555, -0.3424000036625747, 
      -0.3707110715918315, -0.3980680722040493, -0.4244663290933802, 
      -0.4499012539912564, -0.47436834498966646, -0.49786318481784214, 
      -0.5203814391701868, -0.5419188550833868, -0.5624712593607503, 
      -0.5820345570419154, -0.6006047299161592, -0.6181778350776279, 
      -0.6347500035208867, -0.6503174387752669, -0.6648764155765567, 
      -0.678423278574655, -0.6909544410758647, -0.7024663838185715, 
      -0.7129556537811037, -0.7224188630206269, -0.7308526875419779, 
      -0.7382538661953922, -0.7446191996021215, -0.7499455491069863, 
      -0.7542298357569458, -0.7574690393048106, -0.7596601972372554, 
      -0.7608004038263319, -0.7608868092037058, -0.7599166184568857, 
      -0.757887090746729, -0.75479553844555, -0.7506393262951754, 
      -0.7454158705843223, -0.7391226383446973, -0.7317571465652374, 
      -0.723316961423941, -0.7137996975367524, -0.7032030172229878, 
      -0.6915246297868092, -0.6787622908142714, -0.6649138014854853, 
      -0.6499770079014561, -0.633949800425174, -0.6168301130365479, 
      -0.5986159227007899, -0.5793052487498693, -0.5588961522766723, 
      -0.5373867355415135, -0.5147751413906586, -0.4910595526865311, 
      -0.4662381917492844, -0.4403093198094341, -0.41327123647125485, 
      -0.3851222791866552, -0.3558608227392555, -0.32548527873840155, 
      -0.2939940951228555, -0.2613857556739161, -0.22765877953772506, 
      -0.19281172075652797, -0.15684316780866228, -0.11975174315705471, 
      -0.08153610280601614, -0.04219493586612863, -0.0017269641270263934, 
      0.039869058362121845, 0.08259434570461559, 0.12645008056089102, 
      0.17143741454603034, 0.2175574686202821, 0.2648113334727568, 
      0.3132000698984583, 0.36272470916880506, 0.4133862533957931, 
      0.4651856758899455, 0.5181239215121907, 0.5722019070198074, 
      0.6274205214065703, 0.683780626237225, 0.7412830559764201, 
      0.7999286183122178, 0.859718094474304, 0.9206522395470103, 
      0.9827317827772651, 1.04595742787758, 1.1103298533241792, 
      1.1758497126503753, 1.2425176347352938, 1.3103342240880411, 
      1.3793000611274162, 1.4494157024572538, 1.520681681137495, 
      1.5930985069510673, 1.6666666666666667}}, {Automatic}]
 
numeric10b = InterpolatingFunction[{{0., 1.}}, {4, 7, 0, {201}, {4}, 0, 0, 
      0, 0, Automatic}, {{0., 0.005, 0.01, 0.015, 0.02, 0.025, 0.03, 0.035, 
      0.04, 0.045, 0.05, 0.055, 0.06, 0.065, 0.07, 0.075, 0.08, 0.085, 0.09, 
      0.095, 0.1, 0.105, 0.11, 0.115, 0.12, 0.125, 0.13, 0.135, 0.14, 0.145, 
      0.15, 0.155, 0.16, 0.165, 0.17, 0.175, 0.18, 0.185, 0.19, 0.195, 0.2, 
      0.205, 0.21, 0.215, 0.22, 0.225, 0.23, 0.235, 0.24, 0.245, 0.25, 0.255, 
      0.26, 0.265, 0.27, 0.275, 0.28, 0.285, 0.29, 0.295, 0.3, 0.305, 0.31, 
      0.315, 0.32, 0.325, 0.33, 0.335, 0.34, 0.345, 0.35, 0.355, 0.36, 0.365, 
      0.37, 0.375, 0.38, 0.385, 0.39, 0.395, 0.4, 0.405, 0.41, 0.415, 0.42, 
      0.425, 0.43, 0.435, 0.44, 0.445, 0.45, 0.455, 0.46, 0.465, 0.47, 0.475, 
      0.48, 0.485, 0.49, 0.495, 0.5, 0.505, 0.51, 0.515, 0.52, 0.525, 0.53, 
      0.535, 0.54, 0.545, 0.55, 0.555, 0.56, 0.565, 0.57, 0.575, 0.58, 0.585, 
      0.59, 0.595, 0.6, 0.605, 0.61, 0.615, 0.62, 0.625, 0.63, 0.635, 0.64, 
      0.645, 0.65, 0.655, 0.66, 0.665, 0.67, 0.675, 0.68, 0.685, 0.69, 0.695, 
      0.7, 0.705, 0.71, 0.715, 0.72, 0.725, 0.73, 0.735, 0.74, 0.745, 0.75, 
      0.755, 0.76, 0.765, 0.77, 0.775, 0.78, 0.785, 0.79, 0.795, 0.8, 0.805, 
      0.81, 0.815, 0.82, 0.825, 0.83, 0.835, 0.84, 0.845, 0.85, 0.855, 0.86, 
      0.865, 0.87, 0.875, 0.88, 0.885, 0.89, 0.895, 0.9, 0.905, 0.91, 0.915, 
      0.92, 0.925, 0.93, 0.935, 0.94, 0.945, 0.95, 0.955, 0.96, 0.965, 0.97, 
      0.975, 0.98, 0.985, 0.99, 0.995, 1.}}, {Developer`PackedArrayForm, {0, 
      1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
      39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
      57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
      75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
      93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 
      108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 
      122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
      136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 
      150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 
      164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
      178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 
      192, 193, 194, 195, 196, 197, 198, 199, 200, 201}, {10.45931112009098, 
      10.4274979248373, 10.369270221173727, 10.296945109252162, 
      10.215020062592854, 10.126014696040691, 10.031562069267807, 
      9.932809453786474, 9.830605809292857, 9.725602673946476, 
      9.618313779540726, 9.509152735462928, 9.398458100570487, 
      9.286510749537811, 9.173546300020996, 9.059764247814527, 
      8.945334835553929, 8.830404317718724, 8.715099063976274, 
      8.599528803807207, 8.483789224979201, 8.367964078140993, 
      8.252126898631683, 8.13634242789165, 8.020667796472083, 
      7.905153515916709, 7.789844315996486, 7.674779855757794, 
      7.559995330810151, 7.445521994686976, 7.331387608580961, 
      7.217616831012945, 7.104231556844199, 6.991251213344211, 
      6.878693019674254, 6.766572215062873, 6.654902260074137, 
      6.543695014658279, 6.432960896092975, 6.322709019445763, 
      6.21294732279318, 6.103682679104426, 5.994920996423742, 
      5.8866673077564835, 5.7789258518709365, 5.671700146064894, 
      5.56499305180777, 5.458806834051324, 5.353143214901592, 
      5.248003422258482, 5.14338823395559, 5.039298017869036, 
      4.935732768409223, 4.832692139761891, 4.730175476203721, 
      4.628181839782112, 4.5267100356175805, 4.425758635059822, 
      4.325325996903571, 4.225410286846736, 4.12601052041663, 
      4.027122255466924, 3.928744461409276, 3.8308746854740328, 
      3.733510358337484, 3.6366488054782633, 3.5402872576524103, 
      3.444422860557424, 3.349052683749898, 3.25417372887573, 
      3.159782937267018, 3.0658771969552103, 2.9724533491459697, 
      2.8795081941974368, 2.787038497140161, 2.695040992773837, 
      2.603512390373099, 2.512449378032068, 2.4218486266748758, 
      2.3317067937573137, 2.242020526682647, 2.152786465952885, 
      2.064001248075101, 1.9756615082408508, 1.8877638827953427, 
      1.800305011511745, 1.7132815396847847, 1.6266901200567916, 
      1.5405274145882115, 1.4547900960838827, 1.3694748496853406, 
      1.284578374238784, 1.2000973835475361, 1.1160286075172487, 
      1.0323687932014305, 0.9491147057543612, 0.86626312929796, 
      0.7838108677086422, 0.7017547453298121, 0.6200916076152595, 
      0.538818321708252, 0.4579317769609124, 0.37742888539801495, 
      0.29730658212916494, 0.21756182571296018, 0.13819159847650403, 
      0.05919290679346491, -0.019437218676435847, -0.09770172278375934, 
      -0.17560352571894006, -0.2531455228728099, -0.33033058472580373, 
      -0.4071615567637931, -0.48364125941866054, -0.5597724880317517, 
      -0.6355580128386108, -0.7110005789733695, -0.7861029064913754, 
      -0.8608676904086802, -0.9352976007571109, -1.0093952826537536, 
      -1.0831633563837308, -1.1566044174952241, -1.229721036905798, 
      -1.3025157610191078, -1.3749911118511366, -1.447149587165195, 
      -1.5189936606149188, -1.5905257818946057, -1.661748376896202, 
      -1.7326638478723964, -1.8032745736051896, -1.87358290957949, 
      -1.9435911881611612, -2.0133017187791364, -2.082716788111126, 
      -2.1518386602725332, -2.2206695770081906, -2.2892117578866094, 
      -2.3574674004963505, -2.4254386806442696, -2.493127752555321, 
      -2.5605367490736817, -2.6276677818649166, -2.6945229416189798, 
      -2.7611042982538305, -2.8274139011194657, -2.893453779202183, 
      -2.959225941328894, -3.024732376371349, -3.0899750534501016, 
      -3.1549559221380807, -3.219676912663665, -3.284139936113094, 
      -3.3483468846321633, -3.4122996316270537, -3.4760000319642224, 
      -3.5394499221692897, -3.6026511206247855, -3.6656054277667534, 
      -3.7283146262800875, -3.790780481292559, -3.8530047405675165, 
      -3.9149891346951136, -3.9767353772821576, -4.038245165140353, 
      -4.099520178473127, -4.160562081060766, -4.221372520444027, 
      -4.2819531281061005, -4.342305519652895, -4.402431294991662, 
      -4.462332038507952, -4.5220093192408095, -4.581464691056292, 
      -4.6406996928192354, -4.699715848563266, -4.758514667659095, 
      -4.817097644981043, -4.87546626107179, -4.933621982305386, 
      -4.991566261048522, -5.049300535819988, -5.106826231448427, 
      -5.164144759228312, -5.221257517074196, -5.278165889673178, 
      -5.3348712486356975, -5.391374952644551, -5.447678347602204, 
      -5.503782766776415, -5.559689530944139, -5.615399948533735, 
      -5.670915315765526, -5.726236916790668, -5.78136602382839, 
      -5.836303897301556, -5.891051785970641, -5.945610927066057, 
      -5.999982546418935, -6.054167858590218}}, {Automatic}]



(* end best guess data *)

(* end new data section *)

(* ::Section:: *)
(*Data section*)

masterData["m-3l-8a",0] = numeric8a[x];

masterData["m-3l-9a",0] = numeric9a[x];

masterData["m-3l-8b",0] = numeric8b[x];

masterData["m-3l-9b",0] = numeric9b[x];

masterData["m-3l-10a",0] = numeric10a[x];

masterData["m-3l-10b",0] = numeric10b[x];



masterData["m-3l-8a",0, "ipol"] = Interpolation[Coefficient[points8a, eps, 0]][x];

masterData["m-3l-9a",0, "ipol"] = Interpolation[Coefficient[points9a, eps, 0]][x];

masterData["m-3l-8b",0, "ipol"] = Interpolation[Coefficient[points8b, eps, 0]][x];

masterData["m-3l-9b",0, "ipol"] = Interpolation[Coefficient[points9b, eps, 0]][x];


(* ::Subsection:: *)
(*Single Scale Integrals*)


singScal["s-3l-6"]= 2*Zeta[3]/ep -((11*Pi^4)/45) - 4/3*Pi^2 Log[2]^2 + (4*Log[2]^4)/3 + 32*PolyLog[4, 1/2] + 6*Zeta[3] + O[ep];

singScal["s-3l-7"]= (-2*(-1 + ep)^2 * (-1 + 4*ep)*(* new sign-convention in version 2 -> -1:*)(-1)*singScal["s-3l-0"] + 3*(2 - 13*ep + 27*ep^2 - 18*ep^3)*singScal["s-3l-1"])/(8*ep*(1 - 6*ep + 8*ep^2));


singScal["s-1l-0"]=Gamma[-1+ep]/Gamma[1+ep];

singScal["s-2l-1"]=Gamma[1-ep]^2Gamma[ep]Gamma[2ep-1]/Gamma[2-ep]/Gamma[1+ep]^2;

singScal["s-2l-2"]=1/Gamma[1+ep]^2Gamma[ep]^2Gamma[1-ep]Gamma[2ep-1]/Gamma[2ep]/Gamma[2-ep];

singScal["s-2l-0"]=singScal["s-1l-0"]^2;

singScal["s-3l-0"]=singScal["s-1l-0"]^3;

singScal["s-3l-1"]=Gamma[1-ep]^2Gamma[ep]Gamma[-1+2ep]^2Gamma[-2+3ep]/Gamma[2-ep]/Gamma[-2+4ep]/Gamma[1+ep]^3;

singScal["s-3l-2"]=Gamma[1-ep]^4Gamma[ep]^2Gamma[3ep-1]Gamma[2-3ep]/Gamma[2-2ep]^2/Gamma[2-ep]/Gamma[1+ep]^3;


B4=16PolyLog[4,1/2]+2/3Log[2]^2(Log[2]^2-Pi^2)-13/180Pi^4+O[ep];

singScal["s-3l-3"]=4/3/(1-ep)/(1-2ep)/(1-3ep)/(2-3ep)(3(1-6ep)/ep^3+7/ep^2Gamma[1-ep]Gamma[1+2ep]^2Gamma[1+3ep]/Gamma[1+ep]^2/Gamma[1+4ep]+24ep^2B4);

Ls2=(PolyGamma[1,1/3]-PolyGamma[1,2/3])/(6 Sqrt[3]);

singScal["s-3l-4"]=(-1)^4*(-singScal["s-1l-0"])^3(-1-3/4ep+1/8ep^2+(91/16-9/2Sqrt[3]Ls2 )ep^3+O[ep]^4);

singScal["s-3l-5"]=Gamma[1-ep]^3Gamma[2ep-1]Gamma[3ep-2]/Gamma[2-ep]/Gamma[1+ep]^3;


(* ::Subsection:: *)
(*Integrals composed of the master integrals: i-3l-0,1,2,5a,5b,6a,6b*)


(* m-3l-10a *)
masterData["m-3l-10a",-3] = 0;

masterData["m-3l-10a",-2] = 0;

masterData["m-3l-10a",-1] = 2 Zeta[3];

(*masterData["m-3l-10a",0] = unknown["integral: m-3l-10a","epOrder: 0"];*)

masterData["m-3l-10a",0,"exp1"] = f10aGl;

masterData["m-3l-10a",0,"exp0"] = f10aAsyN;

masterData["m-3l-10a",0,"exp0-sym"] = f10aAsy;

masterData["m-3l-10a",0,"exp0-ex"] = f10aAsy/.matadSymbols;


(* m-3l-10b *)
masterData["m-3l-10b",-3] = 0;

masterData["m-3l-10b",-2] = 0;

masterData["m-3l-10b",-1] = 2 Zeta[3];

(*masterData["m-3l-10b",0] = unknown["integral: m-3l-10b","epOrder: 0",x];*)

masterData["m-3l-10b",0,"exp1"] = f10bGl;


masterData["m-3l-10b",0,"exp0"] = f10bAsyN;

masterData["m-3l-10b",0,"exp0-sym"] = f10bAsy;

masterData["m-3l-10b",0,"exp0-ex"] = f10bAsy/.matadSymbols;


(* i-3l-6b *)
masterData["i-3l-6b",-3] = 1/3;

masterData["i-3l-6b",-2] = -(2/3) (-1+3 HPL[{0},x]);

masterData["i-3l-6b",-1] = 1/6 (4-\[Pi]^2-24 HPL[{0},x]+12 HPL[{-1,0},x]+48 HPL[{0,0},x]-12 HPL[{1,0},x]);

masterData["i-3l-6b",0] = 1/(6 x^2) (-4 x^2-3 \[Pi]^2 x^2-\[Pi]^2 HPL[{-1},x]+3 \[Pi]^2 x^2 HPL[{-1},x]-24 x^2 HPL[{0},x]+\[Pi]^2 HPL[{1},x]-3 \[Pi]^2 x^2 HPL[{1},x]+36 x^2 HPL[{-1,0},x]+72 x^2 HPL[{0,0},x]-36 x^2 HPL[{1,0},x]+12 HPL[{-1,-1,0},x]-36 x^2 HPL[{-1,-1,0},x]-24 HPL[{-1,0,0},x]-48 x^2 HPL[{-1,0,0},x]-12 HPL[{-1,1,0},x]+36 x^2 HPL[{-1,1,0},x]-192 x^2 HPL[{0,0,0},x]-12 HPL[{1,-1,0},x]+36 x^2 HPL[{1,-1,0},x]+24 HPL[{1,0,0},x]+48 x^2 HPL[{1,0,0},x]+12 HPL[{1,1,0},x]-36 x^2 HPL[{1,1,0},x]+10 x^2 Zeta[3]);

masterData["i-3l-6b",1] = 1/(180 x^2) (-1080 x^2-210 \[Pi]^2 x^2-23 \[Pi]^4 x^2+60 \[Pi]^2 HPL[{-2},x]+60 \[Pi]^2 x^2 HPL[{-2},x]-150 \[Pi]^2 HPL[{-1},x]+330 \[Pi]^2 x^2 HPL[{-1},x]+720 x^2 HPL[{0},x]-120 \[Pi]^2 x^2 HPL[{0},x]+150 \[Pi]^2 HPL[{1},x]-330 \[Pi]^2 x^2 HPL[{1},x]-60 \[Pi]^2 HPL[{2},x]-60 \[Pi]^2 x^2 HPL[{2},x]+1440 x^2 HPL[{-2,0},x]+180 \[Pi]^2 HPL[{-1,-1},x]-300 \[Pi]^2 x^2 HPL[{-1,-1},x]-120 \[Pi]^2 HPL[{-1,0},x]+2520 x^2 HPL[{-1,0},x]-180 \[Pi]^2 HPL[{-1,1},x]+300 \[Pi]^2 x^2 HPL[{-1,1},x]-720 x^2 HPL[{0,0},x]-180 \[Pi]^2 HPL[{1,-1},x]+300 \[Pi]^2 x^2 HPL[{1,-1},x]+120 \[Pi]^2 HPL[{1,0},x]-2520 x^2 HPL[{1,0},x]+180 \[Pi]^2 HPL[{1,1},x]-300 \[Pi]^2 x^2 HPL[{1,1},x]-1440 x^2 HPL[{2,0},x]-720 HPL[{-2,-1,0},x]-720 x^2 HPL[{-2,-1,0},x]+1440 HPL[{-2,0,0},x]+1440 x^2 HPL[{-2,0,0},x]+720 HPL[{-2,1,0},x]+720 x^2 HPL[{-2,1,0},x]+1440 HPL[{-1,-2,0},x]+1800 HPL[{-1,-1,0},x]-3960 x^2 HPL[{-1,-1,0},x]-3600 HPL[{-1,0,0},x]-2880 x^2 HPL[{-1,0,0},x]-1800 HPL[{-1,1,0},x]+3960 x^2 HPL[{-1,1,0},x]-1440 HPL[{-1,2,0},x]-7200 x^2 HPL[{0,0,0},x]-1440 HPL[{1,-2,0},x]-1800 HPL[{1,-1,0},x]+3960 x^2 HPL[{1,-1,0},x]+3600 HPL[{1,0,0},x]+2880 x^2 HPL[{1,0,0},x]+1800 HPL[{1,1,0},x]-3960 x^2 HPL[{1,1,0},x]+1440 HPL[{1,2,0},x]+720 HPL[{2,-1,0},x]+720 x^2 HPL[{2,-1,0},x]-1440 HPL[{2,0,0},x]-1440 x^2 HPL[{2,0,0},x]-720 HPL[{2,1,0},x]-720 x^2 HPL[{2,1,0},x]-2160 HPL[{-1,-1,-1,0},x]+3600 x^2 HPL[{-1,-1,-1,0},x]+720 HPL[{-1,-1,0,0},x]+3600 x^2 HPL[{-1,-1,0,0},x]+2160 HPL[{-1,-1,1,0},x]-3600 x^2 HPL[{-1,-1,1,0},x]+4320 HPL[{-1,0,0,0},x]+5760 x^2 HPL[{-1,0,0,0},x]+2160 HPL[{-1,1,-1,0},x]-3600 x^2 HPL[{-1,1,-1,0},x]-720 HPL[{-1,1,0,0},x]-3600 x^2 HPL[{-1,1,0,0},x]-2160 HPL[{-1,1,1,0},x]+3600 x^2 HPL[{-1,1,1,0},x]+23040 x^2 HPL[{0,0,0,0},x]+2160 HPL[{1,-1,-1,0},x]-3600 x^2 HPL[{1,-1,-1,0},x]-720 HPL[{1,-1,0,0},x]-3600 x^2 HPL[{1,-1,0,0},x]-2160 HPL[{1,-1,1,0},x]+3600 x^2 HPL[{1,-1,1,0},x]-4320 HPL[{1,0,0,0},x]-5760 x^2 HPL[{1,0,0,0},x]-2160 HPL[{1,1,-1,0},x]+3600 x^2 HPL[{1,1,-1,0},x]+720 HPL[{1,1,0,0},x]+3600 x^2 HPL[{1,1,0,0},x]+2160 HPL[{1,1,1,0},x]-3600 x^2 HPL[{1,1,1,0},x]+1140 x^2 Zeta[3]+540 HPL[{-1},x] Zeta[3]-900 x^2 HPL[{-1},x] Zeta[3]-540 HPL[{1},x] Zeta[3]+900 x^2 HPL[{1},x] Zeta[3]);


(* i-3l-6a *)
masterData["i-3l-6a",-3] = 1/3;

masterData["i-3l-6a",-2] = 2/3;

masterData["i-3l-6a",-1] = 1/6 (4+\[Pi]^2-12 HPL[{-1,0},x]+12 HPL[{1,0},x]);

masterData["i-3l-6a",0] =1/6 (-4+3 \[Pi]^2-3 \[Pi]^2 HPL[{-1},x]+\[Pi]^2 x^2 HPL[{-1},x]-2 \[Pi]^2 x^2 HPL[{0},x]+3 \[Pi]^2 HPL[{1},x]-\[Pi]^2 x^2 HPL[{1},x]+24 x^2 HPL[{-2,0},x]-36 HPL[{-1,0},x]+36 HPL[{1,0},x]-24 x^2 HPL[{2,0},x]+36 HPL[{-1,-1,0},x]-12 x^2 HPL[{-1,-1,0},x]+24 HPL[{-1,0,0},x]-36 HPL[{-1,1,0},x]+12 x^2 HPL[{-1,1,0},x]-36 HPL[{1,-1,0},x]+12 x^2 HPL[{1,-1,0},x]-24 HPL[{1,0,0},x]+36 HPL[{1,1,0},x]-12 x^2 HPL[{1,1,0},x]-8 Zeta[3]+6 x^2 Zeta[3]);

masterData["i-3l-6a",1] = 1/180 (-1080+210 \[Pi]^2+16 \[Pi]^4-21 \[Pi]^4 x^2+240 \[Pi]^2 x^2 HPL[{-2},x]-330 \[Pi]^2 HPL[{-1},x]+150 \[Pi]^2 x^2 HPL[{-1},x]-300 \[Pi]^2 x^2 HPL[{0},x]+330 \[Pi]^2 HPL[{1},x]-150 \[Pi]^2 x^2 HPL[{1},x]-240 \[Pi]^2 x^2 HPL[{2},x]-1440 x^2 HPL[{-3,0},x]+3600 x^2 HPL[{-2,0},x]+300 \[Pi]^2 HPL[{-1,-1},x]-180 \[Pi]^2 x^2 HPL[{-1,-1},x]-2520 HPL[{-1,0},x]-60 \[Pi]^2 HPL[{-1,0},x]+60 \[Pi]^2 x^2 HPL[{-1,0},x]-300 \[Pi]^2 HPL[{-1,1},x]+180 \[Pi]^2 x^2 HPL[{-1,1},x]+120 \[Pi]^2 x^2 HPL[{0,0},x]-300 \[Pi]^2 HPL[{1,-1},x]+180 \[Pi]^2 x^2 HPL[{1,-1},x]+2520 HPL[{1,0},x]+60 \[Pi]^2 HPL[{1,0},x]-60 \[Pi]^2 x^2 HPL[{1,0},x]+300 \[Pi]^2 HPL[{1,1},x]-180 \[Pi]^2 x^2 HPL[{1,1},x]-3600 x^2 HPL[{2,0},x]+1440 x^2 HPL[{3,0},x]-2880 x^2 HPL[{-2,-1,0},x]-1440 x^2 HPL[{-2,0,0},x]+2880 x^2 HPL[{-2,1,0},x]+720 HPL[{-1,-2,0},x]-720 x^2 HPL[{-1,-2,0},x]+3960 HPL[{-1,-1,0},x]-1800 x^2 HPL[{-1,-1,0},x]+2160 HPL[{-1,0,0},x]-3960 HPL[{-1,1,0},x]+1800 x^2 HPL[{-1,1,0},x]-720 HPL[{-1,2,0},x]+720 x^2 HPL[{-1,2,0},x]-720 HPL[{1,-2,0},x]+720 x^2 HPL[{1,-2,0},x]-3960 HPL[{1,-1,0},x]+1800 x^2 HPL[{1,-1,0},x]-2160 HPL[{1,0,0},x]+3960 HPL[{1,1,0},x]-1800 x^2 HPL[{1,1,0},x]+720 HPL[{1,2,0},x]-720 x^2 HPL[{1,2,0},x]+2880 x^2 HPL[{2,-1,0},x]+1440 x^2 HPL[{2,0,0},x]-2880 x^2 HPL[{2,1,0},x]-3600 HPL[{-1,-1,-1,0},x]+2160 x^2 HPL[{-1,-1,-1,0},x]-2160 HPL[{-1,-1,0,0},x]+720 x^2 HPL[{-1,-1,0,0},x]+3600 HPL[{-1,-1,1,0},x]-2160 x^2 HPL[{-1,-1,1,0},x]-1440 HPL[{-1,0,0,0},x]+3600 HPL[{-1,1,-1,0},x]-2160 x^2 HPL[{-1,1,-1,0},x]+2160 HPL[{-1,1,0,0},x]-720 x^2 HPL[{-1,1,0,0},x]-3600 HPL[{-1,1,1,0},x]+2160 x^2 HPL[{-1,1,1,0},x]+3600 HPL[{1,-1,-1,0},x]-2160 x^2 HPL[{1,-1,-1,0},x]+2160 HPL[{1,-1,0,0},x]-720 x^2 HPL[{1,-1,0,0},x]-3600 HPL[{1,-1,1,0},x]+2160 x^2 HPL[{1,-1,1,0},x]+1440 HPL[{1,0,0,0},x]-3600 HPL[{1,1,-1,0},x]+2160 x^2 HPL[{1,1,-1,0},x]-2160 HPL[{1,1,0,0},x]+720 x^2 HPL[{1,1,0,0},x]+3600 HPL[{1,1,1,0},x]-2160 x^2 HPL[{1,1,1,0},x]-840 Zeta[3]+900 x^2 Zeta[3]+900 HPL[{-1},x] Zeta[3]-540 x^2 HPL[{-1},x] Zeta[3]+360 x^2 HPL[{0},x] Zeta[3]-900 HPL[{1},x] Zeta[3]+540 x^2 HPL[{1},x] Zeta[3]);


(* i-3l-0 *)
masterData["i-3l-0",-3] = 0;

masterData["i-3l-0",-2] = 0;

masterData["i-3l-0",-1] = 2 Zeta[3];

masterData["i-3l-0",0] = -(\[Pi]^4/18)-2/3 \[Pi]^2 HPL[{-2},x]+2/3 \[Pi]^2 HPL[{2},x]+2/3 \[Pi]^2 HPL[{-1,0},x]-2/3 \[Pi]^2 HPL[{1,0},x]+8 HPL[{-2,-1,0},x]-16 HPL[{-2,0,0},x]-8 HPL[{-2,1,0},x]-8 HPL[{-1,-2,0},x]+8 HPL[{-1,2,0},x]+8 HPL[{1,-2,0},x]-8 HPL[{1,2,0},x]-8 HPL[{2,-1,0},x]+16 HPL[{2,0,0},x]+8 HPL[{2,1,0},x]-16 HPL[{-1,1,0,0},x]-16 HPL[{1,-1,0,0},x]+6 Zeta[3]-8 HPL[{-1},x] Zeta[3]+8 HPL[{1},x] Zeta[3];


(* i-3l-5a *)
masterData["i-3l-5a",-3] = 1/3;

masterData["i-3l-5a",-2] = 2/3;

masterData["i-3l-5a",-1] = 1/3 (2+\[Pi]^2-12 HPL[{-1,0},x]+12 HPL[{1,0},x]);

masterData["i-3l-5a",0] = -(2/3)+(2 \[Pi]^2)/3+(\[Pi]^2 x^2)/3+1/3 \[Pi]^2 (-3+x^4) HPL[{-1},x]-2/3 \[Pi]^2 x^4 HPL[{0},x]+\[Pi]^2 HPL[{1},x]-1/3 \[Pi]^2 x^4 HPL[{1},x]+8 x^4 HPL[{-2,0},x]-8 HPL[{-1,0},x]-4 x^2 HPL[{-1,0},x]+8 x^2 HPL[{0,0},x]+8 HPL[{1,0},x]+4 x^2 HPL[{1,0},x]-8 x^4 HPL[{2,0},x]+12 HPL[{-1,-1,0},x]-4 x^4 HPL[{-1,-1,0},x]+16 HPL[{-1,0,0},x]+8 x^4 HPL[{-1,0,0},x]-12 HPL[{-1,1,0},x]+4 x^4 HPL[{-1,1,0},x]-16 x^4 HPL[{0,0,0},x]-12 HPL[{1,-1,0},x]+4 x^4 HPL[{1,-1,0},x]-16 HPL[{1,0,0},x]-8 x^4 HPL[{1,0,0},x]+12 HPL[{1,1,0},x]-4 x^4 HPL[{1,1,0},x]-(4 Zeta[3])/3+2 x^4 Zeta[3];

masterData["i-3l-5a",1] = 1/90 (-540+60 \[Pi]^2+26 \[Pi]^4+150 \[Pi]^2 x^2-29 \[Pi]^4 x^4+120 \[Pi]^2 x^4 HPL[{-2},x]-180 \[Pi]^2 HPL[{-1},x]-120 \[Pi]^2 x^2 HPL[{-1},x]+120 \[Pi]^2 x^4 HPL[{-1},x]+60 \[Pi]^2 x^2 HPL[{0},x]-240 \[Pi]^2 x^4 HPL[{0},x]+180 \[Pi]^2 HPL[{1},x]+120 \[Pi]^2 x^2 HPL[{1},x]-120 \[Pi]^2 x^4 HPL[{1},x]-120 \[Pi]^2 x^4 HPL[{2},x]-1440 x^4 HPL[{-3,0},x]-720 x^2 HPL[{-2,0},x]+2880 x^4 HPL[{-2,0},x]+300 \[Pi]^2 HPL[{-1,-1},x]-180 \[Pi]^2 x^4 HPL[{-1,-1},x]-720 HPL[{-1,0},x]-60 \[Pi]^2 HPL[{-1,0},x]-1800 x^2 HPL[{-1,0},x]+180 \[Pi]^2 x^4 HPL[{-1,0},x]-300 \[Pi]^2 HPL[{-1,1},x]+180 \[Pi]^2 x^4 HPL[{-1,1},x]+3600 x^2 HPL[{0,0},x]+120 \[Pi]^2 x^4 HPL[{0,0},x]-300 \[Pi]^2 HPL[{1,-1},x]+180 \[Pi]^2 x^4 HPL[{1,-1},x]+720 HPL[{1,0},x]+60 \[Pi]^2 HPL[{1,0},x]+1800 x^2 HPL[{1,0},x]-180 \[Pi]^2 x^4 HPL[{1,0},x]+300 \[Pi]^2 HPL[{1,1},x]-180 \[Pi]^2 x^4 HPL[{1,1},x]+720 x^2 HPL[{2,0},x]-2880 x^4 HPL[{2,0},x]+1440 x^4 HPL[{3,0},x]-1440 x^4 HPL[{-2,-1,0},x]-4320 x^4 HPL[{-2,0,0},x]+1440 x^4 HPL[{-2,1,0},x]+720 HPL[{-1,-2,0},x]-2160 x^4 HPL[{-1,-2,0},x]+2160 HPL[{-1,-1,0},x]+1440 x^2 HPL[{-1,-1,0},x]-1440 x^4 HPL[{-1,-1,0},x]+2880 HPL[{-1,0,0},x]+720 x^2 HPL[{-1,0,0},x]+2880 x^4 HPL[{-1,0,0},x]-2160 HPL[{-1,1,0},x]-1440 x^2 HPL[{-1,1,0},x]+1440 x^4 HPL[{-1,1,0},x]-720 HPL[{-1,2,0},x]+2160 x^4 HPL[{-1,2,0},x]-5760 x^2 HPL[{0,0,0},x]-5760 x^4 HPL[{0,0,0},x]-720 HPL[{1,-2,0},x]+2160 x^4 HPL[{1,-2,0},x]-2160 HPL[{1,-1,0},x]-1440 x^2 HPL[{1,-1,0},x]+1440 x^4 HPL[{1,-1,0},x]-2880 HPL[{1,0,0},x]-720 x^2 HPL[{1,0,0},x]-2880 x^4 HPL[{1,0,0},x]+2160 HPL[{1,1,0},x]+1440 x^2 HPL[{1,1,0},x]-1440 x^4 HPL[{1,1,0},x]+720 HPL[{1,2,0},x]-2160 x^4 HPL[{1,2,0},x]+1440 x^4 HPL[{2,-1,0},x]+4320 x^4 HPL[{2,0,0},x]-1440 x^4 HPL[{2,1,0},x]-3600 HPL[{-1,-1,-1,0},x]+2160 x^4 HPL[{-1,-1,-1,0},x]-3600 HPL[{-1,-1,0,0},x]-720 x^4 HPL[{-1,-1,0,0},x]+3600 HPL[{-1,-1,1,0},x]-2160 x^4 HPL[{-1,-1,1,0},x]-7200 HPL[{-1,0,0,0},x]-2880 x^4 HPL[{-1,0,0,0},x]+3600 HPL[{-1,1,-1,0},x]-2160 x^4 HPL[{-1,1,-1,0},x]+3600 HPL[{-1,1,0,0},x]+720 x^4 HPL[{-1,1,0,0},x]-3600 HPL[{-1,1,1,0},x]+2160 x^4 HPL[{-1,1,1,0},x]+17280 x^4 HPL[{0,0,0,0},x]+3600 HPL[{1,-1,-1,0},x]-2160 x^4 HPL[{1,-1,-1,0},x]+3600 HPL[{1,-1,0,0},x]+720 x^4 HPL[{1,-1,0,0},x]-3600 HPL[{1,-1,1,0},x]+2160 x^4 HPL[{1,-1,1,0},x]+7200 HPL[{1,0,0,0},x]+2880 x^4 HPL[{1,0,0,0},x]-3600 HPL[{1,1,-1,0},x]+2160 x^4 HPL[{1,1,-1,0},x]-3600 HPL[{1,1,0,0},x]-720 x^4 HPL[{1,1,0,0},x]+3600 HPL[{1,1,1,0},x]-2160 x^4 HPL[{1,1,1,0},x]-240 Zeta[3]+180 x^2 Zeta[3]+720 x^4 Zeta[3]+540 HPL[{-1},x] Zeta[3]-180 x^4 HPL[{-1},x] Zeta[3]-1080 x^4 HPL[{0},x] Zeta[3]-540 HPL[{1},x] Zeta[3]+180 x^4 HPL[{1},x] Zeta[3]);

masterData["i-3l-5a",2] = 1/90 (-1980-60 \[Pi]^2+52 \[Pi]^4+510 \[Pi]^2 x^2+31 \[Pi]^4 x^2-116 \[Pi]^4 x^4-240 \[Pi]^2 x^4 HPL[{-3},x]-120 \[Pi]^2 x^2 HPL[{-2},x]+480 \[Pi]^2 x^4 HPL[{-2},x]-180 \[Pi]^2 HPL[{-1},x]-107 \[Pi]^4 HPL[{-1},x]-600 \[Pi]^2 x^2 HPL[{-1},x]+360 \[Pi]^2 x^4 HPL[{-1},x]+89 \[Pi]^4 x^4 HPL[{-1},x]+300 \[Pi]^2 x^2 HPL[{0},x]-720 \[Pi]^2 x^4 HPL[{0},x]+54 \[Pi]^4 x^4 HPL[{0},x]+180 \[Pi]^2 HPL[{1},x]+107 \[Pi]^4 HPL[{1},x]+600 \[Pi]^2 x^2 HPL[{1},x]-360 \[Pi]^2 x^4 HPL[{1},x]-89 \[Pi]^4 x^4 HPL[{1},x]+120 \[Pi]^2 x^2 HPL[{2},x]-480 \[Pi]^2 x^4 HPL[{2},x]+240 \[Pi]^2 x^4 HPL[{3},x]+2880 x^4 HPL[{-4,0},x]+1440 x^2 HPL[{-3,0},x]-5760 x^4 HPL[{-3,0},x]-240 \[Pi]^2 x^4 HPL[{-2,-1},x]-3600 x^2 HPL[{-2,0},x]+8640 x^4 HPL[{-2,0},x]-240 \[Pi]^2 x^4 HPL[{-2,0},x]+240 \[Pi]^2 x^4 HPL[{-2,1},x]+120 \[Pi]^2 HPL[{-1,-2},x]-360 \[Pi]^2 x^4 HPL[{-1,-2},x]+600 \[Pi]^2 HPL[{-1,-1},x]+480 \[Pi]^2 x^2 HPL[{-1,-1},x]-720 \[Pi]^2 x^4 HPL[{-1,-1},x]+720 HPL[{-1,0},x]-120 \[Pi]^2 HPL[{-1,0},x]-6120 x^2 HPL[{-1,0},x]-240 \[Pi]^2 x^2 HPL[{-1,0},x]+720 \[Pi]^2 x^4 HPL[{-1,0},x]-600 \[Pi]^2 HPL[{-1,1},x]-480 \[Pi]^2 x^2 HPL[{-1,1},x]+720 \[Pi]^2 x^4 HPL[{-1,1},x]-120 \[Pi]^2 HPL[{-1,2},x]+360 \[Pi]^2 x^4 HPL[{-1,2},x]+12240 x^2 HPL[{0,0},x]-120 \[Pi]^2 x^2 HPL[{0,0},x]+480 \[Pi]^2 x^4 HPL[{0,0},x]-120 \[Pi]^2 HPL[{1,-2},x]+360 \[Pi]^2 x^4 HPL[{1,-2},x]-600 \[Pi]^2 HPL[{1,-1},x]-480 \[Pi]^2 x^2 HPL[{1,-1},x]+720 \[Pi]^2 x^4 HPL[{1,-1},x]-720 HPL[{1,0},x]+120 \[Pi]^2 HPL[{1,0},x]+6120 x^2 HPL[{1,0},x]+240 \[Pi]^2 x^2 HPL[{1,0},x]-720 \[Pi]^2 x^4 HPL[{1,0},x]+600 \[Pi]^2 HPL[{1,1},x]+480 \[Pi]^2 x^2 HPL[{1,1},x]-720 \[Pi]^2 x^4 HPL[{1,1},x]+120 \[Pi]^2 HPL[{1,2},x]-360 \[Pi]^2 x^4 HPL[{1,2},x]+240 \[Pi]^2 x^4 HPL[{2,-1},x]+3600 x^2 HPL[{2,0},x]-8640 x^4 HPL[{2,0},x]+240 \[Pi]^2 x^4 HPL[{2,0},x]-240 \[Pi]^2 x^4 HPL[{2,1},x]-1440 x^2 HPL[{3,0},x]+5760 x^4 HPL[{3,0},x]-2880 x^4 HPL[{4,0},x]+2880 x^4 HPL[{-3,-1,0},x]+8640 x^4 HPL[{-3,0,0},x]-2880 x^4 HPL[{-3,1,0},x]+2880 x^4 HPL[{-2,-2,0},x]+1440 x^2 HPL[{-2,-1,0},x]-5760 x^4 HPL[{-2,-1,0},x]+4320 x^2 HPL[{-2,0,0},x]-17280 x^4 HPL[{-2,0,0},x]-1440 x^2 HPL[{-2,1,0},x]+5760 x^4 HPL[{-2,1,0},x]-2880 x^4 HPL[{-2,2,0},x]-1440 HPL[{-1,-3,0},x]+4320 x^4 HPL[{-1,-3,0},x]+1440 HPL[{-1,-2,0},x]+2880 x^2 HPL[{-1,-2,0},x]-8640 x^4 HPL[{-1,-2,0},x]-1080 \[Pi]^2 HPL[{-1,-1,-1},x]+840 \[Pi]^2 x^4 HPL[{-1,-1,-1},x]+2160 HPL[{-1,-1,0},x]+360 \[Pi]^2 HPL[{-1,-1,0},x]+7200 x^2 HPL[{-1,-1,0},x]-4320 x^4 HPL[{-1,-1,0},x]-600 \[Pi]^2 x^4 HPL[{-1,-1,0},x]+1080 \[Pi]^2 HPL[{-1,-1,1},x]-840 \[Pi]^2 x^4 HPL[{-1,-1,1},x]+2880 HPL[{-1,0,0},x]+120 \[Pi]^2 HPL[{-1,0,0},x]+3600 x^2 HPL[{-1,0,0},x]+8640 x^4 HPL[{-1,0,0},x]-360 \[Pi]^2 x^4 HPL[{-1,0,0},x]+1080 \[Pi]^2 HPL[{-1,1,-1},x]-840 \[Pi]^2 x^4 HPL[{-1,1,-1},x]-2160 HPL[{-1,1,0},x]-360 \[Pi]^2 HPL[{-1,1,0},x]-7200 x^2 HPL[{-1,1,0},x]+4320 x^4 HPL[{-1,1,0},x]+600 \[Pi]^2 x^4 HPL[{-1,1,0},x]-1080 \[Pi]^2 HPL[{-1,1,1},x]+840 \[Pi]^2 x^4 HPL[{-1,1,1},x]-1440 HPL[{-1,2,0},x]-2880 x^2 HPL[{-1,2,0},x]+8640 x^4 HPL[{-1,2,0},x]+1440 HPL[{-1,3,0},x]-4320 x^4 HPL[{-1,3,0},x]-28800 x^2 HPL[{0,0,0},x]-17280 x^4 HPL[{0,0,0},x]-240 \[Pi]^2 x^4 HPL[{0,0,0},x]+1440 HPL[{1,-3,0},x]-4320 x^4 HPL[{1,-3,0},x]-1440 HPL[{1,-2,0},x]-2880 x^2 HPL[{1,-2,0},x]+8640 x^4 HPL[{1,-2,0},x]+1080 \[Pi]^2 HPL[{1,-1,-1},x]-840 \[Pi]^2 x^4 HPL[{1,-1,-1},x]-2160 HPL[{1,-1,0},x]-360 \[Pi]^2 HPL[{1,-1,0},x]-7200 x^2 HPL[{1,-1,0},x]+4320 x^4 HPL[{1,-1,0},x]+600 \[Pi]^2 x^4 HPL[{1,-1,0},x]-1080 \[Pi]^2 HPL[{1,-1,1},x]+840 \[Pi]^2 x^4 HPL[{1,-1,1},x]-2880 HPL[{1,0,0},x]-120 \[Pi]^2 HPL[{1,0,0},x]-3600 x^2 HPL[{1,0,0},x]-8640 x^4 HPL[{1,0,0},x]+360 \[Pi]^2 x^4 HPL[{1,0,0},x]-1080 \[Pi]^2 HPL[{1,1,-1},x]+840 \[Pi]^2 x^4 HPL[{1,1,-1},x]+2160 HPL[{1,1,0},x]+360 \[Pi]^2 HPL[{1,1,0},x]+7200 x^2 HPL[{1,1,0},x]-4320 x^4 HPL[{1,1,0},x]-600 \[Pi]^2 x^4 HPL[{1,1,0},x]+1080 \[Pi]^2 HPL[{1,1,1},x]-840 \[Pi]^2 x^4 HPL[{1,1,1},x]+1440 HPL[{1,2,0},x]+2880 x^2 HPL[{1,2,0},x]-8640 x^4 HPL[{1,2,0},x]-1440 HPL[{1,3,0},x]+4320 x^4 HPL[{1,3,0},x]-2880 x^4 HPL[{2,-2,0},x]-1440 x^2 HPL[{2,-1,0},x]+5760 x^4 HPL[{2,-1,0},x]-4320 x^2 HPL[{2,0,0},x]+17280 x^4 HPL[{2,0,0},x]+1440 x^2 HPL[{2,1,0},x]-5760 x^4 HPL[{2,1,0},x]+2880 x^4 HPL[{2,2,0},x]-2880 x^4 HPL[{3,-1,0},x]-8640 x^4 HPL[{3,0,0},x]+2880 x^4 HPL[{3,1,0},x]+2880 x^4 HPL[{-2,-1,-1,0},x]+8640 x^4 HPL[{-2,-1,0,0},x]-2880 x^4 HPL[{-2,-1,1,0},x]+20160 x^4 HPL[{-2,0,0,0},x]-2880 x^4 HPL[{-2,1,-1,0},x]-8640 x^4 HPL[{-2,1,0,0},x]+2880 x^4 HPL[{-2,1,1,0},x]-1440 HPL[{-1,-2,-1,0},x]+4320 x^4 HPL[{-1,-2,-1,0},x]-4320 HPL[{-1,-2,0,0},x]+12960 x^4 HPL[{-1,-2,0,0},x]+1440 HPL[{-1,-2,1,0},x]-4320 x^4 HPL[{-1,-2,1,0},x]-4320 HPL[{-1,-1,-2,0},x]+7200 x^4 HPL[{-1,-1,-2,0},x]-7200 HPL[{-1,-1,-1,0},x]-5760 x^2 HPL[{-1,-1,-1,0},x]+8640 x^4 HPL[{-1,-1,-1,0},x]-7200 HPL[{-1,-1,0,0},x]-2880 x^2 HPL[{-1,-1,0,0},x]-2880 x^4 HPL[{-1,-1,0,0},x]+7200 HPL[{-1,-1,1,0},x]+5760 x^2 HPL[{-1,-1,1,0},x]-8640 x^4 HPL[{-1,-1,1,0},x]+4320 HPL[{-1,-1,2,0},x]-7200 x^4 HPL[{-1,-1,2,0},x]-14400 HPL[{-1,0,0,0},x]-4320 x^2 HPL[{-1,0,0,0},x]-11520 x^4 HPL[{-1,0,0,0},x]+4320 HPL[{-1,1,-2,0},x]-7200 x^4 HPL[{-1,1,-2,0},x]+7200 HPL[{-1,1,-1,0},x]+5760 x^2 HPL[{-1,1,-1,0},x]-8640 x^4 HPL[{-1,1,-1,0},x]+7200 HPL[{-1,1,0,0},x]+2880 x^2 HPL[{-1,1,0,0},x]+2880 x^4 HPL[{-1,1,0,0},x]-7200 HPL[{-1,1,1,0},x]-5760 x^2 HPL[{-1,1,1,0},x]+8640 x^4 HPL[{-1,1,1,0},x]-4320 HPL[{-1,1,2,0},x]+7200 x^4 HPL[{-1,1,2,0},x]+1440 HPL[{-1,2,-1,0},x]-4320 x^4 HPL[{-1,2,-1,0},x]+4320 HPL[{-1,2,0,0},x]-12960 x^4 HPL[{-1,2,0,0},x]-1440 HPL[{-1,2,1,0},x]+4320 x^4 HPL[{-1,2,1,0},x]+37440 x^2 HPL[{0,0,0,0},x]+69120 x^4 HPL[{0,0,0,0},x]+1440 HPL[{1,-2,-1,0},x]-4320 x^4 HPL[{1,-2,-1,0},x]+4320 HPL[{1,-2,0,0},x]-12960 x^4 HPL[{1,-2,0,0},x]-1440 HPL[{1,-2,1,0},x]+4320 x^4 HPL[{1,-2,1,0},x]+4320 HPL[{1,-1,-2,0},x]-7200 x^4 HPL[{1,-1,-2,0},x]+7200 HPL[{1,-1,-1,0},x]+5760 x^2 HPL[{1,-1,-1,0},x]-8640 x^4 HPL[{1,-1,-1,0},x]+7200 HPL[{1,-1,0,0},x]+2880 x^2 HPL[{1,-1,0,0},x]+2880 x^4 HPL[{1,-1,0,0},x]-7200 HPL[{1,-1,1,0},x]-5760 x^2 HPL[{1,-1,1,0},x]+8640 x^4 HPL[{1,-1,1,0},x]-4320 HPL[{1,-1,2,0},x]+7200 x^4 HPL[{1,-1,2,0},x]+14400 HPL[{1,0,0,0},x]+4320 x^2 HPL[{1,0,0,0},x]+11520 x^4 HPL[{1,0,0,0},x]-4320 HPL[{1,1,-2,0},x]+7200 x^4 HPL[{1,1,-2,0},x]-7200 HPL[{1,1,-1,0},x]-5760 x^2 HPL[{1,1,-1,0},x]+8640 x^4 HPL[{1,1,-1,0},x]-7200 HPL[{1,1,0,0},x]-2880 x^2 HPL[{1,1,0,0},x]-2880 x^4 HPL[{1,1,0,0},x]+7200 HPL[{1,1,1,0},x]+5760 x^2 HPL[{1,1,1,0},x]-8640 x^4 HPL[{1,1,1,0},x]+4320 HPL[{1,1,2,0},x]-7200 x^4 HPL[{1,1,2,0},x]-1440 HPL[{1,2,-1,0},x]+4320 x^4 HPL[{1,2,-1,0},x]-4320 HPL[{1,2,0,0},x]+12960 x^4 HPL[{1,2,0,0},x]+1440 HPL[{1,2,1,0},x]-4320 x^4 HPL[{1,2,1,0},x]-2880 x^4 HPL[{2,-1,-1,0},x]-8640 x^4 HPL[{2,-1,0,0},x]+2880 x^4 HPL[{2,-1,1,0},x]-20160 x^4 HPL[{2,0,0,0},x]+2880 x^4 HPL[{2,1,-1,0},x]+8640 x^4 HPL[{2,1,0,0},x]-2880 x^4 HPL[{2,1,1,0},x]+12960 HPL[{-1,-1,-1,-1,0},x]-10080 x^4 HPL[{-1,-1,-1,-1,0},x]+10080 HPL[{-1,-1,-1,0,0},x]-1440 x^4 HPL[{-1,-1,-1,0,0},x]-12960 HPL[{-1,-1,-1,1,0},x]+10080 x^4 HPL[{-1,-1,-1,1,0},x]+18720 HPL[{-1,-1,0,0,0},x]+1440 x^4 HPL[{-1,-1,0,0,0},x]-12960 HPL[{-1,-1,1,-1,0},x]+10080 x^4 HPL[{-1,-1,1,-1,0},x]-10080 HPL[{-1,-1,1,0,0},x]+1440 x^4 HPL[{-1,-1,1,0,0},x]+12960 HPL[{-1,-1,1,1,0},x]-10080 x^4 HPL[{-1,-1,1,1,0},x]+40320 HPL[{-1,0,0,0,0},x]+2880 x^4 HPL[{-1,0,0,0,0},x]-12960 HPL[{-1,1,-1,-1,0},x]+10080 x^4 HPL[{-1,1,-1,-1,0},x]-10080 HPL[{-1,1,-1,0,0},x]+1440 x^4 HPL[{-1,1,-1,0,0},x]+12960 HPL[{-1,1,-1,1,0},x]-10080 x^4 HPL[{-1,1,-1,1,0},x]-18720 HPL[{-1,1,0,0,0},x]-1440 x^4 HPL[{-1,1,0,0,0},x]+12960 HPL[{-1,1,1,-1,0},x]-10080 x^4 HPL[{-1,1,1,-1,0},x]+10080 HPL[{-1,1,1,0,0},x]-1440 x^4 HPL[{-1,1,1,0,0},x]-12960 HPL[{-1,1,1,1,0},x]+10080 x^4 HPL[{-1,1,1,1,0},x]-144000 x^4 HPL[{0,0,0,0,0},x]-12960 HPL[{1,-1,-1,-1,0},x]+10080 x^4 HPL[{1,-1,-1,-1,0},x]-10080 HPL[{1,-1,-1,0,0},x]+1440 x^4 HPL[{1,-1,-1,0,0},x]+12960 HPL[{1,-1,-1,1,0},x]-10080 x^4 HPL[{1,-1,-1,1,0},x]-18720 HPL[{1,-1,0,0,0},x]-1440 x^4 HPL[{1,-1,0,0,0},x]+12960 HPL[{1,-1,1,-1,0},x]-10080 x^4 HPL[{1,-1,1,-1,0},x]+10080 HPL[{1,-1,1,0,0},x]-1440 x^4 HPL[{1,-1,1,0,0},x]-12960 HPL[{1,-1,1,1,0},x]+10080 x^4 HPL[{1,-1,1,1,0},x]-40320 HPL[{1,0,0,0,0},x]-2880 x^4 HPL[{1,0,0,0,0},x]+12960 HPL[{1,1,-1,-1,0},x]-10080 x^4 HPL[{1,1,-1,-1,0},x]+10080 HPL[{1,1,-1,0,0},x]-1440 x^4 HPL[{1,1,-1,0,0},x]-12960 HPL[{1,1,-1,1,0},x]+10080 x^4 HPL[{1,1,-1,1,0},x]+18720 HPL[{1,1,0,0,0},x]+1440 x^4 HPL[{1,1,0,0,0},x]-12960 HPL[{1,1,1,-1,0},x]+10080 x^4 HPL[{1,1,1,-1,0},x]-10080 HPL[{1,1,1,0,0},x]+1440 x^4 HPL[{1,1,1,0,0},x]+12960 HPL[{1,1,1,1,0},x]-10080 x^4 HPL[{1,1,1,1,0},x]-240 Zeta[3]-120 \[Pi]^2 Zeta[3]+900 x^2 Zeta[3]+2160 x^4 Zeta[3]+60 \[Pi]^2 x^4 Zeta[3]-720 x^4 HPL[{-2},x] Zeta[3]+1080 HPL[{-1},x] Zeta[3]+720 x^2 HPL[{-1},x] Zeta[3]-720 x^4 HPL[{-1},x] Zeta[3]-1800 x^2 HPL[{0},x] Zeta[3]-4320 x^4 HPL[{0},x] Zeta[3]-1080 HPL[{1},x] Zeta[3]-720 x^2 HPL[{1},x] Zeta[3]+720 x^4 HPL[{1},x] Zeta[3]+720 x^4 HPL[{2},x] Zeta[3]-1800 HPL[{-1,-1},x] Zeta[3]+1080 x^4 HPL[{-1,-1},x] Zeta[3]-1080 HPL[{-1,0},x] Zeta[3]+360 x^4 HPL[{-1,0},x] Zeta[3]+1800 HPL[{-1,1},x] Zeta[3]-1080 x^4 HPL[{-1,1},x] Zeta[3]+7920 x^4 HPL[{0,0},x] Zeta[3]+1800 HPL[{1,-1},x] Zeta[3]-1080 x^4 HPL[{1,-1},x] Zeta[3]+1080 HPL[{1,0},x] Zeta[3]-360 x^4 HPL[{1,0},x] Zeta[3]-1800 HPL[{1,1},x] Zeta[3]+1080 x^4 HPL[{1,1},x] Zeta[3]-360 Zeta[5]+4140 x^4 Zeta[5]);


(* i-3l-1 *)
masterData["i-3l-1",-3] = 0;

masterData["i-3l-1",-2] = 0;

masterData["i-3l-1",-1] = 2 Zeta[3];

masterData["i-3l-1",0] = 1/30 (\[Pi]^4+20 \[Pi]^2 HPL[{-2},x]-20 \[Pi]^2 HPL[{2},x]-20 \[Pi]^2 HPL[{-1,0},x]+20 \[Pi]^2 HPL[{1,0},x]-240 HPL[{-2,-1,0},x]+480 HPL[{-2,0,0},x]+240 HPL[{-2,1,0},x]+240 HPL[{-1,-2,0},x]-240 HPL[{-1,2,0},x]-240 HPL[{1,-2,0},x]+240 HPL[{1,2,0},x]+240 HPL[{2,-1,0},x]-480 HPL[{2,0,0},x]-240 HPL[{2,1,0},x]-480 HPL[{-1,0,0,0},x]+480 HPL[{1,0,0,0},x]+180 Zeta[3]-120 HPL[{-1},x] Zeta[3]+120 HPL[{1},x] Zeta[3]);


(* i-3l-5b *)
masterData["i-3l-5b",-3] = 1/3;

masterData["i-3l-5b",-2] = -(2/3) (-1+3 HPL[{0},x]);

masterData["i-3l-5b",-1] = 1/3 (2-\[Pi]^2-12 HPL[{0},x]+12 HPL[{-1,0},x]+12 HPL[{0,0},x]-12 HPL[{1,0},x]);

masterData["i-3l-5b",0] = 1/(3 x^4) (-\[Pi]^2 x^2-2 x^4-2 \[Pi]^2 x^4-\[Pi]^2 HPL[{-1},x]+3 \[Pi]^2 x^4 HPL[{-1},x]-12 x^4 HPL[{0},x]+\[Pi]^2 HPL[{1},x]-3 \[Pi]^2 x^4 HPL[{1},x]+12 x^2 HPL[{-1,0},x]+24 x^4 HPL[{-1,0},x]+24 x^4 HPL[{0,0},x]-12 x^2 HPL[{1,0},x]-24 x^4 HPL[{1,0},x]+12 HPL[{-1,-1,0},x]-36 x^4 HPL[{-1,-1,0},x]-24 x^4 HPL[{-1,0,0},x]-12 HPL[{-1,1,0},x]+36 x^4 HPL[{-1,1,0},x]-24 x^4 HPL[{0,0,0},x]-12 HPL[{1,-1,0},x]+36 x^4 HPL[{1,-1,0},x]+24 x^4 HPL[{1,0,0},x]+12 HPL[{1,1,0},x]-36 x^4 HPL[{1,1,0},x]+14 x^4 Zeta[3]);

masterData["i-3l-5b",1] = 1/(30 x^4) (-50 \[Pi]^2 x^2-180 x^4-20 \[Pi]^2 x^4-7 \[Pi]^4 x^4-20 \[Pi]^2 HPL[{-2},x]+20 \[Pi]^2 x^4 HPL[{-2},x]-40 \[Pi]^2 HPL[{-1},x]+40 \[Pi]^2 x^2 HPL[{-1},x]+60 \[Pi]^2 x^4 HPL[{-1},x]+120 x^4 HPL[{0},x]+40 \[Pi]^2 HPL[{1},x]-40 \[Pi]^2 x^2 HPL[{1},x]-60 \[Pi]^2 x^4 HPL[{1},x]+20 \[Pi]^2 HPL[{2},x]-20 \[Pi]^2 x^4 HPL[{2},x]+60 \[Pi]^2 HPL[{-1,-1},x]-100 \[Pi]^2 x^4 HPL[{-1,-1},x]+600 x^2 HPL[{-1,0},x]+240 x^4 HPL[{-1,0},x]-60 \[Pi]^2 HPL[{-1,1},x]+100 \[Pi]^2 x^4 HPL[{-1,1},x]+240 x^4 HPL[{0,0},x]-60 \[Pi]^2 HPL[{1,-1},x]+100 \[Pi]^2 x^4 HPL[{1,-1},x]-600 x^2 HPL[{1,0},x]-240 x^4 HPL[{1,0},x]+60 \[Pi]^2 HPL[{1,1},x]-100 \[Pi]^2 x^4 HPL[{1,1},x]+240 HPL[{-2,-1,0},x]-240 x^4 HPL[{-2,-1,0},x]-240 HPL[{-2,1,0},x]+240 x^4 HPL[{-2,1,0},x]+480 HPL[{-1,-1,0},x]-480 x^2 HPL[{-1,-1,0},x]-720 x^4 HPL[{-1,-1,0},x]-240 x^2 HPL[{-1,0,0},x]-480 x^4 HPL[{-1,0,0},x]-480 HPL[{-1,1,0},x]+480 x^2 HPL[{-1,1,0},x]+720 x^4 HPL[{-1,1,0},x]-480 x^4 HPL[{0,0,0},x]-480 HPL[{1,-1,0},x]+480 x^2 HPL[{1,-1,0},x]+720 x^4 HPL[{1,-1,0},x]+240 x^2 HPL[{1,0,0},x]+480 x^4 HPL[{1,0,0},x]+480 HPL[{1,1,0},x]-480 x^2 HPL[{1,1,0},x]-720 x^4 HPL[{1,1,0},x]-240 HPL[{2,-1,0},x]+240 x^4 HPL[{2,-1,0},x]+240 HPL[{2,1,0},x]-240 x^4 HPL[{2,1,0},x]-720 HPL[{-1,-1,-1,0},x]+1200 x^4 HPL[{-1,-1,-1,0},x]-240 HPL[{-1,-1,0,0},x]+720 x^4 HPL[{-1,-1,0,0},x]+720 HPL[{-1,-1,1,0},x]-1200 x^4 HPL[{-1,-1,1,0},x]+480 x^4 HPL[{-1,0,0,0},x]+720 HPL[{-1,1,-1,0},x]-1200 x^4 HPL[{-1,1,-1,0},x]+240 HPL[{-1,1,0,0},x]-720 x^4 HPL[{-1,1,0,0},x]-720 HPL[{-1,1,1,0},x]+1200 x^4 HPL[{-1,1,1,0},x]+480 x^4 HPL[{0,0,0,0},x]+720 HPL[{1,-1,-1,0},x]-1200 x^4 HPL[{1,-1,-1,0},x]+240 HPL[{1,-1,0,0},x]-720 x^4 HPL[{1,-1,0,0},x]-720 HPL[{1,-1,1,0},x]+1200 x^4 HPL[{1,-1,1,0},x]-480 x^4 HPL[{1,0,0,0},x]-720 HPL[{1,1,-1,0},x]+1200 x^4 HPL[{1,1,-1,0},x]-240 HPL[{1,1,0,0},x]+720 x^4 HPL[{1,1,0,0},x]+720 HPL[{1,1,1,0},x]-1200 x^4 HPL[{1,1,1,0},x]+300 x^2 Zeta[3]+280 x^4 Zeta[3]+300 HPL[{-1},x] Zeta[3]-420 x^4 HPL[{-1},x] Zeta[3]-300 HPL[{1},x] Zeta[3]+420 x^4 HPL[{1},x] Zeta[3]);


(* i-3l-2 *)
masterData["i-3l-2",-3] = 0;

masterData["i-3l-2",-2] = 0;

masterData["i-3l-2",-1] = 2 Zeta[3];

masterData["i-3l-2",0] = 1/18 (-\[Pi]^4+12 \[Pi]^2 HPL[{-2},x]-12 \[Pi]^2 HPL[{2},x]-12 \[Pi]^2 HPL[{-1,0},x]+12 \[Pi]^2 HPL[{1,0},x]-144 HPL[{-2,-1,0},x]+144 HPL[{-2,1,0},x]+144 HPL[{-1,-2,0},x]-144 HPL[{-1,2,0},x]-144 HPL[{1,-2,0},x]+144 HPL[{1,2,0},x]+144 HPL[{2,-1,0},x]-144 HPL[{2,1,0},x]+108 Zeta[3]-72 HPL[{-1},x] Zeta[3]+72 HPL[{1},x] Zeta[3]);


(* ::Section:: *)
(*Master Integrals 1,2,3,4,5a,5b,6a,6b,7a,7b,*)


(* ::Subsection:: *)
(*master 8, 9, 10, a/b*)


(* m-3l-8a *)
masterData["m-3l-8a",-3] = x^2+1;

masterData["m-3l-8a",-2] = 15/4+4 x^2-x^4/12-3 x^2 HPL[{0},x];

masterData["m-3l-8a",-1] = 1/8 (65+80 x^2-5 x^4-96 x^2 HPL[{0},x]+4 x^4 HPL[{0},x]+48 x^2 HPL[{0,0},x]);

(*masterData["m-3l-8a",0] = unknown["integral: m-3l-8a","epOrder: 0",x];*)

masterData["m-3l-8a",0, "exp1"] = f8aGl;

masterData["m-3l-8a",0,"exp0"] = f8aAsyN;

masterData["m-3l-8a",0,"exp0-sym"] = f8aAsy;

masterData["m-3l-8a",0,"exp0-ex"] = f8aAsy/.matadSymbols;


(* m-3l-9a *)
masterData["m-3l-9a",-3] = -1*(x^2/3+2/3);

masterData["m-3l-9a",-2] = -1*(3/2+(5 x^2)/6-x^2 HPL[{0},x]);

masterData["m-3l-9a",-1] = -1*(1/3 (5+4 x^2-6 x^2 HPL[{0},x]+6 x^2 HPL[{0,0},x]));

(*masterData["m-3l-9a",0] = unknown["integral: m-3l-9a","epOrder: 0",x];*)

masterData["m-3l-9a",0, "exp1"] = f9aGl;

masterData["m-3l-9a",0,"exp0"] =  f9aAsyN;

masterData["m-3l-9a",0,"exp0-sym"] =  f9aAsy;

masterData["m-3l-9a",0,"exp0-ex"] =  f9aAsy/.matadSymbols;

(* m-3l-8b *)
masterData["m-3l-8b",-3] = x^2+x^4;

masterData["m-3l-8b",-2] = -(1/12)+4 x^2+(15 x^4)/4-3 x^2 HPL[{0},x]-6 x^4 HPL[{0},x];

masterData["m-3l-8b",-1] = 1/8 (-5+80 x^2+65 x^4-96 x^2 HPL[{0},x]-180 x^4 HPL[{0},x]+48 x^2 HPL[{0,0},x]+288 x^4 HPL[{0,0},x]);

(*masterData["m-3l-8b",0] = unknown["integral: m-3l-8b","epOrder: 0",x];*)

masterData["m-3l-8b",0,"exp1"] = f8bGl;

masterData["m-3l-8b",0,"exp0"] =  f8bAsyN;

masterData["m-3l-8b",0,"exp0-sym"] =  f8bAsy;

masterData["m-3l-8b",0,"exp0-ex"] =  f8bAsy/.matadSymbols;

(* m-3l-9b *)
masterData["m-3l-9b",-3] = -x^2;

masterData["m-3l-9b",-2] = -1*(-(1/6)+(5 x^2)/2-3 x^2 HPL[{0},x]);

masterData["m-3l-9b",-1] = -1*(-1+4 x^2-6 x^2 HPL[{0},x]+6 x^2 HPL[{0,0},x]);

(*masterData["m-3l-9b",0] = unknown["integral: m-3l-9b","epOrder: 0",x];*)

masterData["m-3l-9b",0,"exp1"] = f9bGl;

masterData["m-3l-9b",0,"exp0"] =  f9bAsyN;

masterData["m-3l-9b",0,"exp0-sym"] =  f9bAsy;

masterData["m-3l-9b",0,"exp0-ex"] =  f9bAsy/.matadSymbols;

(* ::Subsection:: *)
(*master 2l-2*)


masterData["m-2l-2",-3]=0;

masterData["m-2l-2",-2]=x^2;

masterData["m-2l-2",-1]=-2 x^2 (-1+HPL[{0},x]);

masterData["m-2l-2",0]=x^2 (3-4 HPL[{0},x]+4 HPL[{0,0},x]);

masterData["m-2l-2",1]=2 x^2 (2-3 HPL[{0},x]+4 HPL[{0,0},x]-4 HPL[{0,0,0},x]);

masterData["m-2l-2",2]=x^2 (5-8 HPL[{0},x]+12 HPL[{0,0},x]-16 HPL[{0,0,0},x]+16 HPL[{0,0,0,0},x]);

masterData["m-2l-2",3]=2 x^2 (3-5 HPL[{0},x]+8 HPL[{0,0},x]-12 HPL[{0,0,0},x]+16 HPL[{0,0,0,0},x]-16 HPL[{0,0,0,0,0},x]);


(* ::Subsection:: *)
(*master 3l-5a*)


masterData["m-3l-5a",-3]=-1*(x^2);

masterData["m-3l-5a",-2]=-1*(3 x^2-2 x^2 HPL[{0},x]);

masterData["m-3l-5a",-1]=2 (-3 x^2+3 x^2 HPL[{0},x]-2 x^2 HPL[{0,0},x]);

masterData["m-3l-5a",0]=2 (-5 x^2+6 x^2 HPL[{0},x]-6 x^2 HPL[{0,0},x]+4 x^2 HPL[{0,0,0},x]);

masterData["m-3l-5a",1]=-1*(15 x^2-20 x^2 HPL[{0},x]+24 x^2 HPL[{0,0},x]-24 x^2 HPL[{0,0,0},x]+16 x^2 HPL[{0,0,0,0},x]);

masterData["m-3l-5a",2]=-1*(21 x^2-30 x^2 HPL[{0},x]+40 x^2 HPL[{0,0},x]-48 x^2 HPL[{0,0,0},x]+48 x^2 HPL[{0,0,0,0},x]-32 x^2 HPL[{0,0,0,0,0},x]);

masterData["m-3l-5a",3]=-1*(-2 (-14 x^2+21 x^2 HPL[{0},x]-30 x^2 HPL[{0,0},x]+40 x^2 HPL[{0,0,0},x]-48 x^2 HPL[{0,0,0,0},x]+48 x^2 HPL[{0,0,0,0,0},x]-32 x^2 HPL[{0,0,0,0,0,0},x]));


(* ::Subsection:: *)
(*master 3l-5b*)


masterData["m-3l-5b",-3]=-x^4;

masterData["m-3l-5b",-2]=-3 x^4+4 x^4 HPL[{0},x];

masterData["m-3l-5b",-1]=2 (-3 x^4+6 x^4 HPL[{0},x]-8 x^4 HPL[{0,0},x]);

masterData["m-3l-5b",0]=2 (-5 x^4+12 x^4 HPL[{0},x]-24 x^4 HPL[{0,0},x]+32 x^4 HPL[{0,0,0},x]);

masterData["m-3l-5b",1]=-1*(15 x^4-40 x^4 HPL[{0},x]+96 x^4 HPL[{0,0},x]-192 x^4 HPL[{0,0,0},x]+256 x^4 HPL[{0,0,0,0},x]);

masterData["m-3l-5b",2]=-1*(21 x^4-60 x^4 HPL[{0},x]+160 x^4 HPL[{0,0},x]-384 x^4 HPL[{0,0,0},x]+768 x^4 HPL[{0,0,0,0},x]-1024 x^4 HPL[{0,0,0,0,0},x]);

masterData["m-3l-5b",3]=4 (-7 x^4+21 x^4 HPL[{0},x]-60 x^4 HPL[{0,0},x]+160 x^4 HPL[{0,0,0},x]-384 x^4 HPL[{0,0,0,0},x]+768 x^4 HPL[{0,0,0,0,0},x]-1024 x^4 HPL[{0,0,0,0,0,0},x]);


(* ::Subsection:: *)
(*master 3l-6a*)


masterData["m-3l-6a",-3]=1/2 (1+x^2);

masterData["m-3l-6a",-2]=-2 (-1-x^2+x^2 HPL[{0},x]);

masterData["m-3l-6a",-1]=1/6 (33+\[Pi]^2+33 x^2-\[Pi]^2 x^2-48 x^2 HPL[{0},x]-12 HPL[{-1,0},x]+12 x^2 HPL[{-1,0},x]+24 x^2 HPL[{0,0},x]+12 HPL[{1,0},x]-12 x^2 HPL[{1,0},x]);

masterData["m-3l-6a",0]=1/3 (39+2 \[Pi]^2+39 x^2-2 \[Pi]^2 x^2-\[Pi]^2 HPL[{-1},x]+\[Pi]^2 x^2 HPL[{-1},x]-66 x^2 HPL[{0},x]+\[Pi]^2 HPL[{1},x]-\[Pi]^2 x^2 HPL[{1},x]-24 HPL[{-1,0},x]+24 x^2 HPL[{-1,0},x]+48 x^2 HPL[{0,0},x]+24 HPL[{1,0},x]-24 x^2 HPL[{1,0},x]+12 HPL[{-1,-1,0},x]-12 x^2 HPL[{-1,-1,0},x]+12 HPL[{-1,0,0},x]-12 x^2 HPL[{-1,0,0},x]-12 HPL[{-1,1,0},x]+12 x^2 HPL[{-1,1,0},x]-24 x^2 HPL[{0,0,0},x]-12 HPL[{1,-1,0},x]+12 x^2 HPL[{1,-1,0},x]-12 HPL[{1,0,0},x]+12 x^2 HPL[{1,0,0},x]+12 HPL[{1,1,0},x]-12 x^2 HPL[{1,1,0},x]-3 Zeta[3]+3 x^2 Zeta[3]);

masterData["m-3l-6a",1]=1/60 (1710+110 \[Pi]^2+3 \[Pi]^4+1710 x^2-110 \[Pi]^2 x^2-3 \[Pi]^4 x^2-80 \[Pi]^2 HPL[{-1},x]+80 \[Pi]^2 x^2 HPL[{-1},x]-3120 x^2 HPL[{0},x]+80 \[Pi]^2 HPL[{1},x]-80 \[Pi]^2 x^2 HPL[{1},x]+40 \[Pi]^2 HPL[{-1,-1},x]-40 \[Pi]^2 x^2 HPL[{-1,-1},x]-1320 HPL[{-1,0},x]+1320 x^2 HPL[{-1,0},x]-40 \[Pi]^2 HPL[{-1,1},x]+40 \[Pi]^2 x^2 HPL[{-1,1},x]+2640 x^2 HPL[{0,0},x]-40 \[Pi]^2 HPL[{1,-1},x]+40 \[Pi]^2 x^2 HPL[{1,-1},x]+1320 HPL[{1,0},x]-1320 x^2 HPL[{1,0},x]+40 \[Pi]^2 HPL[{1,1},x]-40 \[Pi]^2 x^2 HPL[{1,1},x]+960 HPL[{-1,-1,0},x]-960 x^2 HPL[{-1,-1,0},x]+960 HPL[{-1,0,0},x]-960 x^2 HPL[{-1,0,0},x]-960 HPL[{-1,1,0},x]+960 x^2 HPL[{-1,1,0},x]-1920 x^2 HPL[{0,0,0},x]-960 HPL[{1,-1,0},x]+960 x^2 HPL[{1,-1,0},x]-960 HPL[{1,0,0},x]+960 x^2 HPL[{1,0,0},x]+960 HPL[{1,1,0},x]-960 x^2 HPL[{1,1,0},x]-480 HPL[{-1,-1,-1,0},x]+480 x^2 HPL[{-1,-1,-1,0},x]-480 HPL[{-1,-1,0,0},x]+480 x^2 HPL[{-1,-1,0,0},x]+480 HPL[{-1,-1,1,0},x]-480 x^2 HPL[{-1,-1,1,0},x]-480 HPL[{-1,0,0,0},x]+480 x^2 HPL[{-1,0,0,0},x]+480 HPL[{-1,1,-1,0},x]-480 x^2 HPL[{-1,1,-1,0},x]+480 HPL[{-1,1,0,0},x]-480 x^2 HPL[{-1,1,0,0},x]-480 HPL[{-1,1,1,0},x]+480 x^2 HPL[{-1,1,1,0},x]+960 x^2 HPL[{0,0,0,0},x]+480 HPL[{1,-1,-1,0},x]-480 x^2 HPL[{1,-1,-1,0},x]+480 HPL[{1,-1,0,0},x]-480 x^2 HPL[{1,-1,0,0},x]-480 HPL[{1,-1,1,0},x]+480 x^2 HPL[{1,-1,1,0},x]+480 HPL[{1,0,0,0},x]-480 x^2 HPL[{1,0,0,0},x]-480 HPL[{1,1,-1,0},x]+480 x^2 HPL[{1,1,-1,0},x]-480 HPL[{1,1,0,0},x]+480 x^2 HPL[{1,1,0,0},x]+480 HPL[{1,1,1,0},x]-480 x^2 HPL[{1,1,1,0},x]-240 Zeta[3]+240 x^2 Zeta[3]+120 HPL[{-1},x] Zeta[3]-120 x^2 HPL[{-1},x] Zeta[3]-120 HPL[{1},x] Zeta[3]+120 x^2 HPL[{1},x] Zeta[3]);

masterData["m-3l-6a",2]=1/30 (1800+130 \[Pi]^2+6 \[Pi]^4+1800 x^2-130 \[Pi]^2 x^2-6 \[Pi]^4 x^2-110 \[Pi]^2 HPL[{-1},x]-3 \[Pi]^4 HPL[{-1},x]+110 \[Pi]^2 x^2 HPL[{-1},x]+3 \[Pi]^4 x^2 HPL[{-1},x]-3420 x^2 HPL[{0},x]+110 \[Pi]^2 HPL[{1},x]+3 \[Pi]^4 HPL[{1},x]-110 \[Pi]^2 x^2 HPL[{1},x]-3 \[Pi]^4 x^2 HPL[{1},x]+80 \[Pi]^2 HPL[{-1,-1},x]-80 \[Pi]^2 x^2 HPL[{-1,-1},x]-1560 HPL[{-1,0},x]+1560 x^2 HPL[{-1,0},x]-80 \[Pi]^2 HPL[{-1,1},x]+80 \[Pi]^2 x^2 HPL[{-1,1},x]+3120 x^2 HPL[{0,0},x]-80 \[Pi]^2 HPL[{1,-1},x]+80 \[Pi]^2 x^2 HPL[{1,-1},x]+1560 HPL[{1,0},x]-1560 x^2 HPL[{1,0},x]+80 \[Pi]^2 HPL[{1,1},x]-80 \[Pi]^2 x^2 HPL[{1,1},x]-40 \[Pi]^2 HPL[{-1,-1,-1},x]+40 \[Pi]^2 x^2 HPL[{-1,-1,-1},x]+1320 HPL[{-1,-1,0},x]-1320 x^2 HPL[{-1,-1,0},x]+40 \[Pi]^2 HPL[{-1,-1,1},x]-40 \[Pi]^2 x^2 HPL[{-1,-1,1},x]+1320 HPL[{-1,0,0},x]-1320 x^2 HPL[{-1,0,0},x]+40 \[Pi]^2 HPL[{-1,1,-1},x]-40 \[Pi]^2 x^2 HPL[{-1,1,-1},x]-1320 HPL[{-1,1,0},x]+1320 x^2 HPL[{-1,1,0},x]-40 \[Pi]^2 HPL[{-1,1,1},x]+40 \[Pi]^2 x^2 HPL[{-1,1,1},x]-2640 x^2 HPL[{0,0,0},x]+40 \[Pi]^2 HPL[{1,-1,-1},x]-40 \[Pi]^2 x^2 HPL[{1,-1,-1},x]-1320 HPL[{1,-1,0},x]+1320 x^2 HPL[{1,-1,0},x]-40 \[Pi]^2 HPL[{1,-1,1},x]+40 \[Pi]^2 x^2 HPL[{1,-1,1},x]-1320 HPL[{1,0,0},x]+1320 x^2 HPL[{1,0,0},x]-40 \[Pi]^2 HPL[{1,1,-1},x]+40 \[Pi]^2 x^2 HPL[{1,1,-1},x]+1320 HPL[{1,1,0},x]-1320 x^2 HPL[{1,1,0},x]+40 \[Pi]^2 HPL[{1,1,1},x]-40 \[Pi]^2 x^2 HPL[{1,1,1},x]-960 HPL[{-1,-1,-1,0},x]+960 x^2 HPL[{-1,-1,-1,0},x]-960 HPL[{-1,-1,0,0},x]+960 x^2 HPL[{-1,-1,0,0},x]+960 HPL[{-1,-1,1,0},x]-960 x^2 HPL[{-1,-1,1,0},x]-960 HPL[{-1,0,0,0},x]+960 x^2 HPL[{-1,0,0,0},x]+960 HPL[{-1,1,-1,0},x]-960 x^2 HPL[{-1,1,-1,0},x]+960 HPL[{-1,1,0,0},x]-960 x^2 HPL[{-1,1,0,0},x]-960 HPL[{-1,1,1,0},x]+960 x^2 HPL[{-1,1,1,0},x]+1920 x^2 HPL[{0,0,0,0},x]+960 HPL[{1,-1,-1,0},x]-960 x^2 HPL[{1,-1,-1,0},x]+960 HPL[{1,-1,0,0},x]-960 x^2 HPL[{1,-1,0,0},x]-960 HPL[{1,-1,1,0},x]+960 x^2 HPL[{1,-1,1,0},x]+960 HPL[{1,0,0,0},x]-960 x^2 HPL[{1,0,0,0},x]-960 HPL[{1,1,-1,0},x]+960 x^2 HPL[{1,1,-1,0},x]-960 HPL[{1,1,0,0},x]+960 x^2 HPL[{1,1,0,0},x]+960 HPL[{1,1,1,0},x]-960 x^2 HPL[{1,1,1,0},x]+480 HPL[{-1,-1,-1,-1,0},x]-480 x^2 HPL[{-1,-1,-1,-1,0},x]+480 HPL[{-1,-1,-1,0,0},x]-480 x^2 HPL[{-1,-1,-1,0,0},x]-480 HPL[{-1,-1,-1,1,0},x]+480 x^2 HPL[{-1,-1,-1,1,0},x]+480 HPL[{-1,-1,0,0,0},x]-480 x^2 HPL[{-1,-1,0,0,0},x]-480 HPL[{-1,-1,1,-1,0},x]+480 x^2 HPL[{-1,-1,1,-1,0},x]-480 HPL[{-1,-1,1,0,0},x]+480 x^2 HPL[{-1,-1,1,0,0},x]+480 HPL[{-1,-1,1,1,0},x]-480 x^2 HPL[{-1,-1,1,1,0},x]+480 HPL[{-1,0,0,0,0},x]-480 x^2 HPL[{-1,0,0,0,0},x]-480 HPL[{-1,1,-1,-1,0},x]+480 x^2 HPL[{-1,1,-1,-1,0},x]-480 HPL[{-1,1,-1,0,0},x]+480 x^2 HPL[{-1,1,-1,0,0},x]+480 HPL[{-1,1,-1,1,0},x]-480 x^2 HPL[{-1,1,-1,1,0},x]-480 HPL[{-1,1,0,0,0},x]+480 x^2 HPL[{-1,1,0,0,0},x]+480 HPL[{-1,1,1,-1,0},x]-480 x^2 HPL[{-1,1,1,-1,0},x]+480 HPL[{-1,1,1,0,0},x]-480 x^2 HPL[{-1,1,1,0,0},x]-480 HPL[{-1,1,1,1,0},x]+480 x^2 HPL[{-1,1,1,1,0},x]-960 x^2 HPL[{0,0,0,0,0},x]-480 HPL[{1,-1,-1,-1,0},x]+480 x^2 HPL[{1,-1,-1,-1,0},x]-480 HPL[{1,-1,-1,0,0},x]+480 x^2 HPL[{1,-1,-1,0,0},x]+480 HPL[{1,-1,-1,1,0},x]-480 x^2 HPL[{1,-1,-1,1,0},x]-480 HPL[{1,-1,0,0,0},x]+480 x^2 HPL[{1,-1,0,0,0},x]+480 HPL[{1,-1,1,-1,0},x]-480 x^2 HPL[{1,-1,1,-1,0},x]+480 HPL[{1,-1,1,0,0},x]-480 x^2 HPL[{1,-1,1,0,0},x]-480 HPL[{1,-1,1,1,0},x]+480 x^2 HPL[{1,-1,1,1,0},x]-480 HPL[{1,0,0,0,0},x]+480 x^2 HPL[{1,0,0,0,0},x]+480 HPL[{1,1,-1,-1,0},x]-480 x^2 HPL[{1,1,-1,-1,0},x]+480 HPL[{1,1,-1,0,0},x]-480 x^2 HPL[{1,1,-1,0,0},x]-480 HPL[{1,1,-1,1,0},x]+480 x^2 HPL[{1,1,-1,1,0},x]+480 HPL[{1,1,0,0,0},x]-480 x^2 HPL[{1,1,0,0,0},x]-480 HPL[{1,1,1,-1,0},x]+480 x^2 HPL[{1,1,1,-1,0},x]-480 HPL[{1,1,1,0,0},x]+480 x^2 HPL[{1,1,1,0,0},x]+480 HPL[{1,1,1,1,0},x]-480 x^2 HPL[{1,1,1,1,0},x]-330 Zeta[3]-10 \[Pi]^2 Zeta[3]+330 x^2 Zeta[3]+10 \[Pi]^2 x^2 Zeta[3]+240 HPL[{-1},x] Zeta[3]-240 x^2 HPL[{-1},x] Zeta[3]-240 HPL[{1},x] Zeta[3]+240 x^2 HPL[{1},x] Zeta[3]-120 HPL[{-1,-1},x] Zeta[3]+120 x^2 HPL[{-1,-1},x] Zeta[3]+120 HPL[{-1,1},x] Zeta[3]-120 x^2 HPL[{-1,1},x] Zeta[3]+120 HPL[{1,-1},x] Zeta[3]-120 x^2 HPL[{1,-1},x] Zeta[3]-120 HPL[{1,1},x] Zeta[3]+120 x^2 HPL[{1,1},x] Zeta[3]-90 Zeta[5]+90 x^2 Zeta[5]);


(* ::Subsection:: *)
(*master 3l-6b*)


masterData["m-3l-6b",-3]=1/2 (x^2+x^4);

masterData["m-3l-6b",-2]=2 x^2+2 x^4-x^2 HPL[{0},x]-3 x^4 HPL[{0},x];

masterData["m-3l-6b",-1]=1/6 (33 x^2+\[Pi]^2 x^2+33 x^4-\[Pi]^2 x^4-24 x^2 HPL[{0},x]-72 x^4 HPL[{0},x]-12 x^2 HPL[{-1,0},x]+12 x^4 HPL[{-1,0},x]+12 x^2 HPL[{0,0},x]+84 x^4 HPL[{0,0},x]+12 x^2 HPL[{1,0},x]-12 x^4 HPL[{1,0},x]);

masterData["m-3l-6b",0] =1/3 (39 x^2+2 \[Pi]^2 x^2+39 x^4-2 \[Pi]^2 x^4-\[Pi]^2 x^2 HPL[{-1},x]+\[Pi]^2 x^4 HPL[{-1},x]-33 x^2 HPL[{0},x]-\[Pi]^2 x^2 HPL[{0},x]-99 x^4 HPL[{0},x]+\[Pi]^2 x^4 HPL[{0},x]+\[Pi]^2 x^2 HPL[{1},x]-\[Pi]^2 x^4 HPL[{1},x]+12 x^2 HPL[{-2,0},x]-12 x^4 HPL[{-2,0},x]-24 x^2 HPL[{-1,0},x]+24 x^4 HPL[{-1,0},x]+24 x^2 HPL[{0,0},x]+168 x^4 HPL[{0,0},x]+24 x^2 HPL[{1,0},x]-24 x^4 HPL[{1,0},x]-12 x^2 HPL[{2,0},x]+12 x^4 HPL[{2,0},x]+12 x^2 HPL[{-1,-1,0},x]-12 x^4 HPL[{-1,-1,0},x]+36 x^2 HPL[{-1,0,0},x]-36 x^4 HPL[{-1,0,0},x]-12 x^2 HPL[{-1,1,0},x]+12 x^4 HPL[{-1,1,0},x]-12 x^2 HPL[{0,0,0},x]-180 x^4 HPL[{0,0,0},x]-12 x^2 HPL[{1,-1,0},x]+12 x^4 HPL[{1,-1,0},x]-36 x^2 HPL[{1,0,0},x]+36 x^4 HPL[{1,0,0},x]+12 x^2 HPL[{1,1,0},x]-12 x^4 HPL[{1,1,0},x]-3 x^2 Zeta[3]+3 x^4 Zeta[3]);

masterData["m-3l-6b",1]=1/60 (1710 x^2+110 \[Pi]^2 x^2+3 \[Pi]^4 x^2+1710 x^4-110 \[Pi]^2 x^4-3 \[Pi]^4 x^4+40 \[Pi]^2 x^2 HPL[{-2},x]-40 \[Pi]^2 x^4 HPL[{-2},x]-80 \[Pi]^2 x^2 HPL[{-1},x]+80 \[Pi]^2 x^4 HPL[{-1},x]-1560 x^2 HPL[{0},x]-80 \[Pi]^2 x^2 HPL[{0},x]-4680 x^4 HPL[{0},x]+80 \[Pi]^2 x^4 HPL[{0},x]+80 \[Pi]^2 x^2 HPL[{1},x]-80 \[Pi]^2 x^4 HPL[{1},x]-40 \[Pi]^2 x^2 HPL[{2},x]+40 \[Pi]^2 x^4 HPL[{2},x]-480 x^2 HPL[{-3,0},x]+480 x^4 HPL[{-3,0},x]+960 x^2 HPL[{-2,0},x]-960 x^4 HPL[{-2,0},x]+40 \[Pi]^2 x^2 HPL[{-1,-1},x]-40 \[Pi]^2 x^4 HPL[{-1,-1},x]-1320 x^2 HPL[{-1,0},x]+40 \[Pi]^2 x^2 HPL[{-1,0},x]+1320 x^4 HPL[{-1,0},x]-40 \[Pi]^2 x^4 HPL[{-1,0},x]-40 \[Pi]^2 x^2 HPL[{-1,1},x]+40 \[Pi]^2 x^4 HPL[{-1,1},x]+1320 x^2 HPL[{0,0},x]+40 \[Pi]^2 x^2 HPL[{0,0},x]+9240 x^4 HPL[{0,0},x]-40 \[Pi]^2 x^4 HPL[{0,0},x]-40 \[Pi]^2 x^2 HPL[{1,-1},x]+40 \[Pi]^2 x^4 HPL[{1,-1},x]+1320 x^2 HPL[{1,0},x]-40 \[Pi]^2 x^2 HPL[{1,0},x]-1320 x^4 HPL[{1,0},x]+40 \[Pi]^2 x^4 HPL[{1,0},x]+40 \[Pi]^2 x^2 HPL[{1,1},x]-40 \[Pi]^2 x^4 HPL[{1,1},x]-960 x^2 HPL[{2,0},x]+960 x^4 HPL[{2,0},x]+480 x^2 HPL[{3,0},x]-480 x^4 HPL[{3,0},x]-480 x^2 HPL[{-2,-1,0},x]+480 x^4 HPL[{-2,-1,0},x]-1440 x^2 HPL[{-2,0,0},x]+1440 x^4 HPL[{-2,0,0},x]+480 x^2 HPL[{-2,1,0},x]-480 x^4 HPL[{-2,1,0},x]-480 x^2 HPL[{-1,-2,0},x]+480 x^4 HPL[{-1,-2,0},x]+960 x^2 HPL[{-1,-1,0},x]-960 x^4 HPL[{-1,-1,0},x]+2880 x^2 HPL[{-1,0,0},x]-2880 x^4 HPL[{-1,0,0},x]-960 x^2 HPL[{-1,1,0},x]+960 x^4 HPL[{-1,1,0},x]+480 x^2 HPL[{-1,2,0},x]-480 x^4 HPL[{-1,2,0},x]-960 x^2 HPL[{0,0,0},x]-14400 x^4 HPL[{0,0,0},x]+480 x^2 HPL[{1,-2,0},x]-480 x^4 HPL[{1,-2,0},x]-960 x^2 HPL[{1,-1,0},x]+960 x^4 HPL[{1,-1,0},x]-2880 x^2 HPL[{1,0,0},x]+2880 x^4 HPL[{1,0,0},x]+960 x^2 HPL[{1,1,0},x]-960 x^4 HPL[{1,1,0},x]-480 x^2 HPL[{1,2,0},x]+480 x^4 HPL[{1,2,0},x]+480 x^2 HPL[{2,-1,0},x]-480 x^4 HPL[{2,-1,0},x]+1440 x^2 HPL[{2,0,0},x]-1440 x^4 HPL[{2,0,0},x]-480 x^2 HPL[{2,1,0},x]+480 x^4 HPL[{2,1,0},x]-480 x^2 HPL[{-1,-1,-1,0},x]+480 x^4 HPL[{-1,-1,-1,0},x]-1440 x^2 HPL[{-1,-1,0,0},x]+1440 x^4 HPL[{-1,-1,0,0},x]+480 x^2 HPL[{-1,-1,1,0},x]-480 x^4 HPL[{-1,-1,1,0},x]-3360 x^2 HPL[{-1,0,0,0},x]+3360 x^4 HPL[{-1,0,0,0},x]+480 x^2 HPL[{-1,1,-1,0},x]-480 x^4 HPL[{-1,1,-1,0},x]+1440 x^2 HPL[{-1,1,0,0},x]-1440 x^4 HPL[{-1,1,0,0},x]-480 x^2 HPL[{-1,1,1,0},x]+480 x^4 HPL[{-1,1,1,0},x]+480 x^2 HPL[{0,0,0,0},x]+14880 x^4 HPL[{0,0,0,0},x]+480 x^2 HPL[{1,-1,-1,0},x]-480 x^4 HPL[{1,-1,-1,0},x]+1440 x^2 HPL[{1,-1,0,0},x]-1440 x^4 HPL[{1,-1,0,0},x]-480 x^2 HPL[{1,-1,1,0},x]+480 x^4 HPL[{1,-1,1,0},x]+3360 x^2 HPL[{1,0,0,0},x]-3360 x^4 HPL[{1,0,0,0},x]-480 x^2 HPL[{1,1,-1,0},x]+480 x^4 HPL[{1,1,-1,0},x]-1440 x^2 HPL[{1,1,0,0},x]+1440 x^4 HPL[{1,1,0,0},x]+480 x^2 HPL[{1,1,1,0},x]-480 x^4 HPL[{1,1,1,0},x]-240 x^2 Zeta[3]+240 x^4 Zeta[3]+120 x^2 HPL[{-1},x] Zeta[3]-120 x^4 HPL[{-1},x] Zeta[3]+120 x^2 HPL[{0},x] Zeta[3]-120 x^4 HPL[{0},x] Zeta[3]-120 x^2 HPL[{1},x] Zeta[3]+120 x^4 HPL[{1},x] Zeta[3]);

masterData["m-3l-6b",2]=1/30 (1800 x^2+130 \[Pi]^2 x^2+6 \[Pi]^4 x^2+1800 x^4-130 \[Pi]^2 x^4-6 \[Pi]^4 x^4-40 \[Pi]^2 x^2 HPL[{-3},x]+40 \[Pi]^2 x^4 HPL[{-3},x]+80 \[Pi]^2 x^2 HPL[{-2},x]-80 \[Pi]^2 x^4 HPL[{-2},x]-110 \[Pi]^2 x^2 HPL[{-1},x]-3 \[Pi]^4 x^2 HPL[{-1},x]+110 \[Pi]^2 x^4 HPL[{-1},x]+3 \[Pi]^4 x^4 HPL[{-1},x]-1710 x^2 HPL[{0},x]-110 \[Pi]^2 x^2 HPL[{0},x]-3 \[Pi]^4 x^2 HPL[{0},x]-5130 x^4 HPL[{0},x]+110 \[Pi]^2 x^4 HPL[{0},x]+3 \[Pi]^4 x^4 HPL[{0},x]+110 \[Pi]^2 x^2 HPL[{1},x]+3 \[Pi]^4 x^2 HPL[{1},x]-110 \[Pi]^2 x^4 HPL[{1},x]-3 \[Pi]^4 x^4 HPL[{1},x]-80 \[Pi]^2 x^2 HPL[{2},x]+80 \[Pi]^2 x^4 HPL[{2},x]+40 \[Pi]^2 x^2 HPL[{3},x]-40 \[Pi]^2 x^4 HPL[{3},x]+480 x^2 HPL[{-4,0},x]-480 x^4 HPL[{-4,0},x]-960 x^2 HPL[{-3,0},x]+960 x^4 HPL[{-3,0},x]-40 \[Pi]^2 x^2 HPL[{-2,-1},x]+40 \[Pi]^2 x^4 HPL[{-2,-1},x]+1320 x^2 HPL[{-2,0},x]-40 \[Pi]^2 x^2 HPL[{-2,0},x]-1320 x^4 HPL[{-2,0},x]+40 \[Pi]^2 x^4 HPL[{-2,0},x]+40 \[Pi]^2 x^2 HPL[{-2,1},x]-40 \[Pi]^2 x^4 HPL[{-2,1},x]-40 \[Pi]^2 x^2 HPL[{-1,-2},x]+40 \[Pi]^2 x^4 HPL[{-1,-2},x]+80 \[Pi]^2 x^2 HPL[{-1,-1},x]-80 \[Pi]^2 x^4 HPL[{-1,-1},x]-1560 x^2 HPL[{-1,0},x]+80 \[Pi]^2 x^2 HPL[{-1,0},x]+1560 x^4 HPL[{-1,0},x]-80 \[Pi]^2 x^4 HPL[{-1,0},x]-80 \[Pi]^2 x^2 HPL[{-1,1},x]+80 \[Pi]^2 x^4 HPL[{-1,1},x]+40 \[Pi]^2 x^2 HPL[{-1,2},x]-40 \[Pi]^2 x^4 HPL[{-1,2},x]+1560 x^2 HPL[{0,0},x]+80 \[Pi]^2 x^2 HPL[{0,0},x]+10920 x^4 HPL[{0,0},x]-80 \[Pi]^2 x^4 HPL[{0,0},x]+40 \[Pi]^2 x^2 HPL[{1,-2},x]-40 \[Pi]^2 x^4 HPL[{1,-2},x]-80 \[Pi]^2 x^2 HPL[{1,-1},x]+80 \[Pi]^2 x^4 HPL[{1,-1},x]+1560 x^2 HPL[{1,0},x]-80 \[Pi]^2 x^2 HPL[{1,0},x]-1560 x^4 HPL[{1,0},x]+80 \[Pi]^2 x^4 HPL[{1,0},x]+80 \[Pi]^2 x^2 HPL[{1,1},x]-80 \[Pi]^2 x^4 HPL[{1,1},x]-40 \[Pi]^2 x^2 HPL[{1,2},x]+40 \[Pi]^2 x^4 HPL[{1,2},x]+40 \[Pi]^2 x^2 HPL[{2,-1},x]-40 \[Pi]^2 x^4 HPL[{2,-1},x]-1320 x^2 HPL[{2,0},x]+40 \[Pi]^2 x^2 HPL[{2,0},x]+1320 x^4 HPL[{2,0},x]-40 \[Pi]^2 x^4 HPL[{2,0},x]-40 \[Pi]^2 x^2 HPL[{2,1},x]+40 \[Pi]^2 x^4 HPL[{2,1},x]+960 x^2 HPL[{3,0},x]-960 x^4 HPL[{3,0},x]-480 x^2 HPL[{4,0},x]+480 x^4 HPL[{4,0},x]+480 x^2 HPL[{-3,-1,0},x]-480 x^4 HPL[{-3,-1,0},x]+1440 x^2 HPL[{-3,0,0},x]-1440 x^4 HPL[{-3,0,0},x]-480 x^2 HPL[{-3,1,0},x]+480 x^4 HPL[{-3,1,0},x]+480 x^2 HPL[{-2,-2,0},x]-480 x^4 HPL[{-2,-2,0},x]-960 x^2 HPL[{-2,-1,0},x]+960 x^4 HPL[{-2,-1,0},x]-2880 x^2 HPL[{-2,0,0},x]+2880 x^4 HPL[{-2,0,0},x]+960 x^2 HPL[{-2,1,0},x]-960 x^4 HPL[{-2,1,0},x]-480 x^2 HPL[{-2,2,0},x]+480 x^4 HPL[{-2,2,0},x]+480 x^2 HPL[{-1,-3,0},x]-480 x^4 HPL[{-1,-3,0},x]-960 x^2 HPL[{-1,-2,0},x]+960 x^4 HPL[{-1,-2,0},x]-40 \[Pi]^2 x^2 HPL[{-1,-1,-1},x]+40 \[Pi]^2 x^4 HPL[{-1,-1,-1},x]+1320 x^2 HPL[{-1,-1,0},x]-40 \[Pi]^2 x^2 HPL[{-1,-1,0},x]-1320 x^4 HPL[{-1,-1,0},x]+40 \[Pi]^2 x^4 HPL[{-1,-1,0},x]+40 \[Pi]^2 x^2 HPL[{-1,-1,1},x]-40 \[Pi]^2 x^4 HPL[{-1,-1,1},x]+3960 x^2 HPL[{-1,0,0},x]-40 \[Pi]^2 x^2 HPL[{-1,0,0},x]-3960 x^4 HPL[{-1,0,0},x]+40 \[Pi]^2 x^4 HPL[{-1,0,0},x]+40 \[Pi]^2 x^2 HPL[{-1,1,-1},x]-40 \[Pi]^2 x^4 HPL[{-1,1,-1},x]-1320 x^2 HPL[{-1,1,0},x]+40 \[Pi]^2 x^2 HPL[{-1,1,0},x]+1320 x^4 HPL[{-1,1,0},x]-40 \[Pi]^2 x^4 HPL[{-1,1,0},x]-40 \[Pi]^2 x^2 HPL[{-1,1,1},x]+40 \[Pi]^2 x^4 HPL[{-1,1,1},x]+960 x^2 HPL[{-1,2,0},x]-960 x^4 HPL[{-1,2,0},x]-480 x^2 HPL[{-1,3,0},x]+480 x^4 HPL[{-1,3,0},x]-1320 x^2 HPL[{0,0,0},x]-40 \[Pi]^2 x^2 HPL[{0,0,0},x]-19800 x^4 HPL[{0,0,0},x]+40 \[Pi]^2 x^4 HPL[{0,0,0},x]-480 x^2 HPL[{1,-3,0},x]+480 x^4 HPL[{1,-3,0},x]+960 x^2 HPL[{1,-2,0},x]-960 x^4 HPL[{1,-2,0},x]+40 \[Pi]^2 x^2 HPL[{1,-1,-1},x]-40 \[Pi]^2 x^4 HPL[{1,-1,-1},x]-1320 x^2 HPL[{1,-1,0},x]+40 \[Pi]^2 x^2 HPL[{1,-1,0},x]+1320 x^4 HPL[{1,-1,0},x]-40 \[Pi]^2 x^4 HPL[{1,-1,0},x]-40 \[Pi]^2 x^2 HPL[{1,-1,1},x]+40 \[Pi]^2 x^4 HPL[{1,-1,1},x]-3960 x^2 HPL[{1,0,0},x]+40 \[Pi]^2 x^2 HPL[{1,0,0},x]+3960 x^4 HPL[{1,0,0},x]-40 \[Pi]^2 x^4 HPL[{1,0,0},x]-40 \[Pi]^2 x^2 HPL[{1,1,-1},x]+40 \[Pi]^2 x^4 HPL[{1,1,-1},x]+1320 x^2 HPL[{1,1,0},x]-40 \[Pi]^2 x^2 HPL[{1,1,0},x]-1320 x^4 HPL[{1,1,0},x]+40 \[Pi]^2 x^4 HPL[{1,1,0},x]+40 \[Pi]^2 x^2 HPL[{1,1,1},x]-40 \[Pi]^2 x^4 HPL[{1,1,1},x]-960 x^2 HPL[{1,2,0},x]+960 x^4 HPL[{1,2,0},x]+480 x^2 HPL[{1,3,0},x]-480 x^4 HPL[{1,3,0},x]-480 x^2 HPL[{2,-2,0},x]+480 x^4 HPL[{2,-2,0},x]+960 x^2 HPL[{2,-1,0},x]-960 x^4 HPL[{2,-1,0},x]+2880 x^2 HPL[{2,0,0},x]-2880 x^4 HPL[{2,0,0},x]-960 x^2 HPL[{2,1,0},x]+960 x^4 HPL[{2,1,0},x]+480 x^2 HPL[{2,2,0},x]-480 x^4 HPL[{2,2,0},x]-480 x^2 HPL[{3,-1,0},x]+480 x^4 HPL[{3,-1,0},x]-1440 x^2 HPL[{3,0,0},x]+1440 x^4 HPL[{3,0,0},x]+480 x^2 HPL[{3,1,0},x]-480 x^4 HPL[{3,1,0},x]+480 x^2 HPL[{-2,-1,-1,0},x]-480 x^4 HPL[{-2,-1,-1,0},x]+1440 x^2 HPL[{-2,-1,0,0},x]-1440 x^4 HPL[{-2,-1,0,0},x]-480 x^2 HPL[{-2,-1,1,0},x]+480 x^4 HPL[{-2,-1,1,0},x]+3360 x^2 HPL[{-2,0,0,0},x]-3360 x^4 HPL[{-2,0,0,0},x]-480 x^2 HPL[{-2,1,-1,0},x]+480 x^4 HPL[{-2,1,-1,0},x]-1440 x^2 HPL[{-2,1,0,0},x]+1440 x^4 HPL[{-2,1,0,0},x]+480 x^2 HPL[{-2,1,1,0},x]-480 x^4 HPL[{-2,1,1,0},x]+480 x^2 HPL[{-1,-2,-1,0},x]-480 x^4 HPL[{-1,-2,-1,0},x]+1440 x^2 HPL[{-1,-2,0,0},x]-1440 x^4 HPL[{-1,-2,0,0},x]-480 x^2 HPL[{-1,-2,1,0},x]+480 x^4 HPL[{-1,-2,1,0},x]+480 x^2 HPL[{-1,-1,-2,0},x]-480 x^4 HPL[{-1,-1,-2,0},x]-960 x^2 HPL[{-1,-1,-1,0},x]+960 x^4 HPL[{-1,-1,-1,0},x]-2880 x^2 HPL[{-1,-1,0,0},x]+2880 x^4 HPL[{-1,-1,0,0},x]+960 x^2 HPL[{-1,-1,1,0},x]-960 x^4 HPL[{-1,-1,1,0},x]-480 x^2 HPL[{-1,-1,2,0},x]+480 x^4 HPL[{-1,-1,2,0},x]-6720 x^2 HPL[{-1,0,0,0},x]+6720 x^4 HPL[{-1,0,0,0},x]-480 x^2 HPL[{-1,1,-2,0},x]+480 x^4 HPL[{-1,1,-2,0},x]+960 x^2 HPL[{-1,1,-1,0},x]-960 x^4 HPL[{-1,1,-1,0},x]+2880 x^2 HPL[{-1,1,0,0},x]-2880 x^4 HPL[{-1,1,0,0},x]-960 x^2 HPL[{-1,1,1,0},x]+960 x^4 HPL[{-1,1,1,0},x]+480 x^2 HPL[{-1,1,2,0},x]-480 x^4 HPL[{-1,1,2,0},x]-480 x^2 HPL[{-1,2,-1,0},x]+480 x^4 HPL[{-1,2,-1,0},x]-1440 x^2 HPL[{-1,2,0,0},x]+1440 x^4 HPL[{-1,2,0,0},x]+480 x^2 HPL[{-1,2,1,0},x]-480 x^4 HPL[{-1,2,1,0},x]+960 x^2 HPL[{0,0,0,0},x]+29760 x^4 HPL[{0,0,0,0},x]-480 x^2 HPL[{1,-2,-1,0},x]+480 x^4 HPL[{1,-2,-1,0},x]-1440 x^2 HPL[{1,-2,0,0},x]+1440 x^4 HPL[{1,-2,0,0},x]+480 x^2 HPL[{1,-2,1,0},x]-480 x^4 HPL[{1,-2,1,0},x]-480 x^2 HPL[{1,-1,-2,0},x]+480 x^4 HPL[{1,-1,-2,0},x]+960 x^2 HPL[{1,-1,-1,0},x]-960 x^4 HPL[{1,-1,-1,0},x]+2880 x^2 HPL[{1,-1,0,0},x]-2880 x^4 HPL[{1,-1,0,0},x]-960 x^2 HPL[{1,-1,1,0},x]+960 x^4 HPL[{1,-1,1,0},x]+480 x^2 HPL[{1,-1,2,0},x]-480 x^4 HPL[{1,-1,2,0},x]+6720 x^2 HPL[{1,0,0,0},x]-6720 x^4 HPL[{1,0,0,0},x]+480 x^2 HPL[{1,1,-2,0},x]-480 x^4 HPL[{1,1,-2,0},x]-960 x^2 HPL[{1,1,-1,0},x]+960 x^4 HPL[{1,1,-1,0},x]-2880 x^2 HPL[{1,1,0,0},x]+2880 x^4 HPL[{1,1,0,0},x]+960 x^2 HPL[{1,1,1,0},x]-960 x^4 HPL[{1,1,1,0},x]-480 x^2 HPL[{1,1,2,0},x]+480 x^4 HPL[{1,1,2,0},x]+480 x^2 HPL[{1,2,-1,0},x]-480 x^4 HPL[{1,2,-1,0},x]+1440 x^2 HPL[{1,2,0,0},x]-1440 x^4 HPL[{1,2,0,0},x]-480 x^2 HPL[{1,2,1,0},x]+480 x^4 HPL[{1,2,1,0},x]-480 x^2 HPL[{2,-1,-1,0},x]+480 x^4 HPL[{2,-1,-1,0},x]-1440 x^2 HPL[{2,-1,0,0},x]+1440 x^4 HPL[{2,-1,0,0},x]+480 x^2 HPL[{2,-1,1,0},x]-480 x^4 HPL[{2,-1,1,0},x]-3360 x^2 HPL[{2,0,0,0},x]+3360 x^4 HPL[{2,0,0,0},x]+480 x^2 HPL[{2,1,-1,0},x]-480 x^4 HPL[{2,1,-1,0},x]+1440 x^2 HPL[{2,1,0,0},x]-1440 x^4 HPL[{2,1,0,0},x]-480 x^2 HPL[{2,1,1,0},x]+480 x^4 HPL[{2,1,1,0},x]+480 x^2 HPL[{-1,-1,-1,-1,0},x]-480 x^4 HPL[{-1,-1,-1,-1,0},x]+1440 x^2 HPL[{-1,-1,-1,0,0},x]-1440 x^4 HPL[{-1,-1,-1,0,0},x]-480 x^2 HPL[{-1,-1,-1,1,0},x]+480 x^4 HPL[{-1,-1,-1,1,0},x]+3360 x^2 HPL[{-1,-1,0,0,0},x]-3360 x^4 HPL[{-1,-1,0,0,0},x]-480 x^2 HPL[{-1,-1,1,-1,0},x]+480 x^4 HPL[{-1,-1,1,-1,0},x]-1440 x^2 HPL[{-1,-1,1,0,0},x]+1440 x^4 HPL[{-1,-1,1,0,0},x]+480 x^2 HPL[{-1,-1,1,1,0},x]-480 x^4 HPL[{-1,-1,1,1,0},x]+7200 x^2 HPL[{-1,0,0,0,0},x]-7200 x^4 HPL[{-1,0,0,0,0},x]-480 x^2 HPL[{-1,1,-1,-1,0},x]+480 x^4 HPL[{-1,1,-1,-1,0},x]-1440 x^2 HPL[{-1,1,-1,0,0},x]+1440 x^4 HPL[{-1,1,-1,0,0},x]+480 x^2 HPL[{-1,1,-1,1,0},x]-480 x^4 HPL[{-1,1,-1,1,0},x]-3360 x^2 HPL[{-1,1,0,0,0},x]+3360 x^4 HPL[{-1,1,0,0,0},x]+480 x^2 HPL[{-1,1,1,-1,0},x]-480 x^4 HPL[{-1,1,1,-1,0},x]+1440 x^2 HPL[{-1,1,1,0,0},x]-1440 x^4 HPL[{-1,1,1,0,0},x]-480 x^2 HPL[{-1,1,1,1,0},x]+480 x^4 HPL[{-1,1,1,1,0},x]-480 x^2 HPL[{0,0,0,0,0},x]-30240 x^4 HPL[{0,0,0,0,0},x]-480 x^2 HPL[{1,-1,-1,-1,0},x]+480 x^4 HPL[{1,-1,-1,-1,0},x]-1440 x^2 HPL[{1,-1,-1,0,0},x]+1440 x^4 HPL[{1,-1,-1,0,0},x]+480 x^2 HPL[{1,-1,-1,1,0},x]-480 x^4 HPL[{1,-1,-1,1,0},x]-3360 x^2 HPL[{1,-1,0,0,0},x]+3360 x^4 HPL[{1,-1,0,0,0},x]+480 x^2 HPL[{1,-1,1,-1,0},x]-480 x^4 HPL[{1,-1,1,-1,0},x]+1440 x^2 HPL[{1,-1,1,0,0},x]-1440 x^4 HPL[{1,-1,1,0,0},x]-480 x^2 HPL[{1,-1,1,1,0},x]+480 x^4 HPL[{1,-1,1,1,0},x]-7200 x^2 HPL[{1,0,0,0,0},x]+7200 x^4 HPL[{1,0,0,0,0},x]+480 x^2 HPL[{1,1,-1,-1,0},x]-480 x^4 HPL[{1,1,-1,-1,0},x]+1440 x^2 HPL[{1,1,-1,0,0},x]-1440 x^4 HPL[{1,1,-1,0,0},x]-480 x^2 HPL[{1,1,-1,1,0},x]+480 x^4 HPL[{1,1,-1,1,0},x]+3360 x^2 HPL[{1,1,0,0,0},x]-3360 x^4 HPL[{1,1,0,0,0},x]-480 x^2 HPL[{1,1,1,-1,0},x]+480 x^4 HPL[{1,1,1,-1,0},x]-1440 x^2 HPL[{1,1,1,0,0},x]+1440 x^4 HPL[{1,1,1,0,0},x]+480 x^2 HPL[{1,1,1,1,0},x]-480 x^4 HPL[{1,1,1,1,0},x]-330 x^2 Zeta[3]-10 \[Pi]^2 x^2 Zeta[3]+330 x^4 Zeta[3]+10 \[Pi]^2 x^4 Zeta[3]-120 x^2 HPL[{-2},x] Zeta[3]+120 x^4 HPL[{-2},x] Zeta[3]+240 x^2 HPL[{-1},x] Zeta[3]-240 x^4 HPL[{-1},x] Zeta[3]+240 x^2 HPL[{0},x] Zeta[3]-240 x^4 HPL[{0},x] Zeta[3]-240 x^2 HPL[{1},x] Zeta[3]+240 x^4 HPL[{1},x] Zeta[3]+120 x^2 HPL[{2},x] Zeta[3]-120 x^4 HPL[{2},x] Zeta[3]-120 x^2 HPL[{-1,-1},x] Zeta[3]+120 x^4 HPL[{-1,-1},x] Zeta[3]-120 x^2 HPL[{-1,0},x] Zeta[3]+120 x^4 HPL[{-1,0},x] Zeta[3]+120 x^2 HPL[{-1,1},x] Zeta[3]-120 x^4 HPL[{-1,1},x] Zeta[3]-120 x^2 HPL[{0,0},x] Zeta[3]+120 x^4 HPL[{0,0},x] Zeta[3]+120 x^2 HPL[{1,-1},x] Zeta[3]-120 x^4 HPL[{1,-1},x] Zeta[3]+120 x^2 HPL[{1,0},x] Zeta[3]-120 x^4 HPL[{1,0},x] Zeta[3]-120 x^2 HPL[{1,1},x] Zeta[3]+120 x^4 HPL[{1,1},x] Zeta[3]-90 x^2 Zeta[5]+90 x^4 Zeta[5]);



(* ::Subsection:: *)
(*master 2l*)


masterData["m-2l-1", -3] = 0;

masterData["m-2l-1", -2] = -1*(1 + x^2)/2;

masterData["m-2l-1", -1] =-1*((3*(1 + x^2))/2 - 2*x^2*HPL[{0}, x]);

masterData["m-2l-1", 0] = -1*(-6*x^2*HPL[{0}, x] + 2*(-1 + x^2)*HPL[{-1, 0}, x] + 
   (21 + Pi^2 - (-21 + Pi^2)*x^2 + 24*x^2*HPL[{0, 0}, x])/6 - 
   2*(-1 + x^2)*HPL[{1, 0}, x]);

masterData["m-2l-1", 1] =  -1*((2*Pi^2*(-1 + x^2)*HPL[{-1}, x] + 2*Pi^2*HPL[{1}, x] - 
    3*(Pi^2*(-1 + x^2) - 15*(1 + x^2) + 12*HPL[{-1, 0}, x] - 
      12*HPL[{1, 0}, x] - 8*HPL[{-1, -1, 0}, x] - 8*HPL[{-1, 0, 0}, x] + 
      8*HPL[{-1, 1, 0}, x] + 8*HPL[{1, -1, 0}, x] + 8*HPL[{1, 0, 0}, x] - 
      8*HPL[{1, 1, 0}, x] + 2*Zeta[3]) - 
    2*x^2*(42*HPL[{0}, x] + Pi^2*HPL[{1}, x] - 
      3*(6*HPL[{-1, 0}, x] + 12*HPL[{0, 0}, x] - 6*HPL[{1, 0}, x] - 
        4*(HPL[{-1, -1, 0}, x] + HPL[{-1, 0, 0}, x] - HPL[{-1, 1, 0}, x] + 
          2*HPL[{0, 0, 0}, x] - HPL[{1, -1, 0}, x] - HPL[{1, 0, 0}, x] + 
          HPL[{1, 1, 0}, x]) + Zeta[3])))/6);

masterData["m-2l-1", 2] = -1*(-(Pi^2*(70 + 3*Pi^2)*(-1 + x^2))/60 + (31*(1 + x^2))/2 - 
   30*x^2*HPL[{0}, x] + Pi^2*HPL[{1}, x] - Pi^2*x^2*HPL[{1}, x] + 
   (2*Pi^2*HPL[{-1, -1}, x])/3 - (2*Pi^2*x^2*HPL[{-1, -1}, x])/3 - 
   14*HPL[{-1, 0}, x] + 14*x^2*HPL[{-1, 0}, x] - (2*Pi^2*HPL[{-1, 1}, x])/3 + 
   (2*Pi^2*x^2*HPL[{-1, 1}, x])/3 + 28*x^2*HPL[{0, 0}, x] - 
   (2*Pi^2*HPL[{1, -1}, x])/3 + (2*Pi^2*x^2*HPL[{1, -1}, x])/3 + 
   14*HPL[{1, 0}, x] - 14*x^2*HPL[{1, 0}, x] + (2*Pi^2*HPL[{1, 1}, x])/3 - 
   (2*Pi^2*x^2*HPL[{1, 1}, x])/3 + 12*HPL[{-1, -1, 0}, x] - 
   12*x^2*HPL[{-1, -1, 0}, x] + 12*HPL[{-1, 0, 0}, x] - 
   12*x^2*HPL[{-1, 0, 0}, x] - 12*HPL[{-1, 1, 0}, x] + 
   12*x^2*HPL[{-1, 1, 0}, x] - 24*x^2*HPL[{0, 0, 0}, x] - 
   12*HPL[{1, -1, 0}, x] + 12*x^2*HPL[{1, -1, 0}, x] - 12*HPL[{1, 0, 0}, x] + 
   12*x^2*HPL[{1, 0, 0}, x] + 12*HPL[{1, 1, 0}, x] - 
   12*x^2*HPL[{1, 1, 0}, x] - 8*HPL[{-1, -1, -1, 0}, x] + 
   8*x^2*HPL[{-1, -1, -1, 0}, x] - 8*HPL[{-1, -1, 0, 0}, x] + 
   8*x^2*HPL[{-1, -1, 0, 0}, x] + 8*HPL[{-1, -1, 1, 0}, x] - 
   8*x^2*HPL[{-1, -1, 1, 0}, x] - 8*HPL[{-1, 0, 0, 0}, x] + 
   8*x^2*HPL[{-1, 0, 0, 0}, x] + 8*HPL[{-1, 1, -1, 0}, x] - 
   8*x^2*HPL[{-1, 1, -1, 0}, x] + 8*HPL[{-1, 1, 0, 0}, x] - 
   8*x^2*HPL[{-1, 1, 0, 0}, x] - 8*HPL[{-1, 1, 1, 0}, x] + 
   8*x^2*HPL[{-1, 1, 1, 0}, x] + 16*x^2*HPL[{0, 0, 0, 0}, x] + 
   8*HPL[{1, -1, -1, 0}, x] - 8*x^2*HPL[{1, -1, -1, 0}, x] + 
   8*HPL[{1, -1, 0, 0}, x] - 8*x^2*HPL[{1, -1, 0, 0}, x] - 
   8*HPL[{1, -1, 1, 0}, x] + 8*x^2*HPL[{1, -1, 1, 0}, x] + 
   8*HPL[{1, 0, 0, 0}, x] - 8*x^2*HPL[{1, 0, 0, 0}, x] - 
   8*HPL[{1, 1, -1, 0}, x] + 8*x^2*HPL[{1, 1, -1, 0}, x] - 
   8*HPL[{1, 1, 0, 0}, x] + 8*x^2*HPL[{1, 1, 0, 0}, x] + 
   8*HPL[{1, 1, 1, 0}, x] - 8*x^2*HPL[{1, 1, 1, 0}, x] + 
   (-1 + x^2)*HPL[{-1}, x]*(Pi^2 - 2*Zeta[3]) + 
   (-1 + x^2)*(3 + 2*HPL[{1}, x])*Zeta[3]);

masterData["m-2l-1", 3] =  -1*(63/2 + (5*Pi^2)/2 + (3*Pi^4)/20 + (63*x^2)/2 - 
   (5*Pi^2*x^2)/2 - (3*Pi^4*x^2)/20 - 62*x^2*HPL[{0}, x] + 
   (7*Pi^2*HPL[{1}, x])/3 + (Pi^4*HPL[{1}, x])/10 - 
   (7*Pi^2*x^2*HPL[{1}, x])/3 - (Pi^4*x^2*HPL[{1}, x])/10 + 
   2*Pi^2*HPL[{-1, -1}, x] - 2*Pi^2*x^2*HPL[{-1, -1}, x] - 
   30*HPL[{-1, 0}, x] + 30*x^2*HPL[{-1, 0}, x] - 2*Pi^2*HPL[{-1, 1}, x] + 
   2*Pi^2*x^2*HPL[{-1, 1}, x] + 60*x^2*HPL[{0, 0}, x] - 
   2*Pi^2*HPL[{1, -1}, x] + 2*Pi^2*x^2*HPL[{1, -1}, x] + 30*HPL[{1, 0}, x] - 
   30*x^2*HPL[{1, 0}, x] + 2*Pi^2*HPL[{1, 1}, x] - 
   2*Pi^2*x^2*HPL[{1, 1}, x] - (4*Pi^2*HPL[{-1, -1, -1}, x])/3 + 
   (4*Pi^2*x^2*HPL[{-1, -1, -1}, x])/3 + 28*HPL[{-1, -1, 0}, x] - 
   28*x^2*HPL[{-1, -1, 0}, x] + (4*Pi^2*HPL[{-1, -1, 1}, x])/3 - 
   (4*Pi^2*x^2*HPL[{-1, -1, 1}, x])/3 + 28*HPL[{-1, 0, 0}, x] - 
   28*x^2*HPL[{-1, 0, 0}, x] + (4*Pi^2*HPL[{-1, 1, -1}, x])/3 - 
   (4*Pi^2*x^2*HPL[{-1, 1, -1}, x])/3 - 28*HPL[{-1, 1, 0}, x] + 
   28*x^2*HPL[{-1, 1, 0}, x] - (4*Pi^2*HPL[{-1, 1, 1}, x])/3 + 
   (4*Pi^2*x^2*HPL[{-1, 1, 1}, x])/3 - 56*x^2*HPL[{0, 0, 0}, x] + 
   (4*Pi^2*HPL[{1, -1, -1}, x])/3 - (4*Pi^2*x^2*HPL[{1, -1, -1}, x])/3 - 
   28*HPL[{1, -1, 0}, x] + 28*x^2*HPL[{1, -1, 0}, x] - 
   (4*Pi^2*HPL[{1, -1, 1}, x])/3 + (4*Pi^2*x^2*HPL[{1, -1, 1}, x])/3 - 
   28*HPL[{1, 0, 0}, x] + 28*x^2*HPL[{1, 0, 0}, x] - 
   (4*Pi^2*HPL[{1, 1, -1}, x])/3 + (4*Pi^2*x^2*HPL[{1, 1, -1}, x])/3 + 
   28*HPL[{1, 1, 0}, x] - 28*x^2*HPL[{1, 1, 0}, x] + 
   (4*Pi^2*HPL[{1, 1, 1}, x])/3 - (4*Pi^2*x^2*HPL[{1, 1, 1}, x])/3 - 
   24*HPL[{-1, -1, -1, 0}, x] + 24*x^2*HPL[{-1, -1, -1, 0}, x] - 
   24*HPL[{-1, -1, 0, 0}, x] + 24*x^2*HPL[{-1, -1, 0, 0}, x] + 
   24*HPL[{-1, -1, 1, 0}, x] - 24*x^2*HPL[{-1, -1, 1, 0}, x] - 
   24*HPL[{-1, 0, 0, 0}, x] + 24*x^2*HPL[{-1, 0, 0, 0}, x] + 
   24*HPL[{-1, 1, -1, 0}, x] - 24*x^2*HPL[{-1, 1, -1, 0}, x] + 
   24*HPL[{-1, 1, 0, 0}, x] - 24*x^2*HPL[{-1, 1, 0, 0}, x] - 
   24*HPL[{-1, 1, 1, 0}, x] + 24*x^2*HPL[{-1, 1, 1, 0}, x] + 
   48*x^2*HPL[{0, 0, 0, 0}, x] + 24*HPL[{1, -1, -1, 0}, x] - 
   24*x^2*HPL[{1, -1, -1, 0}, x] + 24*HPL[{1, -1, 0, 0}, x] - 
   24*x^2*HPL[{1, -1, 0, 0}, x] - 24*HPL[{1, -1, 1, 0}, x] + 
   24*x^2*HPL[{1, -1, 1, 0}, x] + 24*HPL[{1, 0, 0, 0}, x] - 
   24*x^2*HPL[{1, 0, 0, 0}, x] - 24*HPL[{1, 1, -1, 0}, x] + 
   24*x^2*HPL[{1, 1, -1, 0}, x] - 24*HPL[{1, 1, 0, 0}, x] + 
   24*x^2*HPL[{1, 1, 0, 0}, x] + 24*HPL[{1, 1, 1, 0}, x] - 
   24*x^2*HPL[{1, 1, 1, 0}, x] + 16*HPL[{-1, -1, -1, -1, 0}, x] - 
   16*x^2*HPL[{-1, -1, -1, -1, 0}, x] + 16*HPL[{-1, -1, -1, 0, 0}, x] - 
   16*x^2*HPL[{-1, -1, -1, 0, 0}, x] - 16*HPL[{-1, -1, -1, 1, 0}, x] + 
   16*x^2*HPL[{-1, -1, -1, 1, 0}, x] + 16*HPL[{-1, -1, 0, 0, 0}, x] - 
   16*x^2*HPL[{-1, -1, 0, 0, 0}, x] - 16*HPL[{-1, -1, 1, -1, 0}, x] + 
   16*x^2*HPL[{-1, -1, 1, -1, 0}, x] - 16*HPL[{-1, -1, 1, 0, 0}, x] + 
   16*x^2*HPL[{-1, -1, 1, 0, 0}, x] + 16*HPL[{-1, -1, 1, 1, 0}, x] - 
   16*x^2*HPL[{-1, -1, 1, 1, 0}, x] + 16*HPL[{-1, 0, 0, 0, 0}, x] - 
   16*x^2*HPL[{-1, 0, 0, 0, 0}, x] - 16*HPL[{-1, 1, -1, -1, 0}, x] + 
   16*x^2*HPL[{-1, 1, -1, -1, 0}, x] - 16*HPL[{-1, 1, -1, 0, 0}, x] + 
   16*x^2*HPL[{-1, 1, -1, 0, 0}, x] + 16*HPL[{-1, 1, -1, 1, 0}, x] - 
   16*x^2*HPL[{-1, 1, -1, 1, 0}, x] - 16*HPL[{-1, 1, 0, 0, 0}, x] + 
   16*x^2*HPL[{-1, 1, 0, 0, 0}, x] + 16*HPL[{-1, 1, 1, -1, 0}, x] - 
   16*x^2*HPL[{-1, 1, 1, -1, 0}, x] + 16*HPL[{-1, 1, 1, 0, 0}, x] - 
   16*x^2*HPL[{-1, 1, 1, 0, 0}, x] - 16*HPL[{-1, 1, 1, 1, 0}, x] + 
   16*x^2*HPL[{-1, 1, 1, 1, 0}, x] - 32*x^2*HPL[{0, 0, 0, 0, 0}, x] - 
   16*HPL[{1, -1, -1, -1, 0}, x] + 16*x^2*HPL[{1, -1, -1, -1, 0}, x] - 
   16*HPL[{1, -1, -1, 0, 0}, x] + 16*x^2*HPL[{1, -1, -1, 0, 0}, x] + 
   16*HPL[{1, -1, -1, 1, 0}, x] - 16*x^2*HPL[{1, -1, -1, 1, 0}, x] - 
   16*HPL[{1, -1, 0, 0, 0}, x] + 16*x^2*HPL[{1, -1, 0, 0, 0}, x] + 
   16*HPL[{1, -1, 1, -1, 0}, x] - 16*x^2*HPL[{1, -1, 1, -1, 0}, x] + 
   16*HPL[{1, -1, 1, 0, 0}, x] - 16*x^2*HPL[{1, -1, 1, 0, 0}, x] - 
   16*HPL[{1, -1, 1, 1, 0}, x] + 16*x^2*HPL[{1, -1, 1, 1, 0}, x] - 
   16*HPL[{1, 0, 0, 0, 0}, x] + 16*x^2*HPL[{1, 0, 0, 0, 0}, x] + 
   16*HPL[{1, 1, -1, -1, 0}, x] - 16*x^2*HPL[{1, 1, -1, -1, 0}, x] + 
   16*HPL[{1, 1, -1, 0, 0}, x] - 16*x^2*HPL[{1, 1, -1, 0, 0}, x] - 
   16*HPL[{1, 1, -1, 1, 0}, x] + 16*x^2*HPL[{1, 1, -1, 1, 0}, x] + 
   16*HPL[{1, 1, 0, 0, 0}, x] - 16*x^2*HPL[{1, 1, 0, 0, 0}, x] - 
   16*HPL[{1, 1, 1, -1, 0}, x] + 16*x^2*HPL[{1, 1, 1, -1, 0}, x] - 
   16*HPL[{1, 1, 1, 0, 0}, x] + 16*x^2*HPL[{1, 1, 1, 0, 0}, x] + 
   16*HPL[{1, 1, 1, 1, 0}, x] - 16*x^2*HPL[{1, 1, 1, 1, 0}, x] + 
   ((-1 + x^2)*HPL[{-1}, x]*(70*Pi^2 + 3*Pi^4 - 180*Zeta[3]))/30 + 
   ((-1 + x^2)*(21 + Pi^2 + 18*HPL[{1}, x] + 12*HPL[{-1, -1}, x] - 
      12*HPL[{-1, 1}, x] - 12*HPL[{1, -1}, x] + 12*HPL[{1, 1}, x])*Zeta[3])/
    3 + 3*(-1 + x^2)*Zeta[5]);


(* ::Subsection:: *)
(*master 3l-1*)


masterData["m-3l-1",-3] = (1 + 4*x^2 + x^4)/3;

masterData["m-3l-1", -2] = (7 + 32*x^2 + 7*x^4 - 12*x^2*(2 + x^2)*HPL[{0}, x])/6;
 
masterData["m-3l-1", -1] = (5*(5 + 32*x^2 + 5*x^4))/12 + 
   x^2*(-((16 + 7*x^2)*HPL[{0}, x]) + 4*(2 + 3*x^2)*HPL[{0, 0}, x]);

masterData["m-3l-1", 0] = -5/24 + (70*x^2)/3 - (5*x^4)/24 - 
   (5*x^2*(16 + 5*x^2)*HPL[{0}, x])/2 + 6*x^2*(4 + 7*x^2)*HPL[{0, 0}, x] - 
   8*(-1 + x^2)^2*HPL[{-1, 0, 0}, x] - 8*x^2*(2 + 7*x^2)*HPL[{0, 0, 0}, x] + 
   8*HPL[{1, 0, 0}, x] + 8*x^2*(-2 + x^2)*HPL[{1, 0, 0}, x] + 
   (8*(-1 + x^2)^2*Zeta[3])/3;

masterData["m-3l-1", 1] = -959/48 + (49*x^2)/3 - (959*x^4)/48 - (2*Pi^4*(-1 + x^2)^2)/15 + 
   (5*x^2*(-56 + x^2)*HPL[{0}, x])/4 - 28*HPL[{-1, 0, 0}, x] + 
   28*HPL[{1, 0, 0}, x] + 16*HPL[{-1, -1, 0, 0}, x] + 
   48*HPL[{-1, 0, 0, 0}, x] - 32*HPL[{-1, 1, 0, 0}, x] - 
   32*HPL[{1, -1, 0, 0}, x] - 48*HPL[{1, 0, 0, 0}, x] + 
   16*HPL[{1, 1, 0, 0}, x] + x*(5*x*(4 + 15*x^2)*HPL[{0, 0}, x] + 
     4*((4 + x*(22 + (4 - 7*x)*x))*HPL[{-1, 0, 0}, x] + 4*HPL[{1, 0, 0}, x] + 
       x*(-((4 + 49*x^2)*HPL[{0, 0, 0}, x]) + (-22 + x*(4 + 7*x))*
          HPL[{1, 0, 0}, x] + 4*((-2 + x^2)*HPL[{-1, -1, 0, 0}, x] + 
           3*(-2 + x^2)*HPL[{-1, 0, 0, 0}, x] + 2*(2*HPL[{-1, 1, 0, 0}, x] + 
             HPL[{0, 0, 0, 0}, x] + 2*HPL[{1, -1, 0, 0}, x] + 
             3*HPL[{1, 0, 0, 0}, x] - HPL[{1, 1, 0, 0}, x]) + 
           x^2*(-2*HPL[{-1, 1, 0, 0}, x] + 15*HPL[{0, 0, 0, 0}, x] - 
             2*HPL[{1, -1, 0, 0}, x] - 3*HPL[{1, 0, 0, 0}, x] + 
             HPL[{1, 1, 0, 0}, x]))))) - 
   (4*(-7 + 22*x^2 - 7*x^4 + 6*(-1 + x^2)^2*HPL[{-1}, x] - 
      6*(-1 + x^2)^2*HPL[{1}, x])*Zeta[3])/3;


(* ::Subsection:: *)
(*master 3l-2*)


masterData["m-3l-2", -3] = -1*(2*(1 + 2*x^2 + 2*x^4 + x^6))/3;
 
masterData["m-3l-2", -2] = -1*(19/9 + 5*x^2 + 5*x^4 + (19*x^6)/9 - 
   4*(x^2 + x^4 + x^6)*HPL[{0}, x]);

masterData["m-3l-2", -1] = -1*(19 + 75*x^2 + 75*x^4 + 19*x^6 - 4*x^2*(18 + 27*x^2 + 19*x^4)*HPL[{0}, x] + 
    48*(x^2 + x^4 + 3*x^6)*HPL[{0, 0}, x])/6;

masterData["m-3l-2", 0] = -1*(-101/36 + (99*x^2)/4 + (99*x^4)/4 - (101*x^6)/36 - 
   x^2*(16 + 59*x^2 + 19*x^4)*HPL[{0}, x] + 4*x^2*(2 + 11*x^2 + 19*x^4)*
    HPL[{0, 0}, x] - 16*(-1 + x^2)^2*(1 + x^2)*HPL[{-1, 0, 0}, x] - 
   16*x^2*(1 + x^2 + 7*x^4)*HPL[{0, 0, 0}, x] + 16*HPL[{1, 0, 0}, x] + 
   16*x^2*(-1 - x^2 + x^4)*HPL[{1, 0, 0}, x] + 
   (16*(-1 + x^2)^2*(1 + x^2)*Zeta[3])/3);

masterData["m-3l-2", 1] = -1*(-((1 + x^2)*(5065 - 9440*x^2 + 5065*x^4 + 32*Pi^4*(-1 + x^2)^2))/120 + 
   (x^2*(152 - 1043*x^2 + 101*x^4)*HPL[{0}, x])/6 + 
   (2*x^2*(-124 + 263*x^2 + 171*x^4)*HPL[{0, 0}, x])/3 - 
   (152*HPL[{-1, 0, 0}, x])/3 + 
   (8*x*(12 + x*(27 + x*(-8 + x*(27 + (12 - 19*x)*x))))*HPL[{-1, 0, 0}, x])/
    3 + (152*HPL[{1, 0, 0}, x])/3 + 32*HPL[{-1, -1, 0, 0}, x] + 
   96*HPL[{-1, 0, 0, 0}, x] - 64*HPL[{-1, 1, 0, 0}, x] - 
   64*HPL[{1, -1, 0, 0}, x] - 96*HPL[{1, 0, 0, 0}, x] + 
   32*HPL[{1, 1, 0, 0}, x] - 
   (8*x*(-12*HPL[{1, 0, 0}, x] + x*((-18 + 45*x^2 + 133*x^4)*
         HPL[{0, 0, 0}, x] + (27 + x*(8 + x*(27 - x*(12 + 19*x))))*
         HPL[{1, 0, 0}, x] + 12*(-((-1 - x^2 + x^4)*(HPL[{-1, -1, 0, 0}, x] + 
             3*HPL[{-1, 0, 0, 0}, x] - 2*HPL[{-1, 1, 0, 0}, x])) - 
          (1 + x^2 + 15*x^4)*HPL[{0, 0, 0, 0}, x] + 2*(-1 - x^2 + x^4)*
           HPL[{1, -1, 0, 0}, x] + 3*(-1 - x^2 + x^4)*HPL[{1, 0, 0, 0}, x] + 
          (1 + x^2 - x^4)*HPL[{1, 1, 0, 0}, x]))))/3 - 
   (8*(1 + x^2)*(-19 + 46*x^2 - 19*x^4 + 18*(-1 + x^2)^2*HPL[{-1}, x] - 
      18*(-1 + x^2)^2*HPL[{1}, x])*Zeta[3])/9);


(* ::Subsection:: *)
(*master 3l3*)


masterData["m-3l-3", -3] = x^2/3;
 
masterData["m-3l-3", -2] = (-1 + 16*x^2 - x^4 - 12*x^2*HPL[{0}, x])/12;

masterData["m-3l-3", -1] = (-5*(3 - 16*x^2 + 3*x^4))/24 + 
   (x^2*((-8 + x^2)*HPL[{0}, x] + 4*HPL[{0, 0}, x]))/2;
 
masterData["m-3l-3", 0] = (4*Pi^2*(-1 + x^4) - 5*(29 - 56*x^2 + 29*x^4) + 
    48*HPL[{-1, 0}, x] - 48*HPL[{1, 0}, x] + 
    4*x^2*((-4*(30 + Pi^2) + 45*x^2)*HPL[{0}, x] - 
      12*x^2*(HPL[{-1, 0}, x] + HPL[{0, 0}, x] - HPL[{1, 0}, x]) + 
      8*(6*HPL[{-2, 0}, x] + 12*HPL[{0, 0}, x] - 
        6*(HPL[{2, 0}, x] + HPL[{0, 0, 0}, x]) + Zeta[3])))/48;

masterData["m-3l-3", 1] = (-7*Pi^4*x^2)/90 + (5*Pi^2*(-1 + x^4))/8 - 
   (7*(165 - 56*x^2 + 165*x^4))/96 + (4*Pi^2*x^2*HPL[{-2}, x])/3 - 
   (Pi^2*(-1 + x^4)*HPL[{-1}, x])/3 - (35*x^2*HPL[{0}, x])/2 - 
   (4*Pi^2*x^2*HPL[{0}, x])/3 + (145*x^4*HPL[{0}, x])/8 + 
   (Pi^2*x^4*HPL[{0}, x])/6 - (Pi^2*HPL[{1}, x])/3 + 
   (Pi^2*x^4*HPL[{1}, x])/3 - (4*Pi^2*x^2*HPL[{2}, x])/3 - 
   8*x^2*HPL[{-3, 0}, x] + 16*x^2*HPL[{-2, 0}, x] - 2*x^4*HPL[{-2, 0}, x] + 
   (15*HPL[{-1, 0}, x])/2 - (15*x^4*HPL[{-1, 0}, x])/2 + 
   20*x^2*HPL[{0, 0}, x] + (2*Pi^2*x^2*HPL[{0, 0}, x])/3 - 
   (15*x^4*HPL[{0, 0}, x])/2 - (15*HPL[{1, 0}, x])/2 + 
   (15*x^4*HPL[{1, 0}, x])/2 - 16*x^2*HPL[{2, 0}, x] + 2*x^4*HPL[{2, 0}, x] + 
   8*x^2*HPL[{3, 0}, x] - 16*x^2*HPL[{-2, -1, 0}, x] - 
   8*x^2*HPL[{-2, 0, 0}, x] + 16*x^2*HPL[{-2, 1, 0}, x] - 
   4*HPL[{-1, -1, 0}, x] + 4*x^4*HPL[{-1, -1, 0}, x] - 2*HPL[{-1, 0, 0}, x] + 
   2*x^4*HPL[{-1, 0, 0}, x] + 4*HPL[{-1, 1, 0}, x] - 
   4*x^4*HPL[{-1, 1, 0}, x] - 16*x^2*HPL[{0, 0, 0}, x] + 
   2*x^4*HPL[{0, 0, 0}, x] + 4*HPL[{1, -1, 0}, x] - 
   4*x^4*HPL[{1, -1, 0}, x] + 2*HPL[{1, 0, 0}, x] - 2*x^4*HPL[{1, 0, 0}, x] - 
   4*HPL[{1, 1, 0}, x] + 4*x^4*HPL[{1, 1, 0}, x] + 
   16*x^2*HPL[{2, -1, 0}, x] + 8*x^2*HPL[{2, 0, 0}, x] - 
   16*x^2*HPL[{2, 1, 0}, x] + 8*x^2*HPL[{0, 0, 0, 0}, x] + 
   ((5 + x^2*(16 - 7*x^2 + 12*HPL[{0}, x]))*Zeta[3])/6;

masterData["m-3l-3", 2] = -8281/192 - (553*x^2)/24 - (8281*x^4)/192 + 
   (145*Pi^2*(-1 + x^4))/48 + (Pi^4*(-23 - 112*x^2 + 37*x^4))/360 - 
   (8*Pi^2*x^2*HPL[{-3}, x])/3 + (5*Pi^2*HPL[{-1}, x])/2 - 
   (5*Pi^2*x^4*HPL[{-1}, x])/2 - (49*x^2*HPL[{0}, x])/4 - 
   (10*Pi^2*x^2*HPL[{0}, x])/3 - (Pi^4*x^2*HPL[{0}, x])/10 + 
   (1155*x^4*HPL[{0}, x])/16 + (5*Pi^2*x^4*HPL[{0}, x])/4 - 
   (5*Pi^2*HPL[{1}, x])/2 + (5*Pi^2*x^4*HPL[{1}, x])/2 - 
   (16*Pi^2*x^2*HPL[{2}, x])/3 + (2*Pi^2*x^4*HPL[{2}, x])/3 + 
   (8*Pi^2*x^2*HPL[{3}, x])/3 + 16*x^2*HPL[{-4, 0}, x] - 
   32*x^2*HPL[{-3, 0}, x] + 4*x^4*HPL[{-3, 0}, x] - 
   (16*Pi^2*x^2*HPL[{-2, -1}, x])/3 + 40*x^2*HPL[{-2, 0}, x] + 
   (4*Pi^2*x^2*HPL[{-2, 0}, x])/3 - 15*x^4*HPL[{-2, 0}, x] + 
   (16*Pi^2*x^2*HPL[{-2, 1}, x])/3 - (4*Pi^2*HPL[{-1, -1}, x])/3 + 
   (4*Pi^2*x^4*HPL[{-1, -1}, x])/3 + (145*HPL[{-1, 0}, x])/4 + 
   (Pi^2*HPL[{-1, 0}, x])/3 - (145*x^4*HPL[{-1, 0}, x])/4 - 
   (Pi^2*x^4*HPL[{-1, 0}, x])/3 + (4*Pi^2*HPL[{-1, 1}, x])/3 - 
   (4*Pi^2*x^4*HPL[{-1, 1}, x])/3 + 35*x^2*HPL[{0, 0}, x] + 
   (8*Pi^2*x^2*HPL[{0, 0}, x])/3 - (145*x^4*HPL[{0, 0}, x])/4 - 
   (Pi^2*x^4*HPL[{0, 0}, x])/3 + (4*Pi^2*HPL[{1, -1}, x])/3 - 
   (4*Pi^2*x^4*HPL[{1, -1}, x])/3 - (145*HPL[{1, 0}, x])/4 - 
   (Pi^2*HPL[{1, 0}, x])/3 + (145*x^4*HPL[{1, 0}, x])/4 + 
   (Pi^2*x^4*HPL[{1, 0}, x])/3 - (4*Pi^2*HPL[{1, 1}, x])/3 + 
   (4*Pi^2*x^4*HPL[{1, 1}, x])/3 + (16*Pi^2*x^2*HPL[{2, -1}, x])/3 - 
   40*x^2*HPL[{2, 0}, x] - (4*Pi^2*x^2*HPL[{2, 0}, x])/3 + 
   15*x^4*HPL[{2, 0}, x] - (16*Pi^2*x^2*HPL[{2, 1}, x])/3 + 
   32*x^2*HPL[{3, 0}, x] - 4*x^4*HPL[{3, 0}, x] - 16*x^2*HPL[{4, 0}, x] + 
   32*x^2*HPL[{-3, -1, 0}, x] + 16*x^2*HPL[{-3, 0, 0}, x] - 
   32*x^2*HPL[{-3, 1, 0}, x] - 16*x^2*HPL[{-2, -2, 0}, x] - 
   64*x^2*HPL[{-2, -1, 0}, x] + 8*x^4*HPL[{-2, -1, 0}, x] - 
   32*x^2*HPL[{-2, 0, 0}, x] + 4*x^4*HPL[{-2, 0, 0}, x] + 
   64*x^2*HPL[{-2, 1, 0}, x] - 8*x^4*HPL[{-2, 1, 0}, x] + 
   16*x^2*HPL[{-2, 2, 0}, x] - 4*HPL[{-1, -2, 0}, x] + 
   4*x^4*HPL[{-1, -2, 0}, x] - 30*HPL[{-1, -1, 0}, x] + 
   30*x^4*HPL[{-1, -1, 0}, x] - 15*HPL[{-1, 0, 0}, x] + 
   15*x^4*HPL[{-1, 0, 0}, x] + 30*HPL[{-1, 1, 0}, x] - 
   30*x^4*HPL[{-1, 1, 0}, x] + 4*HPL[{-1, 2, 0}, x] - 
   4*x^4*HPL[{-1, 2, 0}, x] - 40*x^2*HPL[{0, 0, 0}, x] - 
   (4*Pi^2*x^2*HPL[{0, 0, 0}, x])/3 + 15*x^4*HPL[{0, 0, 0}, x] + 
   4*HPL[{1, -2, 0}, x] - 4*x^4*HPL[{1, -2, 0}, x] + 30*HPL[{1, -1, 0}, x] - 
   30*x^4*HPL[{1, -1, 0}, x] + 15*HPL[{1, 0, 0}, x] - 
   15*x^4*HPL[{1, 0, 0}, x] - 30*HPL[{1, 1, 0}, x] + 
   30*x^4*HPL[{1, 1, 0}, x] - 4*HPL[{1, 2, 0}, x] + 4*x^4*HPL[{1, 2, 0}, x] + 
   16*x^2*HPL[{2, -2, 0}, x] + 64*x^2*HPL[{2, -1, 0}, x] - 
   8*x^4*HPL[{2, -1, 0}, x] + 32*x^2*HPL[{2, 0, 0}, x] - 
   4*x^4*HPL[{2, 0, 0}, x] - 64*x^2*HPL[{2, 1, 0}, x] + 
   8*x^4*HPL[{2, 1, 0}, x] - 16*x^2*HPL[{2, 2, 0}, x] - 
   32*x^2*HPL[{3, -1, 0}, x] - 16*x^2*HPL[{3, 0, 0}, x] + 
   32*x^2*HPL[{3, 1, 0}, x] + 64*x^2*HPL[{-2, -1, -1, 0}, x] + 
   32*x^2*HPL[{-2, -1, 0, 0}, x] - 64*x^2*HPL[{-2, -1, 1, 0}, x] + 
   16*x^2*HPL[{-2, 0, 0, 0}, x] - 64*x^2*HPL[{-2, 1, -1, 0}, x] - 
   32*x^2*HPL[{-2, 1, 0, 0}, x] + 64*x^2*HPL[{-2, 1, 1, 0}, x] + 
   16*HPL[{-1, -1, -1, 0}, x] - 16*x^4*HPL[{-1, -1, -1, 0}, x] + 
   8*HPL[{-1, -1, 0, 0}, x] - 8*x^4*HPL[{-1, -1, 0, 0}, x] - 
   16*HPL[{-1, -1, 1, 0}, x] + 16*x^4*HPL[{-1, -1, 1, 0}, x] + 
   4*HPL[{-1, 0, 0, 0}, x] - 4*x^4*HPL[{-1, 0, 0, 0}, x] - 
   16*HPL[{-1, 1, -1, 0}, x] + 16*x^4*HPL[{-1, 1, -1, 0}, x] - 
   8*HPL[{-1, 1, 0, 0}, x] + 8*x^4*HPL[{-1, 1, 0, 0}, x] + 
   16*HPL[{-1, 1, 1, 0}, x] - 16*x^4*HPL[{-1, 1, 1, 0}, x] + 
   32*x^2*HPL[{0, 0, 0, 0}, x] - 4*x^4*HPL[{0, 0, 0, 0}, x] - 
   16*HPL[{1, -1, -1, 0}, x] + 16*x^4*HPL[{1, -1, -1, 0}, x] - 
   8*HPL[{1, -1, 0, 0}, x] + 8*x^4*HPL[{1, -1, 0, 0}, x] + 
   16*HPL[{1, -1, 1, 0}, x] - 16*x^4*HPL[{1, -1, 1, 0}, x] - 
   4*HPL[{1, 0, 0, 0}, x] + 4*x^4*HPL[{1, 0, 0, 0}, x] + 
   16*HPL[{1, 1, -1, 0}, x] - 16*x^4*HPL[{1, 1, -1, 0}, x] + 
   8*HPL[{1, 1, 0, 0}, x] - 8*x^4*HPL[{1, 1, 0, 0}, x] - 
   16*HPL[{1, 1, 1, 0}, x] + 16*x^4*HPL[{1, 1, 1, 0}, x] - 
   64*x^2*HPL[{2, -1, -1, 0}, x] - 32*x^2*HPL[{2, -1, 0, 0}, x] + 
   64*x^2*HPL[{2, -1, 1, 0}, x] - 16*x^2*HPL[{2, 0, 0, 0}, x] + 
   64*x^2*HPL[{2, 1, -1, 0}, x] + 32*x^2*HPL[{2, 1, 0, 0}, x] - 
   64*x^2*HPL[{2, 1, 1, 0}, x] - 16*x^2*HPL[{0, 0, 0, 0, 0}, x] + 
   (25*Zeta[3])/4 + ((16*(5 + Pi^2)*x^2 - 105*x^4 + 
      48*(-1 + x^4)*HPL[{-1}, x] + 48*HPL[{1}, x] - 
      12*x^2*((-8 + x^2)*HPL[{0}, x] + 4*(x^2*HPL[{1}, x] - 4*HPL[{2}, x] + 
          HPL[{0, 0}, x])))*Zeta[3])/12 - 
   (2*x^2*HPL[{-2}, x]*(Pi^2*(-8 + x^2) + 24*Zeta[3]))/3 + 6*x^2*Zeta[5];


(* ::Subsection:: *)
(*master 3l-4*)


masterData["m-3l-4", -3] = x^2/3;

masterData["m-3l-4", -2] = -1*((2 - 45*x^2 + 6*x^4 - x^6)/36 + x^2*HPL[{0}, x]);

masterData["m-3l-4", -1] = -1*(10 - 69*x^2 + 26*x^4 - 5*x^6 + 
    4*x^2*((24 - 6*x^2 + x^4)*HPL[{0}, x] - 12*HPL[{0, 0}, x]))/24;

masterData["m-3l-4", 0] = -1*((290 - 609*x^2 + 666*x^4 - 145*x^6 + 
    4*Pi^2*(2 + 3*x^2 - 6*x^4 + x^6) - 96*HPL[{-1, 0}, x] + 
    96*HPL[{1, 0}, x] + 12*x^2*((124 + 4*Pi^2 - 82*x^2 + 15*x^4)*
       HPL[{0}, x] - 4*x^2*(-6 + x^2)*(HPL[{-1, 0}, x] + HPL[{0, 0}, x] - 
        HPL[{1, 0}, x]) - 12*(4*HPL[{-2, 0}, x] + HPL[{-1, 0}, x] + 
        8*HPL[{0, 0}, x] - HPL[{1, 0}, x] - 
        4*(HPL[{2, 0}, x] + HPL[{0, 0, 0}, x])) - 8*Zeta[3]))/144);

masterData["m-3l-4", 1] = -1*(385/48 + (47*x^2)/96 + (7*Pi^4*x^2)/90 + (797*x^4)/48 - 
   (385*x^6)/96 + (Pi^2*(30 + 41*x^2 - 86*x^4 + 15*x^6))/72 - 
   (4*Pi^2*x^2*HPL[{-2}, x])/3 - (Pi^2*(2 + 3*x^2 - 6*x^4 + x^6)*
     HPL[{-1}, x])/9 + (61*x^2*HPL[{0}, x])/3 + (4*Pi^2*x^2*HPL[{0}, x])/3 - 
   (367*x^4*HPL[{0}, x])/12 - (Pi^2*x^4*HPL[{0}, x])/3 + 
   (145*x^6*HPL[{0}, x])/24 + (Pi^2*x^6*HPL[{0}, x])/18 + 
   (2*Pi^2*HPL[{1}, x])/9 + (Pi^2*x^2*HPL[{1}, x])/3 - 
   (2*Pi^2*x^4*HPL[{1}, x])/3 + (Pi^2*x^6*HPL[{1}, x])/9 + 
   (4*Pi^2*x^2*HPL[{2}, x])/3 + 8*x^2*HPL[{-3, 0}, x] - 
   16*x^2*HPL[{-2, 0}, x] + 4*x^4*HPL[{-2, 0}, x] - 
   (2*x^6*HPL[{-2, 0}, x])/3 - 5*HPL[{-1, 0}, x] - 
   (41*x^2*HPL[{-1, 0}, x])/6 + (43*x^4*HPL[{-1, 0}, x])/3 - 
   (5*x^6*HPL[{-1, 0}, x])/2 - (62*x^2*HPL[{0, 0}, x])/3 - 
   (2*Pi^2*x^2*HPL[{0, 0}, x])/3 + (41*x^4*HPL[{0, 0}, x])/3 - 
   (5*x^6*HPL[{0, 0}, x])/2 + 5*HPL[{1, 0}, x] + (41*x^2*HPL[{1, 0}, x])/6 - 
   (43*x^4*HPL[{1, 0}, x])/3 + (5*x^6*HPL[{1, 0}, x])/2 + 
   16*x^2*HPL[{2, 0}, x] - 4*x^4*HPL[{2, 0}, x] + (2*x^6*HPL[{2, 0}, x])/3 - 
   8*x^2*HPL[{3, 0}, x] + 16*x^2*HPL[{-2, -1, 0}, x] + 
   8*x^2*HPL[{-2, 0, 0}, x] - 16*x^2*HPL[{-2, 1, 0}, x] + 
   (8*HPL[{-1, -1, 0}, x])/3 + 4*x^2*HPL[{-1, -1, 0}, x] - 
   8*x^4*HPL[{-1, -1, 0}, x] + (4*x^6*HPL[{-1, -1, 0}, x])/3 + 
   (4*HPL[{-1, 0, 0}, x])/3 + 2*x^2*HPL[{-1, 0, 0}, x] - 
   4*x^4*HPL[{-1, 0, 0}, x] + (2*x^6*HPL[{-1, 0, 0}, x])/3 - 
   (8*HPL[{-1, 1, 0}, x])/3 - 4*x^2*HPL[{-1, 1, 0}, x] + 
   8*x^4*HPL[{-1, 1, 0}, x] - (4*x^6*HPL[{-1, 1, 0}, x])/3 + 
   16*x^2*HPL[{0, 0, 0}, x] - 4*x^4*HPL[{0, 0, 0}, x] + 
   (2*x^6*HPL[{0, 0, 0}, x])/3 - (8*HPL[{1, -1, 0}, x])/3 - 
   4*x^2*HPL[{1, -1, 0}, x] + 8*x^4*HPL[{1, -1, 0}, x] - 
   (4*x^6*HPL[{1, -1, 0}, x])/3 - (4*HPL[{1, 0, 0}, x])/3 - 
   2*x^2*HPL[{1, 0, 0}, x] + 4*x^4*HPL[{1, 0, 0}, x] - 
   (2*x^6*HPL[{1, 0, 0}, x])/3 + (8*HPL[{1, 1, 0}, x])/3 + 
   4*x^2*HPL[{1, 1, 0}, x] - 8*x^4*HPL[{1, 1, 0}, x] + 
   (4*x^6*HPL[{1, 1, 0}, x])/3 - 16*x^2*HPL[{2, -1, 0}, x] - 
   8*x^2*HPL[{2, 0, 0}, x] + 16*x^2*HPL[{2, 1, 0}, x] - 
   8*x^2*HPL[{0, 0, 0, 0}, x] - 
   ((10 + 7*x^2*(-3 + x^2)^2 + 36*x^2*HPL[{0}, x])*Zeta[3])/18);

masterData["m-3l-4", 2] = -1*(8281/288 + (6653*x^2)/192 + (5255*x^4)/96 - 
   (8281*x^6)/576 + (Pi^2*(290 + 367*x^2 - 802*x^4 + 145*x^6))/144 + 
   (Pi^4*(46 + x^2*(405 + 37*x^2*(-6 + x^2))))/1080 + 
   (8*Pi^2*x^2*HPL[{-3}, x])/3 - (16*Pi^2*x^2*HPL[{-2}, x])/3 + 
   (4*Pi^2*x^4*HPL[{-2}, x])/3 - (2*Pi^2*x^6*HPL[{-2}, x])/9 - 
   (5*Pi^2*HPL[{-1}, x])/3 - (41*Pi^2*x^2*HPL[{-1}, x])/18 + 
   (43*Pi^2*x^4*HPL[{-1}, x])/9 - (5*Pi^2*x^6*HPL[{-1}, x])/6 + 
   (163*x^2*HPL[{0}, x])/6 + (31*Pi^2*x^2*HPL[{0}, x])/9 + 
   (Pi^4*x^2*HPL[{0}, x])/10 - (2749*x^4*HPL[{0}, x])/24 - 
   (41*Pi^2*x^4*HPL[{0}, x])/18 + (385*x^6*HPL[{0}, x])/16 + 
   (5*Pi^2*x^6*HPL[{0}, x])/12 + (5*Pi^2*HPL[{1}, x])/3 + 
   (41*Pi^2*x^2*HPL[{1}, x])/18 - (43*Pi^2*x^4*HPL[{1}, x])/9 + 
   (5*Pi^2*x^6*HPL[{1}, x])/6 + (16*Pi^2*x^2*HPL[{2}, x])/3 - 
   (4*Pi^2*x^4*HPL[{2}, x])/3 + (2*Pi^2*x^6*HPL[{2}, x])/9 - 
   (8*Pi^2*x^2*HPL[{3}, x])/3 - 16*x^2*HPL[{-4, 0}, x] + 
   32*x^2*HPL[{-3, 0}, x] - 8*x^4*HPL[{-3, 0}, x] + 
   (4*x^6*HPL[{-3, 0}, x])/3 + (16*Pi^2*x^2*HPL[{-2, -1}, x])/3 - 
   (124*x^2*HPL[{-2, 0}, x])/3 - (4*Pi^2*x^2*HPL[{-2, 0}, x])/3 + 
   (82*x^4*HPL[{-2, 0}, x])/3 - 5*x^6*HPL[{-2, 0}, x] - 
   (16*Pi^2*x^2*HPL[{-2, 1}, x])/3 + (8*Pi^2*HPL[{-1, -1}, x])/9 + 
   (4*Pi^2*x^2*HPL[{-1, -1}, x])/3 - (8*Pi^2*x^4*HPL[{-1, -1}, x])/3 + 
   (4*Pi^2*x^6*HPL[{-1, -1}, x])/9 - (145*HPL[{-1, 0}, x])/6 - 
   (2*Pi^2*HPL[{-1, 0}, x])/9 - (367*x^2*HPL[{-1, 0}, x])/12 - 
   (Pi^2*x^2*HPL[{-1, 0}, x])/3 + (401*x^4*HPL[{-1, 0}, x])/6 + 
   (2*Pi^2*x^4*HPL[{-1, 0}, x])/3 - (145*x^6*HPL[{-1, 0}, x])/12 - 
   (Pi^2*x^6*HPL[{-1, 0}, x])/9 - (8*Pi^2*HPL[{-1, 1}, x])/9 - 
   (4*Pi^2*x^2*HPL[{-1, 1}, x])/3 + (8*Pi^2*x^4*HPL[{-1, 1}, x])/3 - 
   (4*Pi^2*x^6*HPL[{-1, 1}, x])/9 - (122*x^2*HPL[{0, 0}, x])/3 - 
   (8*Pi^2*x^2*HPL[{0, 0}, x])/3 + (367*x^4*HPL[{0, 0}, x])/6 + 
   (2*Pi^2*x^4*HPL[{0, 0}, x])/3 - (145*x^6*HPL[{0, 0}, x])/12 - 
   (Pi^2*x^6*HPL[{0, 0}, x])/9 - (8*Pi^2*HPL[{1, -1}, x])/9 - 
   (4*Pi^2*x^2*HPL[{1, -1}, x])/3 + (8*Pi^2*x^4*HPL[{1, -1}, x])/3 - 
   (4*Pi^2*x^6*HPL[{1, -1}, x])/9 + (145*HPL[{1, 0}, x])/6 + 
   (2*Pi^2*HPL[{1, 0}, x])/9 + (367*x^2*HPL[{1, 0}, x])/12 + 
   (Pi^2*x^2*HPL[{1, 0}, x])/3 - (401*x^4*HPL[{1, 0}, x])/6 - 
   (2*Pi^2*x^4*HPL[{1, 0}, x])/3 + (145*x^6*HPL[{1, 0}, x])/12 + 
   (Pi^2*x^6*HPL[{1, 0}, x])/9 + (8*Pi^2*HPL[{1, 1}, x])/9 + 
   (4*Pi^2*x^2*HPL[{1, 1}, x])/3 - (8*Pi^2*x^4*HPL[{1, 1}, x])/3 + 
   (4*Pi^2*x^6*HPL[{1, 1}, x])/9 - (16*Pi^2*x^2*HPL[{2, -1}, x])/3 + 
   (124*x^2*HPL[{2, 0}, x])/3 + (4*Pi^2*x^2*HPL[{2, 0}, x])/3 - 
   (82*x^4*HPL[{2, 0}, x])/3 + 5*x^6*HPL[{2, 0}, x] + 
   (16*Pi^2*x^2*HPL[{2, 1}, x])/3 - 32*x^2*HPL[{3, 0}, x] + 
   8*x^4*HPL[{3, 0}, x] - (4*x^6*HPL[{3, 0}, x])/3 + 16*x^2*HPL[{4, 0}, x] - 
   32*x^2*HPL[{-3, -1, 0}, x] - 16*x^2*HPL[{-3, 0, 0}, x] + 
   32*x^2*HPL[{-3, 1, 0}, x] + 16*x^2*HPL[{-2, -2, 0}, x] + 
   64*x^2*HPL[{-2, -1, 0}, x] - 16*x^4*HPL[{-2, -1, 0}, x] + 
   (8*x^6*HPL[{-2, -1, 0}, x])/3 + 32*x^2*HPL[{-2, 0, 0}, x] - 
   8*x^4*HPL[{-2, 0, 0}, x] + (4*x^6*HPL[{-2, 0, 0}, x])/3 - 
   64*x^2*HPL[{-2, 1, 0}, x] + 16*x^4*HPL[{-2, 1, 0}, x] - 
   (8*x^6*HPL[{-2, 1, 0}, x])/3 - 16*x^2*HPL[{-2, 2, 0}, x] + 
   (8*HPL[{-1, -2, 0}, x])/3 + 4*x^2*HPL[{-1, -2, 0}, x] - 
   8*x^4*HPL[{-1, -2, 0}, x] + (4*x^6*HPL[{-1, -2, 0}, x])/3 + 
   20*HPL[{-1, -1, 0}, x] + (82*x^2*HPL[{-1, -1, 0}, x])/3 - 
   (172*x^4*HPL[{-1, -1, 0}, x])/3 + 10*x^6*HPL[{-1, -1, 0}, x] + 
   10*HPL[{-1, 0, 0}, x] + (41*x^2*HPL[{-1, 0, 0}, x])/3 - 
   (86*x^4*HPL[{-1, 0, 0}, x])/3 + 5*x^6*HPL[{-1, 0, 0}, x] - 
   20*HPL[{-1, 1, 0}, x] - (82*x^2*HPL[{-1, 1, 0}, x])/3 + 
   (172*x^4*HPL[{-1, 1, 0}, x])/3 - 10*x^6*HPL[{-1, 1, 0}, x] - 
   (8*HPL[{-1, 2, 0}, x])/3 - 4*x^2*HPL[{-1, 2, 0}, x] + 
   8*x^4*HPL[{-1, 2, 0}, x] - (4*x^6*HPL[{-1, 2, 0}, x])/3 + 
   (124*x^2*HPL[{0, 0, 0}, x])/3 + (4*Pi^2*x^2*HPL[{0, 0, 0}, x])/3 - 
   (82*x^4*HPL[{0, 0, 0}, x])/3 + 5*x^6*HPL[{0, 0, 0}, x] - 
   (8*HPL[{1, -2, 0}, x])/3 - 4*x^2*HPL[{1, -2, 0}, x] + 
   8*x^4*HPL[{1, -2, 0}, x] - (4*x^6*HPL[{1, -2, 0}, x])/3 - 
   20*HPL[{1, -1, 0}, x] - (82*x^2*HPL[{1, -1, 0}, x])/3 + 
   (172*x^4*HPL[{1, -1, 0}, x])/3 - 10*x^6*HPL[{1, -1, 0}, x] - 
   10*HPL[{1, 0, 0}, x] - (41*x^2*HPL[{1, 0, 0}, x])/3 + 
   (86*x^4*HPL[{1, 0, 0}, x])/3 - 5*x^6*HPL[{1, 0, 0}, x] + 
   20*HPL[{1, 1, 0}, x] + (82*x^2*HPL[{1, 1, 0}, x])/3 - 
   (172*x^4*HPL[{1, 1, 0}, x])/3 + 10*x^6*HPL[{1, 1, 0}, x] + 
   (8*HPL[{1, 2, 0}, x])/3 + 4*x^2*HPL[{1, 2, 0}, x] - 
   8*x^4*HPL[{1, 2, 0}, x] + (4*x^6*HPL[{1, 2, 0}, x])/3 - 
   16*x^2*HPL[{2, -2, 0}, x] - 64*x^2*HPL[{2, -1, 0}, x] + 
   16*x^4*HPL[{2, -1, 0}, x] - (8*x^6*HPL[{2, -1, 0}, x])/3 - 
   32*x^2*HPL[{2, 0, 0}, x] + 8*x^4*HPL[{2, 0, 0}, x] - 
   (4*x^6*HPL[{2, 0, 0}, x])/3 + 64*x^2*HPL[{2, 1, 0}, x] - 
   16*x^4*HPL[{2, 1, 0}, x] + (8*x^6*HPL[{2, 1, 0}, x])/3 + 
   16*x^2*HPL[{2, 2, 0}, x] + 32*x^2*HPL[{3, -1, 0}, x] + 
   16*x^2*HPL[{3, 0, 0}, x] - 32*x^2*HPL[{3, 1, 0}, x] - 
   64*x^2*HPL[{-2, -1, -1, 0}, x] - 32*x^2*HPL[{-2, -1, 0, 0}, x] + 
   64*x^2*HPL[{-2, -1, 1, 0}, x] - 16*x^2*HPL[{-2, 0, 0, 0}, x] + 
   64*x^2*HPL[{-2, 1, -1, 0}, x] + 32*x^2*HPL[{-2, 1, 0, 0}, x] - 
   64*x^2*HPL[{-2, 1, 1, 0}, x] - (32*HPL[{-1, -1, -1, 0}, x])/3 - 
   16*x^2*HPL[{-1, -1, -1, 0}, x] + 32*x^4*HPL[{-1, -1, -1, 0}, x] - 
   (16*x^6*HPL[{-1, -1, -1, 0}, x])/3 - (16*HPL[{-1, -1, 0, 0}, x])/3 - 
   8*x^2*HPL[{-1, -1, 0, 0}, x] + 16*x^4*HPL[{-1, -1, 0, 0}, x] - 
   (8*x^6*HPL[{-1, -1, 0, 0}, x])/3 + (32*HPL[{-1, -1, 1, 0}, x])/3 + 
   16*x^2*HPL[{-1, -1, 1, 0}, x] - 32*x^4*HPL[{-1, -1, 1, 0}, x] + 
   (16*x^6*HPL[{-1, -1, 1, 0}, x])/3 - (8*HPL[{-1, 0, 0, 0}, x])/3 - 
   4*x^2*HPL[{-1, 0, 0, 0}, x] + 8*x^4*HPL[{-1, 0, 0, 0}, x] - 
   (4*x^6*HPL[{-1, 0, 0, 0}, x])/3 + (32*HPL[{-1, 1, -1, 0}, x])/3 + 
   16*x^2*HPL[{-1, 1, -1, 0}, x] - 32*x^4*HPL[{-1, 1, -1, 0}, x] + 
   (16*x^6*HPL[{-1, 1, -1, 0}, x])/3 + (16*HPL[{-1, 1, 0, 0}, x])/3 + 
   8*x^2*HPL[{-1, 1, 0, 0}, x] - 16*x^4*HPL[{-1, 1, 0, 0}, x] + 
   (8*x^6*HPL[{-1, 1, 0, 0}, x])/3 - (32*HPL[{-1, 1, 1, 0}, x])/3 - 
   16*x^2*HPL[{-1, 1, 1, 0}, x] + 32*x^4*HPL[{-1, 1, 1, 0}, x] - 
   (16*x^6*HPL[{-1, 1, 1, 0}, x])/3 - 32*x^2*HPL[{0, 0, 0, 0}, x] + 
   8*x^4*HPL[{0, 0, 0, 0}, x] - (4*x^6*HPL[{0, 0, 0, 0}, x])/3 + 
   (32*HPL[{1, -1, -1, 0}, x])/3 + 16*x^2*HPL[{1, -1, -1, 0}, x] - 
   32*x^4*HPL[{1, -1, -1, 0}, x] + (16*x^6*HPL[{1, -1, -1, 0}, x])/3 + 
   (16*HPL[{1, -1, 0, 0}, x])/3 + 8*x^2*HPL[{1, -1, 0, 0}, x] - 
   16*x^4*HPL[{1, -1, 0, 0}, x] + (8*x^6*HPL[{1, -1, 0, 0}, x])/3 - 
   (32*HPL[{1, -1, 1, 0}, x])/3 - 16*x^2*HPL[{1, -1, 1, 0}, x] + 
   32*x^4*HPL[{1, -1, 1, 0}, x] - (16*x^6*HPL[{1, -1, 1, 0}, x])/3 + 
   (8*HPL[{1, 0, 0, 0}, x])/3 + 4*x^2*HPL[{1, 0, 0, 0}, x] - 
   8*x^4*HPL[{1, 0, 0, 0}, x] + (4*x^6*HPL[{1, 0, 0, 0}, x])/3 - 
   (32*HPL[{1, 1, -1, 0}, x])/3 - 16*x^2*HPL[{1, 1, -1, 0}, x] + 
   32*x^4*HPL[{1, 1, -1, 0}, x] - (16*x^6*HPL[{1, 1, -1, 0}, x])/3 - 
   (16*HPL[{1, 1, 0, 0}, x])/3 - 8*x^2*HPL[{1, 1, 0, 0}, x] + 
   16*x^4*HPL[{1, 1, 0, 0}, x] - (8*x^6*HPL[{1, 1, 0, 0}, x])/3 + 
   (32*HPL[{1, 1, 1, 0}, x])/3 + 16*x^2*HPL[{1, 1, 1, 0}, x] - 
   32*x^4*HPL[{1, 1, 1, 0}, x] + (16*x^6*HPL[{1, 1, 1, 0}, x])/3 + 
   64*x^2*HPL[{2, -1, -1, 0}, x] + 32*x^2*HPL[{2, -1, 0, 0}, x] - 
   64*x^2*HPL[{2, -1, 1, 0}, x] + 16*x^2*HPL[{2, 0, 0, 0}, x] - 
   64*x^2*HPL[{2, 1, -1, 0}, x] - 32*x^2*HPL[{2, 1, 0, 0}, x] + 
   64*x^2*HPL[{2, 1, 1, 0}, x] + 16*x^2*HPL[{0, 0, 0, 0, 0}, x] - 
   ((50 + (151 + 16*Pi^2)*x^2 - 198*x^4 + 35*x^6 - 32*HPL[{-1}, x] + 
      32*HPL[{1}, x] + 4*x^2*(-48*HPL[{-2}, x] - 4*(3 - 6*x^2 + x^4)*
         HPL[{-1}, x] + x^2*(-6 + x^2)*(HPL[{0}, x] + 4*HPL[{1}, x]) + 
        12*(2*HPL[{0}, x] + HPL[{1}, x] + 4*HPL[{2}, x] - HPL[{0, 0}, x])))*
     Zeta[3])/12 - 6*x^2*Zeta[5]);


(* ::Subsection:: *)
(*master 3l-4b*)


masterData["m-3l-4b", -3] = (x^4/3);

masterData["m-3l-4b", -2] = -1*(1/36 (-1+6 x^2-45 x^4+2 x^6+36 x^4 HPL[{0},x]));

masterData["m-3l-4b", -1] = -1*(1/24 (-5+26 x^2-69 x^4+10 x^6+84 x^4 HPL[{0},x]-8 x^6 HPL[{0},x]-48 x^4 HPL[{0,0},x]));

masterData["m-3l-4b", 0] = -1*(1/144 (-145-4 \[Pi]^2+666 x^2+24 \[Pi]^2 x^2-609 x^4-12 \[Pi]^2 x^4+290 x^6-8 \[Pi]^2 x^6+48 x^2 HPL[{0},x]+996 x^4 HPL[{0},x]+48 \[Pi]^2 x^4 HPL[{0},x]-360 x^6 HPL[{0},x]-576 x^4 HPL[{-2,0},x]+48 HPL[{-1,0},x]-288 x^2 HPL[{-1,0},x]+144 x^4 HPL[{-1,0},x]+96 x^6 HPL[{-1,0},x]-1008 x^4 HPL[{0,0},x]+96 x^6 HPL[{0,0},x]-48 HPL[{1,0},x]+288 x^2 HPL[{1,0},x]-144 x^4 HPL[{1,0},x]-96 x^6 HPL[{1,0},x]+576 x^4 HPL[{2,0},x]+576 x^4 HPL[{0,0,0},x]-96 x^4 Zeta[3]));

masterData["m-3l-4b", 1] = -1*(1/1440 (-5775-300 \[Pi]^2+23910 x^2+1720 \[Pi]^2 x^2+705 x^4-820 \[Pi]^2 x^4+112 \[Pi]^4 x^4+11550 x^6-600 \[Pi]^2 x^6-1920 \[Pi]^2 x^4 HPL[{-2},x]+160 \[Pi]^2 HPL[{-1},x]-960 \[Pi]^2 x^2 HPL[{-1},x]+480 \[Pi]^2 x^4 HPL[{-1},x]+320 \[Pi]^2 x^6 HPL[{-1},x]+4080 x^2 HPL[{0},x]+7260 x^4 HPL[{0},x]+1680 \[Pi]^2 x^4 HPL[{0},x]-17400 x^6 HPL[{0},x]-160 \[Pi]^2 x^6 HPL[{0},x]-160 \[Pi]^2 HPL[{1},x]+960 \[Pi]^2 x^2 HPL[{1},x]-480 \[Pi]^2 x^4 HPL[{1},x]-320 \[Pi]^2 x^6 HPL[{1},x]+1920 \[Pi]^2 x^4 HPL[{2},x]+11520 x^4 HPL[{-3,0},x]-20160 x^4 HPL[{-2,0},x]+1920 x^6 HPL[{-2,0},x]+3600 HPL[{-1,0},x]-20640 x^2 HPL[{-1,0},x]+9840 x^4 HPL[{-1,0},x]+7200 x^6 HPL[{-1,0},x]-960 x^2 HPL[{0,0},x]-19920 x^4 HPL[{0,0},x]-960 \[Pi]^2 x^4 HPL[{0,0},x]+7200 x^6 HPL[{0,0},x]-3600 HPL[{1,0},x]+20640 x^2 HPL[{1,0},x]-9840 x^4 HPL[{1,0},x]-7200 x^6 HPL[{1,0},x]+20160 x^4 HPL[{2,0},x]-1920 x^6 HPL[{2,0},x]-11520 x^4 HPL[{3,0},x]+23040 x^4 HPL[{-2,-1,0},x]+11520 x^4 HPL[{-2,0,0},x]-23040 x^4 HPL[{-2,1,0},x]-1920 HPL[{-1,-1,0},x]+11520 x^2 HPL[{-1,-1,0},x]-5760 x^4 HPL[{-1,-1,0},x]-3840 x^6 HPL[{-1,-1,0},x]-960 HPL[{-1,0,0},x]+5760 x^2 HPL[{-1,0,0},x]-2880 x^4 HPL[{-1,0,0},x]-1920 x^6 HPL[{-1,0,0},x]+1920 HPL[{-1,1,0},x]-11520 x^2 HPL[{-1,1,0},x]+5760 x^4 HPL[{-1,1,0},x]+3840 x^6 HPL[{-1,1,0},x]+20160 x^4 HPL[{0,0,0},x]-1920 x^6 HPL[{0,0,0},x]+1920 HPL[{1,-1,0},x]-11520 x^2 HPL[{1,-1,0},x]+5760 x^4 HPL[{1,-1,0},x]+3840 x^6 HPL[{1,-1,0},x]+960 HPL[{1,0,0},x]-5760 x^2 HPL[{1,0,0},x]+2880 x^4 HPL[{1,0,0},x]+1920 x^6 HPL[{1,0,0},x]-1920 HPL[{1,1,0},x]+11520 x^2 HPL[{1,1,0},x]-5760 x^4 HPL[{1,1,0},x]-3840 x^6 HPL[{1,1,0},x]-23040 x^4 HPL[{2,-1,0},x]-11520 x^4 HPL[{2,0,0},x]+23040 x^4 HPL[{2,1,0},x]-11520 x^4 HPL[{0,0,0,0},x]+400 Zeta[3]-2400 x^2 Zeta[3]-2160 x^4 Zeta[3]+1120 x^6 Zeta[3]-2880 x^4 HPL[{0},x] Zeta[3]));

masterData["m-3l-4b", 2] = -1*(1/8640 (-124215-8700 \[Pi]^2-184 \[Pi]^4+472950 x^2+48120 \[Pi]^2 x^2+1104 \[Pi]^4 x^2+299385 x^4-22020 \[Pi]^2 x^4+1800 \[Pi]^4 x^4+248430 x^6-17400 \[Pi]^2 x^6-592 \[Pi]^4 x^6+23040 \[Pi]^2 x^4 HPL[{-3},x]-40320 \[Pi]^2 x^4 HPL[{-2},x]+3840 \[Pi]^2 x^6 HPL[{-2},x]+7200 \[Pi]^2 HPL[{-1},x]-41280 \[Pi]^2 x^2 HPL[{-1},x]+19680 \[Pi]^2 x^4 HPL[{-1},x]+14400 \[Pi]^2 x^6 HPL[{-1},x]+128880 x^2 HPL[{0},x]+960 \[Pi]^2 x^2 HPL[{0},x]-260100 x^4 HPL[{0},x]+19920 \[Pi]^2 x^4 HPL[{0},x]+864 \[Pi]^4 x^4 HPL[{0},x]-415800 x^6 HPL[{0},x]-7200 \[Pi]^2 x^6 HPL[{0},x]-7200 \[Pi]^2 HPL[{1},x]+41280 \[Pi]^2 x^2 HPL[{1},x]-19680 \[Pi]^2 x^4 HPL[{1},x]-14400 \[Pi]^2 x^6 HPL[{1},x]+40320 \[Pi]^2 x^4 HPL[{2},x]-3840 \[Pi]^2 x^6 HPL[{2},x]-23040 \[Pi]^2 x^4 HPL[{3},x]-138240 x^4 HPL[{-4,0},x]+241920 x^4 HPL[{-3,0},x]-23040 x^6 HPL[{-3,0},x]+46080 \[Pi]^2 x^4 HPL[{-2,-1},x]-11520 x^2 HPL[{-2,0},x]-239040 x^4 HPL[{-2,0},x]-11520 \[Pi]^2 x^4 HPL[{-2,0},x]+86400 x^6 HPL[{-2,0},x]-46080 \[Pi]^2 x^4 HPL[{-2,1},x]-3840 \[Pi]^2 HPL[{-1,-1},x]+23040 \[Pi]^2 x^2 HPL[{-1,-1},x]-11520 \[Pi]^2 x^4 HPL[{-1,-1},x]-7680 \[Pi]^2 x^6 HPL[{-1,-1},x]+104400 HPL[{-1,0},x]+960 \[Pi]^2 HPL[{-1,0},x]-577440 x^2 HPL[{-1,0},x]-5760 \[Pi]^2 x^2 HPL[{-1,0},x]+264240 x^4 HPL[{-1,0},x]+2880 \[Pi]^2 x^4 HPL[{-1,0},x]+208800 x^6 HPL[{-1,0},x]+1920 \[Pi]^2 x^6 HPL[{-1,0},x]+3840 \[Pi]^2 HPL[{-1,1},x]-23040 \[Pi]^2 x^2 HPL[{-1,1},x]+11520 \[Pi]^2 x^4 HPL[{-1,1},x]+7680 \[Pi]^2 x^6 HPL[{-1,1},x]-48960 x^2 HPL[{0,0},x]-87120 x^4 HPL[{0,0},x]-20160 \[Pi]^2 x^4 HPL[{0,0},x]+208800 x^6 HPL[{0,0},x]+1920 \[Pi]^2 x^6 HPL[{0,0},x]+3840 \[Pi]^2 HPL[{1,-1},x]-23040 \[Pi]^2 x^2 HPL[{1,-1},x]+11520 \[Pi]^2 x^4 HPL[{1,-1},x]+7680 \[Pi]^2 x^6 HPL[{1,-1},x]-104400 HPL[{1,0},x]-960 \[Pi]^2 HPL[{1,0},x]+577440 x^2 HPL[{1,0},x]+5760 \[Pi]^2 x^2 HPL[{1,0},x]-264240 x^4 HPL[{1,0},x]-2880 \[Pi]^2 x^4 HPL[{1,0},x]-208800 x^6 HPL[{1,0},x]-1920 \[Pi]^2 x^6 HPL[{1,0},x]-3840 \[Pi]^2 HPL[{1,1},x]+23040 \[Pi]^2 x^2 HPL[{1,1},x]-11520 \[Pi]^2 x^4 HPL[{1,1},x]-7680 \[Pi]^2 x^6 HPL[{1,1},x]-46080 \[Pi]^2 x^4 HPL[{2,-1},x]+11520 x^2 HPL[{2,0},x]+239040 x^4 HPL[{2,0},x]+11520 \[Pi]^2 x^4 HPL[{2,0},x]-86400 x^6 HPL[{2,0},x]+46080 \[Pi]^2 x^4 HPL[{2,1},x]-241920 x^4 HPL[{3,0},x]+23040 x^6 HPL[{3,0},x]+138240 x^4 HPL[{4,0},x]-276480 x^4 HPL[{-3,-1,0},x]-138240 x^4 HPL[{-3,0,0},x]+276480 x^4 HPL[{-3,1,0},x]+138240 x^4 HPL[{-2,-2,0},x]+483840 x^4 HPL[{-2,-1,0},x]-46080 x^6 HPL[{-2,-1,0},x]+241920 x^4 HPL[{-2,0,0},x]-23040 x^6 HPL[{-2,0,0},x]-483840 x^4 HPL[{-2,1,0},x]+46080 x^6 HPL[{-2,1,0},x]-138240 x^4 HPL[{-2,2,0},x]-11520 HPL[{-1,-2,0},x]+69120 x^2 HPL[{-1,-2,0},x]-34560 x^4 HPL[{-1,-2,0},x]-23040 x^6 HPL[{-1,-2,0},x]-86400 HPL[{-1,-1,0},x]+495360 x^2 HPL[{-1,-1,0},x]-236160 x^4 HPL[{-1,-1,0},x]-172800 x^6 HPL[{-1,-1,0},x]-43200 HPL[{-1,0,0},x]+247680 x^2 HPL[{-1,0,0},x]-118080 x^4 HPL[{-1,0,0},x]-86400 x^6 HPL[{-1,0,0},x]+86400 HPL[{-1,1,0},x]-495360 x^2 HPL[{-1,1,0},x]+236160 x^4 HPL[{-1,1,0},x]+172800 x^6 HPL[{-1,1,0},x]+11520 HPL[{-1,2,0},x]-69120 x^2 HPL[{-1,2,0},x]+34560 x^4 HPL[{-1,2,0},x]+23040 x^6 HPL[{-1,2,0},x]+11520 x^2 HPL[{0,0,0},x]+239040 x^4 HPL[{0,0,0},x]+11520 \[Pi]^2 x^4 HPL[{0,0,0},x]-86400 x^6 HPL[{0,0,0},x]+11520 HPL[{1,-2,0},x]-69120 x^2 HPL[{1,-2,0},x]+34560 x^4 HPL[{1,-2,0},x]+23040 x^6 HPL[{1,-2,0},x]+86400 HPL[{1,-1,0},x]-495360 x^2 HPL[{1,-1,0},x]+236160 x^4 HPL[{1,-1,0},x]+172800 x^6 HPL[{1,-1,0},x]+43200 HPL[{1,0,0},x]-247680 x^2 HPL[{1,0,0},x]+118080 x^4 HPL[{1,0,0},x]+86400 x^6 HPL[{1,0,0},x]-86400 HPL[{1,1,0},x]+495360 x^2 HPL[{1,1,0},x]-236160 x^4 HPL[{1,1,0},x]-172800 x^6 HPL[{1,1,0},x]-11520 HPL[{1,2,0},x]+69120 x^2 HPL[{1,2,0},x]-34560 x^4 HPL[{1,2,0},x]-23040 x^6 HPL[{1,2,0},x]-138240 x^4 HPL[{2,-2,0},x]-483840 x^4 HPL[{2,-1,0},x]+46080 x^6 HPL[{2,-1,0},x]-241920 x^4 HPL[{2,0,0},x]+23040 x^6 HPL[{2,0,0},x]+483840 x^4 HPL[{2,1,0},x]-46080 x^6 HPL[{2,1,0},x]+138240 x^4 HPL[{2,2,0},x]+276480 x^4 HPL[{3,-1,0},x]+138240 x^4 HPL[{3,0,0},x]-276480 x^4 HPL[{3,1,0},x]-552960 x^4 HPL[{-2,-1,-1,0},x]-276480 x^4 HPL[{-2,-1,0,0},x]+552960 x^4 HPL[{-2,-1,1,0},x]-138240 x^4 HPL[{-2,0,0,0},x]+552960 x^4 HPL[{-2,1,-1,0},x]+276480 x^4 HPL[{-2,1,0,0},x]-552960 x^4 HPL[{-2,1,1,0},x]+46080 HPL[{-1,-1,-1,0},x]-276480 x^2 HPL[{-1,-1,-1,0},x]+138240 x^4 HPL[{-1,-1,-1,0},x]+92160 x^6 HPL[{-1,-1,-1,0},x]+23040 HPL[{-1,-1,0,0},x]-138240 x^2 HPL[{-1,-1,0,0},x]+69120 x^4 HPL[{-1,-1,0,0},x]+46080 x^6 HPL[{-1,-1,0,0},x]-46080 HPL[{-1,-1,1,0},x]+276480 x^2 HPL[{-1,-1,1,0},x]-138240 x^4 HPL[{-1,-1,1,0},x]-92160 x^6 HPL[{-1,-1,1,0},x]+11520 HPL[{-1,0,0,0},x]-69120 x^2 HPL[{-1,0,0,0},x]+34560 x^4 HPL[{-1,0,0,0},x]+23040 x^6 HPL[{-1,0,0,0},x]-46080 HPL[{-1,1,-1,0},x]+276480 x^2 HPL[{-1,1,-1,0},x]-138240 x^4 HPL[{-1,1,-1,0},x]-92160 x^6 HPL[{-1,1,-1,0},x]-23040 HPL[{-1,1,0,0},x]+138240 x^2 HPL[{-1,1,0,0},x]-69120 x^4 HPL[{-1,1,0,0},x]-46080 x^6 HPL[{-1,1,0,0},x]+46080 HPL[{-1,1,1,0},x]-276480 x^2 HPL[{-1,1,1,0},x]+138240 x^4 HPL[{-1,1,1,0},x]+92160 x^6 HPL[{-1,1,1,0},x]-241920 x^4 HPL[{0,0,0,0},x]+23040 x^6 HPL[{0,0,0,0},x]-46080 HPL[{1,-1,-1,0},x]+276480 x^2 HPL[{1,-1,-1,0},x]-138240 x^4 HPL[{1,-1,-1,0},x]-92160 x^6 HPL[{1,-1,-1,0},x]-23040 HPL[{1,-1,0,0},x]+138240 x^2 HPL[{1,-1,0,0},x]-69120 x^4 HPL[{1,-1,0,0},x]-46080 x^6 HPL[{1,-1,0,0},x]+46080 HPL[{1,-1,1,0},x]-276480 x^2 HPL[{1,-1,1,0},x]+138240 x^4 HPL[{1,-1,1,0},x]+92160 x^6 HPL[{1,-1,1,0},x]-11520 HPL[{1,0,0,0},x]+69120 x^2 HPL[{1,0,0,0},x]-34560 x^4 HPL[{1,0,0,0},x]-23040 x^6 HPL[{1,0,0,0},x]+46080 HPL[{1,1,-1,0},x]-276480 x^2 HPL[{1,1,-1,0},x]+138240 x^4 HPL[{1,1,-1,0},x]+92160 x^6 HPL[{1,1,-1,0},x]+23040 HPL[{1,1,0,0},x]-138240 x^2 HPL[{1,1,0,0},x]+69120 x^4 HPL[{1,1,0,0},x]+46080 x^6 HPL[{1,1,0,0},x]-46080 HPL[{1,1,1,0},x]+276480 x^2 HPL[{1,1,1,0},x]-138240 x^4 HPL[{1,1,1,0},x]-92160 x^6 HPL[{1,1,1,0},x]+552960 x^4 HPL[{2,-1,-1,0},x]+276480 x^4 HPL[{2,-1,0,0},x]-552960 x^4 HPL[{2,-1,1,0},x]+138240 x^4 HPL[{2,0,0,0},x]-552960 x^4 HPL[{2,1,-1,0},x]-276480 x^4 HPL[{2,1,0,0},x]+552960 x^4 HPL[{2,1,1,0},x]+138240 x^4 HPL[{0,0,0,0,0},x]+18000 Zeta[3]-105120 x^2 Zeta[3]+9360 x^4 Zeta[3]-11520 \[Pi]^2 x^4 Zeta[3]+50400 x^6 Zeta[3]+138240 x^4 HPL[{-2},x] Zeta[3]-11520 HPL[{-1},x] Zeta[3]+69120 x^2 HPL[{-1},x] Zeta[3]-34560 x^4 HPL[{-1},x] Zeta[3]-23040 x^6 HPL[{-1},x] Zeta[3]-60480 x^4 HPL[{0},x] Zeta[3]+5760 x^6 HPL[{0},x] Zeta[3]+11520 HPL[{1},x] Zeta[3]-69120 x^2 HPL[{1},x] Zeta[3]+34560 x^4 HPL[{1},x] Zeta[3]+23040 x^6 HPL[{1},x] Zeta[3]-138240 x^4 HPL[{2},x] Zeta[3]+34560 x^4 HPL[{0,0},x] Zeta[3]-51840 x^4 Zeta[5]));


(* ::Subsection:: *)
(*master 3l-7a*)


masterData["m-3l-7a", -3] = -1*(1 + x^2)/3;
 
masterData["m-3l-7a", -2] = -1*(2 + (5*x^2)/3 - 2*x^2*HPL[{0}, x]);

masterData["m-3l-7a", -1] = -1*((25 + Pi^2 - (-17 + Pi^2)*x^2 - 12*HPL[{-1, 0}, x] + 
    6*x^2*(-5*HPL[{0}, x] + 2*(HPL[{-1, 0}, x] + HPL[{0, 0}, x] - 
        HPL[{1, 0}, x])) + 12*HPL[{1, 0}, x])/3);

masterData["m-3l-7a", 0] = -1*((x^2*(90 + 49*x^2 - 5*Pi^2*(-1 + x^2)) + 
    Pi^2*(1 - 4*x^2 + 3*x^4)*HPL[{-1}, x] - Pi^2*HPL[{1}, x] - 
    12*HPL[{-1, -1, 0}, x] + 12*HPL[{-1, 1, 0}, x] + 12*HPL[{1, -1, 0}, x] - 
    12*HPL[{1, 1, 0}, x] + x^2*(-102*x^2*HPL[{0}, x] + 
      Pi^2*(4 - 3*x^2)*HPL[{1}, x] + 12*(5*(-1 + x^2)*HPL[{-1, 0}, x] + 
        5*HPL[{1, 0}, x] + 4*HPL[{-1, -1, 0}, x] + 2*HPL[{-1, 0, 0}, x] - 
        4*HPL[{-1, 1, 0}, x] - 4*HPL[{1, -1, 0}, x] - 2*HPL[{1, 0, 0}, x] + 
        x^2*(5*HPL[{0, 0}, x] - 5*HPL[{1, 0}, x] - 3*HPL[{-1, -1, 0}, x] - 
          2*HPL[{-1, 0, 0}, x] + 3*HPL[{-1, 1, 0}, x] - 2*HPL[{0, 0, 0}, x] + 
          3*HPL[{1, -1, 0}, x] + 2*HPL[{1, 0, 0}, x] - 3*HPL[{1, 1, 0}, x]) + 
        4*HPL[{1, 1, 0}, x]) + 2*(-11 + 7*x^2)*Zeta[3]))/(3*x^2));

 masterData["m-3l-7a", 1] = -1*(301/3 + 43*x^2 + (Pi^4*(11 - 7*x^2))/30 - 
   (17*Pi^2*(-1 + x^2))/3 - 68*HPL[{-1, 0}, x] + 68*HPL[{1, 0}, x] + 
   16*HPL[{-2, -1, 0}, x] - 16*HPL[{-2, 1, 0}, x] + 80*HPL[{-1, -1, 0}, x] + 
   40*HPL[{-1, 0, 0}, x] - 80*HPL[{-1, 1, 0}, x] - 80*HPL[{1, -1, 0}, x] - 
   40*HPL[{1, 0, 0}, x] + 80*HPL[{1, 1, 0}, x] - 16*HPL[{2, -1, 0}, x] + 
   16*HPL[{2, 1, 0}, x] - 64*HPL[{-1, -1, -1, 0}, x] - 
   32*HPL[{-1, -1, 0, 0}, x] + 64*HPL[{-1, -1, 1, 0}, x] - 
   16*HPL[{-1, 0, 0, 0}, x] + 64*HPL[{-1, 1, -1, 0}, x] + 
   32*HPL[{-1, 1, 0, 0}, x] - 64*HPL[{-1, 1, 1, 0}, x] + 
   64*HPL[{1, -1, -1, 0}, x] + 32*HPL[{1, -1, 0, 0}, x] - 
   64*HPL[{1, -1, 1, 0}, x] + 16*HPL[{1, 0, 0, 0}, x] - 
   64*HPL[{1, 1, -1, 0}, x] - 32*HPL[{1, 1, 0, 0}, x] + 
   64*HPL[{1, 1, 1, 0}, x] - 34*Zeta[3] + 
   (2*Pi^2*(-1 + x^2)^2*HPL[{-2}, x] - 294*x^4*HPL[{0}, x] - 
     5*Pi^2*HPL[{1}, x] + 20*Pi^2*x^2*HPL[{1}, x] - 15*Pi^2*x^4*HPL[{1}, x] - 
     2*Pi^2*HPL[{2}, x] + 4*Pi^2*x^2*HPL[{2}, x] - 2*Pi^2*x^4*HPL[{2}, x] - 
     6*Pi^2*HPL[{-1, -1}, x] + 16*Pi^2*x^2*HPL[{-1, -1}, x] - 
     10*Pi^2*x^4*HPL[{-1, -1}, x] + 204*x^4*HPL[{-1, 0}, x] + 
     6*Pi^2*HPL[{-1, 1}, x] - 16*Pi^2*x^2*HPL[{-1, 1}, x] + 
     10*Pi^2*x^4*HPL[{-1, 1}, x] + 204*x^4*HPL[{0, 0}, x] + 
     6*Pi^2*HPL[{1, -1}, x] - 16*Pi^2*x^2*HPL[{1, -1}, x] + 
     10*Pi^2*x^4*HPL[{1, -1}, x] - 204*x^4*HPL[{1, 0}, x] - 
     6*Pi^2*HPL[{1, 1}, x] + 16*Pi^2*x^2*HPL[{1, 1}, x] - 
     10*Pi^2*x^4*HPL[{1, 1}, x] - 24*x^4*HPL[{-2, -1, 0}, x] + 
     24*x^4*HPL[{-2, 1, 0}, x] - 180*x^4*HPL[{-1, -1, 0}, x] - 
     120*x^4*HPL[{-1, 0, 0}, x] + 180*x^4*HPL[{-1, 1, 0}, x] - 
     120*x^4*HPL[{0, 0, 0}, x] + 180*x^4*HPL[{1, -1, 0}, x] + 
     120*x^4*HPL[{1, 0, 0}, x] - 180*x^4*HPL[{1, 1, 0}, x] + 
     24*x^4*HPL[{2, -1, 0}, x] - 24*x^4*HPL[{2, 1, 0}, x] + 
     120*x^4*HPL[{-1, -1, -1, 0}, x] + 72*x^4*HPL[{-1, -1, 0, 0}, x] - 
     120*x^4*HPL[{-1, -1, 1, 0}, x] + 48*x^4*HPL[{-1, 0, 0, 0}, x] - 
     120*x^4*HPL[{-1, 1, -1, 0}, x] - 72*x^4*HPL[{-1, 1, 0, 0}, x] + 
     120*x^4*HPL[{-1, 1, 1, 0}, x] + 48*x^4*HPL[{0, 0, 0, 0}, x] - 
     120*x^4*HPL[{1, -1, -1, 0}, x] - 72*x^4*HPL[{1, -1, 0, 0}, x] + 
     120*x^4*HPL[{1, -1, 1, 0}, x] - 48*x^4*HPL[{1, 0, 0, 0}, x] + 
     120*x^4*HPL[{1, 1, -1, 0}, x] + 72*x^4*HPL[{1, 1, 0, 0}, x] - 
     12*(2*HPL[{-2, -1, 0}, x] - 2*HPL[{-2, 1, 0}, x] + 
       5*HPL[{-1, -1, 0}, x] - 5*HPL[{-1, 1, 0}, x] - 5*HPL[{1, -1, 0}, x] + 
       5*HPL[{1, 1, 0}, x] - 2*(HPL[{2, -1, 0}, x] - HPL[{2, 1, 0}, x] + 
         3*HPL[{-1, -1, -1, 0}, x] + HPL[{-1, -1, 0, 0}, x] - 
         3*HPL[{-1, -1, 1, 0}, x] - 3*HPL[{-1, 1, -1, 0}, x] - 
         HPL[{-1, 1, 0, 0}, x] + 3*HPL[{-1, 1, 1, 0}, x] - 
         3*HPL[{1, -1, -1, 0}, x] - HPL[{1, -1, 0, 0}, x] + 
         3*HPL[{1, -1, 1, 0}, x] + 3*HPL[{1, 1, -1, 0}, x] + 
         HPL[{1, 1, 0, 0}, x] - 3*HPL[{1, 1, 1, 0}, x])) - 
     120*x^4*HPL[{1, 1, 1, 0}, x] + 
     2*(35*x^4 + 3*(5 - 12*x^2 + 7*x^4)*HPL[{1}, x])*Zeta[3] + 
     (-1 + x^2)*HPL[{-1}, x]*(5*Pi^2*(-1 + 3*x^2) + 6*(5 - 7*x^2)*Zeta[3]))/
    (3*x^2));


(* ::Subsection:: *)
(*master 3l-7b*)


masterData["m-3l-7b", -3] = -1*(1 + x^2)/3;

masterData["m-3l-7b", -2] = -1*(5/3 + 2*x^2 - 2*x^2*HPL[{0}, x]);

masterData["m-3l-7b", -1] = -1*((17 + Pi^2 - (-25 + Pi^2)*x^2 - 12*HPL[{-1, 0}, x] + 
    12*x^2*(-3*HPL[{0}, x] + HPL[{-1, 0}, x] + HPL[{0, 0}, x] - 
      HPL[{1, 0}, x]) + 12*HPL[{1, 0}, x])/3);

masterData["m-3l-7b", 0] = -1*((49 + 5*Pi^2 + 90*x^2 - 5*Pi^2*x^2 - 
    Pi^2*(3 - 4*x^2 + x^4)*HPL[{-1}, x] + 2*x^2*(-75 + Pi^2*(-1 + x^2))*
     HPL[{0}, x] + 3*Pi^2*HPL[{1}, x] - 4*Pi^2*x^2*HPL[{1}, x] + 
    Pi^2*x^4*HPL[{1}, x] + 24*x^2*HPL[{-2, 0}, x] - 24*x^4*HPL[{-2, 0}, x] - 
    60*HPL[{-1, 0}, x] + 60*x^2*HPL[{-1, 0}, x] + 96*x^2*HPL[{0, 0}, x] + 
    60*HPL[{1, 0}, x] - 60*x^2*HPL[{1, 0}, x] - 24*x^2*HPL[{2, 0}, x] + 
    24*x^4*HPL[{2, 0}, x] + 36*HPL[{-1, -1, 0}, x] - 
    48*x^2*HPL[{-1, -1, 0}, x] + 12*x^4*HPL[{-1, -1, 0}, x] + 
    48*HPL[{-1, 0, 0}, x] - 24*x^2*HPL[{-1, 0, 0}, x] - 
    24*x^4*HPL[{-1, 0, 0}, x] - 36*HPL[{-1, 1, 0}, x] + 
    48*x^2*HPL[{-1, 1, 0}, x] - 12*x^4*HPL[{-1, 1, 0}, x] - 
    24*x^2*HPL[{0, 0, 0}, x] + 48*x^4*HPL[{0, 0, 0}, x] - 
    36*HPL[{1, -1, 0}, x] + 48*x^2*HPL[{1, -1, 0}, x] - 
    12*x^4*HPL[{1, -1, 0}, x] - 48*HPL[{1, 0, 0}, x] + 
    24*x^2*HPL[{1, 0, 0}, x] + 24*x^4*HPL[{1, 0, 0}, x] + 
    36*HPL[{1, 1, 0}, x] - 48*x^2*HPL[{1, 1, 0}, x] + 
    12*x^4*HPL[{1, 1, 0}, x] + 2*(-2 + x^2 - 3*x^4)*Zeta[3])/3);

masterData["m-3l-7b", 1] = -1*(43 + (301*x^2)/3 + 
   (Pi^2*(-510*(-1 + x^2) + Pi^2*(26 - 43*x^2 + 29*x^4)))/90 - 
   (4*Pi^2*x^2*(-1 + x^2)*HPL[{-2}, x])/3 - 68*HPL[{-1, 0}, x] + 
   68*HPL[{1, 0}, x] + 8*HPL[{-1, -2, 0}, x] + 60*HPL[{-1, -1, 0}, x] + 
   80*HPL[{-1, 0, 0}, x] - 60*HPL[{-1, 1, 0}, x] - 8*HPL[{-1, 2, 0}, x] - 
   8*HPL[{1, -2, 0}, x] - 60*HPL[{1, -1, 0}, x] - 80*HPL[{1, 0, 0}, x] + 
   60*HPL[{1, 1, 0}, x] + 8*HPL[{1, 2, 0}, x] - 40*HPL[{-1, -1, -1, 0}, x] - 
   40*HPL[{-1, -1, 0, 0}, x] + 40*HPL[{-1, -1, 1, 0}, x] - 
   80*HPL[{-1, 0, 0, 0}, x] + 40*HPL[{-1, 1, -1, 0}, x] + 
   40*HPL[{-1, 1, 0, 0}, x] - 40*HPL[{-1, 1, 1, 0}, x] + 
   40*HPL[{1, -1, -1, 0}, x] + 40*HPL[{1, -1, 0, 0}, x] - 
   40*HPL[{1, -1, 1, 0}, x] + 80*HPL[{1, 0, 0, 0}, x] - 
   40*HPL[{1, 1, -1, 0}, x] - 40*HPL[{1, 1, 0, 0}, x] + 
   40*HPL[{1, 1, 1, 0}, x] - (20*Zeta[3])/3 + 
   (15*Pi^2*HPL[{1}, x] - 20*Pi^2*x^2*HPL[{1}, x] + 5*Pi^2*x^4*HPL[{1}, x] - 
     4*Pi^2*x^2*HPL[{2}, x] + 4*Pi^2*x^4*HPL[{2}, x] - 
     48*x^2*HPL[{-3, 0}, x] + 48*x^4*HPL[{-3, 0}, x] + 
     120*x^2*HPL[{-2, 0}, x] - 120*x^4*HPL[{-2, 0}, x] + 
     10*Pi^2*HPL[{-1, -1}, x] - 16*Pi^2*x^2*HPL[{-1, -1}, x] + 
     6*Pi^2*x^4*HPL[{-1, -1}, x] - 2*Pi^2*HPL[{-1, 0}, x] + 
     204*x^2*HPL[{-1, 0}, x] + 8*Pi^2*x^2*HPL[{-1, 0}, x] - 
     6*Pi^2*x^4*HPL[{-1, 0}, x] - 10*Pi^2*HPL[{-1, 1}, x] + 
     16*Pi^2*x^2*HPL[{-1, 1}, x] - 6*Pi^2*x^4*HPL[{-1, 1}, x] + 
     492*x^2*HPL[{0, 0}, x] + 4*Pi^2*x^2*HPL[{0, 0}, x] - 
     4*Pi^2*x^4*HPL[{0, 0}, x] - 10*Pi^2*HPL[{1, -1}, x] + 
     16*Pi^2*x^2*HPL[{1, -1}, x] - 6*Pi^2*x^4*HPL[{1, -1}, x] + 
     2*Pi^2*HPL[{1, 0}, x] - 204*x^2*HPL[{1, 0}, x] - 
     8*Pi^2*x^2*HPL[{1, 0}, x] + 6*Pi^2*x^4*HPL[{1, 0}, x] + 
     10*Pi^2*HPL[{1, 1}, x] - 16*Pi^2*x^2*HPL[{1, 1}, x] + 
     6*Pi^2*x^4*HPL[{1, 1}, x] - 120*x^2*HPL[{2, 0}, x] + 
     120*x^4*HPL[{2, 0}, x] + 48*x^2*HPL[{3, 0}, x] - 48*x^4*HPL[{3, 0}, x] - 
     48*x^2*HPL[{-2, -1, 0}, x] + 48*x^4*HPL[{-2, -1, 0}, x] - 
     144*x^2*HPL[{-2, 0, 0}, x] + 144*x^4*HPL[{-2, 0, 0}, x] + 
     48*x^2*HPL[{-2, 1, 0}, x] - 48*x^4*HPL[{-2, 1, 0}, x] - 
     96*x^2*HPL[{-1, -2, 0}, x] + 72*x^4*HPL[{-1, -2, 0}, x] - 
     240*x^2*HPL[{-1, -1, 0}, x] + 60*x^4*HPL[{-1, -1, 0}, x] - 
     120*x^2*HPL[{-1, 0, 0}, x] - 120*x^4*HPL[{-1, 0, 0}, x] + 
     240*x^2*HPL[{-1, 1, 0}, x] - 60*x^4*HPL[{-1, 1, 0}, x] + 
     96*x^2*HPL[{-1, 2, 0}, x] - 72*x^4*HPL[{-1, 2, 0}, x] - 
     336*x^2*HPL[{0, 0, 0}, x] + 240*x^4*HPL[{0, 0, 0}, x] + 
     96*x^2*HPL[{1, -2, 0}, x] - 72*x^4*HPL[{1, -2, 0}, x] + 
     240*x^2*HPL[{1, -1, 0}, x] - 60*x^4*HPL[{1, -1, 0}, x] + 
     120*x^2*HPL[{1, 0, 0}, x] + 120*x^4*HPL[{1, 0, 0}, x] - 
     240*x^2*HPL[{1, 1, 0}, x] + 60*x^4*HPL[{1, 1, 0}, x] - 
     96*x^2*HPL[{1, 2, 0}, x] + 72*x^4*HPL[{1, 2, 0}, x] + 
     48*x^2*HPL[{2, -1, 0}, x] - 48*x^4*HPL[{2, -1, 0}, x] + 
     144*x^2*HPL[{2, 0, 0}, x] - 144*x^4*HPL[{2, 0, 0}, x] - 
     48*x^2*HPL[{2, 1, 0}, x] + 48*x^4*HPL[{2, 1, 0}, x] + 
     192*x^2*HPL[{-1, -1, -1, 0}, x] - 72*x^4*HPL[{-1, -1, -1, 0}, x] + 
     96*x^2*HPL[{-1, -1, 0, 0}, x] + 24*x^4*HPL[{-1, -1, 0, 0}, x] - 
     192*x^2*HPL[{-1, -1, 1, 0}, x] + 72*x^4*HPL[{-1, -1, 1, 0}, x] + 
     144*x^2*HPL[{-1, 0, 0, 0}, x] + 96*x^4*HPL[{-1, 0, 0, 0}, x] - 
     192*x^2*HPL[{-1, 1, -1, 0}, x] + 72*x^4*HPL[{-1, 1, -1, 0}, x] - 
     96*x^2*HPL[{-1, 1, 0, 0}, x] - 24*x^4*HPL[{-1, 1, 0, 0}, x] + 
     192*x^2*HPL[{-1, 1, 1, 0}, x] - 72*x^4*HPL[{-1, 1, 1, 0}, x] + 
     48*x^2*HPL[{0, 0, 0, 0}, x] - 576*x^4*HPL[{0, 0, 0, 0}, x] - 
     192*x^2*HPL[{1, -1, -1, 0}, x] + 72*x^4*HPL[{1, -1, -1, 0}, x] - 
     96*x^2*HPL[{1, -1, 0, 0}, x] - 24*x^4*HPL[{1, -1, 0, 0}, x] + 
     192*x^2*HPL[{1, -1, 1, 0}, x] - 72*x^4*HPL[{1, -1, 1, 0}, x] - 
     144*x^2*HPL[{1, 0, 0, 0}, x] - 96*x^4*HPL[{1, 0, 0, 0}, x] + 
     192*x^2*HPL[{1, 1, -1, 0}, x] - 72*x^4*HPL[{1, 1, -1, 0}, x] + 
     96*x^2*HPL[{1, 1, 0, 0}, x] + 24*x^4*HPL[{1, 1, 0, 0}, x] - 
     192*x^2*HPL[{1, 1, 1, 0}, x] + 72*x^4*HPL[{1, 1, 1, 0}, x] - 
     (3 - 4*x^2 + x^4)*HPL[{-1}, x]*(5*Pi^2 - 6*Zeta[3]) - 
     6*(x^2*(-3 + 5*x^2) + (3 - 4*x^2 + x^4)*HPL[{1}, x])*Zeta[3] + 
     2*x^2*HPL[{0}, x]*(-270 + 5*Pi^2*(-1 + x^2) + 6*(1 + 3*x^2)*Zeta[3]))/3);

masterData["m-3l-7b", 2] = -1*(107 + (49*Pi^2)/3 + (13*Pi^4)/9 + 322*x^2 - 
   (49*Pi^2*x^2)/3 - (227*Pi^4*x^2)/90 + (29*Pi^4*x^4)/18 + 
   (8*Pi^2*x^2*(-1 + x^2)*HPL[{-3}, x])/3 - 
   (20*Pi^2*x^2*(-1 + x^2)*HPL[{-2}, x])/3 - 17*Pi^2*HPL[{-1}, x] - 
   (107*Pi^4*HPL[{-1}, x])/90 + (68*Pi^2*x^2*HPL[{-1}, x])/3 + 
   (98*Pi^4*x^2*HPL[{-1}, x])/45 - (17*Pi^2*x^4*HPL[{-1}, x])/3 - 
   (89*Pi^4*x^4*HPL[{-1}, x])/90 - 602*x^2*HPL[{0}, x] - 
   (34*Pi^2*x^2*HPL[{0}, x])/3 - (Pi^4*x^2*HPL[{0}, x])/5 + 
   (34*Pi^2*x^4*HPL[{0}, x])/3 - (3*Pi^4*x^4*HPL[{0}, x])/5 + 
   17*Pi^2*HPL[{1}, x] + (107*Pi^4*HPL[{1}, x])/90 - 
   (68*Pi^2*x^2*HPL[{1}, x])/3 - (98*Pi^4*x^2*HPL[{1}, x])/45 + 
   (17*Pi^2*x^4*HPL[{1}, x])/3 + (89*Pi^4*x^4*HPL[{1}, x])/90 - 
   (20*Pi^2*x^2*HPL[{2}, x])/3 + (20*Pi^2*x^4*HPL[{2}, x])/3 + 
   (8*Pi^2*x^2*HPL[{3}, x])/3 - (8*Pi^2*x^4*HPL[{3}, x])/3 + 
   32*x^2*HPL[{-4, 0}, x] - 32*x^4*HPL[{-4, 0}, x] - 80*x^2*HPL[{-3, 0}, x] + 
   80*x^4*HPL[{-3, 0}, x] - (8*Pi^2*x^2*HPL[{-2, -1}, x])/3 + 
   (8*Pi^2*x^4*HPL[{-2, -1}, x])/3 + 136*x^2*HPL[{-2, 0}, x] - 
   (8*Pi^2*x^2*HPL[{-2, 0}, x])/3 - 136*x^4*HPL[{-2, 0}, x] + 
   (8*Pi^2*x^4*HPL[{-2, 0}, x])/3 + (8*Pi^2*x^2*HPL[{-2, 1}, x])/3 - 
   (8*Pi^2*x^4*HPL[{-2, 1}, x])/3 + (4*Pi^2*HPL[{-1, -2}, x])/3 - 
   (16*Pi^2*x^2*HPL[{-1, -2}, x])/3 + 4*Pi^2*x^4*HPL[{-1, -2}, x] + 
   (50*Pi^2*HPL[{-1, -1}, x])/3 - (80*Pi^2*x^2*HPL[{-1, -1}, x])/3 + 
   10*Pi^2*x^4*HPL[{-1, -1}, x] - 196*HPL[{-1, 0}, x] - 
   (10*Pi^2*HPL[{-1, 0}, x])/3 + 196*x^2*HPL[{-1, 0}, x] + 
   (40*Pi^2*x^2*HPL[{-1, 0}, x])/3 - 10*Pi^2*x^4*HPL[{-1, 0}, x] - 
   (50*Pi^2*HPL[{-1, 1}, x])/3 + (80*Pi^2*x^2*HPL[{-1, 1}, x])/3 - 
   10*Pi^2*x^4*HPL[{-1, 1}, x] - (4*Pi^2*HPL[{-1, 2}, x])/3 + 
   (16*Pi^2*x^2*HPL[{-1, 2}, x])/3 - 4*Pi^2*x^4*HPL[{-1, 2}, x] + 
   688*x^2*HPL[{0, 0}, x] + (20*Pi^2*x^2*HPL[{0, 0}, x])/3 - 
   (20*Pi^2*x^4*HPL[{0, 0}, x])/3 - (4*Pi^2*HPL[{1, -2}, x])/3 + 
   (16*Pi^2*x^2*HPL[{1, -2}, x])/3 - 4*Pi^2*x^4*HPL[{1, -2}, x] - 
   (50*Pi^2*HPL[{1, -1}, x])/3 + (80*Pi^2*x^2*HPL[{1, -1}, x])/3 - 
   10*Pi^2*x^4*HPL[{1, -1}, x] + 196*HPL[{1, 0}, x] + 
   (10*Pi^2*HPL[{1, 0}, x])/3 - 196*x^2*HPL[{1, 0}, x] - 
   (40*Pi^2*x^2*HPL[{1, 0}, x])/3 + 10*Pi^2*x^4*HPL[{1, 0}, x] + 
   (50*Pi^2*HPL[{1, 1}, x])/3 - (80*Pi^2*x^2*HPL[{1, 1}, x])/3 + 
   10*Pi^2*x^4*HPL[{1, 1}, x] + (4*Pi^2*HPL[{1, 2}, x])/3 - 
   (16*Pi^2*x^2*HPL[{1, 2}, x])/3 + 4*Pi^2*x^4*HPL[{1, 2}, x] + 
   (8*Pi^2*x^2*HPL[{2, -1}, x])/3 - (8*Pi^2*x^4*HPL[{2, -1}, x])/3 - 
   136*x^2*HPL[{2, 0}, x] + (8*Pi^2*x^2*HPL[{2, 0}, x])/3 + 
   136*x^4*HPL[{2, 0}, x] - (8*Pi^2*x^4*HPL[{2, 0}, x])/3 - 
   (8*Pi^2*x^2*HPL[{2, 1}, x])/3 + (8*Pi^2*x^4*HPL[{2, 1}, x])/3 + 
   80*x^2*HPL[{3, 0}, x] - 80*x^4*HPL[{3, 0}, x] - 32*x^2*HPL[{4, 0}, x] + 
   32*x^4*HPL[{4, 0}, x] + 32*x^2*HPL[{-3, -1, 0}, x] - 
   32*x^4*HPL[{-3, -1, 0}, x] + 96*x^2*HPL[{-3, 0, 0}, x] - 
   96*x^4*HPL[{-3, 0, 0}, x] - 32*x^2*HPL[{-3, 1, 0}, x] + 
   32*x^4*HPL[{-3, 1, 0}, x] + 32*x^2*HPL[{-2, -2, 0}, x] - 
   32*x^4*HPL[{-2, -2, 0}, x] - 80*x^2*HPL[{-2, -1, 0}, x] + 
   80*x^4*HPL[{-2, -1, 0}, x] - 240*x^2*HPL[{-2, 0, 0}, x] + 
   240*x^4*HPL[{-2, 0, 0}, x] + 80*x^2*HPL[{-2, 1, 0}, x] - 
   80*x^4*HPL[{-2, 1, 0}, x] - 32*x^2*HPL[{-2, 2, 0}, x] + 
   32*x^4*HPL[{-2, 2, 0}, x] - 16*HPL[{-1, -3, 0}, x] + 
   64*x^2*HPL[{-1, -3, 0}, x] - 48*x^4*HPL[{-1, -3, 0}, x] + 
   40*HPL[{-1, -2, 0}, x] - 160*x^2*HPL[{-1, -2, 0}, x] + 
   120*x^4*HPL[{-1, -2, 0}, x] - 12*Pi^2*HPL[{-1, -1, -1}, x] + 
   (64*Pi^2*x^2*HPL[{-1, -1, -1}, x])/3 - (28*Pi^2*x^4*HPL[{-1, -1, -1}, x])/
    3 + 204*HPL[{-1, -1, 0}, x] + 4*Pi^2*HPL[{-1, -1, 0}, x] - 
   272*x^2*HPL[{-1, -1, 0}, x] - (32*Pi^2*x^2*HPL[{-1, -1, 0}, x])/3 + 
   68*x^4*HPL[{-1, -1, 0}, x] + (20*Pi^2*x^4*HPL[{-1, -1, 0}, x])/3 + 
   12*Pi^2*HPL[{-1, -1, 1}, x] - (64*Pi^2*x^2*HPL[{-1, -1, 1}, x])/3 + 
   (28*Pi^2*x^4*HPL[{-1, -1, 1}, x])/3 + 272*HPL[{-1, 0, 0}, x] + 
   (4*Pi^2*HPL[{-1, 0, 0}, x])/3 - 136*x^2*HPL[{-1, 0, 0}, x] - 
   (16*Pi^2*x^2*HPL[{-1, 0, 0}, x])/3 - 136*x^4*HPL[{-1, 0, 0}, x] + 
   4*Pi^2*x^4*HPL[{-1, 0, 0}, x] + 12*Pi^2*HPL[{-1, 1, -1}, x] - 
   (64*Pi^2*x^2*HPL[{-1, 1, -1}, x])/3 + (28*Pi^2*x^4*HPL[{-1, 1, -1}, x])/
    3 - 204*HPL[{-1, 1, 0}, x] - 4*Pi^2*HPL[{-1, 1, 0}, x] + 
   272*x^2*HPL[{-1, 1, 0}, x] + (32*Pi^2*x^2*HPL[{-1, 1, 0}, x])/3 - 
   68*x^4*HPL[{-1, 1, 0}, x] - (20*Pi^2*x^4*HPL[{-1, 1, 0}, x])/3 - 
   12*Pi^2*HPL[{-1, 1, 1}, x] + (64*Pi^2*x^2*HPL[{-1, 1, 1}, x])/3 - 
   (28*Pi^2*x^4*HPL[{-1, 1, 1}, x])/3 - 40*HPL[{-1, 2, 0}, x] + 
   160*x^2*HPL[{-1, 2, 0}, x] - 120*x^4*HPL[{-1, 2, 0}, x] + 
   16*HPL[{-1, 3, 0}, x] - 64*x^2*HPL[{-1, 3, 0}, x] + 
   48*x^4*HPL[{-1, 3, 0}, x] - 712*x^2*HPL[{0, 0, 0}, x] - 
   (8*Pi^2*x^2*HPL[{0, 0, 0}, x])/3 + 272*x^4*HPL[{0, 0, 0}, x] + 
   (8*Pi^2*x^4*HPL[{0, 0, 0}, x])/3 + 16*HPL[{1, -3, 0}, x] - 
   64*x^2*HPL[{1, -3, 0}, x] + 48*x^4*HPL[{1, -3, 0}, x] - 
   40*HPL[{1, -2, 0}, x] + 160*x^2*HPL[{1, -2, 0}, x] - 
   120*x^4*HPL[{1, -2, 0}, x] + 12*Pi^2*HPL[{1, -1, -1}, x] - 
   (64*Pi^2*x^2*HPL[{1, -1, -1}, x])/3 + (28*Pi^2*x^4*HPL[{1, -1, -1}, x])/
    3 - 204*HPL[{1, -1, 0}, x] - 4*Pi^2*HPL[{1, -1, 0}, x] + 
   272*x^2*HPL[{1, -1, 0}, x] + (32*Pi^2*x^2*HPL[{1, -1, 0}, x])/3 - 
   68*x^4*HPL[{1, -1, 0}, x] - (20*Pi^2*x^4*HPL[{1, -1, 0}, x])/3 - 
   12*Pi^2*HPL[{1, -1, 1}, x] + (64*Pi^2*x^2*HPL[{1, -1, 1}, x])/3 - 
   (28*Pi^2*x^4*HPL[{1, -1, 1}, x])/3 - 272*HPL[{1, 0, 0}, x] - 
   (4*Pi^2*HPL[{1, 0, 0}, x])/3 + 136*x^2*HPL[{1, 0, 0}, x] + 
   (16*Pi^2*x^2*HPL[{1, 0, 0}, x])/3 + 136*x^4*HPL[{1, 0, 0}, x] - 
   4*Pi^2*x^4*HPL[{1, 0, 0}, x] - 12*Pi^2*HPL[{1, 1, -1}, x] + 
   (64*Pi^2*x^2*HPL[{1, 1, -1}, x])/3 - (28*Pi^2*x^4*HPL[{1, 1, -1}, x])/3 + 
   204*HPL[{1, 1, 0}, x] + 4*Pi^2*HPL[{1, 1, 0}, x] - 
   272*x^2*HPL[{1, 1, 0}, x] - (32*Pi^2*x^2*HPL[{1, 1, 0}, x])/3 + 
   68*x^4*HPL[{1, 1, 0}, x] + (20*Pi^2*x^4*HPL[{1, 1, 0}, x])/3 + 
   12*Pi^2*HPL[{1, 1, 1}, x] - (64*Pi^2*x^2*HPL[{1, 1, 1}, x])/3 + 
   (28*Pi^2*x^4*HPL[{1, 1, 1}, x])/3 + 40*HPL[{1, 2, 0}, x] - 
   160*x^2*HPL[{1, 2, 0}, x] + 120*x^4*HPL[{1, 2, 0}, x] - 
   16*HPL[{1, 3, 0}, x] + 64*x^2*HPL[{1, 3, 0}, x] - 
   48*x^4*HPL[{1, 3, 0}, x] - 32*x^2*HPL[{2, -2, 0}, x] + 
   32*x^4*HPL[{2, -2, 0}, x] + 80*x^2*HPL[{2, -1, 0}, x] - 
   80*x^4*HPL[{2, -1, 0}, x] + 240*x^2*HPL[{2, 0, 0}, x] - 
   240*x^4*HPL[{2, 0, 0}, x] - 80*x^2*HPL[{2, 1, 0}, x] + 
   80*x^4*HPL[{2, 1, 0}, x] + 32*x^2*HPL[{2, 2, 0}, x] - 
   32*x^4*HPL[{2, 2, 0}, x] - 32*x^2*HPL[{3, -1, 0}, x] + 
   32*x^4*HPL[{3, -1, 0}, x] - 96*x^2*HPL[{3, 0, 0}, x] + 
   96*x^4*HPL[{3, 0, 0}, x] + 32*x^2*HPL[{3, 1, 0}, x] - 
   32*x^4*HPL[{3, 1, 0}, x] + 32*x^2*HPL[{-2, -1, -1, 0}, x] - 
   32*x^4*HPL[{-2, -1, -1, 0}, x] + 96*x^2*HPL[{-2, -1, 0, 0}, x] - 
   96*x^4*HPL[{-2, -1, 0, 0}, x] - 32*x^2*HPL[{-2, -1, 1, 0}, x] + 
   32*x^4*HPL[{-2, -1, 1, 0}, x] + 224*x^2*HPL[{-2, 0, 0, 0}, x] - 
   224*x^4*HPL[{-2, 0, 0, 0}, x] - 32*x^2*HPL[{-2, 1, -1, 0}, x] + 
   32*x^4*HPL[{-2, 1, -1, 0}, x] - 96*x^2*HPL[{-2, 1, 0, 0}, x] + 
   96*x^4*HPL[{-2, 1, 0, 0}, x] + 32*x^2*HPL[{-2, 1, 1, 0}, x] - 
   32*x^4*HPL[{-2, 1, 1, 0}, x] - 16*HPL[{-1, -2, -1, 0}, x] + 
   64*x^2*HPL[{-1, -2, -1, 0}, x] - 48*x^4*HPL[{-1, -2, -1, 0}, x] - 
   48*HPL[{-1, -2, 0, 0}, x] + 192*x^2*HPL[{-1, -2, 0, 0}, x] - 
   144*x^4*HPL[{-1, -2, 0, 0}, x] + 16*HPL[{-1, -2, 1, 0}, x] - 
   64*x^2*HPL[{-1, -2, 1, 0}, x] + 48*x^4*HPL[{-1, -2, 1, 0}, x] - 
   48*HPL[{-1, -1, -2, 0}, x] + 128*x^2*HPL[{-1, -1, -2, 0}, x] - 
   80*x^4*HPL[{-1, -1, -2, 0}, x] - 200*HPL[{-1, -1, -1, 0}, x] + 
   320*x^2*HPL[{-1, -1, -1, 0}, x] - 120*x^4*HPL[{-1, -1, -1, 0}, x] - 
   200*HPL[{-1, -1, 0, 0}, x] + 160*x^2*HPL[{-1, -1, 0, 0}, x] + 
   40*x^4*HPL[{-1, -1, 0, 0}, x] + 200*HPL[{-1, -1, 1, 0}, x] - 
   320*x^2*HPL[{-1, -1, 1, 0}, x] + 120*x^4*HPL[{-1, -1, 1, 0}, x] + 
   48*HPL[{-1, -1, 2, 0}, x] - 128*x^2*HPL[{-1, -1, 2, 0}, x] + 
   80*x^4*HPL[{-1, -1, 2, 0}, x] - 400*HPL[{-1, 0, 0, 0}, x] + 
   240*x^2*HPL[{-1, 0, 0, 0}, x] + 160*x^4*HPL[{-1, 0, 0, 0}, x] + 
   48*HPL[{-1, 1, -2, 0}, x] - 128*x^2*HPL[{-1, 1, -2, 0}, x] + 
   80*x^4*HPL[{-1, 1, -2, 0}, x] + 200*HPL[{-1, 1, -1, 0}, x] - 
   320*x^2*HPL[{-1, 1, -1, 0}, x] + 120*x^4*HPL[{-1, 1, -1, 0}, x] + 
   200*HPL[{-1, 1, 0, 0}, x] - 160*x^2*HPL[{-1, 1, 0, 0}, x] - 
   40*x^4*HPL[{-1, 1, 0, 0}, x] - 200*HPL[{-1, 1, 1, 0}, x] + 
   320*x^2*HPL[{-1, 1, 1, 0}, x] - 120*x^4*HPL[{-1, 1, 1, 0}, x] - 
   48*HPL[{-1, 1, 2, 0}, x] + 128*x^2*HPL[{-1, 1, 2, 0}, x] - 
   80*x^4*HPL[{-1, 1, 2, 0}, x] + 16*HPL[{-1, 2, -1, 0}, x] - 
   64*x^2*HPL[{-1, 2, -1, 0}, x] + 48*x^4*HPL[{-1, 2, -1, 0}, x] + 
   48*HPL[{-1, 2, 0, 0}, x] - 192*x^2*HPL[{-1, 2, 0, 0}, x] + 
   144*x^4*HPL[{-1, 2, 0, 0}, x] - 16*HPL[{-1, 2, 1, 0}, x] + 
   64*x^2*HPL[{-1, 2, 1, 0}, x] - 48*x^4*HPL[{-1, 2, 1, 0}, x] + 
   512*x^2*HPL[{0, 0, 0, 0}, x] - 960*x^4*HPL[{0, 0, 0, 0}, x] + 
   16*HPL[{1, -2, -1, 0}, x] - 64*x^2*HPL[{1, -2, -1, 0}, x] + 
   48*x^4*HPL[{1, -2, -1, 0}, x] + 48*HPL[{1, -2, 0, 0}, x] - 
   192*x^2*HPL[{1, -2, 0, 0}, x] + 144*x^4*HPL[{1, -2, 0, 0}, x] - 
   16*HPL[{1, -2, 1, 0}, x] + 64*x^2*HPL[{1, -2, 1, 0}, x] - 
   48*x^4*HPL[{1, -2, 1, 0}, x] + 48*HPL[{1, -1, -2, 0}, x] - 
   128*x^2*HPL[{1, -1, -2, 0}, x] + 80*x^4*HPL[{1, -1, -2, 0}, x] + 
   200*HPL[{1, -1, -1, 0}, x] - 320*x^2*HPL[{1, -1, -1, 0}, x] + 
   120*x^4*HPL[{1, -1, -1, 0}, x] + 200*HPL[{1, -1, 0, 0}, x] - 
   160*x^2*HPL[{1, -1, 0, 0}, x] - 40*x^4*HPL[{1, -1, 0, 0}, x] - 
   200*HPL[{1, -1, 1, 0}, x] + 320*x^2*HPL[{1, -1, 1, 0}, x] - 
   120*x^4*HPL[{1, -1, 1, 0}, x] - 48*HPL[{1, -1, 2, 0}, x] + 
   128*x^2*HPL[{1, -1, 2, 0}, x] - 80*x^4*HPL[{1, -1, 2, 0}, x] + 
   400*HPL[{1, 0, 0, 0}, x] - 240*x^2*HPL[{1, 0, 0, 0}, x] - 
   160*x^4*HPL[{1, 0, 0, 0}, x] - 48*HPL[{1, 1, -2, 0}, x] + 
   128*x^2*HPL[{1, 1, -2, 0}, x] - 80*x^4*HPL[{1, 1, -2, 0}, x] - 
   200*HPL[{1, 1, -1, 0}, x] + 320*x^2*HPL[{1, 1, -1, 0}, x] - 
   120*x^4*HPL[{1, 1, -1, 0}, x] - 200*HPL[{1, 1, 0, 0}, x] + 
   160*x^2*HPL[{1, 1, 0, 0}, x] + 40*x^4*HPL[{1, 1, 0, 0}, x] + 
   200*HPL[{1, 1, 1, 0}, x] - 320*x^2*HPL[{1, 1, 1, 0}, x] + 
   120*x^4*HPL[{1, 1, 1, 0}, x] + 48*HPL[{1, 1, 2, 0}, x] - 
   128*x^2*HPL[{1, 1, 2, 0}, x] + 80*x^4*HPL[{1, 1, 2, 0}, x] - 
   16*HPL[{1, 2, -1, 0}, x] + 64*x^2*HPL[{1, 2, -1, 0}, x] - 
   48*x^4*HPL[{1, 2, -1, 0}, x] - 48*HPL[{1, 2, 0, 0}, x] + 
   192*x^2*HPL[{1, 2, 0, 0}, x] - 144*x^4*HPL[{1, 2, 0, 0}, x] + 
   16*HPL[{1, 2, 1, 0}, x] - 64*x^2*HPL[{1, 2, 1, 0}, x] + 
   48*x^4*HPL[{1, 2, 1, 0}, x] - 32*x^2*HPL[{2, -1, -1, 0}, x] + 
   32*x^4*HPL[{2, -1, -1, 0}, x] - 96*x^2*HPL[{2, -1, 0, 0}, x] + 
   96*x^4*HPL[{2, -1, 0, 0}, x] + 32*x^2*HPL[{2, -1, 1, 0}, x] - 
   32*x^4*HPL[{2, -1, 1, 0}, x] - 224*x^2*HPL[{2, 0, 0, 0}, x] + 
   224*x^4*HPL[{2, 0, 0, 0}, x] + 32*x^2*HPL[{2, 1, -1, 0}, x] - 
   32*x^4*HPL[{2, 1, -1, 0}, x] + 96*x^2*HPL[{2, 1, 0, 0}, x] - 
   96*x^4*HPL[{2, 1, 0, 0}, x] - 32*x^2*HPL[{2, 1, 1, 0}, x] + 
   32*x^4*HPL[{2, 1, 1, 0}, x] + 144*HPL[{-1, -1, -1, -1, 0}, x] - 
   256*x^2*HPL[{-1, -1, -1, -1, 0}, x] + 
   112*x^4*HPL[{-1, -1, -1, -1, 0}, x] + 112*HPL[{-1, -1, -1, 0, 0}, x] - 
   128*x^2*HPL[{-1, -1, -1, 0, 0}, x] + 16*x^4*HPL[{-1, -1, -1, 0, 0}, x] - 
   144*HPL[{-1, -1, -1, 1, 0}, x] + 256*x^2*HPL[{-1, -1, -1, 1, 0}, x] - 
   112*x^4*HPL[{-1, -1, -1, 1, 0}, x] + 208*HPL[{-1, -1, 0, 0, 0}, x] - 
   192*x^2*HPL[{-1, -1, 0, 0, 0}, x] - 16*x^4*HPL[{-1, -1, 0, 0, 0}, x] - 
   144*HPL[{-1, -1, 1, -1, 0}, x] + 256*x^2*HPL[{-1, -1, 1, -1, 0}, x] - 
   112*x^4*HPL[{-1, -1, 1, -1, 0}, x] - 112*HPL[{-1, -1, 1, 0, 0}, x] + 
   128*x^2*HPL[{-1, -1, 1, 0, 0}, x] - 16*x^4*HPL[{-1, -1, 1, 0, 0}, x] + 
   144*HPL[{-1, -1, 1, 1, 0}, x] - 256*x^2*HPL[{-1, -1, 1, 1, 0}, x] + 
   112*x^4*HPL[{-1, -1, 1, 1, 0}, x] + 448*HPL[{-1, 0, 0, 0, 0}, x] - 
   416*x^2*HPL[{-1, 0, 0, 0, 0}, x] - 32*x^4*HPL[{-1, 0, 0, 0, 0}, x] - 
   144*HPL[{-1, 1, -1, -1, 0}, x] + 256*x^2*HPL[{-1, 1, -1, -1, 0}, x] - 
   112*x^4*HPL[{-1, 1, -1, -1, 0}, x] - 112*HPL[{-1, 1, -1, 0, 0}, x] + 
   128*x^2*HPL[{-1, 1, -1, 0, 0}, x] - 16*x^4*HPL[{-1, 1, -1, 0, 0}, x] + 
   144*HPL[{-1, 1, -1, 1, 0}, x] - 256*x^2*HPL[{-1, 1, -1, 1, 0}, x] + 
   112*x^4*HPL[{-1, 1, -1, 1, 0}, x] - 208*HPL[{-1, 1, 0, 0, 0}, x] + 
   192*x^2*HPL[{-1, 1, 0, 0, 0}, x] + 16*x^4*HPL[{-1, 1, 0, 0, 0}, x] + 
   144*HPL[{-1, 1, 1, -1, 0}, x] - 256*x^2*HPL[{-1, 1, 1, -1, 0}, x] + 
   112*x^4*HPL[{-1, 1, 1, -1, 0}, x] + 112*HPL[{-1, 1, 1, 0, 0}, x] - 
   128*x^2*HPL[{-1, 1, 1, 0, 0}, x] + 16*x^4*HPL[{-1, 1, 1, 0, 0}, x] - 
   144*HPL[{-1, 1, 1, 1, 0}, x] + 256*x^2*HPL[{-1, 1, 1, 1, 0}, x] - 
   112*x^4*HPL[{-1, 1, 1, 1, 0}, x] - 32*x^2*HPL[{0, 0, 0, 0, 0}, x] + 
   1600*x^4*HPL[{0, 0, 0, 0, 0}, x] - 144*HPL[{1, -1, -1, -1, 0}, x] + 
   256*x^2*HPL[{1, -1, -1, -1, 0}, x] - 112*x^4*HPL[{1, -1, -1, -1, 0}, x] - 
   112*HPL[{1, -1, -1, 0, 0}, x] + 128*x^2*HPL[{1, -1, -1, 0, 0}, x] - 
   16*x^4*HPL[{1, -1, -1, 0, 0}, x] + 144*HPL[{1, -1, -1, 1, 0}, x] - 
   256*x^2*HPL[{1, -1, -1, 1, 0}, x] + 112*x^4*HPL[{1, -1, -1, 1, 0}, x] - 
   208*HPL[{1, -1, 0, 0, 0}, x] + 192*x^2*HPL[{1, -1, 0, 0, 0}, x] + 
   16*x^4*HPL[{1, -1, 0, 0, 0}, x] + 144*HPL[{1, -1, 1, -1, 0}, x] - 
   256*x^2*HPL[{1, -1, 1, -1, 0}, x] + 112*x^4*HPL[{1, -1, 1, -1, 0}, x] + 
   112*HPL[{1, -1, 1, 0, 0}, x] - 128*x^2*HPL[{1, -1, 1, 0, 0}, x] + 
   16*x^4*HPL[{1, -1, 1, 0, 0}, x] - 144*HPL[{1, -1, 1, 1, 0}, x] + 
   256*x^2*HPL[{1, -1, 1, 1, 0}, x] - 112*x^4*HPL[{1, -1, 1, 1, 0}, x] - 
   448*HPL[{1, 0, 0, 0, 0}, x] + 416*x^2*HPL[{1, 0, 0, 0, 0}, x] + 
   32*x^4*HPL[{1, 0, 0, 0, 0}, x] + 144*HPL[{1, 1, -1, -1, 0}, x] - 
   256*x^2*HPL[{1, 1, -1, -1, 0}, x] + 112*x^4*HPL[{1, 1, -1, -1, 0}, x] + 
   112*HPL[{1, 1, -1, 0, 0}, x] - 128*x^2*HPL[{1, 1, -1, 0, 0}, x] + 
   16*x^4*HPL[{1, 1, -1, 0, 0}, x] - 144*HPL[{1, 1, -1, 1, 0}, x] + 
   256*x^2*HPL[{1, 1, -1, 1, 0}, x] - 112*x^4*HPL[{1, 1, -1, 1, 0}, x] + 
   208*HPL[{1, 1, 0, 0, 0}, x] - 192*x^2*HPL[{1, 1, 0, 0, 0}, x] - 
   16*x^4*HPL[{1, 1, 0, 0, 0}, x] - 144*HPL[{1, 1, 1, -1, 0}, x] + 
   256*x^2*HPL[{1, 1, 1, -1, 0}, x] - 112*x^4*HPL[{1, 1, 1, -1, 0}, x] - 
   112*HPL[{1, 1, 1, 0, 0}, x] + 128*x^2*HPL[{1, 1, 1, 0, 0}, x] - 
   16*x^4*HPL[{1, 1, 1, 0, 0}, x] + 144*HPL[{1, 1, 1, 1, 0}, x] - 
   256*x^2*HPL[{1, 1, 1, 1, 0}, x] + 112*x^4*HPL[{1, 1, 1, 1, 0}, x] - 
   (2*(34 - 49*x^2 + 51*x^4 + Pi^2*(2 - 3*x^2 + x^4) - 
      12*x^2*(-1 + x^2)*HPL[{-2}, x] + 45*HPL[{1}, x] + 30*HPL[{-1, -1}, x] + 
      18*HPL[{-1, 0}, x] - 30*HPL[{-1, 1}, x] - 30*HPL[{1, -1}, x] - 
      18*HPL[{1, 0}, x] + 30*HPL[{1, 1}, x] + 
      3*(-5*(3 - 4*x^2 + x^4)*HPL[{-1}, x] + 
        x^2*(-2*(1 + 15*x^2)*HPL[{0}, x] + 5*(-4 + x^2)*HPL[{1}, x] + 
          2*(2*(-1 + x^2)*HPL[{2}, x] + (-8 + 3*x^2)*HPL[{-1, -1}, x] - 
            4*HPL[{-1, 0}, x] + 8*HPL[{-1, 1}, x] + 2*HPL[{0, 0}, x] + 
            8*HPL[{1, -1}, x] + 4*HPL[{1, 0}, x] - 8*HPL[{1, 1}, x] + 
            x^2*(HPL[{-1, 0}, x] - 3*HPL[{-1, 1}, x] + 22*HPL[{0, 0}, x] - 
              3*HPL[{1, -1}, x] - HPL[{1, 0}, x] + 3*HPL[{1, 1}, x])))))*
     Zeta[3])/3 + 2*(-2 + x^2 - 23*x^4)*Zeta[5]);




End[ ]

EndPackage[ ]

Protect["TwoMassTadpoles`*"] ;

Protect[Global`ep] ;


